-- sql
-- $Source: gm_dem_br.sh
-- $Revision: 1
-- $Author: Jim Busser, GNUmed project
-- ---------------------------
-- Description:
-- script for importing Brazil street, city, state, zip information
-- … into GNUmed demographics schema
-- … renamed as 'install-data-pack.sql' within GNUmed data packs
-- … configurational name = variants of '<Country> / demographics (2011)'
-- … zip archive name = variants of 'dem_CO.zip'
-- Caveats:
-- 1. There is as yet no agreement whether the base term should include / exclude diacritical marks.
--    If these were excluded, they should need to be created as i18n translations. 
-- ---------------------------
-- References / links:
-- GNUmed git repository, data packs and project
--   git://gitorious.org/gnumed/gnumed.git
--   http://wiki.gnumed.de/bin/view/Gnumed/GmManualReferenceData
--   http://www.gnumed.de/downloads/data/data-packs.conf
--   http://wiki.gnumed.de
-- ----------------------

-- uncomment the following to run from psql (instead of from GNUmed GUI)
-- set default_transaction_read_only to off;

-----------------------------------------------------------------------------
-- ************************************************************
-- set ON_ERROR_STOP 1
-- ************************************************************
-- ---------------------------------------------------------------------------
\set ON_ERROR_STOP 1


-----------------------------------------------------------------------------
-- ************************************************************
-- create staging table
-- ************************************************************
-- -----------------------------------------------------------------------------
-- ---------------------------------------------
\unset ON_ERROR_STOP

DROP TABLE staging.i18n_generic_br;

DROP TABLE staging.state;

DROP TABLE staging.street CASCADE;

DROP TABLE staging.ac;
DROP TABLE staging.al;
DROP TABLE staging.am;
DROP TABLE staging.ap;
DROP TABLE staging.ba;
DROP TABLE staging.ce;
DROP TABLE staging.df;
DROP TABLE staging.es;
DROP TABLE staging.go;
DROP TABLE staging.ma;
DROP TABLE staging.mg;
DROP TABLE staging.ms;
DROP TABLE staging.mt;
DROP TABLE staging.pa;
DROP TABLE staging.pb;
DROP TABLE staging.pe;
DROP TABLE staging.pi;
DROP TABLE staging.pr;
DROP TABLE staging.rj;
DROP TABLE staging.rn;
DROP TABLE staging.ro;
DROP TABLE staging.rr;
DROP TABLE staging.rs;
DROP TABLE staging.sc;
DROP TABLE staging.se;
DROP TABLE staging.sp;
DROP TABLE staging.to;

\set ON_ERROR_STOP 1

begin;

CREATE TABLE staging.i18n_generic_br (
  accented varchar,
  unaccented varchar,
  zip varchar,
  state varchar
);

CREATE TABLE staging.state (
  code varchar,
  name varchar,
  zip1 integer,
  zip2 integer
);

CREATE TABLE staging.street (
  id integer,
  city varchar,
  street varchar,
  district varchar,
  zip varchar,
  street_type varchar,
  state char(2)
);

CREATE TABLE staging.ac () INHERITS (staging.street);
CREATE TABLE staging.al () INHERITS (staging.street);
CREATE TABLE staging.am () INHERITS (staging.street);
CREATE TABLE staging.ap () INHERITS (staging.street);
CREATE TABLE staging.ba () INHERITS (staging.street);
CREATE TABLE staging.ce () INHERITS (staging.street);
CREATE TABLE staging.df () INHERITS (staging.street);
CREATE TABLE staging.es () INHERITS (staging.street);
CREATE TABLE staging.go () INHERITS (staging.street);
CREATE TABLE staging.ma () INHERITS (staging.street);
CREATE TABLE staging.mg () INHERITS (staging.street);
CREATE TABLE staging.ms () INHERITS (staging.street);
CREATE TABLE staging.mt () INHERITS (staging.street);
CREATE TABLE staging.pa () INHERITS (staging.street);
CREATE TABLE staging.pb () INHERITS (staging.street);
CREATE TABLE staging.pe () INHERITS (staging.street);
CREATE TABLE staging.pi () INHERITS (staging.street);
CREATE TABLE staging.pr () INHERITS (staging.street);
CREATE TABLE staging.rj () INHERITS (staging.street);
CREATE TABLE staging.rn () INHERITS (staging.street);
CREATE TABLE staging.ro () INHERITS (staging.street);
CREATE TABLE staging.rr () INHERITS (staging.street);
CREATE TABLE staging.rs () INHERITS (staging.street);
CREATE TABLE staging.sc () INHERITS (staging.street);
CREATE TABLE staging.se () INHERITS (staging.street);
CREATE TABLE staging.sp () INHERITS (staging.street);
CREATE TABLE staging.to () INHERITS (staging.street);

-- -----------------------------------------------------------------------------
-- *********************
-- import staging data
-- *********************
-- -----------------------------------------------------------------------------
--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = staging, pg_catalog;

--
-- Data for Name: i18n_generic_BR; Type: TABLE DATA; Schema: staging; Owner: gm-dbo
--

INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jitaúna', 'Jitauna', '45225-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Crato', 'Crato', 'NULL', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guia', 'Guia', '63885-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quixoá', 'Quixoa', '63502-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jataí', 'Jatai', NULL, 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anil', 'Anil', NULL, 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sabará', 'Sabara', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Outeiro', 'Outeiro', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sousa', 'Sousa', NULL, 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olinda', 'Olinda', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saué', 'Saue', '55572-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caxingó', 'Caxingo', '64228-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araruna', 'Araruna', '87260-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cascavel', 'Cascavel', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paiquerê', 'Paiquere', '86112-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Azul', 'Rio Azul', '84560-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ariquemes', 'Ariquemes', NULL, 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camobi', 'Camobi', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Viamão', 'Viamao', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xangri-Lá', 'Xangri-La', '95588-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Leme', 'Leme', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Claro', 'Rio Claro', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acrelândia', 'Acrelandia', '69945-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Assis Brasil', 'Assis Brasil', '69935-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brasiléia', 'Brasileia', '69932-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bujari', 'Bujari', '69923-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capixaba', 'Capixaba', '69922-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzeiro do Sul', 'Cruzeiro Do Sul', '69980-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Epitaciolândia', 'Epitaciolandia', '69934-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Feijó', 'Feijo', '69960-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jordão', 'Jordao', '69975-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mâncio Lima', 'Mancio Lima', '69990-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manoel Urbano', 'Manoel Urbano', '69950-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marechal Thaumaturgo', 'Marechal Thaumaturgo', '69983-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Plácido de Castro', 'Placido De Castro', '69928-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Acre', 'Porto Acre', '69921-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Walter', 'Porto Walter', '69982-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Branco', 'Rio Branco', 'NULL', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rodrigues Alves', 'Rodrigues Alves', '69985-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa', 'Santa Rosa', '69955-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sena Madureira', 'Sena Madureira', '69940-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Guiomard', 'Senador Guiomard', '69925-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tarauacá', 'Tarauaca', '69970-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xapuri', 'Xapuri', '69930-000', 'AC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Branca', 'Agua Branca', '57490-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alazão', 'Alazao', '57317-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alecrim', 'Alecrim', '57405-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anadia', 'Anadia', '57660-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anel', 'Anel', '57710-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anum Novo', 'Anum Novo', '57610-100', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anum Velho', 'Anum Velho', '57610-200', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arapiraca', 'Arapiraca', 'NULL', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Atalaia', 'Atalaia', '57690-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baixa da Onça', 'Baixa Da Onca', '57317-100', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baixa do Capim', 'Baixa Do Capim', '57317-200', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bálsamo', 'Balsamo', '57317-300', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bananeiras', 'Bananeiras', '57317-400', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra de Santo Antônio', 'Barra De Santo Antonio', '57925-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra de São Miguel', 'Barra De Sao Miguel', '57180-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Bonifácio', 'Barra Do Bonifacio', '57610-300', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Grande', 'Barra Grande', '57958-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Batalha', 'Batalha', '57420-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Batingas', 'Batingas', '57317-500', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belém', 'Belem', '57630-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belo Monte', 'Belo Monte', '57435-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Sorte', 'Boa Sorte', '57610-400', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', '57317-600', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', '57610-500', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boca da Mata', 'Boca Da Mata', '57680-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jardim', 'Bom Jardim', '57317-700', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonifácio', 'Bonifacio', '57610-600', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Branquinha', 'Branquinha', '57830-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cacimbinhas', 'Cacimbinhas', '57570-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cajarana', 'Cajarana', '57317-800', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cajueiro', 'Cajueiro', '57770-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caldeirões de Cima', 'Caldeiroes De Cima', '57614-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camadanta', 'Camadanta', '57318-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campestre', 'Campestre', '57968-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Alegre', 'Campo Alegre', '57250-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Grande', 'Campo Grande', '57350-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canaã', 'Canaa', '57317-900', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canafístula', 'Canafistula', '57613-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canapi', 'Canapi', '57530-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canastra', 'Canastra', '57895-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cangandu', 'Cangandu', '57318-100', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capela', 'Capela', '57780-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carneiros', 'Carneiros', '57535-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carrasco', 'Carrasco', '57318-200', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chã Preta', 'Cha Preta', '57760-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coité do Nóia', 'Coite Do Noia', '57325-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Leopoldina', 'Colonia Leopoldina', '57975-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coqueiro Seco', 'Coqueiro Seco', '57140-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coruripe', 'Coruripe', '57230-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coruripe da Cal', 'Coruripe Da Cal', '57610-900', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Craíbas', 'Craibas', '57320-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Delmiro Gouveia', 'Delmiro Gouveia', '57480-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dois Riachos', 'Dois Riachos', '57560-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Entremontes', 'Entremontes', '57465-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrela de Alagoas', 'Estrela De Alagoas', '57625-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Feira Grande', 'Feira Grande', '57340-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Feliz Deserto', 'Feliz Deserto', '57220-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flexeiras', 'Flexeiras', '57995-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gaspar', 'Gaspar', '57318-300', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Girau do Ponciano', 'Girau Do Ponciano', '57360-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibateguara', 'Ibateguara', '57890-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igaci', 'Igaci', '57620-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igreja Nova', 'Igreja Nova', '57280-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhapi', 'Inhapi', '57545-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacaré dos Homens', 'Jacare Dos Homens', '57430-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacuípe', 'Jacuipe', '57960-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japaratinga', 'Japaratinga', '57950-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaramataia', 'Jaramataia', '57425-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jenipapo', 'Jenipapo', '57318-400', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joaquim Gomes', 'Joaquim Gomes', '57980-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jundiá', 'Jundia', '57965-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Junqueiro', 'Junqueiro', '57270-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa da Areia', 'Lagoa Da Areia', '57611-200', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa da Canoa', 'Lagoa Da Canoa', '57330-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa da Pedra', 'Lagoa Da Pedra', '57318-500', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Dantas', 'Lagoa Dantas', '57611-500', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Caldeirão', 'Lagoa Do Caldeirao', '57611-300', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Canto', 'Lagoa Do Canto', '57611-400', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Exú', 'Lagoa Do Exu', '57611-600', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Rancho', 'Lagoa Do Rancho', '57318-600', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Rancho', 'Lagoa Do Rancho', '57611-700', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajes do Caldeirão', 'Lajes Do Caldeirao', '57611-800', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laranjal', 'Laranjal', '57318-700', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Limoeiro de Anadia', 'Limoeiro De Anadia', '57260-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maceió', 'Maceio', 'NULL', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Major Isidoro', 'Major Isidoro', '57580-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mar Vermelho', 'Mar Vermelho', '57730-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maragogi', 'Maragogi', '57955-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maravilha', 'Maravilha', '57520-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marechal Deodoro', 'Marechal Deodoro', '57160-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maribondo', 'Maribondo', '57670-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Massaranduba', 'Massaranduba', '57318-800', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mata Grande', 'Mata Grande', '57540-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matriz de Camaragibe', 'Matriz De Camaragibe', '57910-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Messias', 'Messias', '57990-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Minador do Negrão', 'Minador Do Negrao', '57615-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monteirópolis', 'Monteiropolis', '57440-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moreira', 'Moreira', '57611-900', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Munguba', 'Munguba', '57850-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Murici', 'Murici', '57820-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Lino', 'Novo Lino', '57970-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olho D''Água Grande', 'Olho D''Agua Grande', '57390-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olho D''Água das Flores', 'Olho D''Agua Das Flores', '57442-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olho D''Água de Cima', 'Olho D''Agua De Cima', '57318-900', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olho D''Água do Casado', 'Olho D''Agua Do Casado', '57470-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olho D''Água dos Dandanhas', 'Olho D''Agua Dos Dandanhas', '57319-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olivença', 'Olivenca', '57550-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Branco', 'Ouro Branco', '57525-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palestina', 'Palestina', '57410-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeira de Fora', 'Palmeira De Fora', '57613-500', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeira dos Índios', 'Palmeira Dos Indios', 'NULL', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pão de Açúcar', 'Pao De Acucar', '57400-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pariconha', 'Pariconha', '57475-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paripueira', 'Paripueira', '57935-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo de Camaragibe', 'Passo De Camaragibe', '57930-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pau D''Arco', 'Pau D''Arco', '57319-100', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pau Ferro', 'Pau Ferro', '57319-200', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulo Jacinto', 'Paulo Jacinto', '57740-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Penedo', 'Penedo', '57200-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piacabuçu', 'Piacabucu', '57210-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pilar', 'Pilar', '57150-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pindoba', 'Pindoba', '57720-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piranhas', 'Piranhas', '57460-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poção', 'Pocao', '57319-300', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço da Pedra', 'Poco Da Pedra', '57319-400', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço das Trincheiras', 'Poco Das Trincheiras', '57510-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Calvo', 'Porto Calvo', '57900-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto de Pedras', 'Porto De Pedras', '57945-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Real do Colégio', 'Porto Real Do Colegio', '57290-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poxim', 'Poxim', '57235-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quebrângulo', 'Quebrangulo', '57750-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho do Sertão', 'Riacho Do Sertao', '57585-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho Fundo de Cima', 'Riacho Fundo De Cima', '57611-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Largo', 'Rio Largo', '57100-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rocha Cavalcante', 'Rocha Cavalcante', '57810-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Roteiro', 'Roteiro', '57246-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Efigênia', 'Santa Efigenia', '57790-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia do Norte', 'Santa Luzia Do Norte', '57130-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Ipanema', 'Santana Do Ipanema', '57500-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Mundaú', 'Santana Do Mundau', '57840-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio', 'Santo Antonio', '57611-100', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Brás', 'Sao Bras', '57380-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Laje', 'Sao Jose Da Laje', '57860-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Tapera', 'Sao Jose Da Tapera', '57445-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luís do Quitundé', 'Sao Luis Do Quitunde', '57920-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel dos Campos', 'Sao Miguel Dos Campos', '57240-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel dos Milagres', 'Sao Miguel Dos Milagres', '57940-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião', 'Sao Sebastiao', '57275-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapucaia', 'Sapucaia', '57319-500', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapucaia', 'Sapucaia', '57693-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Satuba', 'Satuba', '57120-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Rui Palmeira', 'Senador Rui Palmeira', '57515-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra da Mandioca', 'Serra Da Mandioca', '57612-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra do São José', 'Serra Do Sao Jose', '57612-500', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taboleiro do Pinto', 'Taboleiro Do Pinto', '57110-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taboquinha', 'Taboquinha', '57319-600', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tanque D''Arca', 'Tanque D''Arca', '57635-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquarana', 'Taquarana', '57640-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tatuamunha', 'Tatuamunha', '57948-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teotônio Vilela', 'Teotonio Vilela', '57265-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Traipu', 'Traipu', '57370-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('União dos Palmares', 'Uniao Dos Palmares', '57800-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Usina Camaçari', 'Usina Camacari', '57233-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Viçosa', 'Vicosa', '57700-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Aparecida', 'Vila Aparecida', '57319-700', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila São Francisco', 'Vila Sao Francisco', '57319-800', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvarães', 'Alvaraes', '69475-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amatari', 'Amatari', '69105-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amaturá', 'Amatura', '69620-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anamã', 'Anama', '69445-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anori', 'Anori', '69440-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apuí', 'Apui', '69265-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ariaú', 'Ariau', '69165-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Atalaia do Norte', 'Atalaia Do Norte', '69650-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Augusto Montenegro', 'Augusto Montenegro', '69182-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Autazes', 'Autazes', '69240-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Axinim', 'Axinim', '69210-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Badajós', 'Badajos', '69452-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Balbina', 'Balbina', '69736-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barcelos', 'Barcelos', '69700-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreirinha', 'Barreirinha', '69160-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Benjamin Constant', 'Benjamin Constant', '69630-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Beruri', 'Beruri', '69430-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista do Ramos', 'Boa Vista Do Ramos', '69195-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boca do Acre', 'Boca Do Acre', '69850-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Borba', 'Borba', '69200-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caapiranga', 'Caapiranga', '69410-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cametá', 'Cameta', '69162-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canumã', 'Canuma', '69212-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canutama', 'Canutama', '69820-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carauari', 'Carauari', '69500-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Careiro', 'Careiro', '69250-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Careiro da Várzea', 'Careiro Da Varzea', '69255-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carvoeiro', 'Carvoeiro', '69725-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coari', 'Coari', '69460-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Codajás', 'Codajas', '69450-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cucuí', 'Cucui', '69765-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eirunepé', 'Eirunepe', '69880-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Envira', 'Envira', '69870-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floriano Peixoto', 'Floriano Peixoto', '69855-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fonte Boa', 'Fonte Boa', '69670-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Freguesia do Andirá', 'Freguesia Do Andira', '69170-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guajará', 'Guajara', '69895-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Humaitá', 'Humaita', '69800-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iauaretê', 'Iauarete', '69790-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Içanã', 'Icana', '69760-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipixuna', 'Ipixuna', '69890-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iranduba', 'Iranduba', '69405-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itacoatiara', 'Itacoatiara', '69100-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamarati', 'Itamarati', '69510-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapiranga', 'Itapiranga', '69120-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japurá', 'Japura', '69495-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juruá', 'Jurua', '69520-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jutaí', 'Jutai', '69660-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lábrea', 'Labrea', '69830-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lago Preto', 'Lago Preto', '69196-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manacapuru', 'Manacapuru', '69400-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manaquiri', 'Manaquiri', '69435-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manaus', 'Manaus', 'NULL', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manicoré', 'Manicore', '69280-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maraã', 'Maraa', '69490-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Massauari', 'Massauari', '69197-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maués', 'Maues', '69190-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mocambo', 'Mocambo', '69158-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moura', 'Moura', '69720-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Murutinga', 'Murutinga', '69245-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nhamundá', 'Nhamunda', '69140-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Olinda do Norte', 'Nova Olinda Do Norte', '69230-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Airão', 'Novo Airao', '69730-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Aripuanã', 'Novo Aripuana', '69260-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Osório da Fonseca', 'Osorio Da Fonseca', '69192-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parintins', 'Parintins', 'NULL', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pauini', 'Pauini', '69860-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedras', 'Pedras', '69175-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Figueiredo', 'Presidente Figueiredo', '69735-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Repartimento', 'Repartimento', '69193-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Preto da Eva', 'Rio Preto Da Eva', '69115-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Isabel do Rio Negro', 'Santa Isabel Do Rio Negro', '69740-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita', 'Santa Rita', '69610-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Içá', 'Santo Antonio Do Ica', '69680-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Felipe', 'Sao Felipe', '69752-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gabriel da Cachoeira', 'Sao Gabriel Da Cachoeira', '69750-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Paulo de Olivença', 'Sao Paulo De Olivenca', '69600-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Uatumã', 'Sao Sebastiao Do Uatuma', '69135-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silves', 'Silves', '69110-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabatinga', 'Tabatinga', '69640-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapauá', 'Tapaua', '69480-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tefé', 'Tefe', '69470-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tonantins', 'Tonantins', '69685-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uarini', 'Uarini', '69485-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urucará', 'Urucara', '69130-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urucurituba', 'Urucurituba', '69180-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Pitinga', 'Vila Pitinga', '69737-000', 'AM');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abacate da Pedreira', 'Abacate Da Pedreira', '68912-350', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Branca do Amapari', 'Agua Branca Do Amapari', '68948-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amapá', 'Amapa', '68950-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amapari', 'Amapari', '68945-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ambé', 'Ambe', '68912-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aporema', 'Aporema', '68994-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ariri', 'Ariri', '68912-050', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bailique', 'Bailique', '68913-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boca do Jari', 'Boca Do Jari', '68923-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Calçoene', 'Calcoene', '68960-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cantanzal', 'Cantanzal', '68912-800', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carmo', 'Carmo', '68912-100', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Clevelândia do Norte', 'Clevelandia Do Norte', '68985-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corre Água', 'Corre Agua', '68912-600', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cunani', 'Cunani', '68965-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curiaú', 'Curiau', '68912-300', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cutias', 'Cutias', '68973-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazendinha', 'Fazendinha', '68912-250', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ferreira Gomes', 'Ferreira Gomes', '68915-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fortaleza', 'Fortaleza', '68939-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gaivota', 'Gaivota', '68912-150', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gurupora', 'Gurupora', '68912-650', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igarapé do Lago', 'Igarape Do Lago', '68935-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilha de Santana', 'Ilha De Santana', '68937-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inajá', 'Inaja', '68912-750', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaubal', 'Itaubal', '68976-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laranjal do Jari', 'Laranjal Do Jari', '68920-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Livramento do Pacuí', 'Livramento Do Pacui', '68912-450', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lourenço', 'Lourenco', '68970-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macapá', 'Macapa', 'NULL', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mazagão', 'Mazagao', '68940-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mazagão Velho', 'Mazagao Velho', '68943-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oiapoque', 'Oiapoque', '68980-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paredão', 'Paredao', '68917-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Grande', 'Porto Grande', '68997-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pracuúba', 'Pracuuba', '68918-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia do Pacuí', 'Santa Luzia Do Pacui', '68912-530', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria', 'Santa Maria', '68912-200', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana', 'Santana', '68925-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim do Pacuí', 'Sao Joaquim Do Pacui', '68912-500', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Livramento', 'Sao Sebastiao Do Livramento', '68912-550', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Tomé', 'Sao Tome', '68912-700', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra do Navio', 'Serra Do Navio', '68914-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sucuriju', 'Sucuriju', '68958-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tartarugalzinho', 'Tartarugalzinho', '68990-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Velha', 'Vila Velha', '68988-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vitória do Jari', 'Vitoria Do Jari', '68924-000', 'AP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abadia', 'Abadia', '48320-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abaíra', 'Abaira', '46690-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abaré', 'Abare', '48680-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abelhas', 'Abelhas', '45112-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abóbora', 'Abobora', '48912-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abrantes', 'Abrantes', '42840-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acajutiba', 'Acajutiba', '48360-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Açu da Torre', 'Acu Da Torre', '48288-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Açudina', 'Acudina', '47645-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acupe', 'Acupe', '44218-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Adustina', 'Adustina', '48435-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Afligidos', 'Afligidos', '44338-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Afrânio Peixoto', 'Afranio Peixoto', '46965-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Doce', 'Agua Doce', '45295-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Fria', 'Agua Fria', '48170-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas do Paulista', 'Aguas Do Paulista', '47505-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aiquara', 'Aiquara', '45220-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alagoinhas', 'Alagoinhas', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alcobaça', 'Alcobaca', '45990-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alegre', 'Alegre', '46203-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Algodão', 'Algodao', '45582-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Algodões', 'Algodoes', '48832-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Almadina', 'Almadina', '45640-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Bonito', 'Alto Bonito', '44805-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amado Bahia', 'Amado Bahia', '48282-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amaniú', 'Amaniu', '47380-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amargosa', 'Amargosa', '45300-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amélia Rodrigues', 'Amelia Rodrigues', '44230-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('América Dourada', 'America Dourada', '44910-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Américo Alves', 'Americo Alves', '47370-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anagé', 'Anage', '45180-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Andaraí', 'Andarai', '46830-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Andorinha', 'Andorinha', '48990-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angical', 'Angical', '47960-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angico', 'Angico', '44633-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anguera', 'Anguera', '44670-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antas', 'Antas', '48420-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Cardoso', 'Antonio Cardoso', '44180-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Gonçalves', 'Antonio Goncalves', '44780-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aporá', 'Apora', '48350-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apuarema', 'Apuarema', '45355-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araçás', 'Aracas', '48108-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aracatu', 'Aracatu', '46130-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araci', 'Araci', '48760-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aramari', 'Aramari', '48130-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arapiranga', 'Arapiranga', '46177-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arataca', 'Arataca', '45695-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aratuípe', 'Aratuipe', '44490-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areias', 'Areias', '42847-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arembepe', 'Arembepe', '42835-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Argoim', 'Argoim', '44525-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Argolo', 'Argolo', '45925-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aribice', 'Aribice', '48504-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aritaguá', 'Aritagua', '45663-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aurelino Leal', 'Aurelino Leal', '45675-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baianópolis', 'Baianopolis', '47830-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baixa do Palmeira', 'Baixa Do Palmeira', '44535-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baixa Grande', 'Baixa Grande', '44620-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baixão', 'Baixao', '45212-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baixinha', 'Baixinha', '45313-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baluarte', 'Baluarte', '47270-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Banco Central', 'Banco Central', '45673-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Banco da Vitória', 'Banco Da Vitoria', '45661-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bandeira do Almada', 'Bandeira Do Almada', '45635-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bandeira do Colônia', 'Bandeira Do Colonia', '45705-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bandiaçu', 'Bandiacu', '48745-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Banzaê', 'Banzae', '48405-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baraúnas', 'Baraunas', '46920-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barcelos do Sul', 'Barcelos Do Sul', '45448-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra', 'Barra', '47100-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra da Estiva', 'Barra Da Estiva', '46650-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Choça', 'Barra Do Choca', '45120-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Jacuípe', 'Barra Do Jacuipe', '42833-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Mendes', 'Barra Do Mendes', '44990-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Pojuca', 'Barra Do Pojuca', '42825-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Rocha', 'Barra Do Rocha', '45560-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Tarrachil', 'Barra Do Tarrachil', '48668-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barracas', 'Barracas', '44757-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiras', 'Barreiras', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barro Alto', 'Barro Alto', '44895-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Lomanto Junior', 'Governador Lomanto Junior', '45625-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barro Vermelho', 'Barro Vermelho', '48935-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barrocas', 'Barrocas', '48705-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bastião', 'Bastiao', '46745-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bate Pé', 'Bate Pe', '45107-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Batinga', 'Batinga', '45975-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Flor', 'Bela Flor', '48113-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belém da Cachoeira', 'Belem Da Cachoeira', '44315-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belmonte', 'Belmonte', '45800-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belo Campo', 'Belo Campo', '45160-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belo Campo', 'Belo Campo', '44911-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bem-Bom', 'Bem-Bom', '47330-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bendegó', 'Bendego', '48524-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bento Simões', 'Bento Simoes', '44258-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Biritinga', 'Biritinga', '48780-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Espera', 'Boa Espera', '44265-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Nova', 'Boa Nova', '45250-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa União', 'Boa Uniao', '48103-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista do Lagamar', 'Boa Vista Do Lagamar', '47525-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista do Tupim', 'Boa Vista Do Tupim', '46850-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boaçu', 'Boacu', '45209-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boca do Córrego', 'Boca Do Corrego', '45805-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus da Lapa', 'Bom Jesus Da Lapa', '47600-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus da Serra', 'Bom Jesus Da Serra', '45263-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Sossego', 'Bom Sossego', '47540-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonfim da Feira', 'Bonfim Da Feira', '44120-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boninal', 'Boninal', '46740-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonito', 'Bonito', '46820-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boquira', 'Boquira', '46530-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Botuporã', 'Botupora', '46570-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Botuquara', 'Botuquara', '46475-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejinho das Ametistas', 'Brejinho Das Ametistas', '46405-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo da Serra', 'Brejo Da Serra', '47260-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo Luíza de Brito', 'Brejo Luiza De Brito', '46733-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo Novo', 'Brejo Novo', '46855-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejões', 'Brejoes', '45325-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejolândia', 'Brejolandia', '47750-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brotas de Macaúbas', 'Brotas De Macaubas', '47560-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brumado', 'Brumado', '46100-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bucuituba', 'Bucuituba', '46535-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buerarema', 'Buerarema', '45615-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buracica', 'Buracica', '44285-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buranhém', 'Buranhem', '45845-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buril', 'Buril', '48483-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buris de Abrantes', 'Buris De Abrantes', '42845-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buritirama', 'Buritirama', '47120-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caatiba', 'Caatiba', '45130-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabaceiras do Paraguaçu', 'Cabaceiras Do Paraguacu', '44345-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabrália', 'Cabralia', '46768-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cacha Pregos', 'Cacha Pregos', '44478-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira', 'Cachoeira', '44300-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira do Mato', 'Cachoeira Do Mato', '45999-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caculé', 'Cacule', '46300-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caém', 'Caem', '44730-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caetanos', 'Caetanos', '45265-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caeté-Açu', 'Caete-Acu', '46940-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caetité', 'Caetite', '46400-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cafarnaum', 'Cafarnaum', '44880-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiçara', 'Caicara', '45118-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caimbé', 'Caimbe', '48506-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cairu', 'Cairu', '45420-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiubi', 'Caiubi', '45858-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cajuí', 'Cajui', '47390-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caldas do Jorro', 'Caldas Do Jorro', '48793-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caldeirão', 'Caldeirao', '48955-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caldeirão Grande', 'Caldeirao Grande', '44750-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caldeiras', 'Caldeiras', '46420-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camacan', 'Camacan', '45880-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camaçari', 'Camacari', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camamu', 'Camamu', '45445-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camassandi', 'Camassandi', '44482-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camirim', 'Camirim', '44860-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campinhos', 'Campinhos', '44215-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Alegre de Lourdes', 'Campo Alegre De Lourdes', '47220-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Formoso', 'Campo Formoso', '44790-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Formoso', 'Campo Formoso', '44935-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camurugi', 'Camurugi', '45434-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canabravinha', 'Canabravinha', '46195-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canápolis', 'Canapolis', '47730-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canarana', 'Canarana', '44890-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canatiba', 'Canatiba', '46510-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canavieiras', 'Canavieiras', '45860-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canché', 'Canche', '48560-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Candeal', 'Candeal', '48710-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Candeias', 'Candeias', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Candiba', 'Candiba', '46380-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cândido Sales', 'Candido Sales', '45157-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canoão', 'Canoao', '44965-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cansanção', 'Cansancao', '48840-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canto do Sol', 'Canto Do Sol', '42830-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canudos', 'Canudos', '48520-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canudos', 'Canudos', '44889-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão', 'Capao', '45495-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capela do Alto Alegre', 'Capela Do Alto Alegre', '44645-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capim Grosso', 'Capim Grosso', '44695-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraguataí', 'Caraguatai', '46680-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraíbas', 'Caraibas', '45177-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraibuna', 'Caraibuna', '46630-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraípe', 'Caraipe', '44555-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraiva', 'Caraiva', '45819-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caravelas', 'Caravelas', '45900-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cardeal da Silva', 'Cardeal Da Silva', '48390-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carinhanha', 'Carinhanha', '46445-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caripare', 'Caripare', '47980-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carnaíba do Sertão', 'Carnaiba Do Sertao', '48922-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carrapichel', 'Carrapichel', '48985-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Casa Nova', 'Casa Nova', '47300-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Castelo Novo', 'Castelo Novo', '45667-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Castro Alves', 'Castro Alves', '44500-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catinga do Moura', 'Catinga Do Moura', '44704-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catingal', 'Catingal', '45245-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catolândia', 'Catolandia', '47815-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catolés', 'Catoles', '46695-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catolezinho', 'Catolezinho', '45145-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catu', 'Catu', '48110-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catu de Abrantes', 'Catu De Abrantes', '42841-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caturama', 'Caturama', '46575-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cavunge', 'Cavunge', '44685-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Central', 'Central', '44940-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ceraima', 'Ceraima', '46433-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chorrochó', 'Chorrocho', '48660-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cícero Dantas', 'Cicero Dantas', '48410-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cinco Rios', 'Cinco Rios', '43860-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cipó', 'Cipo', '48450-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coaraci', 'Coaraci', '45638-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cocos', 'Cocos', '47680-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia', 'Colonia', '45832-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Comércio', 'Comercio', '44545-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição da Feira', 'Conceicao Da Feira', '44320-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Almeida', 'Conceicao Do Almeida', '44540-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Coité', 'Conceicao Do Coite', '48730-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Jacuípe', 'Conceicao Do Jacuipe', '44245-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conde', 'Conde', '48300-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Condeúba', 'Condeuba', '46200-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Contendas do Sincorá', 'Contendas Do Sincora', '46620-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Copixaba', 'Copixaba', '47430-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coqueiros', 'Coqueiros', '44430-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coquinhos', 'Coquinhos', '45185-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coração de Maria', 'Coracao De Maria', '44250-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cordeiros', 'Cordeiros', '46280-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coribe', 'Coribe', '47690-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel João Sá', 'Coronel Joao Sa', '48590-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Correntina', 'Correntina', '47650-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corta Mão', 'Corta Mao', '45301-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cotegipe', 'Cotegipe', '47900-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coutos', 'Coutos', '45664-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cravolândia', 'Cravolandia', '45330-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Crisópolis', 'Crisopolis', '48480-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristalândia', 'Cristalandia', '46108-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristópolis', 'Cristopolis', '47950-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Crussaí', 'Crussai', '44505-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruz das Almas', 'Cruz Das Almas', '44380-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cumuruxatiba', 'Cumuruxatiba', '45983-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cunhangi', 'Cunhangi', '44488-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curaçá', 'Curaca', '48930-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curral Falso', 'Curral Falso', '48403-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dário Meira', 'Dario Meira', '45590-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Delfino', 'Delfino', '44795-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Descoberto', 'Descoberto', '47695-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dias Coelho', 'Dias Coelho', '44855-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dias D''Ávila', 'Dias D''Avila', '42850-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Diógenes Sampaio', 'Diogenes Sampaio', '45302-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Basílio', 'Dom Basilio', '46165-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Macedo Costa', 'Dom Macedo Costa', '44560-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dona Maria', 'Dona Maria', '48473-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Duas Barras do Morro', 'Duas Barras Do Morro', '44865-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Elísio Medrado', 'Elisio Medrado', '45305-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Encruzilhada', 'Encruzilhada', '45150-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro França', 'Engenheiro Franca', '45312-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro Pontes', 'Engenheiro Pontes', '45498-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Entre Rios', 'Entre Rios', '48180-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Érico Cardoso', 'Erico Cardoso', '46180-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esplanada', 'Esplanada', '48370-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Euclides da Cunha', 'Euclides Da Cunha', '48500-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eunápolis', 'Eunapolis', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fátima', 'Fatima', '48415-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Feira da Mata', 'Feira Da Mata', '46446-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Feira de Santana', 'Feira De Santana', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ferradas', 'Ferradas', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Filadélfia', 'Filadelfia', '44775-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Filanésia', 'Filanesia', '45358-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Firmino Alves', 'Firmino Alves', '45720-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floresta Azul', 'Floresta Azul', '45740-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Formosa do Rio Preto', 'Formosa Do Rio Preto', '47990-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('França', 'Franca', '44837-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gabiarra', 'Gabiarra', '45831-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Galeão', 'Galeao', '45422-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gamboa', 'Gamboa', '45424-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gameleira da Lapa', 'Gameleira Da Lapa', '47620-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gameleira do Assuruá', 'Gameleira Do Assurua', '47470-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gandu', 'Gandu', '45450-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gavião', 'Gaviao', '44650-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gentio do Ouro', 'Gentio Do Ouro', '47450-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Geolândia', 'Geolandia', '44349-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Glória', 'Gloria', '48610-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gongogi', 'Gongogi', '45540-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador João Durval Carneiro', 'Governador Joao Durval Carneiro', '44130-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Mangabeira', 'Governador Mangabeira', '44350-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guagirus', 'Guagirus', '42837-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaí', 'Guai', '44423-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guajeru', 'Guajeru', '46205-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guanambi', 'Guanambi', '46430-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guapira', 'Guapira', '44425-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarajuba', 'Guarajuba', '42827-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaratinga', 'Guaratinga', '45840-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guerém', 'Guerem', '45413-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guiné', 'Guine', '46753-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guirapa', 'Guirapa', '46370-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gurupá Mirim', 'Gurupa Mirim', '45795-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Heliópolis', 'Heliopolis', '48445-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Helvecia', 'Helvecia', '45923-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Hidrolândia', 'Hidrolandia', '44955-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Humildes', 'Humildes', '44135-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iaçu', 'Iacu', '46860-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibatui', 'Ibatui', '48185-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiaçu', 'Ibiacu', '45523-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiajara', 'Ibiajara', '46560-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiapora', 'Ibiapora', '44825-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiassucê', 'Ibiassuce', '46390-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibicaraí', 'Ibicarai', '45745-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibicoara', 'Ibicoara', '46760-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibicuí', 'Ibicui', '45290-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibipeba', 'Ibipeba', '44970-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibipetum', 'Ibipetum', '47595-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibipitanga', 'Ibipitanga', '46540-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiquera', 'Ibiquera', '46840-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiraba', 'Ibiraba', '47110-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibirajá', 'Ibiraja', '45972-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiranhém', 'Ibiranhem', '45938-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibirapitanga', 'Ibirapitanga', '45500-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibirapuã', 'Ibirapua', '45940-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibirataia', 'Ibirataia', '45580-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitiara', 'Ibitiara', '46700-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitiguira', 'Ibitiguira', '45378-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitira', 'Ibitira', '46225-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibititá', 'Ibitita', '44960-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitunane', 'Ibitunane', '47480-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitupa', 'Ibitupa', '45298-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibó', 'Ibo', '48685-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibotirama', 'Ibotirama', '47520-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ichu', 'Ichu', '48725-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Icó', 'Ico', '44852-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igaporã', 'Igapora', '46490-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igará', 'Igara', '48975-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igarité', 'Igarite', '47105-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igatu', 'Igatu', '46834-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igrapiúna', 'Igrapiuna', '45443-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguá', 'Igua', '45105-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguaí', 'Iguai', '45280-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguaibi', 'Iguaibi', '45285-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguatemi', 'Iguatemi', '46150-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguira', 'Iguira', '47410-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguitu', 'Iguitu', '44975-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilha de Mare', 'Ilha De Mare', '42500-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilhéus', 'Ilheus', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indaí', 'Indai', '44810-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inema', 'Inema', '45669-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhambupe', 'Inhambupe', '48490-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhata', 'Inhata', '44235-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhaúmas', 'Inhaumas', '47648-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhobim', 'Inhobim', '45110-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inúbia', 'Inubia', '46766-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipecaetá', 'Ipecaeta', '44680-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipiaú', 'Ipiau', '45570-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipirá', 'Ipira', '44600-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipiúna', 'Ipiuna', '45347-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipucaba', 'Ipucaba', '47550-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipupiara', 'Ipupiara', '47590-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irajuba', 'Irajuba', '45370-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iramaia', 'Iramaia', '46770-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iraporanga', 'Iraporanga', '46985-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iraquara', 'Iraquara', '46980-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irará', 'Irara', '44255-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irecê', 'Irece', '44900-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irundiara', 'Irundiara', '46315-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ita-Azul', 'Ita-Azul', '45838-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itabela', 'Itabela', '45848-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaberaba', 'Itaberaba', '46880-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itabuna', 'Itabuna', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itacaré', 'Itacare', '45530-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itacava', 'Itacava', '44253-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itachama', 'Itachama', '45303-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itacimirim', 'Itacimirim', '42823-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaeté', 'Itaete', '46790-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itagi', 'Itagi', '45230-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itagibá', 'Itagiba', '45585-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itagimirim', 'Itagimirim', '45850-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaguaçu da Bahia', 'Itaguacu Da Bahia', '47440-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaia', 'Itaia', '45723-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaibó', 'Itaibo', '45213-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaipu', 'Itaipu', '45116-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaítu', 'Itaitu', '44702-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itajaí', 'Itajai', '45275-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaju do Colônia', 'Itaju Do Colonia', '45730-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itajubaquara', 'Itajubaquara', '47460-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itajuípe', 'Itajuipe', '45630-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itajuru', 'Itajuru', '45211-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamaraju', 'Itamaraju', '45836-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamari', 'Itamari', '45455-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itambé', 'Itambe', '45140-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamira', 'Itamira', '48355-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamotinga', 'Itamotinga', '48920-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itanagé', 'Itanage', '46143-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itanagra', 'Itanagra', '48290-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itanhém', 'Itanhem', '45970-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itanhi', 'Itanhi', '48315-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaparica', 'Itaparica', '44460-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapé', 'Itape', '45750-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapebi', 'Itapebi', '45855-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapeipu', 'Itapeipu', '44708-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapetinga', 'Itapetinga', '45700-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapicuru', 'Itapicuru', '48475-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapirema', 'Itapirema', '45117-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapitanga', 'Itapitanga', '45645-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapora', 'Itapora', '44343-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapura', 'Itapura', '44727-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaquara', 'Itaquara', '45340-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaquaraí', 'Itaquarai', '46103-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itarantim', 'Itarantim', '45780-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itati', 'Itati', '45714-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itatim', 'Itatim', '46875-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itatingui', 'Itatingui', '45698-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itiruçu', 'Itirucu', '45350-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itiúba', 'Itiuba', '48850-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itororó', 'Itororo', '45710-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ituaçu', 'Ituacu', '46640-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ituberá', 'Itubera', '45435-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itupeva', 'Itupeva', '45968-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iuiu', 'Iuiu', '46438-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaborandi', 'Jaborandi', '47655-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacaraci', 'Jacaraci', '46310-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacobina', 'Jacobina', '44700-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacu', 'Jacu', '44273-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacuípe', 'Jacuipe', '43870-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacuruna', 'Jacuruna', '44484-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguaquara', 'Jaguaquara', '45345-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguara', 'Jaguara', '44125-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguarari', 'Jaguarari', '48960-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguaripe', 'Jaguaripe', '44480-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaíba', 'Jaiba', '44115-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jandaíra', 'Jandaira', '48310-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japomirim', 'Japomirim', '45588-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japu', 'Japu', '45665-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jauá', 'Jaua', '42843-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jequié', 'Jequie', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jequiriçá', 'Jequirica', '45470-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jeremoabo', 'Jeremoabo', '48540-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jiribatuba', 'Jiribatuba', '44475-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Amaro', 'Joao Amaro', '46865-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Correia', 'Joao Correia', '46755-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Dourado', 'Joao Dourado', '44920-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('José Gonçalves', 'Jose Goncalves', '45115-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juacema', 'Juacema', '48965-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juazeiro', 'Juazeiro', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jucuruçu', 'Jucurucu', '45834-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juerana', 'Juerana', '45910-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Junco', 'Junco', '48910-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jupaguá', 'Jupagua', '47920-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juraci', 'Juraci', '46785-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juremal', 'Juremal', '48915-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jussara', 'Jussara', '44925-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jussari', 'Jussari', '45610-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jussiape', 'Jussiape', '46670-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Km Sete', 'Km Sete', '44133-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lafaiete Coutinho', 'Lafaiete Coutinho', '45215-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Clara', 'Lagoa Clara', '46520-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa de Melquíades', 'Lagoa De Melquiades', '45114-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Boi', 'Lagoa Do Boi', '44898-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Grande', 'Lagoa Grande', '45158-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Grande', 'Lagoa Grande', '44972-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa José Luis', 'Lagoa Jose Luis', '45113-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Preta', 'Lagoa Preta', '45175-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Real', 'Lagoa Real', '46425-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laje', 'Laje', '45490-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laje do Banco', 'Laje Do Banco', '45676-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajedão', 'Lajedao', '45950-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajedinho', 'Lajedinho', '46825-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajedo Alto', 'Lajedo Alto', '46868-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajedo do Tabocal', 'Lajedo Do Tabocal', '45365-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lamarão', 'Lamarao', '48720-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lamarão do Passe', 'Lamarao Do Passe', '43855-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lapão', 'Lapao', '44905-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Largo', 'Largo', '44835-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lauro de Freitas', 'Lauro De Freitas', '42700-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lençóis', 'Lencois', '46960-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Licínio de Almeida', 'Licinio De Almeida', '46330-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Limoeiro do Bom Viver', 'Limoeiro Do Bom Viver', '44137-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Livramento de Nossa Senhora', 'Livramento De Nossa Senhora', '46140-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lucaia', 'Lucaia', '45195-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luis Viana', 'Luis Viana', '47340-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lustosa', 'Lustosa', '44283-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macajuba', 'Macajuba', '46805-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macarani', 'Macarani', '45760-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macaúbas', 'Macaubas', '46500-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macururé', 'Macurure', '48650-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Madre de Deus', 'Madre De Deus', '42600-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maetinga', 'Maetinga', '46255-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maiquinique', 'Maiquinique', '45770-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mairi', 'Mairi', '44630-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Malhada', 'Malhada', '46440-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Malhada de Pedras', 'Malhada De Pedras', '46110-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mandiroba', 'Mandiroba', '46455-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mangue Seco', 'Mangue Seco', '48325-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maniaçu', 'Maniacu', '46410-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manoel Vitorino', 'Manoel Vitorino', '45240-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mansidão', 'Mansidao', '47160-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mantiba', 'Mantiba', '44117-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mar Grande', 'Mar Grande', '44473-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maracás', 'Maracas', '45360-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maragogipe', 'Maragogipe', '44420-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maragogipinho', 'Maragogipinho', '44495-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maraú', 'Marau', '45520-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marcionílio Souza', 'Marcionilio Souza', '46780-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marcolino Moura', 'Marcolino Moura', '46175-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maria Quitéria', 'Maria Quiteria', '44110-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maricoabo', 'Maricoabo', '45412-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mariquita', 'Mariquita', '47770-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mascote', 'Mascote', '45870-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Massacara', 'Massacara', '48510-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Massaroca', 'Massaroca', '48918-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mata da Aliança', 'Mata Da Alianca', '44240-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mata de São João', 'Mata De Sao Joao', '48280-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mataripe', 'Mataripe', '43970-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matina', 'Matina', '46480-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matinha', 'Matinha', '44118-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Medeiros Neto', 'Medeiros Neto', '45960-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miguel Calmon', 'Miguel Calmon', '44720-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Milagres', 'Milagres', '45315-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luís Eduardo Magalhães', 'Luis Eduardo Magalhaes', '47850-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Minas do Espírito Santo', 'Minas Do Espirito Santo', '44995-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Minas do Mimoso', 'Minas Do Mimoso', '47375-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirandela', 'Mirandela', '48409-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miranga', 'Miranga', '48126-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirangaba', 'Mirangaba', '44745-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirante', 'Mirante', '45255-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mocambo', 'Mocambo', '46720-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mogiquiçaba', 'Mogiquicaba', '45803-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Cruzeiro', 'Monte Cruzeiro', '45306-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Gordo', 'Monte Gordo', '42820-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Recôncavo', 'Monte Reconcavo', '43980-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Santo', 'Monte Santo', '48800-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morpará', 'Morpara', '47580-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morrinhos', 'Morrinhos', '44127-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro das Flores', 'Morro Das Flores', '46802-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro de São Paulo', 'Morro De Sao Paulo', '45428-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro do Chapéu', 'Morro Do Chapeu', '44850-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mortugaba', 'Mortugaba', '46290-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mucugê', 'Mucuge', '46750-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mucuri', 'Mucuri', '45930-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mulungu do Morro', 'Mulungu Do Morro', '44885-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mundo Novo', 'Mundo Novo', '44800-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muniz Ferreira', 'Muniz Ferreira', '44575-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muquém de São Francisco', 'Muquem De Sao Francisco', '47115-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muritiba', 'Muritiba', '44340-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mutas', 'Mutas', '46436-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mutuípe', 'Mutuipe', '45480-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nagé', 'Nage', '44432-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Narandiba', 'Narandiba', '48107-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nazaré', 'Nazare', '44400-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nilo Peçanha', 'Nilo Pecanha', '45440-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nordestina', 'Nordestina', '48870-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Alegria', 'Nova Alegria', '45838-500', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Brasília', 'Nova Brasilia', '45156-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Canaã', 'Nova Canaa', '45270-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Fátima', 'Nova Fatima', '44642-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Ibiá', 'Nova Ibia', '45452-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Itaipê', 'Nova Itaipe', '45380-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Itaraná', 'Nova Itarana', '45390-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Lídice', 'Nova Lidice', '45965-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Redenção', 'Nova Redencao', '46835-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Soure', 'Nova Soure', '48460-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Viçosa', 'Nova Vicosa', '45920-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Acre', 'Novo Acre', '46775-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Horizonte', 'Novo Horizonte', '46730-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Triunfo', 'Novo Triunfo', '48455-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Núcleo Residencial Pilar', 'Nucleo Residencial Pilar', '48967-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nuguaçu', 'Nuguacu', '44747-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olhos D''Água do Seco', 'Olhos D''Agua Do Seco', '46715-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olhos D''Água do Serafim', 'Olhos D''Agua Do Serafim', '46735-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olindina', 'Olindina', '48470-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oliveira dos Brejinhos', 'Oliveira Dos Brejinhos', '47530-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olivença', 'Olivenca', '45668-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Onha', 'Onha', '44578-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oriente Novo', 'Oriente Novo', '45210-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouricana', 'Ouricana', '45863-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouriçangas', 'Ouricangas', '48150-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouricuri do Ouro', 'Ouricuri Do Ouro', '47565-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ourolândia', 'Ourolandia', '44718-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Outeiro Redondo', 'Outeiro Redondo', '44365-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paiol', 'Paiol', '46320-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pajeú do Vento', 'Pajeu Do Vento', '46402-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palame', 'Palame', '48380-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmas de Monte Alto', 'Palmas De Monte Alto', '46460-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeiras', 'Palmeiras', '46930-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parafuso', 'Parafuso', '42849-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paramirim', 'Paramirim', '46190-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parateca', 'Parateca', '46443-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paratinga', 'Paratinga', '47500-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paripiranga', 'Paripiranga', '48430-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pataíba', 'Pataiba', '48175-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Patamuté', 'Patamute', '48945-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pau a Pique', 'Pau A Pique', '47320-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pau Brasil', 'Pau Brasil', '45890-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulo Afonso', 'Paulo Afonso', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pé de Serra', 'Pe De Serra', '44655-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedrão', 'Pedrao', '48140-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedras Altas do Mirim', 'Pedras Altas Do Mirim', '44697-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Alexandre', 'Pedro Alexandre', '48580-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Peixe', 'Peixe', '47230-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Petim', 'Petim', '44510-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piabanha', 'Piabanha', '45525-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piatã', 'Piata', '46765-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piçarrão', 'Picarrao', '47360-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pilão Arcado', 'Pilao Arcado', '47240-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pimenteira', 'Pimenteira', '45672-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pindaí', 'Pindai', '46360-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pindobaçu', 'Pindobacu', '44770-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhões', 'Pinhoes', '48924-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pintadas', 'Pintadas', '44610-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piragi', 'Piragi', '45837-500', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piraí do Norte', 'Pirai Do Norte', '45436-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirajá', 'Piraja', '45837-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirajuia', 'Pirajuia', '44486-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piri', 'Piri', '47355-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piripá', 'Piripa', '46270-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piritiba', 'Piritiba', '44830-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pituba', 'Pituba', '47454-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planaltino', 'Planaltino', '45375-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planalto', 'Planalto', '45190-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço Central', 'Poco Central', '45678-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço de Fora', 'Poco De Fora', '48940-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poções', 'Pocoes', '45260-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poços', 'Pocos', '47210-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pojuca', 'Pojuca', '48120-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Polo Petroquímico de Camaçari', 'Polo Petroquimico De Camacari', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponta da Areia', 'Ponta Da Areia', '45905-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponto Novo', 'Ponto Novo', '44755-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Novo', 'Porto Novo', '47710-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Seguro', 'Porto Seguro', '45810-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Posto da Mata', 'Posto Da Mata', '45928-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Potiraguá', 'Potiragua', '45790-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poxim do Sul', 'Poxim Do Sul', '45862-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prado', 'Prado', '45980-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Dutra', 'Presidente Dutra', '44930-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Jânio Quadros', 'Presidente Janio Quadros', '46250-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Tancredo Neves', 'Presidente Tancredo Neves', '45416-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prevenido', 'Prevenido', '44912-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quaraçu', 'Quaracu', '45159-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Queimadas', 'Queimadas', '48860-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quijingue', 'Quijingue', '48830-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quixabá', 'Quixaba', '47585-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quixabeira', 'Quixabeira', '44713-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rafael Jambeiro', 'Rafael Jambeiro', '44520-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Recife', 'Recife', '44927-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Remanso', 'Remanso', '47200-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Remédios', 'Remedios', '46738-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Retirolândia', 'Retirolandia', '48750-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riachão das Neves', 'Riachao Das Neves', '47970-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riachão do Jacuípe', 'Riachao Do Jacuipe', '44640-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riachão do Utinga', 'Riachao Do Utinga', '46815-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho da Guia', 'Riacho Da Guia', '48105-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho de Santana', 'Riacho De Santana', '46470-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho Seco', 'Riacho Seco', '48933-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeira do Amparo', 'Ribeira Do Amparo', '48440-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeira do Pombal', 'Ribeira Do Pombal', '48400-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão do Largo', 'Ribeirao Do Largo', '45155-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão do Salto', 'Ribeirao Do Salto', '45785-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio da Dona', 'Rio Da Dona', '44548-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio de Contas', 'Rio De Contas', '46170-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio do Antônio', 'Rio Do Antonio', '46220-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio do Braço', 'Rio Do Braco', '45666-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio do Meio', 'Rio Do Meio', '45712-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio do Pires', 'Rio Do Pires', '46550-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Fundo', 'Rio Fundo', '44275-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Real', 'Rio Real', '48330-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rodelas', 'Rodelas', '48630-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ruy Barbosa', 'Ruy Barbosa', '46800-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saldanha', 'Saldanha', '47250-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salgadália', 'Salgadalia', '48740-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salinas da Margarida', 'Salinas Da Margarida', '44450-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salobrinho', 'Salobrinho', '45662-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salobro', 'Salobro', '44892-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salvador', 'Salvador', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sambaíba', 'Sambaiba', '48476-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Bárbara', 'Santa Barbara', '44150-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Brígida', 'Santa Brigida', '48570-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz Cabrália', 'Santa Cruz Cabralia', '45807-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz da Vitória', 'Santa Cruz Da Vitoria', '45725-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Inês', 'Santa Ines', '45320-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia', 'Santa Luzia', '45865-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria da Vitória', 'Santa Maria Da Vitoria', '47640-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita de Cássia', 'Santa Rita De Cassia', '47150-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha', 'Santa Terezinha', '44590-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santaluz', 'Santaluz', '48880-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana', 'Santana', '47700-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Sobrado', 'Santana Do Sobrado', '47310-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santanópolis', 'Santanopolis', '44260-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santiago do Iguapé', 'Santiago Do Iguape', '44310-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Amaro', 'Santo Amaro', '44200-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio de Barcelona', 'Santo Antonio De Barcelona', '45915-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio de Jesus', 'Santo Antonio De Jesus', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Estevão', 'Santo Estevao', '44190-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Inácio', 'Santo Inacio', '47490-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Desidério', 'Sao Desiderio', '47820-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos', 'Sao Domingos', '48895-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Felipe', 'Sao Felipe', '44550-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Félix', 'Sao Felix', '44360-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Félix do Coribe', 'Sao Felix Do Coribe', '47665-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco do Conde', 'Sao Francisco Do Conde', '43900-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gabriel', 'Sao Gabriel', '44915-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo dos Campos', 'Sao Goncalo Dos Campos', '44330-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Fortaleza', 'Sao Joao Da Fortaleza', '48413-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Vitória', 'Sao Joao Da Vitoria', '45111-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Vitória', 'Sao Jose Da Vitoria', '45620-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Colônia', 'Sao Jose Do Colonia', '45142-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Jacuípe', 'Sao Jose Do Jacuipe', '44698-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Prado', 'Sao Jose Do Prado', '45958-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Rio Grande', 'Sao Jose Do Rio Grande', '47975-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel das Matas', 'Sao Miguel Das Matas', '44580-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Paulinho', 'Sao Paulinho', '45839-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Roque do Paraguaçu', 'Sao Roque Do Paraguacu', '44428-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Passe', 'Sao Sebastiao Do Passe', '43850-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Timóteo', 'Sao Timoteo', '46145-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapeaçu', 'Sapeacu', '44530-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sátiro Dias', 'Satiro Dias', '48485-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saubara', 'Saubara', '44220-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saudável', 'Saudavel', '47570-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saúde', 'Saude', '44740-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Seabra', 'Seabra', '46900-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sebastião Laranjeiras', 'Sebastiao Laranjeiras', '46450-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senhor do Bonfim', 'Senhor Do Bonfim', '48970-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sento Sé', 'Sento Se', '47350-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sergi', 'Sergi', '44335-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra da Canabrava', 'Serra Da Canabrava', '48953-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra do Ramalho', 'Serra Do Ramalho', '47630-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Dourada', 'Serra Dourada', '47740-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Grande', 'Serra Grande', '48414-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Grande', 'Serra Grande', '45414-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Preta', 'Serra Preta', '44660-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrinha', 'Serrinha', '48700-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrolândia', 'Serrolandia', '44710-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Simões Filho', 'Simoes Filho', '43700-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sítio da Baraúna', 'Sitio Da Barauna', '48993-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sítio do Mato', 'Sitio Do Mato', '47610-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sítio do Meio', 'Sitio Do Meio', '44508-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sítio do Quinto', 'Sitio Do Quinto', '48565-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sítio Grande', 'Sitio Grande', '47825-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sítio Novo', 'Sitio Novo', '48115-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Soares', 'Soares', '44913-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sobradinho', 'Sobradinho', '48925-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Souto Soares', 'Souto Soares', '46990-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Subaúma', 'Subauma', '48190-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sussuarana', 'Sussuarana', '46605-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabocas do Brejo Velho', 'Tabocas Do Brejo Velho', '47760-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taboleiro do Castro', 'Taboleiro Do Castro', '44568-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taboquinhas', 'Taboquinhas', '45534-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taguá', 'Tagua', '47930-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tamburil', 'Tamburil', '44862-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tanhaçu', 'Tanhacu', '46600-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tanque Novo', 'Tanque Novo', '46580-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tanquinho', 'Tanquinho', '44160-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tanquinho do Poço', 'Tanquinho Do Poco', '48994-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taperoá', 'Taperoa', '45430-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapiraípe', 'Tapiraipe', '46804-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapirama', 'Tapirama', '45543-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapiramutá', 'Tapiramuta', '44840-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapiranga', 'Tapiranga', '44723-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapúia', 'Tapuia', '45449-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquarendi', 'Taquarendi', '44748-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquarinha', 'Taquarinha', '45935-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tartaruga', 'Tartaruga', '45318-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tauapé', 'Tauape', '46335-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teixeira de Freitas', 'Teixeira De Freitas', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teodoro Sampaio', 'Teodoro Sampaio', '44280-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teofilândia', 'Teofilandia', '48770-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teolândia', 'Teolandia', '45465-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terra Nova', 'Terra Nova', '44270-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tijuaçú', 'Tijuacu', '48980-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tiquaruçu', 'Tiquarucu', '44140-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tremedal', 'Tremedal', '45170-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Triunfo do Sincorá', 'Triunfo Do Sincora', '46660-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tucano', 'Tucano', '48790-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uauá', 'Uaua', '48950-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubaíra', 'Ubaira', '45310-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubaitaba', 'Ubaitaba', '45545-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubatã', 'Ubata', '45550-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubiracaba', 'Ubiracaba', '46105-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubiraitá', 'Ubiraita', '46833-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uibaí', 'Uibai', '44950-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umburanas', 'Umburanas', '44798-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umbuzeiro', 'Umbuzeiro', '48474-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Una', 'Una', '45690-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urandi', 'Urandi', '46350-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uruçuca', 'Urucuca', '45680-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Utinga', 'Utinga', '46810-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vale Verde', 'Vale Verde', '45817-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valença', 'Valenca', '45400-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valente', 'Valente', '48890-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea da Roça', 'Varzea Da Roca', '44635-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea do Caldas', 'Varzea Do Caldas', '46910-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea do Cerco', 'Varzea Do Cerco', '44888-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea do Poço', 'Varzea Do Poco', '44715-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea Nova', 'Varzea Nova', '44690-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzeas', 'Varzeas', '47840-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Varzedo', 'Varzedo', '44565-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Velha Boipeba', 'Velha Boipeba', '45426-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ventura', 'Ventura', '44875-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vera Cruz', 'Vera Cruz', '44470-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vereda', 'Vereda', '45955-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila do Café', 'Vila Do Cafe', '45153-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vitória da Conquista', 'Vitoria Da Conquista', 'NULL', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Volta Grande', 'Volta Grande', '44845-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Wagner', 'Wagner', '46970-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Wanderley', 'Wanderley', '47940-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Wenceslau Guimarães', 'Wenceslau Guimaraes', '45460-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xique-Xique', 'Xique-Xique', '47400-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abaiara', 'Abaiara', '63240-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abílio Martins', 'Abilio Martins', '62252-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acarapé', 'Acarape', '62785-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acaraú', 'Acarau', '62580-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acopiara', 'Acopiara', '63560-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Adrianópolis', 'Adrianopolis', '62435-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Verde', 'Agua Verde', '61895-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aguaí', 'Aguai', '62602-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aiuá', 'Aiua', '62143-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aiuaba', 'Aiuaba', '63575-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alagoinha', 'Alagoinha', '63174-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alagoinha', 'Alagoinha', '62686-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alcântaras', 'Alcantaras', '62120-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Algodões', 'Algodoes', '63655-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Almofala', 'Almofala', '62592-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Altaneira', 'Altaneira', '63195-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Santo', 'Alto Santo', '62970-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amanaiara', 'Amanaiara', '62263-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amanari', 'Amanari', '61965-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amaniutuba', 'Amaniutuba', '63306-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amarelas', 'Amarelas', '62405-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amaro', 'Amaro', '63144-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('América', 'America', '62240-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amontada', 'Amontada', '62540-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anauá', 'Anaua', '63217-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aningás', 'Aningas', '62882-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anjinhos', 'Anjinhos', '63193-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antonina do Norte', 'Antonina Do Norte', '63570-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Bezerra', 'Antonio Bezerra', 'NULL', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Diogo', 'Antonio Diogo', '62791-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Marques', 'Antonio Marques', '61990-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aprazível', 'Aprazivel', '62114-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apuiarés', 'Apuiares', '62630-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aquinópolis', 'Aquinopolis', '63479-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aquiraz', 'Aquiraz', '61700-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araçás', 'Aracas', '62682-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aracati', 'Aracati', '62800-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aracatiaçu', 'Aracatiacu', '62111-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aracatiara', 'Aracatiara', '62548-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aracoiaba', 'Aracoiaba', '62750-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arajara', 'Arajara', '63183-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aranaú', 'Aranau', '62585-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arapá', 'Arapa', '62328-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arapari', 'Arapari', '62508-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araporanga', 'Araporanga', '63194-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araquém', 'Araquem', '62165-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ararendá', 'Ararenda', '62210-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araripe', 'Araripe', '63170-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arariús', 'Ararius', '62186-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aratama', 'Aratama', '63143-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araticum', 'Araticum', '62352-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aratuba', 'Aratuba', '62762-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areial', 'Areial', '62290-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ariscos dos Marianos', 'Ariscos Dos Marianos', '62759-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arneiroz', 'Arneiroz', '63670-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aroeiras', 'Aroeiras', '62163-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arrojado', 'Arrojado', '63305-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aruaru', 'Aruaru', '62951-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Assaré', 'Assare', '63140-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Assunção', 'Assuncao', '62505-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Assunção', 'Assuncao', '63625-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aurora', 'Aurora', '63360-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baixa Grande', 'Baixa Grande', '62605-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baixio', 'Baixio', '63320-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baixio da Donana', 'Baixio Da Donana', '63582-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Banabuiú', 'Banabuiu', '63960-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bandeira', 'Bandeira', '62723-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão de Aquiraz', 'Barao De Aquiraz', '63153-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barbalha', 'Barbalha', '63180-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra', 'Barra', '63578-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra', 'Barra', '62816-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra', 'Barra', '63506-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Sotero', 'Barra Do Sotero', '62393-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Nova', 'Barra Nova', '63667-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreira', 'Barreira', '62795-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreira dos Vianas', 'Barreira Dos Vianas', '62802-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiras', 'Barreiras', '63508-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiros', 'Barreiros', '63785-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiros', 'Barreiros', '63163-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiros', 'Barreiros', '62374-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barrento', 'Barrento', '62515-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barro', 'Barro', '63380-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barro Alto', 'Barro Alto', '63509-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barroquinha', 'Barroquinha', '62410-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baturité', 'Baturite', '62760-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baú', 'Bau', '63512-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Beberibe', 'Beberibe', '62840-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Cruz', 'Bela Cruz', '62570-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista', 'Bela Vista', '62510-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Betânia', 'Betania', '62382-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Betânia', 'Betania', '62273-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Betânia', 'Betania', '63623-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bitupitá', 'Bitupita', '62414-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bixopa', 'Bixopa', '62935-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Água', 'Boa Agua', '62953-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Esperança', 'Boa Esperanca', '63770-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Viagem', 'Boa Viagem', '63870-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', '63615-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', '62687-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista do Caxitoré', 'Boa Vista Do Caxitore', '62623-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonfim', 'Bonfim', '63601-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonfim', 'Bonfim', '62102-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonhu', 'Bonhu', '62905-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonito', 'Bonito', '62705-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Borges', 'Borges', '62835-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejinho', 'Brejinho', '63176-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo Grande', 'Brejo Grande', '63192-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo Santo', 'Brejo Santo', '63260-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brotas', 'Brotas', '62533-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buritizal', 'Buritizal', '62227-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buritizinho', 'Buritizinho', '63213-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabreiro', 'Cabreiro', '62806-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira', 'Cachoeira', '62728-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira Grande', 'Cachoeira Grande', '62228-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiçara', 'Caicara', '62597-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiçarinha', 'Caicarinha', '63957-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caio Prado', 'Caio Prado', '62742-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caioca', 'Caioca', '62109-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caipu', 'Caipu', '63538-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Calabaça', 'Calabaca', '63545-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caldeirão', 'Caldeirao', '63157-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Califórnia', 'California', '63920-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Câmara', 'Camara', '61753-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camboas', 'Camboas', '62688-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camilos', 'Camilos', '62132-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camocim', 'Camocim', '62400-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campanário', 'Campanario', '62468-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campestre', 'Campestre', '62817-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos Sales', 'Campos Sales', '63150-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canaan', 'Canaan', '62692-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canafistula', 'Canafistula', '62638-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canafistula', 'Canafistula', '63583-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cangati', 'Cangati', '63612-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cangati', 'Cangati', '63624-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canindé', 'Caninde', '62700-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canindezinho', 'Canindezinho', '62203-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canindezinho', 'Canindezinho', '62995-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canindezinho', 'Canindezinho', '63555-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capistrano', 'Capistrano', '62748-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caponga', 'Caponga', '62852-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caponga da Bernarda', 'Caponga Da Bernarda', '61754-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caracará', 'Caracara', '62112-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caridade', 'Caridade', '62730-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cariré', 'Carire', '62184-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caririaçu', 'Caririacu', '63220-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cariús', 'Carius', '63530-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cariutaba', 'Cariutaba', '63189-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carmelópolis', 'Carmelopolis', '63151-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carnaubal', 'Carnaubal', '62375-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carnaúbas', 'Carnaubas', '63616-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carnaubinha', 'Carnaubinha', '63637-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carquejo', 'Carquejo', '62175-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carrapateiras', 'Carrapateiras', '63662-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caruataí', 'Caruatai', '62325-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carvalho', 'Carvalho', '63768-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carvoeiro', 'Carvoeiro', '62594-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cascavel', 'Cascavel', '62850-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Castanhão', 'Castanhao', '62975-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catarina', 'Catarina', '63595-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catolé', 'Catole', '63613-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catuana', 'Catuana', '61680-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catunda', 'Catunda', '62297-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caucaia', 'Caucaia', 'NULL', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caxitoré', 'Caxitore', '62614-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caxitoré', 'Caxitore', '62664-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cedro', 'Cedro', '63400-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cemoaba', 'Cemoaba', '62657-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chaval', 'Chaval', '62420-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Choró', 'Choro', '63950-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chorozinho', 'Chorozinho', '62875-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cipó dos Anjos', 'Cipo Dos Anjos', '63925-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cococi', 'Cococi', '63685-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Codiá', 'Codia', '63603-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coité', 'Coite', '63212-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colina', 'Colina', '62774-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição', 'Conceicao', '62275-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coreaú', 'Coreau', '62160-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córrego dos Fernandes', 'Corrego Dos Fernandes', '62807-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Crateús', 'Crateus', '63700-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Crioulos', 'Crioulos', '63465-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristais', 'Cristais', '62859-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Croatá', 'Croata', '62390-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Croatá', 'Croata', '62676-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Croatá', 'Croata', '62269-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruxati', 'Cruxati', '62525-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruz', 'Cruz', '62595-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruz', 'Cruz', '62603-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruz de Pedra', 'Cruz De Pedra', '63513-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzeirinho', 'Cruzeirinho', '63440-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cuncas', 'Cuncas', '63395-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curatis', 'Curatis', '63755-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curupira', 'Curupira', '62758-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Custódio', 'Custodio', '63915-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Daniel de Queirós', 'Daniel De Queiros', '63930-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Delmiro Gouveia', 'Delmiro Gouveia', '62258-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Deputado Irapuan Pinheiro', 'Deputado Irapuan Pinheiro', '63645-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Deserto', 'Deserto', '62502-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Leme', 'Dom Leme', '63191-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Maurício', 'Dom Mauricio', '63945-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Quintino', 'Dom Quintino', '63137-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Domingos da Costa', 'Domingos Da Costa', '63880-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Donato', 'Donato', '62259-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dourados', 'Dourados', '62884-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ebron', 'Ebron', '63567-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ema', 'Ema', '62988-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ematuba', 'Ematuba', '63641-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Encantado', 'Encantado', '63810-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro João Tomé', 'Engenheiro Joao Tome', '62233-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro José Lopes', 'Engenheiro Jose Lopes', '63602-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenho Velho', 'Engenho Velho', '63383-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ererê', 'Erere', '63470-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espacinha', 'Espacinha', '62207-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esperança', 'Esperanca', '62708-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espinho', 'Espinho', '62388-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eusébio', 'Eusebio', '61760-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Farias Brito', 'Farias Brito', '63185-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fátima', 'Fatima', '62772-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Feiticeiro', 'Feiticeiro', '63477-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Feitosa', 'Feitosa', '63225-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Felizardo', 'Felizardo', '63345-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flamengo', 'Flamengo', '63592-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flores', 'Flores', '62253-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flores', 'Flores', '62903-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Forquilha', 'Forquilha', '62115-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fortaleza', 'Fortaleza', 'NULL', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fortim', 'Fortim', '62815-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frecheirinha', 'Frecheirinha', '62340-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gado', 'Gado', '62782-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gado dos Rodrigues', 'Gado Dos Rodrigues', '62784-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gameleira de São Sebastião', 'Gameleira De Sao Sebastiao', '63208-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Garças', 'Garcas', '62541-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gázea', 'Gazea', '62235-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('General Sampaio', 'General Sampaio', '62738-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('General Tibúrcio', 'General Tiburcio', '62305-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Genipapeiro', 'Genipapeiro', '62754-100', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gereraú', 'Gererau', '61887-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Giqui', 'Giqui', '62830-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Girau', 'Girau', '62807-500', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Graça', 'Graca', '62365-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Granja', 'Granja', '62430-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Granjeiro', 'Granjeiro', '63230-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Groairas', 'Groairas', '62190-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaiúba', 'Guaiuba', '61890-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guajiru', 'Guajiru', '62818-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guanacés', 'Guanaces', '62856-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraciaba do Norte', 'Guaraciaba Do Norte', '62380-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaramiranga', 'Guaramiranga', '62766-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guararu', 'Guararu', '61690-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guassi', 'Guassi', '62794-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guassossé', 'Guassosse', '63527-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guriú', 'Guriu', '62408-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Hidrolândia', 'Hidrolandia', '62270-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Holanda', 'Holanda', '63760-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Horizonte', 'Horizonte', '62880-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iapi', 'Iapi', '63643-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iara', 'Iara', '63390-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibaretama', 'Ibaretama', '63970-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiapaba', 'Ibiapaba', '63725-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiapina', 'Ibiapina', '62360-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibicatu', 'Ibicatu', '63558-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibicuã', 'Ibicua', '63608-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibicuitaba', 'Ibicuitaba', '62813-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibicuitinga', 'Ibicuitinga', '62955-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iborepi', 'Iborepi', '63303-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibuaçu', 'Ibuacu', '63890-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibuguaçu', 'Ibuguacu', '62448-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Icapuí', 'Icapui', '62810-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Icaraí', 'Icarai', '62545-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Icó', 'Ico', '63430-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Icozinho', 'Icozinho', '63445-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ideal', 'Ideal', '62754-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igaroi', 'Igaroi', '63528-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguatu', 'Iguatu', '63500-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Independência', 'Independencia', '63640-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ingazeiras', 'Ingazeiras', '63370-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhamuns', 'Inhamuns', '63666-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhuçu', 'Inhucu', '62373-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhuporanga', 'Inhuporanga', '62734-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipaporanga', 'Ipaporanga', '62215-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipaumirim', 'Ipaumirim', '63340-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipu', 'Ipu', '62250-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipueiras', 'Ipueiras', '62230-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipueiras dos Gomes', 'Ipueiras Dos Gomes', '62715-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iracema', 'Iracema', '62980-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irajá', 'Iraja', '62278-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irapuã', 'Irapua', '63728-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iratinga', 'Iratinga', '62608-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irauçuba', 'Iraucuba', '62620-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Isidoro', 'Isidoro', '63563-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itacima', 'Itacima', '61893-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaguá', 'Itagua', '63152-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaiçaba', 'Itaicaba', '62820-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaipaba', 'Itaipaba', '62872-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaitinga', 'Itaitinga', '61880-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itans', 'Itans', '62746-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapagé', 'Itapage', '62600-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapebussu', 'Itapebussu', '61980-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapeim', 'Itapeim', '62843-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapipoca', 'Itapipoca', '62500-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapiúna', 'Itapiuna', '62740-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapó', 'Itapo', '61877-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itarema', 'Itarema', '62590-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itatira', 'Itatira', '62720-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaburuna', 'Jaburuna', '62354-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacampari', 'Jacampari', '63895-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacarecoara', 'Jacarecoara', '62855-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacaúna', 'Jacauna', '61752-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguarão', 'Jaguarao', '62754-050', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguaretama', 'Jaguaretama', '63480-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguaribara', 'Jaguaribara', '63490-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguaribe', 'Jaguaribe', '63475-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguaruana', 'Jaguaruana', '62823-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaibaras', 'Jaibaras', '62107-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jamacaru', 'Jamacaru', '63207-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jandrangoeira', 'Jandrangoeira', '63642-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim', 'Jardim', '63290-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim', 'Jardim', '62684-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardimirim', 'Jardimirim', '63295-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jati', 'Jati', '63275-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jijoca de Jericoacoara', 'Jijoca De Jericoacoara', '62598-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Cordeiro', 'Joao Cordeiro', '62158-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jordão', 'Jordao', '62108-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('José de Alencar', 'Jose De Alencar', '63505-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juá', 'Jua', '62628-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juá', 'Jua', '63940-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juatama', 'Juatama', '63910-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juazeiro de Baixo', 'Juazeiro De Baixo', '62945-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juazeiro do Norte', 'Juazeiro Do Norte', 'NULL', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jubaia', 'Jubaia', '61955-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jucás', 'Jucas', '63580-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jurema', 'Jurema', 'NULL', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Justiniano Serpa', 'Justiniano Serpa', '61751-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lacerda', 'Lacerda', '63820-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ladeira Grande', 'Ladeira Grande', '61985-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa de São José', 'Lagoa De Sao Jose', '62754-150', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Juvenal', 'Lagoa Do Juvenal', '61975-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Mato', 'Lagoa Do Mato', '62725-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa dos Crioulos', 'Lagoa Dos Crioulos', '63158-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Grande', 'Lagoa Grande', '62542-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Grande', 'Lagoa Grande', '62942-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Grande', 'Lagoa Grande', '62902-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoinha', 'Lagoinha', '62922-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lambedouro', 'Lambedouro', '62308-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lameiro', 'Lameiro', '63134-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lavras da Mangabeira', 'Lavras Da Mangabeira', '63300-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lima Campos', 'Lima Campos', '63435-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Limoeiro do Norte', 'Limoeiro Do Norte', '62930-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lisieux', 'Lisieux', '62293-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Livramento', 'Livramento', '62238-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Logradouro', 'Logradouro', '62292-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macambira', 'Macambira', '62225-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macaóca', 'Macaoca', '63865-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macaraú', 'Macarau', '62285-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maceió', 'Maceio', '62819-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Madalena', 'Madalena', '63860-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Major Simplício', 'Major Simplicio', '62208-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Majorlândia', 'Majorlandia', '62809-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Malhada Grande', 'Malhada Grande', '62294-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mangabeira', 'Mangabeira', '63307-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manibu', 'Manibu', '62814-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manituba', 'Manituba', '63830-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mapuá', 'Mapua', '63476-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maracanaú', 'Maracanau', 'NULL', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maraguá', 'Maragua', '63218-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maranguape', 'Maranguape', '61940-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mararupá', 'Mararupa', '63216-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marco', 'Marco', '62560-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marinheiros', 'Marinheiros', '62520-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marrecas', 'Marrecas', '63664-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marrocos', 'Marrocos', '63084-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marruás', 'Marruas', '63665-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Martinópole', 'Martinopole', '62450-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Massapê', 'Massape', '62140-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mata Fresca', 'Mata Fresca', '62808-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matias', 'Matias', '62645-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matriz', 'Matriz', '62232-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mauriti', 'Mauriti', '63210-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mel', 'Mel', '63587-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Meruoca', 'Meruoca', '62130-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Messejana', 'Messejana', 'NULL', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miguel Xavier', 'Miguel Xavier', '63228-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Milagres', 'Milagres', '63250-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Milhã', 'Milha', '63635-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Milton Belo', 'Milton Belo', '62754-200', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mineirolândia', 'Mineirolandia', '63632-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miragem', 'Miragem', '63223-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miraíma', 'Miraima', '62530-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirambé', 'Mirambe', '61685-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Missão Nova', 'Missao Nova', '63203-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Missão Velha', 'Missao Velha', '63200-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Missi', 'Missi', '62625-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moitas', 'Moitas', '62543-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mombaça', 'Mombaca', '63610-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mondubim', 'Mondubim', 'NULL', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monguba', 'Monguba', '61860-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monsenhor Tabosa', 'Monsenhor Tabosa', '63780-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre', 'Monte Alegre', '63389-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre', 'Monte Alegre', '62703-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Castelo', 'Monte Castelo', '63154-100', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Grave', 'Monte Grave', '63639-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Sion', 'Monte Sion', '63695-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montenebo', 'Montenebo', '63715-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morada Nova', 'Morada Nova', '62940-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moraújo', 'Moraujo', '62480-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morrinhos', 'Morrinhos', '62550-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morrinhos Novos', 'Morrinhos Novos', '62386-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro Branco', 'Morro Branco', '62727-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mucambo', 'Mucambo', '62170-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mulungu', 'Mulungu', '62764-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mulungu', 'Mulungu', '63606-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mumbaba', 'Mumbaba', '62142-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mundau', 'Mundau', '62695-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muribeca', 'Muribeca', '62296-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muriti', 'Muriti', 'NULL', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mutambeiras', 'Mutambeiras', '62154-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Naraniu', 'Naraniu', '63550-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nascente', 'Nascente', '62544-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nenenlândia', 'Nenenlandia', '63814-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora do Livramento', 'Nossa Senhora Do Livramento', '63790-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Betânia', 'Nova Betania', '63187-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Betânia', 'Nova Betania', '62205-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Fátima', 'Nova Fatima', '62245-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Floresta', 'Nova Floresta', '63478-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Olinda', 'Nova Olinda', '63165-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Russas', 'Nova Russas', '62200-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Vida', 'Nova Vida', '63980-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Assis', 'Novo Assis', '63690-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Oriente', 'Novo Oriente', '63740-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Oriente', 'Novo Oriente', '62759-100', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ocara', 'Ocara', '62755-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oiticica', 'Oiticica', '63730-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oiticica', 'Oiticica', '63984-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olho-D''Água', 'Olho-D''Agua', '62113-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olho-D''Água da Bica', 'Olho-D''Agua Da Bica', '62964-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oliveiras', 'Oliveiras', '63775-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Orós', 'Oros', '63520-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pacajus', 'Pacajus', '62870-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pacatuba', 'Pacatuba', '61800-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pacoti', 'Pacoti', '62770-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pacujá', 'Pacuja', '62180-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Cícero', 'Padre Cicero', '63082-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Linhares', 'Padre Linhares', '62146-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Vieira', 'Padre Vieira', '62315-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pajeú', 'Pajeu', '63172-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palestina', 'Palestina', '63215-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palestina', 'Palestina', '63525-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palestina do Norte', 'Palestina Do Norte', '62134-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palhano', 'Palhano', '62910-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmácia', 'Palmacia', '62780-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmatória', 'Palmatoria', '62744-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Panacuí', 'Panacui', '62565-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paracuá', 'Paracua', '62465-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paracuru', 'Paracuru', '62680-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraipaba', 'Paraipaba', '62685-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parajuru', 'Parajuru', '62848-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parambu', 'Parambu', '63680-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paramoti', 'Paramoti', '62736-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parangaba', 'Parangaba', 'NULL', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parapuí', 'Parapui', '62156-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parazinho', 'Parazinho', '62437-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paripueira', 'Paripueira', '62844-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passagem', 'Passagem', '62425-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passagem', 'Passagem', '63835-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passagem Funda', 'Passagem Funda', '62754-350', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pasta', 'Pasta', '63622-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Patacas', 'Patacas', '61756-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Patriarca', 'Patriarca', '62104-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pavuna', 'Pavuna', '61870-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pecém', 'Pecem', '62674-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Branca', 'Pedra Branca', '63630-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Branca', 'Pedra Branca', '62754-250', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedras', 'Pedras', '62943-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedrinhas', 'Pedrinhas', '63455-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Peixe', 'Peixe', '62907-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Peixe Gordo', 'Peixe Gordo', '62962-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Penaforte', 'Penaforte', '63280-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pentecoste', 'Pentecoste', '62640-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pereiro', 'Pereiro', '63460-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pernambuquinho', 'Pernambuquinho', '62768-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pessoa Anta', 'Pessoa Anta', '62445-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pindoguaba', 'Pindoguaba', '62330-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pindoretama', 'Pindoretama', '62860-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pio X', 'Pio X', '63315-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piquet Carneiro', 'Piquet Carneiro', '63605-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirabibu', 'Pirabibu', '63802-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirangi', 'Pirangi', '63982-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pires Ferreira', 'Pires Ferreira', '62255-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pitombeira', 'Pitombeira', '62606-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pitombeiras', 'Pitombeiras', '62858-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Plácido Martins', 'Placido Martins', '62754-300', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço', 'Poco', '63268-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço Comprido', 'Poco Comprido', '62546-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço Comprido', 'Poco Comprido', '63495-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço Grande', 'Poco Grande', '63588-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Podimirim', 'Podimirim', '63255-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponta da Serra', 'Ponta Da Serra', '63138-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poranga', 'Poranga', '62220-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porfirio Sampaio', 'Porfirio Sampaio', '62648-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porteiras', 'Porteiras', '63270-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Potengi', 'Potengi', '63160-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poti', 'Poti', '63720-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Potiretama', 'Potiretama', '62990-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prata', 'Prata', '62575-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prudente de Morais', 'Prudente De Morais', '63815-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quatiguaba', 'Quatiguaba', '62310-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Queimadas', 'Queimadas', '62886-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quimami', 'Quimami', '63205-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quincoé', 'Quincoe', '63562-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quincuncá', 'Quincunca', '63188-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quitaiús', 'Quitaius', '63308-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quiterianópolis', 'Quiterianopolis', '63650-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quixadá', 'Quixada', '63900-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quixariú', 'Quixariu', '63154-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quixelô', 'Quixelo', '63515-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quixeramobim', 'Quixeramobim', '63800-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quixeré', 'Quixere', '62920-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Raimundo Martins', 'Raimundo Martins', '62295-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Redenção', 'Redencao', '62790-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Reriutaba', 'Reriutaba', '62260-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riachão do Banabuiú', 'Riachao Do Banabuiu', '63631-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho Grande', 'Riacho Grande', '63178-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho Verde', 'Riacho Verde', '63548-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho Vermelho', 'Riacho Vermelho', '63511-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rinaré', 'Rinare', '63965-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Roldão', 'Roldao', '62948-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Russas', 'Russas', '62900-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sabiaguaba', 'Sabiaguaba', '62547-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saboeiro', 'Saboeiro', '63590-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sacramento', 'Sacramento', '62218-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salão', 'Salao', '62475-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salitre', 'Salitre', '63155-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sambaíba', 'Sambaiba', '62433-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Ana', 'Santa Ana', '62776-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Fé', 'Santa Fe', '63136-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Felícia', 'Santa Felicia', '63565-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia', 'Santa Luzia', '62652-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Quitéria', 'Santa Quiteria', '62280-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Tereza', 'Santa Tereza', '62808-500', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Tereza', 'Santa Tereza', '63668-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana', 'Santana', '63735-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Acaraú', 'Santana Do Acarau', '62150-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Cariri', 'Santana Do Cariri', '63190-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santarém', 'Santarem', '63523-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio', 'Santo Antonio', '63561-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio', 'Santo Antonio', '62213-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio', 'Santo Antonio', '63385-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio', 'Santo Antonio', '63705-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio da Pindoba', 'Santo Antonio Da Pindoba', '62363-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio dos Fernandes', 'Santo Antonio Dos Fernandes', '62138-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bartolomeu', 'Sao Bartolomeu', '63533-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Benedito', 'Sao Benedito', '62370-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos', 'Sao Domingos', '62732-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Felipe', 'Sao Felipe', '63265-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco', 'Sao Francisco', '63652-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco', 'Sao Francisco', '62136-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gerardo', 'Sao Gerardo', '62792-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo do Amarante', 'Sao Goncalo Do Amarante', '62670-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo do Umari', 'Sao Goncalo Do Umari', '63617-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João de Deus', 'Sao Joao De Deus', '62908-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Jaguaribe', 'Sao Joao Do Jaguaribe', '62965-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João dos Queiróz', 'Sao Joao Dos Queiroz', '63948-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim', 'Sao Joaquim', '62663-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim do Salgado', 'Sao Joaquim Do Salgado', '63604-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José', 'Sao Jose', '63245-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José', 'Sao Jose', '62984-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José', 'Sao Jose', '62825-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José', 'Sao Jose', '62913-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José das Lontras', 'Sao Jose Das Lontras', '62248-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José de Solonópole', 'Sao Jose De Solonopole', '63621-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Torto', 'Sao Jose Do Torto', '62105-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luís do Curu', 'Sao Luis Do Curu', '62665-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel', 'Sao Miguel', '63219-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel', 'Sao Miguel', '63825-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Paulo', 'Sao Paulo', '63568-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '63585-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '62209-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Romão', 'Sao Romao', '63198-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião', 'Sao Sebastiao', '63535-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente', 'Sao Vicente', '63450-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente', 'Sao Vicente', '63618-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapo', 'Sapo', '62152-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapupara', 'Sapupara', '61950-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sebastião de Abreu', 'Sebastiao De Abreu', '62642-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Carlos Jereissati', 'Senador Carlos Jereissati', '61865-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Pompeu', 'Senador Pompeu', '63600-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Sá', 'Senador Sa', '62470-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sereno de Cima', 'Sereno De Cima', '62759-200', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra do Félix', 'Serra Do Felix', '62846-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serragem', 'Serragem', '62759-300', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrota', 'Serrota', '63392-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrota', 'Serrota', '62477-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrote', 'Serrote', '63507-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrote', 'Serrote', '62678-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sitiá', 'Sitia', '63962-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sítios Novos', 'Sitios Novos', '61695-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Siupê', 'Siupe', '62675-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sobral', 'Sobral', 'NULL', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Soledade', 'Soledade', '62607-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Solonópole', 'Solonopole', '63620-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Suassurana', 'Suassurana', '63510-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sucatinga', 'Sucatinga', '62842-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sucesso', 'Sucesso', '63765-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sussuanha', 'Sussuanha', '62385-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabainha', 'Tabainha', '62335-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taboleiro', 'Taboleiro', '63573-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabuleiro do Norte', 'Tabuleiro Do Norte', '62960-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taíba', 'Taiba', '62677-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tamboril', 'Tamboril', '63750-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tanques', 'Tanques', '61960-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapera', 'Tapera', '61758-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taperuaba', 'Taperuaba', '62106-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapuiara', 'Tapuiara', '63935-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Targinos', 'Targinos', '62713-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tarrafas', 'Tarrafas', '63145-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tauá', 'Taua', '63660-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tejuçuoca', 'Tejucuoca', '62610-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tianguá', 'Tiangua', '62320-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timonha', 'Timonha', '62440-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tipi', 'Tipi', '63365-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tomé', 'Tome', '62924-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trairi', 'Trairi', '62690-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trapiá', 'Trapia', '62283-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trapiá', 'Trapia', '62110-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trici', 'Trici', '63663-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tróia', 'Troia', '63633-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trussu', 'Trussu', '63564-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tucunduba', 'Tucunduba', '61688-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tucuns', 'Tucuns', '63710-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tuína', 'Tuina', '62141-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tururu', 'Tururu', '62655-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubajara', 'Ubajara', '62350-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubaúna', 'Ubauna', '62168-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubiraçu', 'Ubiracu', '62710-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uiraponga', 'Uiraponga', '62950-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umari', 'Umari', '63310-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umarituba', 'Umarituba', '62672-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umburanas', 'Umburanas', '63214-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umirim', 'Umirim', '62660-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uruburetama', 'Uruburetama', '62650-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uruoca', 'Uruoca', '62460-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uruquê', 'Uruque', '63805-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Varjota', 'Varjota', '62265-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea', 'Varzea', '63405-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea Alegre', 'Varzea Alegre', '63540-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea da Volta', 'Varzea Da Volta', '62485-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea do Gilo', 'Varzea Do Gilo', '62254-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vazantes', 'Vazantes', '62752-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ventura', 'Ventura', '62125-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vertentes do Lagedo', 'Vertentes Do Lagedo', '61970-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Viçosa', 'Vicosa', '62819-500', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Viçosa do Ceará', 'Vicosa Do Ceara', '62300-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Soares', 'Vila Soares', '62635-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brasília', 'Brasilia', 'NULL', 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brazlândia', 'Brazlandia', 'NULL', 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Candangolândia', 'Candangolandia', 'NULL', 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ceilândia', 'Ceilandia', 'NULL', 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzeiro', 'Cruzeiro', 'NULL', 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gama', 'Gama', 'NULL', 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guará', 'Guara', 'NULL', 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lago Norte', 'Lago Norte', 'NULL', 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lago Sul', 'Lago Sul', NULL, 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Núcleo Bandeirante', 'Nucleo Bandeirante', NULL, 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranoá', 'Paranoa', NULL, 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planaltina', 'Planaltina', NULL, 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Recanto das Emas', 'Recanto Das Emas', NULL, 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho Fundo', 'Riacho Fundo', NULL, 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Samambaia', 'Samambaia', NULL, 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria', 'Santa Maria', NULL, 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião', 'Sao Sebastiao', NULL, 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sobradinho', 'Sobradinho', NULL, 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taguatinga', 'Taguatinga', NULL, 'DF');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acioli', 'Acioli', '29687-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Afonso Cláudio', 'Afonso Claudio', '29600-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aghá', 'Agha', '29287-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Doce do Norte', 'Agua Doce Do Norte', '29820-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águia Branca', 'Aguia Branca', '29795-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Airituba', 'Airituba', '29477-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alegre', 'Alegre', '29500-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alfredo Chaves', 'Alfredo Chaves', '29240-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Calçado', 'Alto Calcado', '29475-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Caldeirão', 'Alto Caldeirao', '29656-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Mutum Preto', 'Alto Mutum Preto', '29737-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Rio Novo', 'Alto Rio Novo', '29760-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Santa Maria', 'Alto Santa Maria', '29662-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anchieta', 'Anchieta', '29230-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ângelo Frechiani', 'Angelo Frechiani', '29719-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anutiba', 'Anutiba', '29530-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apiacá', 'Apiaca', '29450-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araçatiba', 'Aracatiba', '29138-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aracê', 'Arace', '29278-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aracruz', 'Aracruz', '29190-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aracui', 'Aracui', '29365-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araguaia', 'Araguaia', '29258-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araraí', 'Ararai', '29535-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Argolas', 'Argolas', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Atílio Vivácqua', 'Atilio Vivacqua', '29490-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baía Nova', 'Baia Nova', '29227-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baixo Guandu', 'Baixo Guandu', '29730-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra de Novo Brasil', 'Barra De Novo Brasil', '29723-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra de São Francisco', 'Barra De Sao Francisco', '29800-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Itapemirim', 'Barra Do Itapemirim', '29349-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Nova', 'Barra Nova', '29932-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Seca', 'Barra Seca', '29954-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baunilha', 'Baunilha', '29712-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bebedouro', 'Bebedouro', '29915-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Esperança', 'Boa Esperanca', '29845-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boapaba', 'Boapaba', '29710-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus do Norte', 'Bom Jesus Do Norte', '29460-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonsucesso', 'Bonsucesso', '29458-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Braço do Rio', 'Braco Do Rio', '29967-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejetuba', 'Brejetuba', '29630-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Burarama', 'Burarama', '29327-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeirinha de Itaúna', 'Cachoeirinha De Itauna', '29805-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeiro de Itapemirim', 'Cachoeiro De Itapemirim', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Café', 'Cafe', '29515-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Calogi', 'Calogi', '29184-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Câmara', 'Camara', '29485-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carapina', 'Carapina', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cariacica', 'Cariacica', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Castelo', 'Castelo', '29360-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Celina', 'Celina', '29510-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colatina', 'Colatina', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição da Barra', 'Conceicao Da Barra', '29960-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Castelo', 'Conceicao Do Castelo', '29370-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Muqui', 'Conceicao Do Muqui', '29410-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conduru', 'Conduru', '29329-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coqueiral', 'Coqueiral', '29195-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córrego dos Monos', 'Corrego Dos Monos', '29328-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cotaxe', 'Cotaxe', '29855-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristal do Norte', 'Cristal Do Norte', '29978-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Crubixá', 'Crubixa', '29242-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Desengano', 'Desengano', '29916-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divino de São Lourenço', 'Divino De Sao Lourenco', '29590-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divino Espírito Santo', 'Divino Espirito Santo', '29479-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Djalma Coutinho', 'Djalma Coutinho', '29642-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Domingos Martins', 'Domingos Martins', '29260-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dona América', 'Dona America', '29445-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dores do Rio Preto', 'Dores Do Rio Preto', '29580-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Duas Barras', 'Duas Barras', '29283-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ecoporanga', 'Ecoporanga', '29850-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrela do Norte', 'Estrela Do Norte', '29367-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fartura', 'Fartura', '29783-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda Guandu', 'Fazenda Guandu', '29609-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fundão', 'Fundao', '29185-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Garrafão', 'Garrafao', '29649-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gironda', 'Gironda', '29326-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goiabeiras', 'Goiabeiras', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Lacerda de Aguiar', 'Governador Lacerda De Aguiar', '29826-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Lindenberg', 'Governador Lindenberg', '29720-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Graça Aranha', 'Graca Aranha', '29716-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gruta', 'Gruta', '29324-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaçuí', 'Guacui', '29560-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraná', 'Guarana', '29199-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarapari', 'Guarapari', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guararema', 'Guararema', '29842-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibatiba', 'Ibatiba', '29395-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibes', 'Ibes', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibicaba', 'Ibicaba', '29612-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiraçu', 'Ibiracu', '29670-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitirama', 'Ibitirama', '29540-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitiruí', 'Ibitirui', '29244-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibituba', 'Ibituba', '29740-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iconha', 'Iconha', '29280-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Imburana', 'Imburana', '29853-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iriritiba', 'Iriritiba', '29238-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irundi', 'Irundi', '29189-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irupi', 'Irupi', '29398-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Isabel', 'Isabel', '29263-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itabaiana', 'Itabaiana', '29884-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaçu', 'Itacu', '29697-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaguaçu', 'Itaguacu', '29690-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaici', 'Itaici', '29388-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaimbé', 'Itaimbe', '29695-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaipava', 'Itaipava', '29338-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamira', 'Itamira', '29889-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaóca', 'Itaoca', '29325-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapecoá', 'Itapecoa', '29335-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapemirim', 'Itapemirim', '29330-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaperuna', 'Itaperuna', '29812-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapina', 'Itapina', '29714-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaquari', 'Itaquari', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaraná', 'Itarana', '29620-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaúnas', 'Itaunas', '29965-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itauninhas', 'Itauninhas', '29944-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iúna', 'Iuna', '29390-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jabaquara', 'Jabaquara', '29236-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacaraipe', 'Jacaraipe', '29160-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaciguá', 'Jacigua', '29297-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacupemba', 'Jacupemba', '29193-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguaré', 'Jaguare', '29950-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jerônimo Monteiro', 'Jeronimo Monteiro', '29550-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joaçuba', 'Joacuba', '29860-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Neiva', 'Joao Neiva', '29680-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joatuba', 'Joatuba', '29617-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('José Carlos', 'Jose Carlos', '29455-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jucu', 'Jucu', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajinha', 'Lajinha', '29755-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laranja da Terra', 'Laranja Da Terra', '29615-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Limoeiro', 'Limoeiro', '29369-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Linhares', 'Linhares', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mangaraí', 'Mangarai', '29644-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mantenópolis', 'Mantenopolis', '29770-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marataízes', 'Marataizes', '29345-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marechal Floriano', 'Marechal Floriano', '29255-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marilândia', 'Marilandia', '29725-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matilde', 'Matilde', '29248-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Melgaço', 'Melgaco', '29276-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Menino Jesus', 'Menino Jesus', '29384-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mimoso do Sul', 'Mimoso Do Sul', '29400-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montanha', 'Montanha', '29890-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Carmelo do Rio Novo', 'Monte Carmelo Do Rio Novo', '29767-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Pio', 'Monte Pio', '29368-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Sinai', 'Monte Sinai', '29807-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mucurici', 'Mucurici', '29880-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mundo Novo', 'Mundo Novo', '29585-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muniz Freire', 'Muniz Freire', '29380-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muqui', 'Muqui', '29480-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nestor Gomes', 'Nestor Gomes', '29942-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Almeida', 'Nova Almeida', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Canaã', 'Nova Canaa', '29333-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Venécia', 'Nova Venecia', '29830-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Verona', 'Nova Verona', '29940-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Brasil', 'Novo Brasil', '29724-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Horizonte', 'Novo Horizonte', '29852-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pacotuba', 'Pacotuba', '29323-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paineiras', 'Paineiras', '29342-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeira', 'Palmeira', '29699-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmerino', 'Palmerino', '29764-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pancas', 'Pancas', '29750-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraju', 'Paraju', '29273-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulista', 'Paulista', '29815-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Canário', 'Pedro Canario', '29970-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pendanga', 'Pendanga', '29675-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pequiá', 'Pequia', '29392-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Perdição', 'Perdicao', '29394-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piaçu', 'Piacu', '29386-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinheiros', 'Pinheiros', '29980-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piracema', 'Piracema', '29607-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piúma', 'Piuma', '29285-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte de Itabapoana', 'Ponte De Itabapoana', '29440-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponto Belo', 'Ponto Belo', '29885-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontões', 'Pontoes', '29604-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porangá', 'Poranga', '29817-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Barra do Riacho', 'Porto Barra Do Riacho', '29197-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Praia Grande', 'Praia Grande', '29187-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Kennedy', 'Presidente Kennedy', '29350-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Princesa', 'Princesa', '29293-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Queimado', 'Queimado', '29183-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quilômetro 14 do Mutum', 'Quilometro 14 Do Mutum', '29735-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Regência', 'Regencia', '29914-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho', 'Riacho', '29198-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão do Cristo', 'Ribeirao Do Cristo', '29250-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Bananal', 'Rio Bananal', '29920-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Calcado', 'Rio Calcado', '29226-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Muqui', 'Rio Muqui', '29340-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Novo do Sul', 'Rio Novo Do Sul', '29290-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Preto', 'Rio Preto', '29841-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rive', 'Rive', '29520-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sagrada Família', 'Sagrada Familia', '29253-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Angélica', 'Santa Angelica', '29525-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz', 'Santa Cruz', '29196-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Júlia', 'Santa Julia', '29669-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Leopoldina', 'Santa Leopoldina', '29640-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia de Mantenópolis', 'Santa Luzia De Mantenopolis', '29772-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia do Azul', 'Santa Luzia Do Azul', '29823-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia do Norte', 'Santa Luzia Do Norte', '29856-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria de Jetibá', 'Santa Maria De Jetiba', '29645-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Marta', 'Santa Marta', '29545-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Teresa', 'Santa Teresa', '29650-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha', 'Santa Terezinha', '29875-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santíssima Trindade', 'Santissima Trindade', '29393-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Agostinho', 'Santo Agostinho', '29824-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio', 'Santo Antonio', '29810-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Canaã', 'Santo Antonio Do Canaa', '29654-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Muqui', 'Santo Antonio Do Muqui', '29407-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos Belos', 'Campos Belos', '73840-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Pousalegre', 'Santo Antonio Do Pousalegre', '29848-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Quinze', 'Santo Antonio Do Quinze', '29839-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos do Norte', 'Sao Domingos Do Norte', '29745-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco', 'Sao Francisco', '29748-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco Xavier do Guandu', 'Sao Francisco Xavier Do Guandu', '29613-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gabriel da Palha', 'Sao Gabriel Da Palha', '29780-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Geraldo', 'Sao Geraldo', '29776-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Jacinto', 'Sao Jacinto', '29667-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João de Petrópolis', 'Sao Joao De Petropolis', '29660-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João de Viçosa', 'Sao Joao De Vicosa', '29378-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Sobrado', 'Sao Joao Do Sobrado', '29985-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Jorge do Oliveira', 'Sao Jorge Do Oliveira', '29635-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Jorge do Tiradentes', 'Sao Jorge Do Tiradentes', '29925-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José das Torres', 'Sao Jose Das Torres', '29420-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José de Mantenópolis', 'Sao Jose De Mantenopolis', '29778-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Calçado', 'Sao Jose Do Calcado', '29470-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Sobradinho', 'Sao Jose Do Sobradinho', '29847-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Mateus', 'Sao Mateus', '29930-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '29389-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro de Itabapoana', 'Sao Pedro De Itabapoana', '29405-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro de Rates', 'Sao Pedro De Rates', '29564-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Rafael', 'Sao Rafael', '29918-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Roque do Cannaã', 'Sao Roque Do Cannaa', '29665-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Tiago', 'Sao Tiago', '29562-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Torquato', 'Sao Torquato', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapucaia', 'Sapucaia', '29728-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra', 'Serra', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Pelada', 'Serra Pelada', '29603-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sobreiro', 'Sobreiro', '29619-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sooretama', 'Sooretama', '29927-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timbuí', 'Timbui', '29188-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Todos os Santos', 'Todos Os Santos', '29228-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urânia', 'Urania', '29246-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargem Alta', 'Vargem Alta', '29295-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargem Grande do Soturno', 'Vargem Grande Do Soturno', '29321-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Venda Nova do Imigrante', 'Venda Nova Do Imigrante', '29375-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Viana', 'Viana', '29135-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vieira Machado', 'Vieira Machado', '29383-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nelita', 'Vila Nelita', '29822-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nova de Bananal', 'Vila Nova De Bananal', '29742-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Pavão', 'Vila Pavao', '29843-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Valério', 'Vila Valerio', '29785-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Velha', 'Vila Velha', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Verde', 'Vila Verde', '29752-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vinhático', 'Vinhatico', '29894-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vinte e Cinco de Julho', 'Vinte E Cinco De Julho', '29652-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vitória', 'Vitoria', NULL, 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abadia de Goiás', 'Abadia De Goias', '75345-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abadiânia', 'Abadiania', '72940-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acreúna', 'Acreuna', '75960-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Adelândia', 'Adelandia', '76155-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Fria de Goiás', 'Agua Fria De Goias', '73780-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Limpa', 'Agua Limpa', '75665-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas Lindas de Goiás', 'Aguas Lindas De Goias', '72910-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alexânia', 'Alexania', '72920-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aloândia', 'Aloandia', '75615-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Alvorada', 'Alto Alvorada', '75283-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Horizonte', 'Alto Horizonte', '76560-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Paraíso de Goiás', 'Alto Paraiso De Goias', '73770-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvorada do Norte', 'Alvorada Do Norte', '73950-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amaralina', 'Amaralina', '76493-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Americano do Brasil', 'Americano Do Brasil', '76165-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amorinópolis', 'Amorinopolis', '76140-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anápolis', 'Anapolis', NULL, 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anhangüera', 'Anhanguera', '75770-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anicuns', 'Anicuns', '76170-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida', 'Aparecida', '76163-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida de Goiânia', 'Aparecida De Goiania', NULL, 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida de Goiás', 'Aparecida De Goias', '76363-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida do Rio Claro', 'Aparecida Do Rio Claro', '76256-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida do Rio Doce', 'Aparecida Do Rio Doce', '75827-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aporé', 'Apore', '75825-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araçu', 'Aracu', '75410-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aragarças', 'Aragarcas', '76240-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aragoiânia', 'Aragoiania', '75360-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araguapaz', 'Araguapaz', '76720-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arenópolis', 'Arenopolis', '76235-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aruanã', 'Aruana', '76710-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aurilândia', 'Aurilandia', '76120-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Auriverde', 'Auriverde', '76513-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Avelinópolis', 'Avelinopolis', '75395-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bacilândia', 'Bacilandia', '76222-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baliza', 'Baliza', '76250-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bandeirantes', 'Bandeirantes', '76523-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barbosilândia', 'Barbosilandia', '73907-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barro Alto', 'Barro Alto', '76390-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista de Goiás', 'Bela Vista De Goias', '75240-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jardim de Goiás', 'Bom Jardim De Goias', '76245-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus de Goiás', 'Bom Jesus De Goias', '75570-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonfinópolis', 'Bonfinopolis', '75195-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonópolis', 'Bonopolis', '76555-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brazabrantes', 'Brazabrantes', '75440-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Britânia', 'Britania', '76280-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buenolândia', 'Buenolandia', '76606-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buriti Alegre', 'Buriti Alegre', '75660-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buriti de Goiás', 'Buriti De Goias', '76152-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buritinópolis', 'Buritinopolis', '73975-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabeceiras', 'Cabeceiras', '73870-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira Alta', 'Cachoeira Alta', '75870-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira de Goiás', 'Cachoeira De Goias', '76125-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira Dourada', 'Cachoeira Dourada', '75560-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caçu', 'Cacu', '75813-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiapônia', 'Caiaponia', '75850-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiçara', 'Caicara', '76742-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Calcilândia', 'Calcilandia', '76604-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caldas Novas', 'Caldas Novas', '75690-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caldazinha', 'Caldazinha', '75245-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Calixto', 'Calixto', '75158-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campestre de Goiás', 'Campestre De Goias', '75385-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campinaçu', 'Campinacu', '76440-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campinorte', 'Campinorte', '76410-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Alegre de Goiás', 'Campo Alegre De Goias', '75795-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Limpo', 'Campo Limpo', '75545-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campolândia', 'Campolandia', '76133-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos Verdes', 'Campos Verdes', '76515-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cana Brava', 'Cana Brava', '76458-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canadá', 'Canada', '76274-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capelinha', 'Capelinha', '76174-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraíba', 'Caraiba', '75263-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carmo do Rio Verde', 'Carmo Do Rio Verde', '76340-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Castelândia', 'Castelandia', '75925-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Castrinópolis', 'Castrinopolis', '76313-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catalão', 'Catalao', NULL, 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caturaí', 'Caturai', '75430-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cavalcante', 'Cavalcante', '73790-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cavalheiro', 'Cavalheiro', '75783-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cebrasa', 'Cebrasa', '75156-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ceres', 'Ceres', '76300-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cezarina', 'Cezarina', '76195-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chapadão do Céu', 'Chapadao Do Ceu', '75828-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Choupana', 'Choupana', '76172-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cibele', 'Cibele', '76682-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cidade Ocidental', 'Cidade Ocidental', '72880-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cirilândia', 'Cirilandia', '76323-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cocalzinho de Goiás', 'Cocalzinho De Goias', '72975-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colinas do Sul', 'Colinas Do Sul', '73740-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córrego do Ouro', 'Corrego Do Ouro', '76145-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córrego Rico', 'Corrego Rico', '73759-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corumbá de Goiás', 'Corumba De Goias', '72960-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corumbaíba', 'Corumbaiba', '75680-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristalina', 'Cristalina', '73850-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristianópolis', 'Cristianopolis', '75230-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Crixás', 'Crixas', '76510-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cromínia', 'Crominia', '75635-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzeiro do Norte', 'Cruzeiro Do Norte', '76554-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cumari', 'Cumari', '75760-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Damianópolis', 'Damianopolis', '73980-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Damolândia', 'Damolandia', '75420-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Davidópolis', 'Davidopolis', '76602-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Davinópolis', 'Davinopolis', '75730-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Diolândia', 'Diolandia', '76683-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Diorama', 'Diorama', '76260-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divinópolis de Goiás', 'Divinopolis De Goias', '73865-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Domiciano Ribeiro', 'Domiciano Ribeiro', '75784-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doverlândia', 'Doverlandia', '75855-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Edealina', 'Edealina', '75945-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Edéia', 'Edeia', '75940-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrela do Norte', 'Estrela Do Norte', '76485-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faina', 'Faina', '76740-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda Nova', 'Fazenda Nova', '76220-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Firminópolis', 'Firminopolis', '76105-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flores de Goiás', 'Flores De Goias', '73890-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Formosa', 'Formosa', NULL, 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Formoso', 'Formoso', '76470-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Forte', 'Forte', '73764-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gameleira de Goiás', 'Gameleira De Goias', '75184-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Geriaçu', 'Geriacu', '76402-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goialândia', 'Goialandia', '75151-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goianápolis', 'Goianapolis', '75170-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goiandira', 'Goiandira', '75740-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goianésia', 'Goianesia', '76380-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goiânia', 'Goiania', NULL, 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goianira', 'Goianira', '75370-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goiás', 'Goias', '76600-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goiatuba', 'Goiatuba', '75600-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gouvelândia', 'Gouvelandia', '75865-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guapó', 'Guapo', '75350-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraíta', 'Guaraita', '76690-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarani de Goiás', 'Guarani De Goias', '73910-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarinos', 'Guarinos', '76385-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Heitoraí', 'Heitorai', '76670-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Hidrolândia', 'Hidrolandia', '75340-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Hidrolina', 'Hidrolina', '76375-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iaciara', 'Iaciara', '73920-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inaciolândia', 'Inaciolandia', '75550-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indiara', 'Indiara', '75955-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhumas', 'Inhumas', '75400-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Interlândia', 'Interlandia', '75152-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipameri', 'Ipameri', '75780-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iporá', 'Ipora', '76200-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Israelândia', 'Israelandia', '76205-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaberaí', 'Itaberai', '76630-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaguaçu', 'Itaguacu', '75893-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaguari', 'Itaguari', '76650-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaguaru', 'Itaguaru', '76660-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itajá', 'Itaja', '75815-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapaci', 'Itapaci', '76360-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapirapuã', 'Itapirapua', '76290-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapuranga', 'Itapuranga', '76680-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itarumã', 'Itaruma', '75810-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itauçu', 'Itaucu', '75450-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itumbiara', 'Itumbiara', NULL, 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ivolândia', 'Ivolandia', '76130-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacilândia', 'Jacilandia', '76293-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jandaia', 'Jandaia', '75950-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaraguá', 'Jaragua', '76330-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaupaci', 'Jaupaci', '76210-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jeroaquara', 'Jeroaquara', '76744-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jesúpolis', 'Jesupolis', '75495-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joanápolis', 'Joanapolis', '75157-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joviânia', 'Joviania', '75610-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juscelândia', 'Juscelandia', '76276-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juscelino Kubitschek', 'Juscelino Kubitschek', '76478-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jussara', 'Jussara', '76270-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Bauzinho', 'Lagoa Do Bauzinho', '75912-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagolândia', 'Lagolandia', '72984-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Leopoldo de Bulhões', 'Leopoldo De Bulhoes', '75190-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lucilândia', 'Lucilandia', '76257-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luziânia', 'Luziania', NULL, 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mairipotaba', 'Mairipotaba', '75630-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mambaí', 'Mambai', '73970-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mara Rosa', 'Mara Rosa', '76490-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marcianópolis', 'Marcianopolis', '75574-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marzagão', 'Marzagao', '75670-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matrinchã', 'Matrincha', '76730-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maurilândia', 'Maurilandia', '75930-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Meia Ponte', 'Meia Ponte', '75547-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Messianópolis', 'Messianopolis', '76138-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mimoso de Goiás', 'Mimoso De Goias', '73730-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Minaçu', 'Minacu', '76450-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mineiros', 'Mineiros', '75830-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moiporá', 'Moipora', '76135-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre de Goiás', 'Monte Alegre De Goias', '73830-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montes Claros de Goiás', 'Montes Claros De Goias', '76255-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montividiu', 'Montividiu', '75915-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montividiu do Norte', 'Montividiu Do Norte', '76465-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morrinhos', 'Morrinhos', '75650-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro Agudo de Goiás', 'Morro Agudo De Goias', '76355-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mossâmedes', 'Mossamedes', '76150-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mozarlândia', 'Mozarlandia', '76700-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mundo Novo', 'Mundo Novo', '76530-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mutunópolis', 'Mutunopolis', '76540-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Natinópolis', 'Natinopolis', '76383-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nazário', 'Nazario', '76180-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nerópolis', 'Neropolis', '75460-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Niquelândia', 'Niquelandia', '76420-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova América', 'Nova America', '76345-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Aurora', 'Nova Aurora', '75750-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Crixás', 'Nova Crixas', '76520-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Glória', 'Nova Gloria', '76305-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Iguaçu de Goiás', 'Nova Iguacu De Goias', '76495-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Roma', 'Nova Roma', '73820-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Veneza', 'Nova Veneza', '75470-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Brasil', 'Novo Brasil', '76285-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Gama', 'Novo Gama', NULL, 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Planalto', 'Novo Planalto', '76580-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olaria do Angico', 'Olaria Do Angico', '75812-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olhos D''Água', 'Olhos D''Agua', '75714-100', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Orizona', 'Orizona', '75280-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Verde de Goiás', 'Ouro Verde De Goias', '75165-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouroana', 'Ouroana', '75911-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouvidor', 'Ouvidor', '75715-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Bernardo', 'Padre Bernardo', '73700-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palestina de Goiás', 'Palestina De Goias', '75845-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeiras de Goiás', 'Palmeiras De Goias', '76190-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmelo', 'Palmelo', '75210-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palminópolis', 'Palminopolis', '75990-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Panamá', 'Panama', '75580-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranaiguara', 'Paranaiguara', '75880-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraúna', 'Parauna', '75980-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pau-Terra', 'Pau-Terra', '76412-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Branca', 'Pedra Branca', '75714-200', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Perolândia', 'Perolandia', '75823-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Petrolina de Goiás', 'Petrolina De Goias', '75480-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pilar de Goiás', 'Pilar De Goias', '76370-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piloândia', 'Piloandia', '76208-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piracanjuba', 'Piracanjuba', '75640-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piranhas', 'Piranhas', '76230-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirenópolis', 'Pirenopolis', '72980-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pires Belo', 'Pires Belo', '75714-300', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pires do Rio', 'Pires Do Rio', '75200-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planaltina de Goiás', 'Planaltina De Goias', NULL, 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontalina', 'Pontalina', '75620-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porangatu', 'Porangatu', '76550-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porteirão', 'Porteirao', '75603-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Portelândia', 'Portelandia', '75835-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Posse', 'Posse', '73900-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Posse D''Abadia', 'Posse D''Abadia', '72944-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Professor Jamil', 'Professor Jamil', '75645-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quirinópolis', 'Quirinopolis', '75860-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Registro do Araguaia', 'Registro Do Araguaia', '76258-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rianápolis', 'Rianapolis', '76315-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Quente', 'Rio Quente', '75695-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Verde', 'Rio Verde', NULL, 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riverlândia', 'Riverlandia', '75914-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Limpo de Goiás', 'Campo Limpo De Goias', '75160-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rosalândia', 'Rosalandia', '76103-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rubiataba', 'Rubiataba', '76350-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sanclerlândia', 'Sanclerlandia', '76160-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Bárbara de Goiás', 'Santa Barbara De Goias', '75390-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz das Lajes', 'Santa Cruz Das Lajes', '75913-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz de Goiás', 'Santa Cruz De Goias', '75220-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Fé de Goiás', 'Santa Fe De Goias', '76265-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Helena de Goiás', 'Santa Helena De Goias', '75920-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Isabel', 'Santa Isabel', '76320-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita do Araguaia', 'Santa Rita Do Araguaia', '75840-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita do Novo Destino', 'Santa Rita Do Novo Destino', '76395-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa', 'Santa Rosa', '73819-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa de Goiás', 'Santa Rosa De Goias', '75455-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Tereza de Goiás', 'Santa Tereza De Goias', '76480-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha de Goiás', 'Santa Terezinha De Goias', '76500-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio da Barra', 'Santo Antonio Da Barra', '75935-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio de Goiás', 'Santo Antonio De Goias', '75375-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Descoberto', 'Santo Antonio Do Descoberto', '72900-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Rio Verde', 'Santo Antonio Do Rio Verde', '75714-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos', 'Sao Domingos', '73860-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco de Goiás', 'Sao Francisco De Goias', '75490-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gabriel de Goiás', 'Sao Gabriel De Goias', '73758-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João', 'Sao Joao', '76610-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João D''Aliança', 'Sao Joao D''Alianca', '73760-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Paraúna', 'Sao Joao Da Parauna', '75985-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luís de Montes Belos', 'Sao Luis De Montes Belos', '76100-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz do Norte', 'Sao Luiz Do Norte', '76365-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz do Tocantins', 'Sao Luiz Do Tocantins', '76422-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel do Araguaia', 'Sao Miguel Do Araguaia', '76590-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel do Passa Quatro', 'Sao Miguel Do Passa Quatro', '75185-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Patrício', 'Sao Patricio', '76343-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Rio Claro', 'Sao Sebastiao Do Rio Claro', '76278-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Simão', 'Sao Simao', '75890-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente', 'Sao Vicente', '75159-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sarandi', 'Sarandi', '75549-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Canedo', 'Senador Canedo', '75250-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Dourada', 'Serra Dourada', '76224-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serranópolis', 'Serranopolis', '75820-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silvânia', 'Silvania', '75180-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Simolândia', 'Simolandia', '73930-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sítio D''Abadia', 'Sitio D''Abadia', '73990-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sousânia', 'Sousania', '75154-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquaral de Goiás', 'Taquaral De Goias', '76640-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taveira', 'Taveira', '76423-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teresina de Goiás', 'Teresina De Goias', '73795-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terezópolis de Goiás', 'Terezopolis De Goias', '75175-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Santa', 'Lagoa Santa', '75819-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Ranchos', 'Tres Ranchos', '75720-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trindade', 'Trindade', '75380-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trombas', 'Trombas', '76460-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupiracaba', 'Tupiracaba', '76424-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Turvânia', 'Turvania', '76110-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Turvelândia', 'Turvelandia', '75970-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uirapuru', 'Uirapuru', '76525-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uruaçu', 'Uruacu', '76400-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uruana', 'Uruana', '76335-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uruita', 'Uruita', '76338-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urutaí', 'Urutai', '75790-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uvá', 'Uva', '76608-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valdelândia', 'Valdelandia', '76352-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valparaíso de Goiás', 'Valparaiso De Goias', NULL, 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Varjão', 'Varjao', '75355-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vianópolis', 'Vianopolis', '75260-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vicentinópolis', 'Vicentinopolis', '75555-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Boa', 'Vila Boa', '73825-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Propício', 'Vila Propicio', '76393-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Sertaneja', 'Vila Sertaneja', '76528-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Açailândia', 'Acailandia', '65930-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Afonso Cunha', 'Afonso Cunha', '65505-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Doce do Maranhão', 'Agua Doce Do Maranhao', '65578-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alcântara', 'Alcantara', '65250-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aldeias Altas', 'Aldeias Altas', '65610-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Altamira do Maranhão', 'Altamira Do Maranhao', '65310-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Alegre do Maranhão', 'Alto Alegre Do Maranhao', '65413-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Alegre do Pindaré', 'Alto Alegre Do Pindare', '65398-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Parnaíba', 'Alto Parnaiba', '65810-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amapá do Maranhão', 'Amapa Do Maranhao', '65293-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amarante do Maranhão', 'Amarante Do Maranhao', '65923-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anajatuba', 'Anajatuba', '65490-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anapurus', 'Anapurus', '65525-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apicum-Açu', 'Apicum-Acu', '65275-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araguanã', 'Araguana', '65368-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araióses', 'Araioses', '65570-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arame', 'Arame', '65945-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arari', 'Arari', '65480-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aurizona', 'Aurizona', '65287-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Axixá', 'Axixa', '65108-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bacabal', 'Bacabal', '65700-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bacabeira', 'Bacabeira', '65103-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bacatuba', 'Bacatuba', '65688-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bacuri', 'Bacuri', '65270-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bacurituba', 'Bacurituba', '65233-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Balsas', 'Balsas', '65800-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão de Grajaú', 'Barao De Grajau', '65660-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão de Tromai', 'Barao De Tromai', '65281-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Corda', 'Barra Do Corda', '65950-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreirinhas', 'Barreirinhas', '65590-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barro Duro', 'Barro Duro', '65582-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista do Maranhão', 'Bela Vista Do Maranhao', '65335-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belagua', 'Belagua', '65535-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Benedito Leite', 'Benedito Leite', '65885-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bequimão', 'Bequimao', '65248-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bernardo do Mearim', 'Bernardo Do Mearim', '65723-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista do Gurupi', 'Boa Vista Do Gurupi', '65292-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista do Pindaré', 'Boa Vista Do Pindare', '65211-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jardim', 'Bom Jardim', '65380-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus das Selvas', 'Bom Jesus Das Selvas', '65395-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Lugar', 'Bom Lugar', '65704-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonfim do Arari', 'Bonfim Do Arari', '65483-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo', 'Brejo', '65520-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo de Areia', 'Brejo De Areia', '65315-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo de São Félix', 'Brejo De Sao Felix', '65643-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buriti', 'Buriti', '65515-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buriti Bravo', 'Buriti Bravo', '65685-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buriti Cortado', 'Buriti Cortado', '65639-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buriticupu', 'Buriticupu', '65393-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buritirama', 'Buritirama', '65935-500', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira Grande', 'Cachoeira Grande', '65165-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cajapió', 'Cajapio', '65230-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cajari', 'Cajari', '65210-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campestre do Maranhão', 'Campestre Do Maranhao', '65968-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cândido Mendes', 'Candido Mendes', '65280-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cantanhede', 'Cantanhede', '65465-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capinzal do Norte', 'Capinzal Do Norte', '65735-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraíba do Norte', 'Caraiba Do Norte', '65655-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carolina', 'Carolina', '65980-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carutapera', 'Carutapera', '65295-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caxias', 'Caxias', NULL, 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cedral', 'Cedral', '65260-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Central do Maranhão', 'Central Do Maranhao', '65267-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Centro do Guilherme', 'Centro Do Guilherme', '65288-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Centro Novo do Maranhão', 'Centro Novo Do Maranhao', '65299-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chapadinha', 'Chapadinha', '65500-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cidelândia', 'Cidelandia', '65921-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Codó', 'Codo', '65400-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Codozinho', 'Codozinho', '65405-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coelho Neto', 'Coelho Neto', '65620-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colinas', 'Colinas', '65690-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Lago Açu', 'Conceicao Do Lago Acu', '65340-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coroatá', 'Coroata', '65415-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curupa', 'Curupa', '65815-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cururupu', 'Cururupu', '65268-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curva Grande', 'Curva Grande', '65209-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Custódio Lima', 'Custodio Lima', '65565-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Davinópolis', 'Davinopolis', '65927-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Pedro', 'Dom Pedro', '65765-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Duque Bacelar', 'Duque Bacelar', '65625-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esperantinópolis', 'Esperantinopolis', '65750-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estandarte', 'Estandarte', '65282-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estreito', 'Estreito', '65975-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Feira Nova do Maranhão', 'Feira Nova Do Maranhao', '65995-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fernando Falcão', 'Fernando Falcao', '65964-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Formosa da Serra Negra', 'Formosa Da Serra Negra', '65943-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fortaleza dos Nogueiras', 'Fortaleza Dos Nogueiras', '65805-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fortuna', 'Fortuna', '65695-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frecheiras', 'Frecheiras', '65575-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Godofredo Viana', 'Godofredo Viana', '65285-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gonçalves Dias', 'Goncalves Dias', '65775-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Archer', 'Governador Archer', '65770-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Edson Lobão', 'Governador Edson Lobao', '65928-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Eugênio Barros', 'Governador Eugenio Barros', '65780-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Luiz Rocha', 'Governador Luiz Rocha', '65795-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Newton Bello', 'Governador Newton Bello', '65363-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Nunes Freire', 'Governador Nunes Freire', '65284-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Graça Aranha', 'Graca Aranha', '65785-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Grajaú', 'Grajau', '65940-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guimarães', 'Guimaraes', '65255-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Humberto de Campos', 'Humberto De Campos', '65180-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibipira', 'Ibipira', '65855-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Icatu', 'Icatu', '65170-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igarapé do Meio', 'Igarape Do Meio', '65345-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igarapé Grande', 'Igarape Grande', '65720-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Imperatriz', 'Imperatriz', NULL, 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaipava do Grajaú', 'Itaipava Do Grajau', '65948-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamataré', 'Itamatare', '65298-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapecuru Mirim', 'Itapecuru Mirim', '65485-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapera', 'Itapera', '65175-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itinga do Maranhão', 'Itinga Do Maranhao', '65939-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jatobá', 'Jatoba', '65693-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jenipapo dos Vieiras', 'Jenipapo Dos Vieiras', '65962-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Lisboa', 'Joao Lisboa', '65922-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joselândia', 'Joselandia', '65755-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Junco do Maranhão', 'Junco Do Maranhao', '65294-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lago da Pedra', 'Lago Da Pedra', '65715-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lago do Junco', 'Lago Do Junco', '65710-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lago dos Rodrigues', 'Lago Dos Rodrigues', '65712-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lago Verde', 'Lago Verde', '65705-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Mato', 'Lagoa Do Mato', '65683-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Grande do Maranhão', 'Lagoa Grande Do Maranhao', '65718-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado Novo', 'Lajeado Novo', '65937-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lapela', 'Lapela', '65355-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Leandro', 'Leandro', '65957-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lima Campos', 'Lima Campos', '65728-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Loreto', 'Loreto', '65895-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luís Domingues', 'Luis Domingues', '65290-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Magalhães de Almeida', 'Magalhaes De Almeida', '65560-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maioba', 'Maioba', '65137-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maracaçumé', 'Maracacume', '65289-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marajá do Sena', 'Maraja Do Sena', '65714-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maranhãozinho', 'Maranhaozinho', '65283-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marianópolis', 'Marianopolis', '65726-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mata', 'Mata', '65115-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mata Roma', 'Mata Roma', '65510-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matinha', 'Matinha', '65218-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matões', 'Matoes', '65645-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matões do Norte', 'Matoes Do Norte', '65468-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Milagres do Maranhão', 'Milagres Do Maranhao', '65545-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirador', 'Mirador', '65850-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miranda do Norte', 'Miranda Do Norte', '65495-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirinzal', 'Mirinzal', '65265-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monção', 'Moncao', '65360-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montes Altos', 'Montes Altos', '65936-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morros', 'Morros', '65160-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nina Rodrigues', 'Nina Rodrigues', '65450-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Colinas', 'Nova Colinas', '65808-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Iorque', 'Nova Iorque', '65880-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Olinda do Maranhão', 'Nova Olinda Do Maranhao', '65274-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olho D''Água das Cunhãs', 'Olho D''Agua Das Cunhas', '65706-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olinda Nova do Maranhão', 'Olinda Nova Do Maranhao', '65223-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paço do Lumiar', 'Paco Do Lumiar', '65130-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeirândia', 'Palmeirandia', '65238-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Papagaio', 'Papagaio', '65955-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraibano', 'Paraibano', '65670-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parnarama', 'Parnarama', '65640-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passagem Franca', 'Passagem Franca', '65680-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pastos Bons', 'Pastos Bons', '65870-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulino Neves', 'Paulino Neves', '65585-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulo Ramos', 'Paulo Ramos', '65716-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedreiras', 'Pedreiras', '65725-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro do Rosário', 'Pedro Do Rosario', '65206-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Penalva', 'Penalva', '65213-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Peri Mirim', 'Peri Mirim', '65245-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Peritoró', 'Peritoro', '65418-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pimentel', 'Pimentel', '65375-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pindaré Mirim', 'Pindare Mirim', '65370-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinheiro', 'Pinheiro', '65200-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pio XII', 'Pio Xii', '65707-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirapemas', 'Pirapemas', '65460-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poção de Pedras', 'Pocao De Pedras', '65740-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto das Gabarras', 'Porto Das Gabarras', '65493-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Franco', 'Porto Franco', '65970-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Rico do Maranhão', 'Porto Rico Do Maranhao', '65263-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Dutra', 'Presidente Dutra', '65760-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Juscelino', 'Presidente Juscelino', '65140-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Médici', 'Presidente Medici', '65279-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Sarney', 'Presidente Sarney', '65204-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Vargas', 'Presidente Vargas', '65455-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Primeira Cruz', 'Primeira Cruz', '65190-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Raposa', 'Raposa', '65138-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Resplandes', 'Resplandes', '65959-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riachão', 'Riachao', '65990-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribamar Fiquene', 'Ribamar Fiquene', '65938-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão Azul', 'Ribeirao Azul', '65658-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rocado', 'Rocado', '65875-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Roque', 'Roque', '65202-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rosário', 'Rosario', '65100-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sambaíba', 'Sambaiba', '65830-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Filomena do Maranhão', 'Santa Filomena Do Maranhao', '65768-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Helena', 'Santa Helena', '65208-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Inês', 'Santa Ines', '65300-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia', 'Santa Luzia', '65390-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia do Paruá', 'Santa Luzia Do Parua', '65272-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Quitéria do Maranhão', 'Santa Quiteria Do Maranhao', '65540-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita', 'Santa Rita', '65105-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Maranhão', 'Santana Do Maranhao', '65555-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Amaro', 'Santo Amaro', '65195-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio dos Lopes', 'Santo Antonio Dos Lopes', '65730-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Benedito do Rio Preto', 'Sao Benedito Do Rio Preto', '65440-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bento', 'Sao Bento', '65235-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bernardo', 'Sao Bernardo', '65550-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos do Azeitão', 'Sao Domingos Do Azeitao', '65888-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos do Maranhão', 'Sao Domingos Do Maranhao', '65790-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Félix de Balsas', 'Sao Felix De Balsas', '65890-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco do Brejão', 'Sao Francisco Do Brejao', '65929-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco do Maranhão', 'Sao Francisco Do Maranhao', '65650-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João Batista', 'Sao Joao Batista', '65225-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João de Cortes', 'Sao Joao De Cortes', '65253-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Carú', 'Sao Joao Do Caru', '65385-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Paraíso', 'Sao Joao Do Paraiso', '65973-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Sóter', 'Sao Joao Do Soter', '65615-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João dos Patos', 'Sao Joao Dos Patos', '65665-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim dos Melos', 'Sao Joaquim Dos Melos', '65764-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José de Ribamar', 'Sao Jose De Ribamar', '65110-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arcângelo', 'Arcangelo', '36318-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José dos Basílios', 'Sao Jose Dos Basilios', '65762-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luís', 'Sao Luis', NULL, 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luís Gonzaga do Maranhão', 'Sao Luis Gonzaga Do Maranhao', '65708-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Mateus do Maranhão', 'Sao Mateus Do Maranhao', '65470-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro da Água Branca', 'Sao Pedro Da Agua Branca', '65920-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro dos Crentes', 'Sao Pedro Dos Crentes', '65978-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Raimundo das Mangabeiras', 'Sao Raimundo Das Mangabeiras', '65840-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Raimundo de Codó', 'Sao Raimundo De Codo', '65410-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Raimundo do Doca Bezerra', 'Sao Raimundo Do Doca Bezerra', '65753-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Roberto', 'Sao Roberto', '65758-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente Ferrer', 'Sao Vicente Ferrer', '65220-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Satubinha', 'Satubinha', '65709-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Alexandre Costa', 'Senador Alexandre Costa', '65783-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador La Roque', 'Senador La Roque', '65935-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrano do Maranhão', 'Serrano Do Maranhao', '65269-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sítio Novo', 'Sitio Novo', '65925-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sucupira do Norte', 'Sucupira Do Norte', '65860-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sucupira do Riachão', 'Sucupira Do Riachao', '65668-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tasso Fragoso', 'Tasso Fragoso', '65820-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timbiras', 'Timbiras', '65420-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timon', 'Timon', NULL, 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trizidela do Vale', 'Trizidela Do Vale', '65727-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tufilândia', 'Tufilandia', '65378-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tuntum', 'Tuntum', '65763-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Turiaçu', 'Turiacu', '65278-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Turilândia', 'Turilandia', '65276-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tutóia', 'Tutoia', '65580-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urbano Santos', 'Urbano Santos', '65530-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargem Grande', 'Vargem Grande', '65430-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Viana', 'Viana', '65215-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nova dos Martírios', 'Vila Nova Dos Martirios', '65924-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vitória do Mearim', 'Vitoria Do Mearim', '65350-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vitorino Freire', 'Vitorino Freire', '65320-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Zé Doca', 'Ze Doca', '65365-000', 'MA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abadia dos Dourados', 'Abadia Dos Dourados', '38540-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abaeté', 'Abaete', '35620-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abaeté dos Mendes', 'Abaete Dos Mendes', '38812-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abaíba', 'Abaiba', '36704-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abre Campo', 'Abre Campo', '35365-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abreus', 'Abreus', '36263-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acaiaca', 'Acaiaca', '35438-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Açucena', 'Acucena', '35150-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acuruí', 'Acurui', '35451-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Adão Colares', 'Adao Colares', '39597-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Boa', 'Agua Boa', '39790-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Branca de Minas', 'Agua Branca De Minas', '39629-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Comprida', 'Agua Comprida', '38110-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Viva', 'Agua Viva', '36728-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aguanil', 'Aguanil', '37273-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas de Araxá', 'Aguas De Araxa', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas de Contendas', 'Aguas De Contendas', '37435-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas Férreas', 'Aguas Ferreas', '35362-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas Formosas', 'Aguas Formosas', '39880-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas Vermelhas', 'Aguas Vermelhas', '39990-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aimorés', 'Aimores', '35200-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aiuruoca', 'Aiuruoca', '37450-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alagoa', 'Alagoa', '37458-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Albertina', 'Albertina', '37596-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alberto Isaacson', 'Alberto Isaacson', '35608-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Albertos', 'Albertos', '35576-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aldeia', 'Aldeia', '35245-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alegre', 'Alegre', '38560-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alegria', 'Alegria', '36935-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Além Paraíba', 'Alem Paraiba', '36660-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alexandrita', 'Alexandrita', '38282-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alfenas', 'Alfenas', '37130-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alfredo Vasconcelos', 'Alfredo Vasconcelos', '36272-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Almeida', 'Almeida', '35835-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Almenara', 'Almenara', '39900-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alpercata', 'Alpercata', '35138-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alpinópolis', 'Alpinopolis', '37940-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alterosa', 'Alterosa', '37145-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Caparaó', 'Alto Caparao', '36836-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Capim', 'Alto Capim', '35210-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto de Santa Helena', 'Alto De Santa Helena', '35102-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Jequitibá', 'Alto Jequitiba', '36976-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Maranhão', 'Alto Maranhao', '36417-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Rio Doce', 'Alto Rio Doce', '36260-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Altolândia', 'Altolandia', '38985-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvação', 'Alvacao', '39347-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvarenga', 'Alvarenga', '35249-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvinópolis', 'Alvinopolis', '35950-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvorada', 'Alvorada', '36803-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvorada de Minas', 'Alvorada De Minas', '39140-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amanda', 'Amanda', '35708-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amanhece', 'Amanhece', '38455-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amarantina', 'Amarantina', '35412-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amparo da Serra', 'Amparo Da Serra', '35444-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Andiroba', 'Andiroba', '35745-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Andradas', 'Andradas', '37795-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Andrelândia', 'Andrelandia', '37300-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Andrequicé', 'Andrequice', '39207-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angaturama', 'Angaturama', '36746-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angelândia', 'Angelandia', '39685-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angicos de Minas', 'Angicos De Minas', '39332-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angueretá', 'Anguereta', '35793-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angustura', 'Angustura', '36664-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Carlos', 'Antonio Carlos', '36220-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Dias', 'Antonio Dias', '35177-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio dos Santos', 'Antonio Dos Santos', '34960-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Ferreira', 'Antonio Ferreira', '39697-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Pereira', 'Antonio Pereira', '35411-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Prado de Minas', 'Antonio Prado De Minas', '36850-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antunes', 'Antunes', '35698-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida de Minas', 'Aparecida De Minas', '38205-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araçaí', 'Aracai', '35777-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aracati de Minas', 'Aracati De Minas', '36776-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aracitaba', 'Aracitaba', '36255-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araçuaí', 'Aracuai', '39600-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araguari', 'Araguari', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aramirim', 'Aramirim', '35151-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aranha', 'Aranha', '35462-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arantina', 'Arantina', '37360-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araponga', 'Araponga', '36594-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araporã', 'Arapora', '38435-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arapuá', 'Arapua', '38860-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araújos', 'Araujos', '35603-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araúna', 'Arauna', '37180-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araxá', 'Araxa', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arceburgo', 'Arceburgo', '37820-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arcos', 'Arcos', '35588-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areado', 'Areado', '37140-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Argenita', 'Argenita', '38955-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Argirita', 'Argirita', '36710-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aricanduva', 'Aricanduva', '39678-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arinos', 'Arinos', '38680-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aristides Batista', 'Aristides Batista', '39341-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ascenção', 'Ascencao', '35665-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Assaraí', 'Assarai', '36966-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Astolfo Dutra', 'Astolfo Dutra', '36780-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ataléia', 'Ataleia', '39850-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Augusto de Lima', 'Augusto De Lima', '39220-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Avaí do Jacinto', 'Avai Do Jacinto', '39931-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Azurita', 'Azurita', '35672-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Babilônia', 'Babilonia', '37915-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bação', 'Bacao', '35453-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baependi', 'Baependi', '37443-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baguari', 'Baguari', '35105-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baiões', 'Baioes', '35575-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baixa', 'Baixa', '38101-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Balbinópolis', 'Balbinopolis', '39877-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baldim', 'Baldim', '35706-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bambuí', 'Bambui', '38900-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bandeira', 'Bandeira', '39917-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bandeira do Sul', 'Bandeira Do Sul', '37740-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bandeirantes', 'Bandeirantes', '35423-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão de Cocais', 'Barao De Cocais', '35970-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão de Monte Alto', 'Barao De Monte Alto', '36870-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barbacena', 'Barbacena', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Alegre', 'Barra Alegre', '35165-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra da Figueira', 'Barra Da Figueira', '36963-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Ariranha', 'Barra Do Ariranha', '35295-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Cuieté', 'Barra Do Cuiete', '35243-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Feliz', 'Barra Feliz', '35963-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Longa', 'Barra Longa', '35447-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barranco Alto', 'Barranco Alto', '37131-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiro', 'Barreiro', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiro Branco', 'Barreiro Branco', '39526-700', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiro da Raiz', 'Barreiro Da Raiz', '39442-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiro do Rio Verde', 'Barreiro Do Rio Verde', '39441-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barretos de Alvinópolis', 'Barretos De Alvinopolis', '35952-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barrocão', 'Barrocao', '39572-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barroso', 'Barroso', '36212-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baú', 'Bau', '35615-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista de Minas', 'Bela Vista De Minas', '35938-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belisário', 'Belisario', '36888-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belmiro Braga', 'Belmiro Braga', '36126-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belo Horizonte', 'Belo Horizonte', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belo Oriente', 'Belo Oriente', '35195-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belo Oriente', 'Belo Oriente', '39806-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belo Vale', 'Belo Vale', '35473-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bentópolis de Minas', 'Bentopolis De Minas', '39325-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Berilo', 'Berilo', '39640-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Berizal', 'Berizal', '39555-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bertópolis', 'Bertopolis', '39875-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Betim', 'Betim', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bias Fortes', 'Bias Fortes', '36230-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bicas', 'Bicas', '36600-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bicuíba', 'Bicuiba', '35352-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Biquinhas', 'Biquinhas', '35621-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bituri', 'Bituri', '35497-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Esperança', 'Boa Esperanca', '37170-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Família', 'Boa Familia', '36891-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa União de Itabirinha', 'Boa Uniao De Itabirinha', '35285-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista de Minas', 'Boa Vista De Minas', '35517-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bocaina de Minas', 'Bocaina De Minas', '37340-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bocaiúva', 'Bocaiuva', '39390-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Despacho', 'Bom Despacho', '35600-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jardim de Minas', 'Bom Jardim De Minas', '37310-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus da Cachoeira', 'Bom Jesus Da Cachoeira', '36892-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus da Penha', 'Bom Jesus Da Penha', '37948-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus de Cardosos', 'Bom Jesus De Cardosos', '35381-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus do Amparo', 'Bom Jesus Do Amparo', '35908-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus do Divino', 'Bom Jesus Do Divino', '36825-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus do Galho', 'Bom Jesus Do Galho', '35340-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus do Madeira', 'Bom Jesus Do Madeira', '36817-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Pastor', 'Bom Pastor', '35233-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Repouso', 'Bom Repouso', '37610-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Retiro', 'Bom Retiro', '36218-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Sucesso', 'Bom Sucesso', '37220-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Sucesso de Patos', 'Bom Sucesso De Patos', '38712-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonança', 'Bonanca', '39456-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonfim', 'Bonfim', '35521-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonfinópolis de Minas', 'Bonfinopolis De Minas', '38650-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonito de Minas', 'Bonito De Minas', '39490-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Borba Gato', 'Borba Gato', '35803-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Borda da Mata', 'Borda Da Mata', '37564-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Botelhos', 'Botelhos', '37720-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Botumirim', 'Botumirim', '39596-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brás Pires', 'Bras Pires', '36542-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brasilândia de Minas', 'Brasilandia De Minas', '38779-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brasília de Minas', 'Brasilia De Minas', '39330-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brasópolis', 'Brasopolis', '37530-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Braúnas', 'Braunas', '35169-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejaúba', 'Brejauba', '35858-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejaubinha', 'Brejaubinha', '35106-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo Bonito', 'Brejo Bonito', '38738-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo do Amparo', 'Brejo Do Amparo', '39482-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brumadinho', 'Brumadinho', '35460-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brumal', 'Brumal', '35966-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buarque de Macedo', 'Buarque De Macedo', '36413-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bueno', 'Bueno', '35244-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bueno Brandão', 'Bueno Brandao', '37578-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buenópolis', 'Buenopolis', '39230-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bugre', 'Bugre', '35193-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buritis', 'Buritis', '38660-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buritizeiro', 'Buritizeiro', '39280-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caatinga', 'Caatinga', '38778-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabeceira Grande', 'Cabeceira Grande', '38625-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabo Verde', 'Cabo Verde', '37880-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caburu', 'Caburu', '36317-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caçaratiba', 'Cacaratiba', '39662-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caçarema', 'Cacarema', '39448-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira Alegre', 'Cachoeira Alegre', '36876-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira da Prata', 'Cachoeira Da Prata', '35765-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira de Minas', 'Cachoeira De Minas', '37545-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira de Pajeú', 'Cachoeira De Pajeu', '39980-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira de Santa Cruz', 'Cachoeira De Santa Cruz', '36574-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira do Brumado', 'Cachoeira Do Brumado', '35424-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira do Campo', 'Cachoeira Do Campo', '35410-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira do Manteiga', 'Cachoeira Do Manteiga', '39288-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira do Vale', 'Cachoeira Do Vale', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira dos Antunes', 'Cachoeira Dos Antunes', '35523-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira Dourada', 'Cachoeira Dourada', '38370-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeirinha', 'Cachoeirinha', '38995-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caetano Lopes', 'Caetano Lopes', '35499-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caetanópolis', 'Caetanopolis', '35770-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caeté', 'Caete', '34800-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caeté', 'Caete', '36102-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiana', 'Caiana', '36832-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiapó', 'Caiapo', '36735-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cajuri', 'Cajuri', '36560-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caldas', 'Caldas', '37780-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Calixto', 'Calixto', '35232-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camacho', 'Camacho', '35555-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camanducaia', 'Camanducaia', '37650-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camargos', 'Camargos', '35427-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cambuí', 'Cambui', '37600-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cambuquira', 'Cambuquira', '37420-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campanário', 'Campanario', '39835-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campanha', 'Campanha', '37400-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campestre', 'Campestre', '37730-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campestrinho', 'Campestrinho', '37797-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campina Verde', 'Campina Verde', '38270-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Alegre de Minas', 'Campo Alegre De Minas', '39457-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Alegre de Minas', 'Campo Alegre De Minas', '35238-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Azul', 'Campo Azul', '39338-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Belo', 'Campo Belo', '37270-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo do Meio', 'Campo Do Meio', '37165-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Florido', 'Campo Florido', '38130-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Redondo', 'Campo Redondo', '39452-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campolide', 'Campolide', '36237-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos Altos', 'Campos Altos', '38970-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos Gerais', 'Campos Gerais', '37160-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cana Verde', 'Cana Verde', '37267-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canaã', 'Canaa', '36592-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canabrava', 'Canabrava', '39581-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canabrava', 'Canabrava', '38773-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canápolis', 'Canapolis', '38380-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canastrão', 'Canastrao', '38890-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Candeias', 'Candeias', '37280-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canoeiros', 'Canoeiros', '38792-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cantagalo', 'Cantagalo', '39703-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caparaó', 'Caparao', '36834-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capela Nova', 'Capela Nova', '36290-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capelinha', 'Capelinha', '39680-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capetinga', 'Capetinga', '37993-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capim Branco', 'Capim Branco', '35730-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capinópolis', 'Capinopolis', '38360-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capitânia', 'Capitania', '39499-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capitão Andrade', 'Capitao Andrade', '35123-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capitão Enéas', 'Capitao Eneas', '39445-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capitólio', 'Capitolio', '37930-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caputira', 'Caputira', '36925-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraí', 'Carai', '39810-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caranaíba', 'Caranaiba', '36428-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carandaí', 'Carandai', '36280-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carangola', 'Carangola', '36800-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caratinga', 'Caratinga', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carbonita', 'Carbonita', '39665-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cardeal Mota', 'Cardeal Mota', '35847-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Careaçu', 'Careacu', '37556-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carioca', 'Carioca', '35665-300', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carlos Alves', 'Carlos Alves', '36686-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carlos Chagas', 'Carlos Chagas', '39864-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carmésia', 'Carmesia', '35878-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carmo da Cachoeira', 'Carmo Da Cachoeira', '37225-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carmo da Mata', 'Carmo Da Mata', '35547-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carmo de Minas', 'Carmo De Minas', '37472-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carmo do Cajuru', 'Carmo Do Cajuru', '35510-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carmo do Paranaíba', 'Carmo Do Paranaiba', '38840-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carmo do Rio Claro', 'Carmo Do Rio Claro', '37150-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carmópolis de Minas', 'Carmopolis De Minas', '35534-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carneirinho', 'Carneirinho', '38290-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carrancas', 'Carrancas', '37245-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carvalho de Brito', 'Carvalho De Brito', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carvalhópolis', 'Carvalhopolis', '37760-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carvalhos', 'Carvalhos', '37456-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Casa Grande', 'Casa Grande', '36422-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cascalho Rico', 'Cascalho Rico', '38460-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cássia', 'Cassia', '37980-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cataguarino', 'Cataguarino', '36779-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cataguases', 'Cataguases', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catajás', 'Catajas', '39937-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catas Altas', 'Catas Altas', '35969-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catas Altas da Noruega', 'Catas Altas Da Noruega', '36450-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catiara', 'Catiara', '38762-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catuji', 'Catuji', '39816-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catuné', 'Catune', '36846-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catuni', 'Catuni', '39585-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catuti', 'Catuti', '39526-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caxambu', 'Caxambu', '37440-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cedro do Abaeté', 'Cedro Do Abaete', '35624-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Centenário', 'Centenario', '36957-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Central de Minas', 'Central De Minas', '35260-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Central de Santa Helena', 'Central De Santa Helena', '35267-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Centralina', 'Centralina', '38390-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cervo', 'Cervo', '37565-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chácara', 'Chacara', '36110-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chalé', 'Chale', '36985-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chapada de Minas', 'Chapada De Minas', '38528-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chapada do Norte', 'Chapada Do Norte', '39648-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chapada Gaúcha', 'Chapada Gaucha', '39314-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chaveslândia', 'Chaveslandia', '38325-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chiador', 'Chiador', '36630-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chonim', 'Chonim', '35109-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chumbo', 'Chumbo', '38713-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cipotânea', 'Cipotanea', '36265-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cisneiros', 'Cisneiros', '36753-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Citrolândia', 'Citrolandia', '32800-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Claraval', 'Claraval', '37997-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Claro de Minas', 'Claro De Minas', '38782-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Claro dos Poções', 'Claro Dos Pocoes', '39380-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cláudio', 'Claudio', '35530-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cláudio Manuel', 'Claudio Manuel', '35429-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cocais', 'Cocais', '35975-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coco', 'Coco', '35472-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coimbra', 'Coimbra', '36550-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coluna', 'Coluna', '39770-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Comendador Gomes', 'Comendador Gomes', '38250-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Comercinho', 'Comercinho', '39628-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição da Aparecida', 'Conceicao Da Aparecida', '37148-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição da Barra de Minas', 'Conceicao Da Barra De Minas', '36360-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição da Boa Vista', 'Conceicao Da Boa Vista', '36743-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição da Brejaúba', 'Conceicao Da Brejauba', '39721-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição da Ibitipoca', 'Conceicao Da Ibitipoca', '36144-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição das Alagoas', 'Conceicao Das Alagoas', '38120-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição das Pedras', 'Conceicao Das Pedras', '37527-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição de Ipanema', 'Conceicao De Ipanema', '36947-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição de Itaguá', 'Conceicao De Itagua', '35466-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição de Minas', 'Conceicao De Minas', '35985-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição de Piracicaba', 'Conceicao De Piracicaba', '35943-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição de Tronqueiras', 'Conceicao De Tronqueiras', '39711-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Capim', 'Conceicao Do Capim', '35202-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Formoso', 'Conceicao Do Formoso', '36248-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Mato Dentro', 'Conceicao Do Mato Dentro', '35860-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Pará', 'Conceicao Do Para', '35668-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Rio Acima', 'Conceicao Do Rio Acima', '35968-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Rio Verde', 'Conceicao Do Rio Verde', '37430-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição dos Ouros', 'Conceicao Dos Ouros', '37548-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Concórdia de Mucuri', 'Concordia De Mucuri', '39826-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Condado do Norte', 'Condado Do Norte', '39435-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cônego João Pio', 'Conego Joao Pio', '35993-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cônego Marinho', 'Conego Marinho', '39489-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Confins', 'Confins', '33500-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Congonhal', 'Congonhal', '37557-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Congonhas', 'Congonhas', '36415-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Congonhas do Norte', 'Congonhas Do Norte', '35850-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conquista', 'Conquista', '38195-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conselheiro Lafaiete', 'Conselheiro Lafaiete', '36400-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conselheiro Mata', 'Conselheiro Mata', '39106-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conselheiro Pena', 'Conselheiro Pena', '35240-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Consolação', 'Consolacao', '37670-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Contagem', 'Contagem', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Contrato', 'Contrato', '39676-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Contria', 'Contria', '39202-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coqueiral', 'Coqueiral', '37235-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coração de Jesus', 'Coracao De Jesus', '39340-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cordisburgo', 'Cordisburgo', '35780-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cordislândia', 'Cordislandia', '37498-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corinto', 'Corinto', '39200-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coroaci', 'Coroaci', '39710-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coromandel', 'Coromandel', '38550-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Fabriciano', 'Coronel Fabriciano', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Murta', 'Coronel Murta', '39635-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Pacheco', 'Coronel Pacheco', '36155-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Xavier Chaves', 'Coronel Xavier Chaves', '36330-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córrego Danta', 'Corrego Danta', '38990-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córrego do Barro', 'Corrego Do Barro', '35665-200', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córrego do Bom Jesus', 'Corrego Do Bom Jesus', '37605-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córrego do Ouro', 'Corrego Do Ouro', '37163-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córrego Fundo', 'Corrego Fundo', '35578-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córrego Novo', 'Corrego Novo', '35345-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córregos', 'Corregos', '35864-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Correia de Almeida', 'Correia De Almeida', '36208-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Correntinho', 'Correntinho', '39741-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Costa Sena', 'Costa Sena', '35859-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Costas', 'Costas', '37665-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Costas da Mantiqueira', 'Costas Da Mantiqueira', '36206-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Couto de Magalhães de Minas', 'Couto De Magalhaes De Minas', '39188-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Crisólia', 'Crisolia', '37572-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Crisólita', 'Crisolita', '39885-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Crispim Jaques', 'Crispim Jaques', '39809-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristais', 'Cristais', '37275-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristália', 'Cristalia', '39598-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristiano Otoni', 'Cristiano Otoni', '36426-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristina', 'Cristina', '37476-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Crucilândia', 'Crucilandia', '35520-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzeiro da Fortaleza', 'Cruzeiro Da Fortaleza', '38735-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzeiro dos Peixotos', 'Cruzeiro Dos Peixotos', '38416-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzília', 'Cruzilia', '37445-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cubas', 'Cubas', '35806-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cuité Velho', 'Cuite Velho', '35242-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cuparaque', 'Cuparaque', '35246-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curimataí', 'Curimatai', '39235-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curral de Dentro', 'Curral De Dentro', '39998-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curvelo', 'Curvelo', '35790-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Datas', 'Datas', '39130-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Delfim Moreira', 'Delfim Moreira', '37514-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Delfinópolis', 'Delfinopolis', '37910-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Delta', 'Delta', '38108-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Deputado Augusto Clementino', 'Deputado Augusto Clementino', '39152-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Derribadinha', 'Derribadinha', '35103-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Descoberto', 'Descoberto', '36690-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Desembargador Otoni', 'Desembargador Otoni', '39113-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Desemboque', 'Desemboque', '38193-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Desterro de Entre Rios', 'Desterro De Entre Rios', '35494-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Desterro do Melo', 'Desterro Do Melo', '36210-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Diamante de Ubá', 'Diamante De Uba', '36506-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Diamantina', 'Diamantina', '39100-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dias', 'Dias', '37532-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dias Tavares/Siderúrgica', 'Dias Tavares/Siderurgica', '36105-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Diogo de Vasconcelos', 'Diogo De Vasconcelos', '35437-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dionísio', 'Dionisio', '35984-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divinésia', 'Divinesia', '36546-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divino', 'Divino', '36820-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divino das Laranjeiras', 'Divino Das Laranjeiras', '35265-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divino de Virgolândia', 'Divino De Virgolandia', '39716-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divino Espirito Santo', 'Divino Espirito Santo', '37147-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divinolândia de Minas', 'Divinolandia De Minas', '39735-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divinópolis', 'Divinopolis', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divisa Alegre', 'Divisa Alegre', '39995-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divisa Nova', 'Divisa Nova', '37134-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divisópolis', 'Divisopolis', '39912-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dois de Abril', 'Dois De Abril', '39948-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Bosco', 'Dom Bosco', '38654-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Cavati', 'Dom Cavati', '35148-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Joaquim', 'Dom Joaquim', '35865-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Lara', 'Dom Lara', '35314-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Modesto', 'Dom Modesto', '35313-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Silvério', 'Dom Silverio', '35440-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Viçoso', 'Dom Vicoso', '37474-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dona Euzébia', 'Dona Euzebia', '36784-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dores da Vitória', 'Dores Da Vitoria', '36792-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dores de Campos', 'Dores De Campos', '36213-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dores de Guanhães', 'Dores De Guanhaes', '35894-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dores do Indaiá', 'Dores Do Indaia', '35610-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dores do Paraibuna', 'Dores Do Paraibuna', '36243-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dores do Turvo', 'Dores Do Turvo', '36513-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doresópolis', 'Doresopolis', '37926-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Douradinho', 'Douradinho', '37755-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Douradoquara', 'Douradoquara', '38530-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doutor Campolina', 'Doutor Campolina', '35768-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doutor Lund', 'Doutor Lund', '33650-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Durandé', 'Durande', '36974-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Edgard Melo', 'Edgard Melo', '35122-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Elói Mendes', 'Eloi Mendes', '37110-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Emboabas', 'Emboabas', '36319-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro Caldas', 'Engenheiro Caldas', '35130-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro Correia', 'Engenheiro Correia', '35416-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro Navarro', 'Engenheiro Navarro', '39417-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro Schnoor', 'Engenheiro Schnoor', '39602-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenho do Ribeiro', 'Engenho Do Ribeiro', '35602-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenho Novo', 'Engenho Novo', '36643-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Entre Folhas', 'Entre Folhas', '35324-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Entre Rios de Minas', 'Entre Rios De Minas', '35490-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Epaminondas Otoni', 'Epaminondas Otoni', '39866-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ermidinha', 'Ermidinha', '39410-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ervália', 'Ervalia', '36555-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esmeraldas', 'Esmeraldas', '35740-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esmeraldas de Ferros', 'Esmeraldas De Ferros', '35804-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espera Feliz', 'Espera Feliz', '36830-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espinosa', 'Espinosa', '39510-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espírito Santo do Dourado', 'Espirito Santo Do Dourado', '37566-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esteios', 'Esteios', '35596-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estevão de Araújo', 'Estevao De Araujo', '36596-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estiva', 'Estiva', '37542-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrela da Barra', 'Estrela Da Barra', '38294-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrela Dalva', 'Estrela Dalva', '36725-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrela de Jordânia', 'Estrela De Jordania', '39923-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrela do Indaiá', 'Estrela Do Indaia', '35613-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrela do Sul', 'Estrela Do Sul', '38525-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eugenópolis', 'Eugenopolis', '36855-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Euxenita', 'Euxenita', '39751-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ewbank da Câmara', 'Ewbank Da Camara', '36108-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Expedicionário Alício', 'Expedicionario Alicio', '35204-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Extração', 'Extracao', '39105-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Extrema', 'Extrema', '37640-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fama', 'Fama', '37138-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faria Lemos', 'Faria Lemos', '36840-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Farias', 'Farias', '39744-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fechados', 'Fechados', '35788-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Felicina', 'Felicina', '35152-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Felício dos Santos', 'Felicio Dos Santos', '39180-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Felisburgo', 'Felisburgo', '39895-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Felixlândia', 'Felixlandia', '35794-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fernandes Tourinho', 'Fernandes Tourinho', '35135-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fernão Dias', 'Fernao Dias', '39334-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ferreiras', 'Ferreiras', '37493-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ferreirópolis', 'Ferreiropolis', '39562-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ferros', 'Ferros', '35800-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ferruginha', 'Ferruginha', '35245-500', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fervedouro', 'Fervedouro', '36815-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fidalgo', 'Fidalgo', '33620-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fidelândia', 'Fidelandia', '39851-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flor de Minas', 'Flor De Minas', '38315-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Florália', 'Floralia', '35961-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floresta', 'Floresta', '35263-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Florestal', 'Florestal', '35690-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Florestina', 'Florestina', '38450-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fonseca', 'Fonseca', '35955-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Formiga', 'Formiga', '35570-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Formoso', 'Formoso', '38690-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fortaleza de Minas', 'Fortaleza De Minas', '37905-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fortuna de Minas', 'Fortuna De Minas', '35760-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Francisco Badaró', 'Francisco Badaro', '39644-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Francisco Dumont', 'Francisco Dumont', '39387-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Francisco Sá', 'Francisco Sa', '39580-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Franciscópolis', 'Franciscopolis', '39695-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frei Eustáquio', 'Frei Eustaquio', '37237-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frei Gaspar', 'Frei Gaspar', '39840-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frei Inocêncio', 'Frei Inocencio', '35112-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frei Lagonegro', 'Frei Lagonegro', '39708-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frei Orlando', 'Frei Orlando', '35629-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frei Serafim', 'Frei Serafim', '39832-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Freire Cardoso', 'Freire Cardoso', '39637-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fronteira', 'Fronteira', '38230-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fronteira dos Vales', 'Fronteira Dos Vales', '39870-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fruta de Leite', 'Fruta De Leite', '39558-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frutal', 'Frutal', '38200-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Funchal', 'Funchal', '38802-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Funilândia', 'Funilandia', '35709-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Furnas', 'Furnas', '37943-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Furquim', 'Furquim', '35426-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Galego', 'Galego', '36206-100', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Galena', 'Galena', '38753-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Galiléia', 'Galileia', '35250-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gama', 'Gama', '35153-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gameleiras', 'Gameleiras', '39505-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Garapuava', 'Garapuava', '38615-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gavião', 'Gaviao', '36858-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Glaucilândia', 'Glaucilandia', '39592-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Glaura', 'Glaura', '35408-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Glucínio', 'Glucinio', '39782-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goiabeira', 'Goiabeira', '35248-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goianá', 'Goiana', '36152-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goianases', 'Goianases', '37994-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gonçalves', 'Goncalves', '37680-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gonzaga', 'Gonzaga', '39720-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gororós', 'Gororos', '35868-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gorutuba', 'Gorutuba', '39522-500', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gouvêa', 'Gouvea', '39120-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Valadares', 'Governador Valadares', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gramínea', 'Graminea', '37796-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Granada', 'Granada', '35365-700', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Grão Mogol', 'Grao Mogol', '39570-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Grota', 'Grota', '35395-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Grupiara', 'Grupiara', '38470-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaçuí', 'Guacui', '39265-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaipava', 'Guaipava', '37125-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guanhães', 'Guanhaes', '39740-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guapé', 'Guape', '37177-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraciaba', 'Guaraciaba', '35436-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraciama', 'Guaraciama', '39397-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaranésia', 'Guaranesia', '37810-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarani', 'Guarani', '36160-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaranilândia', 'Guaranilandia', '39965-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarará', 'Guarara', '36606-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarataia', 'Guarataia', '39833-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarda dos Ferreiros', 'Guarda Dos Ferreiros', '38803-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarda-Mor', 'Guarda-Mor', '38570-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guardinha', 'Guardinha', '37952-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaxima', 'Guaxima', '38198-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaxupé', 'Guaxupe', '37800-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guidoval', 'Guidoval', '36515-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guimarânia', 'Guimarania', '38730-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guinda', 'Guinda', '39103-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guiricema', 'Guiricema', '36525-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gurinhatã', 'Gurinhata', '38310-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Heliodora', 'Heliodora', '37484-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Hematita', 'Hematita', '35178-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Hermilo Alves', 'Hermilo Alves', '36285-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Honorópolis', 'Honoropolis', '38272-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iapu', 'Iapu', '35190-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibertioga', 'Ibertioga', '36225-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiá', 'Ibia', '38950-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiaí', 'Ibiai', '39350-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiracatu', 'Ibiracatu', '39455-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiraci', 'Ibiraci', '37990-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibirité', 'Ibirite', '32400-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitira', 'Ibitira', '35607-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitiúra de Minas', 'Ibitiura De Minas', '37790-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibituruna', 'Ibituruna', '37223-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Icaraí de Minas', 'Icarai De Minas', '39318-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igarapé', 'Igarape', '32900-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igaratinga', 'Igaratinga', '35695-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguatama', 'Iguatama', '38910-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ijaci', 'Ijaci', '37205-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilhéus do Prata', 'Ilheus Do Prata', '35994-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilicínea', 'Ilicinea', '37175-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Imbé de Minas', 'Imbe De Minas', '35323-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inconfidentes', 'Inconfidentes', '37576-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indaiabira', 'Indaiabira', '39536-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Independência', 'Independencia', '35236-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indianópolis', 'Indianopolis', '38490-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ingaí', 'Ingai', '37215-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhaí', 'Inhai', '39111-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhapim', 'Inhapim', '35330-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhaúma', 'Inhauma', '35710-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inimutaba', 'Inimutaba', '35796-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipaba', 'Ipaba', '35198-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipanema', 'Ipanema', '36950-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipatinga', 'Ipatinga', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipiaçu', 'Ipiacu', '38350-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipoema', 'Ipoema', '35905-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipuiúna', 'Ipuiuna', '37559-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iraí de Minas', 'Irai De Minas', '38510-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itabira', 'Itabira', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itabirinha de Mantena', 'Itabirinha De Mantena', '35280-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itabirito', 'Itabirito', '35450-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaboca', 'Itaboca', '36138-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itacambira', 'Itacambira', '39594-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itacarambi', 'Itacarambi', '39470-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaci', 'Itaci', '37155-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itacolomi', 'Itacolomi', '35861-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaguara', 'Itaguara', '35514-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaim', 'Itaim', '37546-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaipé', 'Itaipe', '39815-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itajubá', 'Itajuba', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itajutiba', 'Itajutiba', '35331-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamarandiba', 'Itamarandiba', '39670-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamarati', 'Itamarati', '39993-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamarati de Minas', 'Itamarati De Minas', '36788-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itambacuri', 'Itambacuri', '39830-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itambé do Mato Dentro', 'Itambe Do Mato Dentro', '35820-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamirim', 'Itamirim', '39515-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamogi', 'Itamogi', '37955-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamonte', 'Itamonte', '37466-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamuri', 'Itamuri', '36886-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itanhandu', 'Itanhandu', '37464-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itanhomi', 'Itanhomi', '35120-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaobim', 'Itaobim', '39625-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapagipe', 'Itapagipe', '38240-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapanhoacanga', 'Itapanhoacanga', '39145-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapecerica', 'Itapecerica', '35550-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapeva', 'Itapeva', '37655-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapiru', 'Itapiru', '39955-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapirucu', 'Itapirucu', '36756-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itatiaiuçu', 'Itatiaiucu', '35685-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaú de Minas', 'Itau De Minas', '37975-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaúna', 'Itauna', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itauninha', 'Itauninha', '35915-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaverava', 'Itaverava', '36440-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itererê', 'Iterere', '37513-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itinga', 'Itinga', '39610-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itira', 'Itira', '39605-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itueta', 'Itueta', '35220-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ituí', 'Itui', '36684-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ituiutaba', 'Ituiutaba', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itumirim', 'Itumirim', '37210-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iturama', 'Iturama', '38280-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itutinga', 'Itutinga', '36390-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaboticatubas', 'Jaboticatubas', '35830-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacarandira', 'Jacarandira', '36342-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacaré', 'Jacare', '39613-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacinto', 'Jacinto', '39930-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacuí', 'Jacui', '37965-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacutinga', 'Jacutinga', '37590-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguaraçu', 'Jaguaracu', '35188-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguarão', 'Jaguarao', '39933-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguaritira', 'Jaguaritira', '39692-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaíba', 'Jaiba', '39508-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jampruca', 'Jampruca', '39837-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Janaúba', 'Janauba', '39440-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Januária', 'Januaria', '39480-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japaraíba', 'Japaraiba', '35580-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japonvar', 'Japonvar', '39335-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardinésia', 'Jardinesia', '38142-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jeceaba', 'Jeceaba', '35498-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jenipapo de Minas', 'Jenipapo De Minas', '39645-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jequeri', 'Jequeri', '35390-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jequitaí', 'Jequitai', '39370-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jequitibá', 'Jequitiba', '35767-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jequitinhonha', 'Jequitinhonha', '39960-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jesuânia', 'Jesuania', '37485-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joaíma', 'Joaima', '39890-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joanésia', 'Joanesia', '35168-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Monlevade', 'Joao Monlevade', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Pinheiro', 'Joao Pinheiro', '38770-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joaquim Felício', 'Joaquim Felicio', '39240-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jordânia', 'Jordania', '39920-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Patrocínio', 'Patrocinio', '38740-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('José Gonçalves de Minas', 'Jose Goncalves De Minas', '39642-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('José Raydan', 'Jose Raydan', '39775-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joselândia', 'Joselandia', '36435-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Josenópolis', 'Josenopolis', '39575-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juatuba', 'Juatuba', '35675-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jubaí', 'Jubai', '38196-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juiraçu', 'Juiracu', '35996-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juiz de Fora', 'Juiz De Fora', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Junco de Minas', 'Junco De Minas', '39693-500', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juramento', 'Juramento', '39590-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juréia', 'Jureia', '37117-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juruaia', 'Juruaia', '37805-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jurumirim', 'Jurumirim', '35375-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Justinópolis', 'Justinopolis', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juvenília', 'Juvenilia', '39467-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lacerdinha', 'Lacerdinha', '36802-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ladainha', 'Ladainha', '39825-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagamar', 'Lagamar', '38785-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Bonita', 'Lagoa Bonita', '35782-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa da Prata', 'Lagoa Da Prata', '35590-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa dos Patos', 'Lagoa Dos Patos', '39360-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Dourada', 'Lagoa Dourada', '36345-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Formosa', 'Lagoa Formosa', '38720-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Grande', 'Lagoa Grande', '38755-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Santa', 'Lagoa Santa', '33400-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajinha', 'Lajinha', '36980-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lambari', 'Lambari', '37480-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lamim', 'Lamim', '36455-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lamounier', 'Lamounier', '35551-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lapinha', 'Lapinha', '33450-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laranjal', 'Laranjal', '36760-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laranjeiras de Caldas', 'Laranjeiras De Caldas', '37782-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lassance', 'Lassance', '39250-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lavras', 'Lavras', '37200-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Leandro Ferreira', 'Leandro Ferreira', '35657-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Leme do Prado', 'Leme Do Prado', '39655-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Leopoldina', 'Leopoldina', '36700-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Levinópolis', 'Levinopolis', '39485-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Liberdade', 'Liberdade', '37350-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lima Duarte', 'Lima Duarte', '36140-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Limeira D''Oeste', 'Limeira D''Oeste', '38295-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Limeira de Mantena', 'Limeira De Mantena', '35296-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lobo Leite', 'Lobo Leite', '36419-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lontra', 'Lontra', '39437-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lourenço Velho', 'Lourenco Velho', '37507-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lufa', 'Lufa', '39824-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luisburgo', 'Luisburgo', '36923-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luislândia', 'Luislandia', '39336-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luiz Pires de Minas', 'Luiz Pires De Minas', '39344-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luizlândia do Oeste', 'Luizlandia Do Oeste', '38776-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luminárias', 'Luminarias', '37240-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luminosa', 'Luminosa', '37535-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luz', 'Luz', '35595-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macaia', 'Macaia', '37221-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Machacalis', 'Machacalis', '39873-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Machado', 'Machado', '37750-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macuco', 'Macuco', '36891-500', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macuco de Minas', 'Macuco De Minas', '37212-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Madre de Deus de Minas', 'Madre De Deus De Minas', '37305-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mãe dos Homens', 'Mae Dos Homens', '39797-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Major Ezequiel', 'Major Ezequiel', '35953-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Major Porto', 'Major Porto', '38710-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Malacacheta', 'Malacacheta', '39690-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mamonas', 'Mamonas', '39516-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manga', 'Manga', '39460-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manhuaçu', 'Manhuacu', '36900-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manhumirim', 'Manhumirim', '36970-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mantena', 'Mantena', '35290-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mantiqueira', 'Mantiqueira', '36242-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mantiqueira do Palmital', 'Mantiqueira Do Palmital', '36206-300', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mar de Espanha', 'Mar De Espanha', '36640-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marambainha', 'Marambainha', '39813-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maravilhas', 'Maravilhas', '35666-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maria da Fé', 'Maria Da Fe', '37517-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mariana', 'Mariana', '35420-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marilac', 'Marilac', '35115-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marilândia', 'Marilandia', '35553-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mário Campos', 'Mario Campos', '32470-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maripá de Minas', 'Maripa De Minas', '36608-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marliéria', 'Marlieria', '35185-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marmelópolis', 'Marmelopolis', '37516-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Martinésia', 'Martinesia', '38419-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Martinho Campos', 'Martinho Campos', '35606-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Martins Guimarães', 'Martins Guimaraes', '35593-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Martins Soares', 'Martins Soares', '36972-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mata Verde', 'Mata Verde', '39915-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Materlândia', 'Materlandia', '39755-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mateus Leme', 'Mateus Leme', '35670-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mathias Lobato', 'Mathias Lobato', '35110-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matias Barbosa', 'Matias Barbosa', '36120-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matias Cardoso', 'Matias Cardoso', '39478-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matipó', 'Matipo', '35367-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mato Verde', 'Mato Verde', '39527-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matozinhos', 'Matozinhos', '35720-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matutina', 'Matutina', '38870-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Medeiros', 'Medeiros', '38930-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Medina', 'Medina', '39620-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Melo Viana', 'Melo Viana', '35750-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mendanha', 'Mendanha', '39101-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mendes Pimentel', 'Mendes Pimentel', '35270-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mendonça', 'Mendonca', '39664-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mercês', 'Merces', '36190-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mercês de Água Limpa', 'Merces De Agua Limpa', '36352-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mesquita', 'Mesquita', '35166-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mestre Caetano', 'Mestre Caetano', '34750-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miguel Burnier', 'Miguel Burnier', '35414-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Milagre', 'Milagre', '37959-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Milho Verde', 'Milho Verde', '39155-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Minas Novas', 'Minas Novas', '39650-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Minduri', 'Minduri', '37447-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirabela', 'Mirabela', '39420-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miradouro', 'Miradouro', '36893-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miragaia', 'Miragaia', '36507-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miraí', 'Mirai', '36790-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miralta', 'Miralta', '39415-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirantão', 'Mirantao', '37345-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miraporanga', 'Miraporanga', '38418-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miravânia', 'Miravania', '39465-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Missionário', 'Missionario', '36262-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mocambeiro', 'Mocambeiro', '35725-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mocambinho', 'Mocambinho', '39524-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moeda', 'Moeda', '35470-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moema', 'Moema', '35604-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Alegre', 'Vista Alegre', '36778-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monjolinho de Minas', 'Monjolinho De Minas', '38722-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monjolos', 'Monjolos', '39215-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monsenhor Horta', 'Monsenhor Horta', '35425-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monsenhor Isidro', 'Monsenhor Isidro', '36445-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monsenhor João Alexandre', 'Monsenhor Joao Alexandre', '35532-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monsenhor Paulo', 'Monsenhor Paulo', '37405-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montalvânia', 'Montalvania', '39495-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre de Minas', 'Monte Alegre De Minas', '38420-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Azul', 'Monte Azul', '39500-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Belo', 'Monte Belo', '37115-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Carmelo', 'Monte Carmelo', '38500-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Celeste', 'Monte Celeste', '36532-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Formoso', 'Monte Formoso', '39893-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Rei', 'Monte Rei', '39468-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Santo de Minas', 'Monte Santo De Minas', '37958-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Sião', 'Monte Siao', '37580-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Verde', 'Monte Verde', '37653-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montes Claros', 'Montes Claros', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montezuma', 'Montezuma', '39547-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morada Nova de Minas', 'Morada Nova De Minas', '35628-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro', 'Morro', '39313-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro da Garça', 'Morro Da Garca', '35798-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro do Ferro', 'Morro Do Ferro', '35541-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro do Pilar', 'Morro Do Pilar', '35875-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro Vermelho', 'Morro Vermelho', '34940-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mucuri', 'Mucuri', '39809-800', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mundo Novo de Minas', 'Mundo Novo De Minas', '35208-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Munhoz', 'Munhoz', '37620-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muquém', 'Muquem', '39423-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muriaé', 'Muriae', '36880-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mutum', 'Mutum', '36955-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muzambinho', 'Muzambinho', '37890-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nacip Raydan', 'Nacip Raydan', '39718-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nanuque', 'Nanuque', '39860-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Naque', 'Naque', '35157-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Naque-Nanuque', 'Naque-Nanuque', '35149-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Natalândia', 'Natalandia', '38658-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Natércia', 'Natercia', '37524-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nazaré de Minas', 'Nazare De Minas', '37253-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nazareno', 'Nazareno', '36370-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nelson de Sena', 'Nelson De Sena', '39706-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Neolândia', 'Neolandia', '35552-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nepomuceno', 'Nepomuceno', '37250-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nhandutiba', 'Nhandutiba', '39463-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nicolândia', 'Nicolandia', '35235-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ninheira', 'Ninheira', '39553-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Belém', 'Nova Belem', '35298-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Era', 'Nova Era', '35920-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Esperança', 'Nova Esperanca', '39414-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Lima', 'Nova Lima', '34000-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Minda', 'Nova Minda', '39335-700', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Módica', 'Nova Modica', '35113-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Ponte', 'Nova Ponte', '38160-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Porteirinha', 'Nova Porteirinha', '39525-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Resende', 'Nova Resende', '37860-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Serrana', 'Nova Serrana', '35519-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova União', 'Nova Uniao', '34990-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novilhona', 'Novilhona', '39821-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Cruzeiro', 'Novo Cruzeiro', '39820-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Horizonte', 'Novo Horizonte', '39853-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Oriente de Minas', 'Novo Oriente De Minas', '39817-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novorizonte', 'Novorizonte', '39568-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ocidente', 'Ocidente', '36959-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olaria', 'Olaria', '36145-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olegário Maciel', 'Olegario Maciel', '37509-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olhos D'' Água do Oeste', 'Olhos D'' Agua Do Oeste', '38772-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olhos D'' Água', 'Olhos D'' Agua', '39398-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olímpio Campos', 'Olimpio Campos', '39433-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olímpio Noronha', 'Olimpio Noronha', '37488-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oliveira', 'Oliveira', '35540-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oliveira Fortes', 'Oliveira Fortes', '36250-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Onça de Pitangui', 'Onca De Pitangui', '35655-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oratórios', 'Oratorios', '35439-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Orizânia', 'Orizania', '36828-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Branco', 'Ouro Branco', '36420-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Fino', 'Ouro Fino', '37570-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Preto', 'Ouro Preto', '35400-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Verde de Minas', 'Ouro Verde De Minas', '39855-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paciência', 'Paciencia', '39524-500', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Brito', 'Padre Brito', '36209-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Carvalho', 'Padre Carvalho', '39573-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Felisberto', 'Padre Felisberto', '35445-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Fialho', 'Padre Fialho', '35367-700', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre João Afonso', 'Padre Joao Afonso', '39672-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Júlio Maria', 'Padre Julio Maria', '36978-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Paraíso', 'Padre Paraiso', '39818-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Pinto', 'Padre Pinto', '35945-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Viegas', 'Padre Viegas', '35422-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pai Pedro', 'Pai Pedro', '39517-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paineiras', 'Paineiras', '35622-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pains', 'Pains', '35582-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paiolinho', 'Paiolinho', '37758-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paiva', 'Paiva', '36195-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palma', 'Palma', '36750-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeiral', 'Palmeiral', '37725-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeirinha', 'Palmeirinha', '38613-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmital dos Carvalhos', 'Palmital Dos Carvalhos', '36278-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmópolis', 'Palmopolis', '39945-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pântano', 'Pantano', '37543-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Papagaios', 'Papagaios', '35669-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pará de Minas', 'Para De Minas', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paracatu', 'Paracatu', '38600-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraguaçu', 'Paraguacu', '37120-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraguai', 'Paraguai', '36565-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraíso Garcia', 'Paraiso Garcia', '36236-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraisópolis', 'Paraisopolis', '37660-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraopeba', 'Paraopeba', '35774-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paredão de Minas', 'Paredao De Minas', '39285-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parque Durval de Barros', 'Parque Durval De Barros', '32440-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parque Industrial', 'Parque Industrial', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passa Dez', 'Passa Dez', '35343-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passa Quatro', 'Passa Quatro', '37460-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passa Tempo', 'Passa Tempo', '35537-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passa Vinte', 'Passa Vinte', '37330-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passabém', 'Passabem', '35810-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passagem de Mariana', 'Passagem De Mariana', '35421-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passos', 'Passos', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Patis', 'Patis', '39425-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Patos de Minas', 'Patos De Minas', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Patrimônio', 'Patrimonio', '38145-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Patrocínio do Muriaé', 'Patrocinio Do Muriae', '36860-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paula Cândido', 'Paula Candido', '36544-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paula Lima', 'Paula Lima', '36103-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulistas', 'Paulistas', '39765-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pavão', 'Pavao', '39814-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pé do Morro', 'Pe Do Morro', '37462-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Peçanha', 'Pecanha', '39700-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Azul', 'Pedra Azul', '39970-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Bonita', 'Pedra Bonita', '35364-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Corrida', 'Pedra Corrida', '35155-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra do Anta', 'Pedra Do Anta', '36585-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra do Indaiá', 'Pedra Do Indaia', '35565-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra do Sino', 'Pedra Do Sino', '36282-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Dourada', 'Pedra Dourada', '36847-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Grande', 'Pedra Grande', '39910-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Menina', 'Pedra Menina', '39175-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedralva', 'Pedralva', '37520-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedras de Maria da Cruz', 'Pedras De Maria Da Cruz', '39492-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedrinópolis', 'Pedrinopolis', '38178-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Leopoldo', 'Pedro Leopoldo', '33600-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Lessa', 'Pedro Lessa', '39158-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Teixeira', 'Pedro Teixeira', '36148-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Versiani', 'Pedro Versiani', '39809-300', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Penédia', 'Penedia', '34930-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Penha de França', 'Penha De Franca', '39675-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Penha do Capim', 'Penha Do Capim', '35212-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Penha do Cassiano', 'Penha Do Cassiano', '35107-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Penha do Norte', 'Penha Do Norte', '35241-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Penha Longa', 'Penha Longa', '36635-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pequeri', 'Pequeri', '36610-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pequi', 'Pequi', '35667-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Perdigão', 'Perdigao', '35515-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Perdilândia', 'Perdilandia', '38328-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Perdizes', 'Perdizes', '38170-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Perdões', 'Perdoes', '37260-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pereirinhas', 'Pereirinhas', '35492-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Periquito', 'Periquito', '35156-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Perpétuo Socorro', 'Perpetuo Socorro', '35196-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pescador', 'Pescador', '35114-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Petúnia', 'Petunia', '37865-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piacatuba', 'Piacatuba', '36708-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pião', 'Piao', '37776-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piau', 'Piau', '36157-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pic Sagarana', 'Pic Sagarana', '38686-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piedade de Caratinga', 'Piedade De Caratinga', '35325-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piedade de Ponte Nova', 'Piedade De Ponte Nova', '35382-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piedade do Paraopeba', 'Piedade Do Paraopeba', '35464-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piedade do Rio Grande', 'Piedade Do Rio Grande', '36227-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piedade dos Gerais', 'Piedade Dos Gerais', '35526-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pilar', 'Pilar', '38717-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pimenta', 'Pimenta', '35585-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pindaíbas', 'Pindaibas', '38715-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pingo-D''Água', 'Pingo-D''Agua', '35348-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinheirinhos', 'Pinheirinhos', '37461-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinheiros Altos', 'Pinheiros Altos', '36490-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhotiba', 'Pinhotiba', '36857-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pintópolis', 'Pintopolis', '39317-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pintos Negreiros', 'Pintos Negreiros', '37518-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piracaiba', 'Piracaiba', '38452-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piracema', 'Piracema', '35536-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirajuba', 'Pirajuba', '38210-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piranga', 'Piranga', '36480-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piranguçu', 'Pirangucu', '37511-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piranguinho', 'Piranguinho', '37508-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piranguita', 'Piranguita', '36462-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirapanema', 'Pirapanema', '36889-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirapetinga', 'Pirapetinga', '36730-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirapora', 'Pirapora', '39270-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piraúba', 'Pirauba', '36170-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pires e Albuquerque', 'Pires E Albuquerque', '39394-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piscamba', 'Piscamba', '35393-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pitangui', 'Pitangui', '35650-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pitarana', 'Pitarana', '39498-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piumhi', 'Piumhi', '37925-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planalto de Minas', 'Planalto De Minas', '39114-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planura', 'Planura', '38220-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Plautino Soares', 'Plautino Soares', '35144-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poaia', 'Poaia', '39783-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço Fundo', 'Poco Fundo', '37757-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poções de Paineiras', 'Pocoes De Paineiras', '35623-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poços de Caldas', 'Pocos De Caldas', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pocrane', 'Pocrane', '36960-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pompéu', 'Pompeu', '35640-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poncianos', 'Poncianos', '38126-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontalete', 'Pontalete', '37192-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte Alta', 'Ponte Alta', '38106-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte Alta de Minas', 'Ponte Alta De Minas', '36805-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte dos Ciganos', 'Ponte Dos Ciganos', '39343-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte Firme', 'Ponte Firme', '38754-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte Nova', 'Ponte Nova', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte Segura', 'Ponte Segura', '37618-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontevila', 'Pontevila', '35577-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponto Chique', 'Ponto Chique', '39328-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponto Chique do Martelo', 'Ponto Chique Do Martelo', '36206-500', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponto do Marambaia', 'Ponto Do Marambaia', '39812-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponto dos Volantes', 'Ponto Dos Volantes', '39615-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porteirinha', 'Porteirinha', '39520-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Agrário', 'Porto Agrario', '39469-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto das Flores', 'Porto Das Flores', '36128-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto dos Mendes', 'Porto Dos Mendes', '37271-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Firme', 'Porto Firme', '36576-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poté', 'Pote', '39827-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pouso Alegre', 'Pouso Alegre', '37550-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pouso Alto', 'Pouso Alto', '37468-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prados', 'Prados', '36320-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prata', 'Prata', '38140-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pratápolis', 'Pratapolis', '37970-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pratinha', 'Pratinha', '38960-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Bernardes', 'Presidente Bernardes', '36475-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Juscelino', 'Presidente Juscelino', '35797-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Kubitschek', 'Presidente Kubitschek', '39135-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Olegário', 'Presidente Olegario', '38750-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Pena', 'Presidente Pena', '39865-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Professor Sperber', 'Professor Sperber', '36988-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Providência', 'Providencia', '36706-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prudente de Morais', 'Prudente De Morais', '35715-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quartel de São João', 'Quartel De Sao Joao', '35626-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quartel do Sacramento', 'Quartel Do Sacramento', '35342-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quartel Geral', 'Quartel Geral', '35625-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quatituba', 'Quatituba', '35222-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Queixada', 'Queixada', '39823-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Queluzita', 'Queluzita', '36424-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quem-Quem', 'Quem-Quem', '39443-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quilombo', 'Quilombo', '39753-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quintinos', 'Quintinos', '38845-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Raposos', 'Raposos', '34400-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Raul Soares', 'Raul Soares', '35350-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ravena', 'Ravena', '34740-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Realeza', 'Realeza', '36905-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Recreio', 'Recreio', '36740-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Reduto', 'Reduto', '36920-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Resende Costa', 'Resende Costa', '36340-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Resplendor', 'Resplendor', '35230-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ressaquinha', 'Ressaquinha', '36270-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riachinho', 'Riachinho', '38640-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho da Cruz', 'Riacho Da Cruz', '39483-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho dos Machados', 'Riacho Dos Machados', '39529-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão das Neves', 'Ribeirao Das Neves', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão de São Domingos', 'Ribeirao De Sao Domingos', '36915-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão Vermelho', 'Ribeirao Vermelho', '37264-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeiro Junqueira', 'Ribeiro Junqueira', '36707-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeiros', 'Ribeiros', '37492-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Acima', 'Rio Acima', '34300-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Casca', 'Rio Casca', '35370-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio das Mortes', 'Rio Das Mortes', '36315-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio do Prado', 'Rio Do Prado', '39940-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Doce', 'Rio Doce', '35442-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Espera', 'Rio Espera', '36460-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Manso', 'Rio Manso', '35525-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Melo', 'Rio Melo', '36465-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Novo', 'Rio Novo', '36150-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Paranaíba', 'Rio Paranaiba', '38810-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Pardo de Minas', 'Rio Pardo De Minas', '39530-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Piracicaba', 'Rio Piracicaba', '35940-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Pomba', 'Rio Pomba', '36180-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Pretinho', 'Rio Pretinho', '39808-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Preto', 'Rio Preto', '36130-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Vermelho', 'Rio Vermelho', '39170-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ritápolis', 'Ritapolis', '36335-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Roça Grande', 'Roca Grande', '36682-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Roças Novas', 'Rocas Novas', '34950-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rochedo de Minas', 'Rochedo De Minas', '36604-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rodeador', 'Rodeador', '39218-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rodeiro', 'Rodeiro', '36510-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rodrigo Silva', 'Rodrigo Silva', '35407-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Romaria', 'Romaria', '38520-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rosário da Limeira', 'Rosario Da Limeira', '36878-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rosário de Minas', 'Rosario De Minas', '36106-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rosário do Pontal', 'Rosario Do Pontal', '35435-500', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Roseiral', 'Roseiral', '36958-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rubelita', 'Rubelita', '39565-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rubim', 'Rubim', '39950-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sabinópolis', 'Sabinopolis', '39750-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sacramento', 'Sacramento', '38190-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salinas', 'Salinas', '39560-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salitre de Minas', 'Salitre De Minas', '38743-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salto da Divisa', 'Salto Da Divisa', '39925-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sanatório Santa Fé', 'Sanatorio Santa Fe', '37412-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Bárbara', 'Santa Barbara', '35960-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Bárbara do Leste', 'Santa Barbara Do Leste', '35328-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Bárbara do Monte Verde', 'Santa Barbara Do Monte Verde', '36132-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Bárbara do Tugúrio', 'Santa Barbara Do Tugurio', '36215-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz da Aparecida', 'Santa Cruz Da Aparecida', '37119-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz de Botumirim', 'Santa Cruz De Botumirim', '39595-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz de Minas', 'Santa Cruz De Minas', '36328-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz de Salinas', 'Santa Cruz De Salinas', '39563-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz do Escalvado', 'Santa Cruz Do Escalvado', '35384-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz do Prata', 'Santa Cruz Do Prata', '37815-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa da Pedra', 'Santa Da Pedra', '39368-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Efigênia', 'Santa Efigenia', '35319-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Efigênia de Minas', 'Santa Efigenia De Minas', '39725-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Fé de Minas', 'Santa Fe De Minas', '39295-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Filomena', 'Santa Filomena', '36945-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Helena de Minas', 'Santa Helena De Minas', '39874-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Isabel', 'Santa Isabel', '32850-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Juliana', 'Santa Juliana', '38175-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia', 'Santa Luzia', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia da Serra', 'Santa Luzia Da Serra', '38774-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Margarida', 'Santa Margarida', '36910-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria de Itabira', 'Santa Maria De Itabira', '35910-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria do Salto', 'Santa Maria Do Salto', '39928-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria do Suaçuí', 'Santa Maria Do Suacui', '39780-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita da Estrela', 'Santa Rita Da Estrela', '38526-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita de Caldas', 'Santa Rita De Caldas', '37775-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita de Jacutinga', 'Santa Rita De Jacutinga', '36135-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita de Minas', 'Santa Rita De Minas', '35326-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita de Ouro Preto', 'Santa Rita De Ouro Preto', '35409-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita do Cedro', 'Santa Rita Do Cedro', '35791-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita do Ibitipoca', 'Santa Rita Do Ibitipoca', '36235-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita do Itueto', 'Santa Rita Do Itueto', '35225-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita do Rio do Peixe', 'Santa Rita Do Rio Do Peixe', '35807-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita do Sapucaí', 'Santa Rita Do Sapucai', '37540-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita Durão', 'Santa Rita Durao', '35428-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa da Serra', 'Santa Rosa Da Serra', '38805-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa de Lima', 'Santa Rosa De Lima', '39412-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa dos Dourados', 'Santa Rosa Dos Dourados', '38555-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Teresa do Bonito', 'Santa Teresa Do Bonito', '39702-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha de Minas', 'Santa Terezinha De Minas', '35688-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Vitória', 'Santa Vitoria', '38320-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana da Vargem', 'Santana Da Vargem', '37195-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana de Caldas', 'Santana De Caldas', '37785-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana de Cataguases', 'Santana De Cataguases', '36795-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana de Patos', 'Santana De Patos', '38711-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana de Pirapama', 'Santana De Pirapama', '35785-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Alfié', 'Santana Do Alfie', '35997-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Araçuaí', 'Santana Do Aracuai', '39618-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Campestre', 'Santana Do Campestre', '36783-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Capivari', 'Santana Do Capivari', '37469-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Deserto', 'Santana Do Deserto', '36620-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Garambéu', 'Santana Do Garambeu', '36146-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Jacaré', 'Santana Do Jacare', '37278-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Manhuaçu', 'Santana Do Manhuacu', '36940-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Paraíso', 'Santana Do Paraiso', '35167-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Paraopeba', 'Santana Do Paraopeba', '35475-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Riacho', 'Santana Do Riacho', '35845-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Tabuleiro', 'Santana Do Tabuleiro', '35358-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana dos Montes', 'Santana Dos Montes', '36430-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio da Boa Vista', 'Santo Antonio Da Boa Vista', '39434-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio da Fortaleza', 'Santo Antonio Da Fortaleza', '35801-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio da Vargem Alegre', 'Santo Antonio Da Vargem Alegre', '35522-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Amparo', 'Santo Antonio Do Amparo', '37262-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Aventureiro', 'Santo Antonio Do Aventureiro', '36670-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Boqueirão', 'Santo Antonio Do Boqueirao', '38620-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Cruzeiro', 'Santo Antonio Do Cruzeiro', '37255-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Glória', 'Santo Antonio Do Gloria', '36897-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Grama', 'Santo Antonio Do Grama', '35388-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Itambé', 'Santo Antonio Do Itambe', '39160-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Jacinto', 'Santo Antonio Do Jacinto', '39935-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Leite', 'Santo Antonio Do Leite', '35413-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Manhuaçu', 'Santo Antonio Do Manhuacu', '35321-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Monte', 'Santo Antonio Do Monte', '35560-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Mucuri', 'Santo Antonio Do Mucuri', '39691-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Norte', 'Santo Antonio Do Norte', '35863-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Pirapetinga', 'Santo Antonio Do Pirapetinga', '36485-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Retiro', 'Santo Antonio Do Retiro', '39538-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Rio Abaixo', 'Santo Antonio Do Rio Abaixo', '35880-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio dos Araújos', 'Santo Antonio Dos Araujos', '39796-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio dos Campos', 'Santo Antonio Dos Campos', '35505-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Hilário', 'Santo Hilario', '35586-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Hipólito', 'Santo Hipolito', '39210-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santos Dumont', 'Santos Dumont', '36240-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bartolomeu', 'Sao Bartolomeu', '35406-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Benedito', 'Sao Benedito', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bento Abade', 'Sao Bento Abade', '37414-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bento de Caldas', 'Sao Bento De Caldas', '37778-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Brás do Suaçuí', 'Sao Bras Do Suacui', '35495-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Braz', 'Sao Braz', '38788-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Cândido', 'Sao Candido', '35320-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos', 'Sao Domingos', '36675-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos da Bocaina', 'Sao Domingos Da Bocaina', '36142-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos das Dores', 'Sao Domingos Das Dores', '35335-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos do Prata', 'Sao Domingos Do Prata', '35995-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Félix de Minas', 'Sao Felix De Minas', '35275-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco', 'Sao Francisco', '39300-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco de Paula', 'Sao Francisco De Paula', '35543-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco de Sales', 'Sao Francisco De Sales', '38260-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco do Glória', 'Sao Francisco Do Gloria', '36810-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco do Humaitá', 'Sao Francisco Do Humaita', '36956-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Geraldo', 'Sao Geraldo', '36530-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Geraldo', 'Sao Geraldo', '39342-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Geraldo da Piedade', 'Sao Geraldo Da Piedade', '39723-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Geraldo de Tumiritinga', 'Sao Geraldo De Tumiritinga', '35126-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Geraldo do Baguari', 'Sao Geraldo Do Baguari', '39704-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Geraldo do Baixio', 'Sao Geraldo Do Baixio', '35258-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo de Botelhos', 'Sao Goncalo De Botelhos', '37723-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo do Abaeté', 'Sao Goncalo Do Abaete', '38790-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo do Monte', 'Sao Goncalo Do Monte', '35455-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo do Pará', 'Sao Goncalo Do Para', '35516-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo do Rio Abaixo', 'Sao Goncalo Do Rio Abaixo', '35935-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo do Rio das Pedras', 'Sao Goncalo Do Rio Das Pedras', '39153-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo do Rio Preto', 'Sao Goncalo Do Rio Preto', '39185-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo do Sapucaí', 'Sao Goncalo Do Sapucai', '37490-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gotardo', 'Sao Gotardo', '38800-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Jerônimo dos Poções', 'Sao Jeronimo Dos Pocoes', '38975-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João Batista do Glória', 'Sao Joao Batista Do Gloria', '37920-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Chapada', 'Sao Joao Da Chapada', '39110-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Lagoa', 'Sao Joao Da Lagoa', '39355-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Mata', 'Sao Joao Da Mata', '37568-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Ponte', 'Sao Joao Da Ponte', '39430-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Sapucaia', 'Sao Joao Da Sapucaia', '36765-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Serra', 'Sao Joao Da Serra', '36245-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Serra Negra', 'Sao Joao Da Serra Negra', '38748-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Vereda', 'Sao Joao Da Vereda', '39413-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João das Missões', 'Sao Joao Das Missoes', '39475-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João Del Rei', 'Sao Joao Del Rei', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Bonito', 'Sao Joao Do Bonito', '39528-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Jacutinga', 'Sao Joao Do Jacutinga', '35322-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Manhuaçu', 'Sao Joao Do Manhuacu', '36918-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Manteninha', 'Sao Joao Do Manteninha', '35277-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Oriente', 'Sao Joao Do Oriente', '35146-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Pacuí', 'Sao Joao Do Pacui', '39365-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Paraíso', 'Sao Joao Do Paraiso', '39540-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João Evangelista', 'Sao Joao Evangelista', '39705-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João Nepomuceno', 'Sao Joao Nepomuceno', '36680-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim', 'Sao Joaquim', '39348-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim', 'Sao Joaquim', '39488-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim de Bicas', 'Sao Joaquim De Bicas', '32920-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Barra', 'Sao Jose Da Barra', '37945-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Bela Vista', 'Sao Jose Da Bela Vista', '38804-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Lapa', 'Sao Jose Da Lapa', '33350-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Pedra Menina', 'Sao Jose Da Pedra Menina', '36831-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Safira', 'Sao Jose Da Safira', '39785-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Varginha', 'Sao Jose Da Varginha', '35694-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José das Tronqueiras', 'Sao Jose Das Tronqueiras', '35108-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Acácio', 'Sao Jose Do Acacio', '35133-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Alegre', 'Sao Jose Do Alegre', '37510-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Barreiro', 'Sao Jose Do Barreiro', '37927-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Batatal', 'Sao Jose Do Batatal', '35339-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Buriti', 'Sao Jose Do Buriti', '35795-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Divino', 'Sao Jose Do Divino', '39848-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Goiabal', 'Sao Jose Do Goiabal', '35986-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Itueto', 'Sao Jose Do Itueto', '35228-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Jacuri', 'Sao Jose Do Jacuri', '39707-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Mantimento', 'Sao Jose Do Mantimento', '36990-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Mato Dentro', 'Sao Jose Do Mato Dentro', '37574-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Pântano', 'Sao Jose Do Pantano', '37549-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Paraopeba', 'Sao Jose Do Paraopeba', '35468-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José dos Lopes', 'Sao Jose Dos Lopes', '36141-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José dos Salgados', 'Sao Jose Dos Salgados', '35512-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Lourenço', 'Sao Lourenco', '37470-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Manoel do Guaiaçu', 'Sao Manoel Do Guaiacu', '36787-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Mateus de Minas', 'Sao Mateus De Minas', '37652-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel do Anta', 'Sao Miguel Do Anta', '36590-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro da Garça', 'Sao Pedro Da Garca', '39411-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro da União', 'Sao Pedro Da Uniao', '37855-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro das Tabocas', 'Sao Pedro Das Tabocas', '39494-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro de Caldas', 'Sao Pedro De Caldas', '37787-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro do Avaí', 'Sao Pedro Do Avai', '36906-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro do Glória', 'Sao Pedro Do Gloria', '36819-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro do Jequitinhonha', 'Sao Pedro Do Jequitinhonha', '39961-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro do Suaçuí', 'Sao Pedro Do Suacui', '39784-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro dos Ferros', 'Sao Pedro Dos Ferros', '35360-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Roberto', 'Sao Roberto', '39358-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Romão', 'Sao Romao', '39290-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Roque de Minas', 'Sao Roque De Minas', '37928-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião da Barra', 'Sao Sebastiao Da Barra', '35192-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião da Bela Vista', 'Sao Sebastiao Da Bela Vista', '37567-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião da Vala', 'Sao Sebastiao Da Vala', '35215-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião da Vargem Alegre', 'Sao Sebastiao Da Vargem Alegre', '36793-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião da Vitória', 'Sao Sebastiao Da Vitoria', '36316-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião de Braúnas', 'Sao Sebastiao De Braunas', '35197-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Anta', 'Sao Sebastiao Do Anta', '35334-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Baixio', 'Sao Sebastiao Do Baixio', '35154-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Barreado', 'Sao Sebastiao Do Barreado', '36131-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Barreiro', 'Sao Sebastiao Do Barreiro', '39839-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Bonsucesso', 'Sao Sebastiao Do Bonsucesso', '35862-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Bugre', 'Sao Sebastiao Do Bugre', '39712-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Gil', 'Sao Sebastiao Do Gil', '35493-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Maranhão', 'Sao Sebastiao Do Maranhao', '39795-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Óculo', 'Sao Sebastiao Do Oculo', '35356-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Oeste', 'Sao Sebastiao Do Oeste', '35506-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Paraíso', 'Sao Sebastiao Do Paraiso', '37950-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Pontal', 'Sao Sebastiao Do Pontal', '38292-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Rio Preto', 'Sao Sebastiao Do Rio Preto', '35815-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Rio Verde', 'Sao Sebastiao Do Rio Verde', '37467-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Sacramento', 'Sao Sebastiao Do Sacramento', '36908-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Soberbo', 'Sao Sebastiao Do Soberbo', '35387-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião dos Poções', 'Sao Sebastiao Dos Pocoes', '39497-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião dos Robertos', 'Sao Sebastiao Dos Robertos', '37592-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião dos Torres', 'Sao Sebastiao Dos Torres', '36206-700', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Tiago', 'Sao Tiago', '36350-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Tomás de Aquino', 'Sao Tomas De Aquino', '37960-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Tomé das Letras', 'Sao Tome Das Letras', '37418-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente', 'Sao Vicente', '35707-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente da Estrela', 'Sao Vicente Da Estrela', '35355-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente de Minas', 'Sao Vicente De Minas', '37370-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente do Grama', 'Sao Vicente Do Grama', '35398-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente do Rio Doce', 'Sao Vicente Do Rio Doce', '35143-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vítor', 'Sao Vitor', '35104-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapucaí', 'Sapucai', '37594-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapucaí-Mirim', 'Sapucai-Mirim', '37690-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapucaia', 'Sapucaia', '35311-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapucaia de Guanhães', 'Sapucaia De Guanhaes', '39742-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapucaia do Norte', 'Sapucaia Do Norte', '35255-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sarandira', 'Sarandira', '36104-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sardoá', 'Sardoa', '39728-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sarzedo', 'Sarzedo', '32450-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saudade', 'Saudade', '36645-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sem Peixe', 'Sem Peixe', '35441-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Amaral', 'Senador Amaral', '37615-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Cortes', 'Senador Cortes', '36650-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Firmino', 'Senador Firmino', '36540-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador José Bento', 'Senador Jose Bento', '37558-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Melo Viana', 'Senador Melo Viana', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Modestino Gonçalves', 'Senador Modestino Goncalves', '39190-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Mourão', 'Senador Mourao', '39112-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senhora da Glória', 'Senhora Da Gloria', '39212-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senhora da Penha', 'Senhora Da Penha', '35136-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senhora das Dores', 'Senhora Das Dores', '36207-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senhora de Oliveira', 'Senhora De Oliveira', '36470-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senhora do Carmo', 'Senhora Do Carmo', '35907-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senhora do Porto', 'Senhora Do Porto', '39745-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senhora dos Remédios', 'Senhora Dos Remedios', '36275-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sereno', 'Sereno', '36777-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sericita', 'Sericita', '35368-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Seritinga', 'Seritinga', '37454-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Azul', 'Serra Azul', '35674-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Azul de Minas', 'Serra Azul De Minas', '39165-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Bonita', 'Serra Bonita', '38665-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra da Canastra', 'Serra Da Canastra', '37929-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra da Saudade', 'Serra Da Saudade', '35617-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra das Araras', 'Serra Das Araras', '39310-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra do Camapuã', 'Serra Do Camapua', '35491-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra do Salitre', 'Serra Do Salitre', '38760-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra dos Aimorés', 'Serra Dos Aimores', '39868-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra dos Lemes', 'Serra Dos Lemes', '37885-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Nova', 'Serra Nova', '39532-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrania', 'Serrania', '37136-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serranópolis de Minas', 'Serranopolis De Minas', '39518-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serranos', 'Serranos', '37452-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serro', 'Serro', '39150-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sertãozinho', 'Sertaozinho', '37565-500', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sete Cachoeiras', 'Sete Cachoeiras', '35802-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sete Lagoas', 'Sete Lagoas', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Setubinha', 'Setubinha', '39688-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silva Campos', 'Silva Campos', '35645-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silva Xavier', 'Silva Xavier', '35705-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silvano', 'Silvano', '38744-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silveira Carvalho', 'Silveira Carvalho', '36873-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silveirânia', 'Silveirania', '36185-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silvestre', 'Silvestre', '36572-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silvianópolis', 'Silvianopolis', '37560-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Simão Campos', 'Simao Campos', '39432-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Simão Pereira', 'Simao Pereira', '36123-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Simonésia', 'Simonesia', '36930-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sobral Pinto', 'Sobral Pinto', '36782-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sobrália', 'Sobralia', '35145-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Soledade de Minas', 'Soledade De Minas', '37478-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sopa', 'Sopa', '39102-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabajara', 'Tabajara', '35333-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabaúna', 'Tabauna', '35206-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabuão', 'Tabuao', '37315-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabuleiro', 'Tabuleiro', '36165-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taiobeiras', 'Taiobeiras', '39550-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taparuba', 'Taparuba', '36953-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapira', 'Tapira', '38185-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapiraí', 'Tapirai', '38980-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapuirama', 'Tapuirama', '38417-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquaraçu de Minas', 'Taquaracu De Minas', '33980-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taruaçu', 'Taruacu', '36688-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tarumirim', 'Tarumirim', '35140-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tebas', 'Tebas', '36702-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teixeiras', 'Teixeiras', '36580-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tejuco', 'Tejuco', '39484-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teófilo Otoni', 'Teofilo Otoni', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terra Branca', 'Terra Branca', '39393-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timóteo', 'Timoteo', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tiradentes', 'Tiradentes', '36325-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tiros', 'Tiros', '38880-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tobati', 'Tobati', '38953-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tocandira', 'Tocandira', '39523-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tocantins', 'Tocantins', '36512-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tocos do Moji', 'Tocos Do Moji', '37563-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Toledo', 'Toledo', '37630-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tomás Gonzaga', 'Tomas Gonzaga', '35789-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tombos', 'Tombos', '36844-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Topázio', 'Topazio', '39807-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Torneiros', 'Torneiros', '35665-100', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Torreões', 'Torreoes', '36107-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Corações', 'Tres Coracoes', '37410-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Ilhas', 'Tres Ilhas', '36127-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Marias', 'Tres Marias', '39205-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Pontas', 'Tres Pontas', '37190-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trimonte', 'Trimonte', '36723-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tuiutinga', 'Tuiutinga', '36528-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tumiritinga', 'Tumiritinga', '35125-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupaciguara', 'Tupaciguara', '38430-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tuparecê', 'Tuparece', '39623-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Turmalina', 'Turmalina', '39660-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Turvolândia', 'Turvolandia', '37496-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubá', 'Uba', '36500-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubaí', 'Ubai', '39320-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubaporanga', 'Ubaporanga', '35338-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubari', 'Ubari', '36508-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uberaba', 'Uberaba', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uberlândia', 'Uberlandia', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umburatiba', 'Umburatiba', '39878-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umbuzeiro', 'Umbuzeiro', '39439-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Unaí', 'Unai', '38610-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('União de Minas', 'Uniao De Minas', '38288-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uruana de Minas', 'Uruana De Minas', '38630-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urucânia', 'Urucania', '35380-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urucuia', 'Urucuia', '39315-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Usina Monte Alegre', 'Usina Monte Alegre', '37118-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vai-Volta', 'Vai-Volta', '35142-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valadares', 'Valadares', '36101-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valão', 'Valao', '39829-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vale Verde de Minas', 'Vale Verde De Minas', '35198-500', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valo Fundo', 'Valo Fundo', '39213-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargem Alegre', 'Vargem Alegre', '35199-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargem Bonita', 'Vargem Bonita', '37922-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargem Grande do Rio Pardo', 'Vargem Grande Do Rio Pardo', '39535-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargem Linda', 'Vargem Linda', '35998-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Varginha', 'Varginha', NULL, 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Varjão de Minas', 'Varjao De Minas', '38794-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea da Palma', 'Varzea Da Palma', '39260-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Varzelândia', 'Varzelandia', '39450-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vau-Açu', 'Vau-Acu', '35435-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vazante', 'Vazante', '38780-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vera Cruz de Minas', 'Vera Cruz De Minas', '33680-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Verdelândia', 'Verdelandia', '39458-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vereda do Paraíso', 'Vereda Do Paraiso', '39545-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Veredas', 'Veredas', '38775-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Veredinha', 'Veredinha', '39663-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Veríssimo', 'Verissimo', '38150-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vermelho', 'Vermelho', '36890-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vermelho Novo', 'Vermelho Novo', '35359-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vermelho Velho', 'Vermelho Velho', '35354-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vespasiano', 'Vespasiano', '33200-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Viçosa', 'Vicosa', '36570-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vieiras', 'Vieiras', '36895-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Bom Jesus', 'Vila Bom Jesus', '38688-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Costina', 'Vila Costina', '35583-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nova de Minas', 'Vila Nova De Minas', '39416-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nova dos Poções', 'Vila Nova Dos Pocoes', '39444-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Pereira', 'Vila Pereira', '39862-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vilas Boas', 'Vilas Boas', '36526-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Virgem da Lapa', 'Virgem Da Lapa', '39630-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Virgínia', 'Virginia', '37465-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Virginópolis', 'Virginopolis', '39730-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Virgolândia', 'Virgolandia', '39715-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Visconde do Rio Branco', 'Visconde Do Rio Branco', '36520-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Alegre', 'Vista Alegre', '39385-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vitorinos', 'Vitorinos', '36264-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Volta Grande', 'Volta Grande', '36720-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Wenceslau Braz', 'Wenceslau Braz', '37512-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Zelândia', 'Zelandia', '38176-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Zito Soares', 'Zito Soares', '35383-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Boa', 'Agua Boa', '79452-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Clara', 'Agua Clara', '79680-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Albuquerque', 'Albuquerque', '79362-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alcinópolis', 'Alcinopolis', '79530-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Sucuriú', 'Alto Sucuriu', '79682-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amambái', 'Amambai', '79990-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amandina', 'Amandina', '79742-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amolar', 'Amolar', '79357-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anastácio', 'Anastacio', '79210-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anaurilândia', 'Anaurilandia', '79770-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angélica', 'Angelica', '79785-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anhandui', 'Anhandui', '79125-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio João', 'Antonio Joao', '79910-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida do Taboado', 'Aparecida Do Taboado', '79570-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aquidauana', 'Aquidauana', '79200-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aral Moreira', 'Aral Moreira', '79930-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arapuã', 'Arapua', '79654-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areado', 'Areado', '79492-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Árvore Grande', 'Arvore Grande', '79502-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baianópolis', 'Baianopolis', '79462-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bálsamo', 'Balsamo', '79182-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bandeirantes', 'Bandeirantes', '79430-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bataguassu', 'Bataguassu', '79780-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bataiporã', 'Bataipora', '79760-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baús', 'Baus', '79554-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista', 'Bela Vista', '79260-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bocajá', 'Bocaja', '79886-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bocajá', 'Bocaja', '79923-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bodoquena', 'Bodoquena', '79390-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Fim', 'Bom Fim', '79442-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonito', 'Bonito', '79290-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boqueirão', 'Boqueirao', '79242-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brasilândia', 'Brasilandia', '79670-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caarapó', 'Caarapo', '79940-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabeceira do Apá', 'Cabeceira Do Apa', '79908-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira', 'Cachoeira', '79504-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camapuã', 'Camapua', '79420-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camisão', 'Camisao', '79202-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campestre', 'Campestre', '79912-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Grande', 'Campo Grande', NULL, 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão Seco', 'Capao Seco', '79174-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caracol', 'Caracol', '79270-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carumbé', 'Carumbe', '79892-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cassilândia', 'Cassilandia', '79540-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chapadão do Sul', 'Chapadao Do Sul', '79560-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cipolândia', 'Cipolandia', '79208-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coimbra', 'Coimbra', '79368-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Congonhas', 'Congonhas', '79432-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corguinho', 'Corguinho', '79460-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Sapucaia', 'Coronel Sapucaia', '79995-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corumbá', 'Corumba', NULL, 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Costa Rica', 'Costa Rica', '79550-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coxim', 'Coxim', '79400-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristalina', 'Cristalina', '79944-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzaltina', 'Cruzaltina', '79883-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Culturama', 'Culturama', '79702-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cupins', 'Cupins', '79573-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Debrasa', 'Debrasa', '79677-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Deodápolis', 'Deodapolis', '79790-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dois Irmãos do Buriti', 'Dois Irmaos Do Buriti', '79215-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Douradina', 'Douradina', '79880-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dourados', 'Dourados', NULL, 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eldorado', 'Eldorado', '79970-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fátima do Sul', 'Fatima Do Sul', '79700-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Figueirão', 'Figueirao', '79422-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Garcias', 'Garcias', '79656-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Glória de Dourados', 'Gloria De Dourados', '79730-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaçu', 'Guacu', '79874-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaçulândia', 'Guaculandia', '79734-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guadalupe do Alto Paraná', 'Guadalupe Do Alto Parana', '79658-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guia Lopes da Laguna', 'Guia Lopes Da Laguna', '79230-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguatemi', 'Iguatemi', '79960-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilha Comprida', 'Ilha Comprida', '79652-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilha Grande', 'Ilha Grande', '79578-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indaiá do Sul', 'Indaia Do Sul', '79542-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indaiá Grande', 'Indaia Grande', '79506-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indápolis', 'Indapolis', '79868-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inocência', 'Inocencia', '79580-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipezal', 'Ipezal', '79787-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itahum', 'Itahum', '79864-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaporã', 'Itapora', '79890-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaquiraí', 'Itaquirai', '79965-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ivinhema', 'Ivinhema', '79740-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jabuti', 'Jabuti', '79292-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacareí', 'Jacarei', '79988-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japorã', 'Japora', '79985-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaraguari', 'Jaraguari', '79440-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim', 'Jardim', '79240-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jateí', 'Jatei', '79720-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jauru', 'Jauru', '79406-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juscelândia', 'Juscelandia', '79482-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jutí', 'Juti', '79955-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ladário', 'Ladario', '79370-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Bonita', 'Lagoa Bonita', '79792-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laguna Carapã', 'Laguna Carapa', '79920-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maracajú', 'Maracaju', '79150-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miranda', 'Miranda', '79380-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montese', 'Montese', '79896-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morangas', 'Morangas', '79584-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morraria do Sul', 'Morraria Do Sul', '79392-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morumbi', 'Morumbi', '79972-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mundo Novo', 'Mundo Novo', '79980-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Naviraí', 'Navirai', '79950-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nhecolândia', 'Nhecolandia', '79364-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nioaque', 'Nioaque', '79220-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora de Fátima', 'Nossa Senhora De Fatima', '79262-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Alvorada do Sul', 'Nova Alvorada Do Sul', '79140-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova América', 'Nova America', '79942-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Andradina', 'Nova Andradina', '79750-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Esperança', 'Nova Esperanca', '79722-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Esperança', 'Nova Esperanca', '79472-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Jales', 'Nova Jales', '79508-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Horizonte do Sul', 'Novo Horizonte Do Sul', '79745-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oriente', 'Oriente', '79576-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paiaguás', 'Paiaguas', '79359-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeiras', 'Palmeiras', '79217-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Panambi', 'Panambi', '79876-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraíso', 'Paraiso', '79552-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranaíba', 'Paranaiba', '79500-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranhos', 'Paranhos', '79925-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Gomes', 'Pedro Gomes', '79410-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Picadinha', 'Picadinha', '79866-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirapora', 'Pirapora', '79894-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piraputanga', 'Piraputanga', '79204-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponta Porã', 'Ponta Pora', '79900-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte Vermelha', 'Ponte Vermelha', '79494-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontinha do Cocho', 'Pontinha Do Cocho', '79424-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Esperança', 'Porto Esperanca', '79366-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Murtinho', 'Porto Murtinho', '79280-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Vilma', 'Porto Vilma', '79794-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto XV de Novembro', 'Porto Xv De Novembro', '79782-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Castelo', 'Presidente Castelo', '79798-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prudêncio Thomaz', 'Prudencio Thomaz', '79134-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quebra Côco', 'Quebra Coco', '79173-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quebracho', 'Quebracho', '79774-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribas do Rio Pardo', 'Ribas Do Rio Pardo', '79180-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Brilhante', 'Rio Brilhante', '79130-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Negro', 'Rio Negro', '79470-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Verde de Mato Grosso', 'Rio Verde De Mato Grosso', '79480-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rochedinho', 'Rochedinho', '79127-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rochedo', 'Rochedo', '79450-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sanga Puitã', 'Sanga Puita', '79902-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita do Pardo', 'Santa Rita Do Pardo', '79690-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha', 'Santa Terezinha', '79898-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gabriel do Oeste', 'Sao Gabriel Do Oeste', '79490-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Apore', 'Sao Joao Do Apore', '79512-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José', 'Sao Jose', '79712-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Sucuriú', 'Sao Jose Do Sucuriu', '79586-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '79862-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '79582-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Romão', 'Sao Romao', '79402-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Selvíria', 'Selviria', '79590-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sete Quedas', 'Sete Quedas', '79935-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sidrolândia', 'Sidrolandia', '79170-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sonora', 'Sonora', '79415-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tacuru', 'Tacuru', '79975-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tamandaré', 'Tamandare', '79514-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquari', 'Taquari', '79405-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquarussu', 'Taquarussu', '79765-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taunay', 'Taunay', '79206-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terenos', 'Terenos', '79190-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Lagoas', 'Tres Lagoas', NULL, 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Velhacaria', 'Velhacaria', '79516-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vicentina', 'Vicentina', '79710-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Formosa', 'Vila Formosa', '79872-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Marques', 'Vila Marques', '79932-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Rica', 'Vila Rica', '79714-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila União', 'Vila Uniao', '79796-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Vargas', 'Vila Vargas', '79878-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Alegre', 'Vista Alegre', '79152-000', 'MS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acorizal', 'Acorizal', '78480-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Boa', 'Agua Boa', '78635-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Fria', 'Agua Fria', '78197-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aguaçu', 'Aguacu', '78108-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aguapeí', 'Aguapei', '78248-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas Claras', 'Aguas Claras', '78572-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ainhumas', 'Ainhumas', '78751-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alcantilado', 'Alcantilado', '78762-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alta Floresta', 'Alta Floresta', '78580-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Araguaia', 'Alto Araguaia', '78780-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Boa Vista', 'Alto Boa Vista', '78665-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Coité', 'Alto Coite', '78803-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Garças', 'Alto Garcas', '78770-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Juruena', 'Alto Juruena', '78318-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Paraguai', 'Alto Paraguai', '78410-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Paraíso', 'Alto Paraiso', '78584-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Taquari', 'Alto Taquari', '78785-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Analândia do Norte', 'Analandia Do Norte', '78534-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apiacás', 'Apiacas', '78595-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araguaiana', 'Araguaiana', '78685-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araguainha', 'Araguainha', '78615-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araputanga', 'Araputanga', '78260-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arenápolis', 'Arenapolis', '78420-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aripuanã', 'Aripuana', '78325-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arruda', 'Arruda', '78473-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Assari', 'Assari', '78394-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão de Melgaço', 'Barao De Melgaco', '78190-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Bugres', 'Barra Do Bugres', '78390-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Garças', 'Barra Do Garcas', '78600-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Batovi', 'Batovi', '78776-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baús', 'Baus', '78481-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bauxi', 'Bauxi', '78474-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bel Rios', 'Bel Rios', '78401-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bezerro Branco', 'Bezerro Branco', '78234-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Esperança', 'Boa Esperanca', '78896-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa União', 'Boa Uniao', '78277-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', '78752-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Sucesso', 'Bom Sucesso', '78166-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brasnorte', 'Brasnorte', '78350-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buriti', 'Buriti', '78782-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buriti', 'Buriti', '78764-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cáceres', 'Caceres', '78200-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caite', 'Caite', '78186-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campinápolis', 'Campinapolis', '78630-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Novo do Parecis', 'Campo Novo Do Parecis', '78360-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Verde', 'Campo Verde', '78840-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos de Júlio', 'Campos De Julio', '78307-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos Novos', 'Campos Novos', '78411-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canabrava do Norte', 'Canabrava Do Norte', '78658-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canarana', 'Canarana', '78640-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cangas', 'Cangas', '78178-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão Grande', 'Capao Grande', '78164-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão Verde', 'Capao Verde', '78413-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caramujo', 'Caramujo', '78236-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caravagio', 'Caravagio', '78894-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carlinda', 'Carlinda', '78587-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cassununga', 'Cassununga', '78778-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Castanheira', 'Castanheira', '78345-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catuai', 'Catuai', '78437-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chapada dos Guimarães', 'Chapada Dos Guimaraes', '78195-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cidade Morena', 'Cidade Morena', '78326-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cláudia', 'Claudia', '78540-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cocalinho', 'Cocalinho', '78680-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colider', 'Colider', '78500-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colorado do Norte', 'Colorado Do Norte', '78518-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Comodoro', 'Comodoro', '78310-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Confresa', 'Confresa', '78652-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Ponce', 'Coronel Ponce', '78843-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cotrel', 'Cotrel', '78522-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cotriguaçu', 'Cotriguacu', '78330-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coxipó Açu', 'Coxipo Acu', '78101-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coxipó da Ponte', 'Coxipo Da Ponte', NULL, 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coxipó do Ouro', 'Coxipo Do Ouro', '78102-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristinópolis', 'Cristinopolis', '78272-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristo Rei', 'Cristo Rei', NULL, 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cuiabá', 'Cuiaba', NULL, 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curvelândia', 'Curvelandia', '78237-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Del Rios', 'Del Rios', '78405-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Denise', 'Denise', '78380-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Diamantino', 'Diamantino', '78400-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Aquino', 'Dom Aquino', '78830-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenho', 'Engenho', '78483-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenho Velho', 'Engenho Velho', '78182-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Entre Rios', 'Entre Rios', '78833-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrela do Leste', 'Estrela Do Leste', '78768-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faval', 'Faval', '78171-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda de Cima', 'Fazenda De Cima', '78176-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Feliz Natal', 'Feliz Natal', '78885-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Figueirópolis D''Oeste', 'Figueiropolis D''Oeste', '78290-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Filadélfia', 'Filadelfia', '78321-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flor da Serra', 'Flor Da Serra', '78524-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fontanilhas', 'Fontanilhas', '78348-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gaúcha do Norte', 'Gaucha Do Norte', '78875-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('General Carneiro', 'General Carneiro', '78620-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Glória D''Oeste', 'Gloria D''Oeste', '78293-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarantã do Norte', 'Guaranta Do Norte', '78520-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarita', 'Guarita', '78169-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guiratinga', 'Guiratinga', '78760-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Horizonte do Oeste', 'Horizonte Do Oeste', '78235-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indianápolis', 'Indianapolis', '78603-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indiavaí', 'Indiavai', '78295-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irenópolis', 'Irenopolis', '78813-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamarati Norte', 'Itamarati Norte', '78361-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaúba', 'Itauba', '78510-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itiquira', 'Itiquira', '78790-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaciara', 'Jaciara', '78820-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jangada', 'Jangada', '78490-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jarudore', 'Jarudore', '78806-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jatobá', 'Jatoba', '78823-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jauru', 'Jauru', '78255-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joselândia', 'Joselandia', '78192-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juará', 'Juara', '78575-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juína', 'Juina', '78320-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juruena', 'Juruena', '78340-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juscimeira', 'Juscimeira', '78810-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lambari D''Oeste', 'Lambari D''Oeste', '78278-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lavouras', 'Lavouras', '78414-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lucas do Rio Verde', 'Lucas Do Rio Verde', '78455-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lucialva', 'Lucialva', '78258-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luciara', 'Luciara', '78660-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Machado', 'Machado', '78103-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marcelândia', 'Marcelandia', '78535-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marzagão', 'Marzagao', '78478-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mata Dentro', 'Mata Dentro', '78107-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matupá', 'Matupa', '78525-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mimoso', 'Mimoso', '78188-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirassol D''Oeste', 'Mirassol D''Oeste', '78280-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nobres', 'Nobres', '78460-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nonoai do Norte', 'Nonoai Do Norte', '78502-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nortelândia', 'Nortelandia', '78430-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora da Guia', 'Nossa Senhora Da Guia', '78104-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora do Livramento', 'Nossa Senhora Do Livramento', '78170-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Alvorada', 'Nova Alvorada', '78314-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Bandeirantes', 'Nova Bandeirantes', '78565-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Brasilândia', 'Nova Brasilandia', '78860-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Brasília', 'Nova Brasilia', '78691-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Canãa do Norte', 'Nova Canaa Do Norte', '78515-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Catanduva', 'Nova Catanduva', '78755-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Galileia', 'Nova Galileia', '78754-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Guarita', 'Nova Guarita', '78508-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Lacerda', 'Nova Lacerda', '78243-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Marilândia', 'Nova Marilandia', '78415-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Maringá', 'Nova Maringa', '78445-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Monte Verde', 'Nova Monte Verde', '78593-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Mutum', 'Nova Mutum', '78450-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Olímpia', 'Nova Olimpia', '78370-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Ubiratã', 'Nova Ubirata', '78888-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Xavantina', 'Nova Xavantina', '78690-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Diamantino', 'Novo Diamantino', '78402-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Eldorado', 'Novo Eldorado', '78558-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Horizonte do Norte', 'Novo Horizonte Do Norte', '78570-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Mundo', 'Novo Mundo', '78528-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Paraná', 'Novo Parana', '78562-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo São Joaquim', 'Novo Sao Joaquim', '78625-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padronal', 'Padronal', '78316-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pai Andre', 'Pai Andre', '78167-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraiso do Leste', 'Paraiso Do Leste', '78808-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranaitá', 'Paranaita', '78590-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranatinga', 'Paranatinga', '78870-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passagem da Conceição', 'Passagem Da Conceicao', '78168-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Preta', 'Pedra Preta', '78795-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Peixoto de Azevedo', 'Peixoto De Azevedo', '78530-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirizal', 'Pirizal', '78172-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Placa de Santo Antônio', 'Placa De Santo Antonio', '78811-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planalto da Serra', 'Planalto Da Serra', '78855-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poconé', 'Pocone', '78175-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pombas', 'Pombas', '78834-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontal do Araguaia', 'Pontal Do Araguaia', '78698-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte Branca', 'Ponte Branca', '78610-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte de Pedra', 'Ponte De Pedra', '78759-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontes e Lacerda', 'Pontes E Lacerda', '78250-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontinópolis', 'Pontinopolis', '78672-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Alegre do Norte', 'Porto Alegre Do Norte', '78655-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto dos Gaúchos', 'Porto Dos Gauchos', '78560-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Esperidião', 'Porto Esperidiao', '78240-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Estrela', 'Porto Estrela', '78398-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poxoréo', 'Poxoreo', '78800-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Praia Rica', 'Praia Rica', '78198-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Primavera', 'Primavera', '78898-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Primavera do Leste', 'Primavera Do Leste', '78850-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Progresso', 'Progresso', '78305-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Querência', 'Querencia', '78643-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rancharia', 'Rancharia', '78868-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Reserva do Cabaçal', 'Reserva Do Cabacal', '78265-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão Cascalheira', 'Ribeirao Cascalheira', '78675-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão dos Cocais', 'Ribeirao Dos Cocais', '78173-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirãozinho', 'Ribeiraozinho', '78613-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Branco', 'Rio Branco', '78275-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Manso', 'Rio Manso', '78863-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riolândia', 'Riolandia', '78866-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rondonópolis', 'Rondonopolis', NULL, 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rosário Oeste', 'Rosario Oeste', '78470-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salto do Céu', 'Salto Do Ceu', '78270-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sangradouro', 'Sangradouro', '78623-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Carmem', 'Santa Carmem', '78545-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Elvira', 'Santa Elvira', '78816-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Fé', 'Santa Fe', '78288-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita', 'Santa Rita', '78463-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha', 'Santa Terezinha', '78650-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santaninha', 'Santaninha', '78648-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Afonso', 'Santo Afonso', '78425-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Leverger', 'Santo Antonio Do Leverger', '78180-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Rio Bonito', 'Santo Antonio Do Rio Bonito', '78891-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Cristovão', 'Sao Cristovao', '78551-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vale de São Domingos', 'Vale De Sao Domingos', '78253-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Félix do Araguaia', 'Sao Felix Do Araguaia', '78670-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim', 'Sao Joaquim', '78306-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Jorge', 'Sao Jorge', '78311-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José', 'Sao Jose', '78313-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Apuí', 'Sao Jose Do Apui', '78583-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Planalto', 'Sao Jose Do Planalto', '78798-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Povo', 'Sao Jose Do Povo', '78773-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Rio Claro', 'Sao Jose Do Rio Claro', '78435-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Xingu', 'Sao Jose Do Xingu', '78663-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Perseverança', 'Perseveranca', '68776-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José dos Quatro Marcos', 'Sao Jose Dos Quatro Marcos', '78285-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Lourenço de Fátima', 'Sao Lourenco De Fatima', '78818-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro da Cipa', 'Sao Pedro Da Cipa', '78835-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente', 'Sao Vicente', '78106-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapezal', 'Sapezal', '78365-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Selma', 'Selma', '78828-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Nova Dourada', 'Serra Nova Dourada', '78668-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sinop', 'Sinop', '78550-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sonho Azul', 'Sonho Azul', '78284-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sorriso', 'Sorriso', '78890-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sumidouro', 'Sumidouro', '78404-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabaporã', 'Tabapora', '78563-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tangará da Serra', 'Tangara Da Serra', '78300-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapirapua', 'Tapirapua', '78396-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapurah', 'Tapurah', '78555-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terra Nova do Norte', 'Terra Nova Do Norte', '78505-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terra Roxa', 'Terra Roxa', '78322-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tesouro', 'Tesouro', '78775-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Toricueyje', 'Toricueyje', '78606-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Torixoréu', 'Torixoreu', '78695-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Pontes', 'Tres Pontes', '78756-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('União do Sul', 'Uniao Do Sul', '78543-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vale dos Sonhos', 'Vale Dos Sonhos', '78608-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vale Rico', 'Vale Rico', '78766-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Varginha', 'Varginha', '78184-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea Grande', 'Varzea Grande', NULL, 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vera', 'Vera', '78880-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Atlântica', 'Vila Atlantica', '78536-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Bela da Santíssima Trindade', 'Vila Bela Da Santissima Trindade', '78245-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Bueno', 'Vila Bueno', '78757-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Mutum', 'Vila Mutum', '78585-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Operária', 'Vila Operaria', '78758-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Paulista', 'Vila Paulista', '78753-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Progresso', 'Vila Progresso', '78274-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Rica', 'Vila Rica', '78645-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Santo Antônio', 'Novo Santo Antonio', '78674-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abaetetuba', 'Abaetetuba', '68440-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abel Figueiredo', 'Abel Figueiredo', '68527-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acará', 'Acara', '68690-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Afuá', 'Afua', '68890-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Agrópolis Bela Vista', 'Agropolis Bela Vista', '68111-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Azul do Norte', 'Agua Azul Do Norte', '68533-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Fria', 'Agua Fria', '68559-300', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alenquer', 'Alenquer', '68200-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Algodoal', 'Algodoal', '68712-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Almeirim', 'Almeirim', '68230-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Almoço', 'Almoco', '68608-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alta Pará', 'Alta Para', '68112-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Altamira', 'Altamira', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alter do Chão', 'Alter Do Chao', '68109-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvorada', 'Alvorada', '68191-700', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Americano', 'Americano', '68792-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anajás', 'Anajas', '68810-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ananindeua', 'Ananindeua', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anapu', 'Anapu', '68365-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Lemos', 'Antonio Lemos', '68803-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apeú', 'Apeu', '68747-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apinagés', 'Apinages', '68519-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arapixuna', 'Arapixuna', '68128-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araquaim', 'Araquaim', '68752-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arco-Íris', 'Arco-Iris', '68631-200', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areias', 'Areias', '68495-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arumanduba', 'Arumanduba', '68235-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aruri', 'Aruri', '68191-500', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aturiaí', 'Aturiai', '68612-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Augusto Corrêa', 'Augusto Correa', '68610-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aurora do Pará', 'Aurora Do Para', '68658-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aveiro', 'Aveiro', '68150-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bagre', 'Bagre', '68475-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baião', 'Baiao', '68465-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bannach', 'Bannach', '68388-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barcarena', 'Barcarena', '68445-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreira Branca', 'Barreira Branca', '68568-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreira dos Campos', 'Barreira Dos Campos', '68562-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiras', 'Barreiras', '68192-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baturité', 'Baturite', '68892-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Beja', 'Beja', '68444-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista do Caracol', 'Bela Vista Do Caracol', '68191-600', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belém', 'Belem', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belterra', 'Belterra', '68143-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Benevides', 'Benevides', '68795-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Benfica', 'Benfica', '68797-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Esperança', 'Boa Esperanca', '68718-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Esperança', 'Boa Esperanca', '68113-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Fé', 'Boa Fe', '68114-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Sorte', 'Boa Sorte', '68549-100', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista do Iririteua', 'Boa Vista Do Iririteua', '68751-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boim', 'Boim', '68115-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jardim', 'Bom Jardim', '68713-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus do Tocantins', 'Bom Jesus Do Tocantins', '68525-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonito', 'Bonito', '68645-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bragança', 'Braganca', '68600-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brasil Novo', 'Brasil Novo', '68148-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brasília Legal', 'Brasilia Legal', '68160-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo do Meio', 'Brejo Do Meio', '68514-200', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo Grande do Araguaia', 'Brejo Grande Do Araguaia', '68521-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Breu Branco', 'Breu Branco', '68488-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Breves', 'Breves', '68800-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bujaru', 'Bujaru', '68670-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira de Píria', 'Cachoeira De Piria', '68617-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira do Arari', 'Cachoeira Do Arari', '68840-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cafezal', 'Cafezal', '68723-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cairari', 'Cairari', '68453-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caju', 'Caju', '68661-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Câmara do Marajó', 'Camara Do Marajo', '68845-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cambuquira', 'Cambuquira', '68116-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cametá', 'Cameta', '68400-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camiranga', 'Camiranga', '68624-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canaã dos Carajás', 'Canaa Dos Carajas', '68537-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capanema', 'Capanema', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capitão Poço', 'Capitao Poco', '68650-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caracará do Arari', 'Caracara Do Arari', '68848-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carajás', 'Carajas', '68516-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carapajó', 'Carapajo', '68404-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraparu', 'Caraparu', '68791-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caratateua', 'Caratateua', '68609-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caripi', 'Caripi', '68726-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carrazedo', 'Carrazedo', '68310-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Castanhal', 'Castanhal', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Castelo dos Sonhos', 'Castelo Dos Sonhos', '68379-200', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chaves', 'Chaves', '68880-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colares', 'Colares', '68785-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição', 'Conceicao', '68631-400', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pesqueiro', 'Pesqueiro', '68875-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Araguaia', 'Conceicao Do Araguaia', '68540-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Concórdia do Pará', 'Concordia Do Para', '68685-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Condeixa', 'Condeixa', '68862-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coqueiro', 'Coqueiro', '67000-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cripurizão', 'Cripurizao', '68192-200', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cripurizinho', 'Cripurizinho', '68192-300', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cuiú-Cuiú', 'Cuiu-Cuiu', '68192-400', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cumaru do Norte', 'Cumaru Do Norte', '68398-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curionópolis', 'Curionopolis', '68523-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curralinho', 'Curralinho', '68815-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curuá', 'Curua', '68210-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curuaí', 'Curuai', '68125-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curuçá', 'Curuca', '68750-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curuçambaba', 'Curucambaba', '68406-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curumu', 'Curumu', '68805-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Eliseu', 'Dom Eliseu', '68633-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eldorado dos Carajás', 'Eldorado Dos Carajas', '68524-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Emboraí', 'Emborai', '68614-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espírito Santo do Tauá', 'Espirito Santo Do Taua', '68787-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faro', 'Faro', '68280-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fernandes Belo', 'Fernandes Belo', '68622-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flexal', 'Flexal', '68260-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floresta', 'Floresta', '68192-500', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floresta do Araguaia', 'Floresta Do Araguaia', '68543-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Garrafão do Norte', 'Garrafao Do Norte', '68665-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goianésia do Pará', 'Goianesia Do Para', '68639-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gradaus', 'Gradaus', '68394-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guajará-Açú', 'Guajara-Acu', '68672-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guajará-Miri', 'Guajara-Miri', '68692-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gurupá', 'Gurupa', '68300-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gurupizinho', 'Gurupizinho', '68631-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Hidrelétrica Tucuruí', 'Hidreletrica Tucurui', '68464-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iataí', 'Iatai', '68379-100', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Icoaraci', 'Icoaraci', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igarapé da Lama', 'Igarape Da Lama', '68117-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igarapé-Açu', 'Igarape-Acu', '68725-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igarapé-Miri', 'Igarape-Miri', '68430-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inanu', 'Inanu', '68118-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhangapi', 'Inhangapi', '68770-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipixuna do Pará', 'Ipixuna Do Para', '68637-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irituia', 'Irituia', '68655-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaituba', 'Itaituba', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapixuna', 'Itapixuna', '68615-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itatupã', 'Itatupa', '68320-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itupiranga', 'Itupiranga', '68580-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacareacanga', 'Jacareacanga', '68195-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacundá', 'Jacunda', '68590-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguarari', 'Jaguarari', '68693-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jamanxinzinho', 'Jamanxinzinho', '68192-600', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jambuaçu', 'Jambuacu', '68749-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jandiaí', 'Jandiai', '68772-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japerica', 'Japerica', '68708-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joana Coeli', 'Joana Coeli', '68412-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joana Peres', 'Joana Peres', '68468-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joanes', 'Joanes', '68864-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juabá', 'Juaba', '68402-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jubim', 'Jubim', '68866-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juruti', 'Juruti', '68170-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('km 19', 'Km 19', '68714-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('km 26', 'Km 26', '68715-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lauro Sodré', 'Lauro Sodre', '68753-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ligação do Pará', 'Ligacao Do Para', '68631-600', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Limoeiro do Ajuru', 'Limoeiro Do Ajuru', '68415-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mãe do Rio', 'Mae Do Rio', '68675-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Magalhães Barata', 'Magalhaes Barata', '68722-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maiauata', 'Maiauata', '68435-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manjeiro', 'Manjeiro', '68425-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marabá', 'Maraba', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maracanã', 'Maracana', '68710-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marajoara', 'Marajoara', '68449-300', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marapanim', 'Marapanim', '68760-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marituba', 'Marituba', '67200-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marudá', 'Maruda', '68768-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mata Geral', 'Mata Geral', '68549-200', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matapiquara', 'Matapiquara', '68762-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Medicilândia', 'Medicilandia', '68145-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Melgaço', 'Melgaco', '68490-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Menino Deus do Anapu', 'Menino Deus Do Anapu', '68433-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Meruú', 'Meruu', '68438-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirasselvas', 'Mirasselvas', '68706-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miritituba', 'Miritituba', '68191-400', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mocajuba', 'Mocajuba', '68420-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moiraba', 'Moiraba', '68408-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moju', 'Moju', '68450-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monsaras', 'Monsaras', '68868-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre', 'Monte Alegre', '68220-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre do Mau', 'Monte Alegre Do Mau', '68764-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Dourado', 'Monte Dourado', '68240-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morada Nova', 'Morada Nova', '68514-300', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mosqueiro', 'Mosqueiro', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muaná', 'Muana', '68825-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mujuí dos Campos', 'Mujui Dos Campos', '68120-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Murajá', 'Muraja', '68754-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Murucupi', 'Murucupi', '68448-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Murumuru', 'Murumuru', '68514-400', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muta', 'Muta', '68835-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mutucal', 'Mutucal', '68755-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nazaré de Mocajuba', 'Nazare De Mocajuba', '68756-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nazaré dos Patos', 'Nazare Dos Patos', '68462-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Esperança do Piriá', 'Nova Esperanca Do Piria', '68618-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Ipixuna', 'Nova Ipixuna', '68585-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Mocajuba', 'Nova Mocajuba', '68604-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Timboteua', 'Nova Timboteua', '68730-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Planalto', 'Novo Planalto', '68549-400', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Progresso', 'Novo Progresso', '68193-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Repartimento', 'Novo Repartimento', '68473-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Núcleo Urbano Quilômetro 30', 'Nucleo Urbano Quilometro 30', '68192-700', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Óbidos', 'Obidos', '68250-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oeiras do Pará', 'Oeiras Do Para', '68470-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oriximiná', 'Oriximina', '68270-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Osvaldilândia', 'Osvaldilandia', '68549-500', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Otelo', 'Otelo', '66000-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ourém', 'Ourem', '68640-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ourilândia do Norte', 'Ourilandia Do Norte', '68390-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pacajá', 'Pacaja', '68485-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pacoval', 'Pacoval', '68135-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palestina do Pará', 'Palestina Do Para', '68535-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paragominas', 'Paragominas', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paratins', 'Paratins', '68514-500', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parauapebas', 'Parauapebas', '68515-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pau D'' Arco', 'Pau D'' Arco', '68545-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedreira', 'Pedreira', '68478-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Peixe-Boi', 'Peixe-Boi', '68734-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Penhalonga', 'Penhalonga', '68781-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piabas', 'Piabas', '68607-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piçarra', 'Picarra', '68575-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piçarra', 'Picarra', '68559-400', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhal', 'Pinhal', '68155-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piraquara', 'Piraquara', '68119-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piriá', 'Piria', '68818-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Placas', 'Placas', '68138-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponta de Pedras', 'Ponta De Pedras', '68830-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponta de Ramos', 'Ponta De Ramos', '68758-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Portel', 'Portel', '68480-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto de Moz', 'Porto De Moz', '68330-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Salvo', 'Porto Salvo', '68782-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Trombetas', 'Porto Trombetas', '68275-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prainha', 'Prainha', '68130-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Primavera', 'Primavera', '68707-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quatipuru', 'Quatipuru', '68709-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quatro Bocas', 'Quatro Bocas', '68682-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Redenção', 'Redencao', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Remansão', 'Remansao', '68461-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Repartimento', 'Repartimento', '68463-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Maria', 'Rio Maria', '68530-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Vermelho', 'Rio Vermelho', '68559-500', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riozinho', 'Riozinho', '68191-300', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rondon do Pará', 'Rondon Do Para', '68638-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rurópolis', 'Ruropolis', '68165-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salinópolis', 'Salinopolis', '68721-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salvaterra', 'Salvaterra', '68860-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Bárbara do Pará', 'Santa Barbara Do Para', '68798-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz do Arari', 'Santa Cruz Do Arari', '68850-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Isabel do Pará', 'Santa Isabel Do Para', '68790-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia do Pará', 'Santa Luzia Do Para', '68644-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria', 'Santa Maria', '68716-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria das Barreiras', 'Santa Maria Das Barreiras', '68565-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria do Pará', 'Santa Maria Do Para', '68738-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa da Vigia', 'Santa Rosa Da Vigia', '68783-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha', 'Santa Terezinha', '68747-500', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Araguaia', 'Santana Do Araguaia', '68560-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santarém', 'Santarem', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santarém Novo', 'Santarem Novo', '68720-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio', 'Santo Antonio', '68549-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Tauá', 'Santo Antonio Do Taua', '68786-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Caetano de Odivelas', 'Sao Caetano De Odivelas', '68775-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos do Araguaia', 'Sao Domingos Do Araguaia', '68520-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos do Capim', 'Sao Domingos Do Capim', '68635-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Félix do Xingu', 'Sao Felix Do Xingu', '68380-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco', 'Sao Francisco', '68559-600', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco da Jararaca', 'Sao Francisco Da Jararaca', '68828-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco do Pará', 'Sao Francisco Do Para', '68748-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Geraldo do Araguaia', 'Sao Geraldo Do Araguaia', '68570-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Ponta', 'Sao Joao Da Ponta', '68774-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João de Pirabas', 'Sao Joao De Pirabas', '68719-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Acangata', 'Sao Joao Do Acangata', '68482-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Araguaia', 'Sao Joao Do Araguaia', '68518-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Piriá', 'Sao Joao Do Piria', '68631-800', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João dos Ramos', 'Sao Joao Dos Ramos', '68778-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim do Tapará', 'Sao Joaquim Do Tapara', '68124-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Jorge', 'Sao Jorge', '68126-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Gurupi', 'Sao Jose Do Gurupi', '68623-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Piriá', 'Sao Jose Do Piria', '68621-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz do Tapajós', 'Sao Luiz Do Tapajos', '68190-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel do Guamá', 'Sao Miguel Do Guama', '68660-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel dos Macacos', 'Sao Miguel Dos Macacos', '68808-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro de Viseu', 'Sao Pedro De Viseu', '68428-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro do Capim', 'Sao Pedro Do Capim', '68636-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Raimundo de Borralhos', 'Sao Raimundo De Borralhos', '68788-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Raimundo do Araguaia', 'Sao Raimundo Do Araguaia', '68522-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Raimundo dos Furtados', 'Sao Raimundo Dos Furtados', '68410-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Roberto', 'Sao Roberto', '68711-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião da Boa Vista', 'Sao Sebastiao Da Boa Vista', '68820-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião de Viçosa', 'Sao Sebastiao De Vicosa', '68885-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapucaia', 'Sapucaia', '68548-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador José Porfírio', 'Senador Jose Porfirio', '68360-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Pelada', 'Serra Pelada', '68514-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Soure', 'Soure', '68870-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tailândia', 'Tailandia', '68695-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tatuteua', 'Tatuteua', '68717-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tauari', 'Tauari', '68705-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tauarizinho', 'Tauarizinho', '68735-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tentugal', 'Tentugal', '68642-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terra Alta', 'Terra Alta', '68773-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terra Santa', 'Terra Santa', '68285-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tijoca', 'Tijoca', '68606-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timboteua', 'Timboteua', '68732-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tomé-Açú', 'Tome-Acu', '68680-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tracuateua', 'Tracuateua', '68647-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trairão', 'Trairao', '68198-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tucumã', 'Tucuma', '68385-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tucuruí', 'Tucurui', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ulianópolis', 'Ulianopolis', '68632-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uruará', 'Uruara', '68140-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urucuri', 'Urucuri', '68663-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urucuriteua', 'Urucuriteua', '68662-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Val-de-Cães', 'Val-De-Caes', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Veiros', 'Veiros', '68350-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vigia', 'Vigia', '68780-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila do Carmo do Tocantins', 'Vila Do Carmo Do Tocantins', '68409-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila dos Cabanos', 'Vila Dos Cabanos', '68447-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila França', 'Vila Franca', '68121-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Goreth', 'Vila Goreth', '68122-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Isol', 'Vila Isol', '68191-200', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nova', 'Vila Nova', '68779-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Planalto', 'Vila Planalto', '68191-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Santa Fé', 'Vila Santa Fe', '68514-100', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Socorro', 'Vila Socorro', '68123-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vilarinho do Monte', 'Vilarinho Do Monte', '68340-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Viseu', 'Viseu', '68620-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Alegre', 'Vista Alegre', '68759-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Alegre do Pará', 'Vista Alegre Do Para', '68765-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vitória do Xingu', 'Vitoria Do Xingu', '68383-000', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xinguara', 'Xinguara', NULL, 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xinguarinha', 'Xinguarinha', '68559-200', 'PA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Branca', 'Agua Branca', '58748-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aguiar', 'Aguiar', '58778-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alagoa Grande', 'Alagoa Grande', '58388-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alagoa Nova', 'Alagoa Nova', '58125-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alagoinha', 'Alagoinha', '58390-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alcantil', 'Alcantil', '58460-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Algodão de Jandaíra', 'Algodao De Jandaira', '58399-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alhandra', 'Alhandra', '58320-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amparo', 'Amparo', '58548-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida', 'Aparecida', '58823-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araçagi', 'Aracagi', '58270-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arara', 'Arara', '58396-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araruna', 'Araruna', '58233-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areia', 'Areia', '58397-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areia de Baraúnas', 'Areia De Baraunas', '58732-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areial', 'Areial', '58140-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areias', 'Areias', '58916-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aroeiras', 'Aroeiras', '58400-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Assis Chateaubriand', 'Assis Chateaubriand', '58382-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Assunção', 'Assuncao', '58685-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baía da Traição', 'Baia Da Traicao', '58295-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Balanços', 'Balancos', '58937-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bananeiras', 'Bananeiras', '58220-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baraúna', 'Barauna', '58188-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra de Santa Rosa', 'Barra De Santa Rosa', '58170-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra de Santana', 'Barra De Santana', '58458-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra de São Miguel', 'Barra De Sao Miguel', '58470-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Camaratuba', 'Barra Do Camaratuba', '58293-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bayeux', 'Bayeux', NULL, 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belém', 'Belem', '58255-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belém do Brejo do Cruz', 'Belem Do Brejo Do Cruz', '58895-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bernardino Batista', 'Bernardino Batista', '58922-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Ventura', 'Boa Ventura', '58993-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', '58123-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus', 'Bom Jesus', '58930-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Sucesso', 'Bom Sucesso', '58887-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Sucesso', 'Bom Sucesso', '58156-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonito de Santa Fé', 'Bonito De Santa Fe', '58960-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boqueirão', 'Boqueirao', '58450-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Borborema', 'Borborema', '58394-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo do Cruz', 'Brejo Do Cruz', '58890-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo dos Santos', 'Brejo Dos Santos', '58880-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caaporã', 'Caapora', '58326-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabaceiras', 'Cabaceiras', '58480-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabedelo', 'Cabedelo', '58310-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira', 'Cachoeira', '58205-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira dos Índios', 'Cachoeira Dos Indios', '58935-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeirinha', 'Cachoeirinha', '58983-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cacimba de Areia', 'Cacimba De Areia', '58730-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cacimba de Dentro', 'Cacimba De Dentro', '58230-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cacimbas', 'Cacimbas', '58698-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiçara', 'Caicara', '58253-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cajazeiras', 'Cajazeiras', '58900-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cajazeirinhas', 'Cajazeirinhas', '58855-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caldas Brandão', 'Caldas Brandao', '58350-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camalaú', 'Camalau', '58530-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campina Grande', 'Campina Grande', NULL, 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Alegre', 'Campo Alegre', '58813-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Grande', 'Campo Grande', '58362-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camurupim', 'Camurupim', '58299-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capim', 'Capim', '58287-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraúbas', 'Caraubas', '58595-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cardoso', 'Cardoso', '58973-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carrapateira', 'Carrapateira', '58945-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Casinha do Homem', 'Casinha Do Homem', '58826-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Casserengue', 'Casserengue', '58238-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catingueira', 'Catingueira', '58715-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catolé', 'Catole', '58114-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catolé do Rocha', 'Catole Do Rocha', '58884-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caturité', 'Caturite', '58455-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cepilho', 'Cepilho', '58397-500', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição', 'Conceicao', '58970-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Condado', 'Condado', '58714-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conde', 'Conde', '58322-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Congo', 'Congo', '58535-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coremas', 'Coremas', '58770-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Maia', 'Coronel Maia', '58885-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coxixola', 'Coxixola', '58588-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruz do Espírito Santo', 'Cruz Do Espirito Santo', '58337-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cubati', 'Cubati', '58167-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cuité', 'Cuite', '58175-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cuité de Mamanguape', 'Cuite De Mamanguape', '58289-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cuitegi', 'Cuitegi', '58208-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cupissura', 'Cupissura', '58327-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curral de Cima', 'Curral De Cima', '58291-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curral Velho', 'Curral Velho', '58990-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Damião', 'Damiao', '58173-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Desterro', 'Desterro', '58695-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Diamante', 'Diamante', '58994-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dona Inês', 'Dona Ines', '58228-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Duas Estradas', 'Duas Estradas', '58265-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Emas', 'Emas', '58763-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro Ávidos', 'Engenheiro Avidos', '58905-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esperança', 'Esperanca', '58135-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fagundes', 'Fagundes', '58430-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fátima', 'Fatima', '58936-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda Nova', 'Fazenda Nova', '58918-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Forte Velho', 'Forte Velho', '58304-300', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frei Martinho', 'Frei Martinho', '58195-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gado Bravo', 'Gado Bravo', '58405-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Galante', 'Galante', '58110-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarabira', 'Guarabira', '58200-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarita', 'Guarita', '58364-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gurinhém', 'Gurinhem', '58356-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gurjão', 'Gurjao', '58670-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiara', 'Ibiara', '58980-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igaracy', 'Igaracy', '58775-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Imaculada', 'Imaculada', '58745-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ingá', 'Inga', '58380-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itabaiana', 'Itabaiana', '58360-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itajubatiba', 'Itajubatiba', '58718-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaporanga', 'Itaporanga', '58780-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapororoca', 'Itapororoca', '58275-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itatuba', 'Itatuba', '58378-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacaraú', 'Jacarau', '58278-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jericó', 'Jerico', '58830-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Pessoa', 'Joao Pessoa', NULL, 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juarez Távora', 'Juarez Tavora', '58387-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juazeirinho', 'Juazeirinho', '58660-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Junco do Seridó', 'Junco Do Serido', '58640-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juripiranga', 'Juripiranga', '58330-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juru', 'Juru', '58750-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa', 'Lagoa', '58835-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa de Dentro', 'Lagoa De Dentro', '58250-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa de Dentro', 'Lagoa De Dentro', '58114-200', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Seca', 'Lagoa Seca', '58117-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lastro', 'Lastro', '58820-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lerolândia', 'Lerolandia', '58304-400', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Livramento', 'Livramento', '58690-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Logradouro', 'Logradouro', '58254-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lucena', 'Lucena', '58315-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mãe D''Água', 'Mae D''Agua', '58740-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maia', 'Maia', '58222-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Malta', 'Malta', '58713-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mamanguape', 'Mamanguape', '58280-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manaíra', 'Manaira', '58995-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marcação', 'Marcacao', '58294-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mari', 'Mari', '58345-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marizópolis', 'Marizopolis', '58819-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Massaranduba', 'Massaranduba', '58120-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mata Limpa', 'Mata Limpa', '58397-600', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mata Virgem', 'Mata Virgem', '58425-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mataraca', 'Mataraca', '58292-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matinhas', 'Matinhas', '58128-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mato Grosso', 'Mato Grosso', '58832-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maturéia', 'Matureia', '58737-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Melo', 'Melo', '58176-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mogeiro', 'Mogeiro', '58375-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montadas', 'Montadas', '58145-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Horebe', 'Monte Horebe', '58950-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monteiro', 'Monteiro', '58500-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montevidéu', 'Montevideu', '58975-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mulungu', 'Mulungu', '58354-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muquém', 'Muquem', '58397-700', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Natuba', 'Natuba', '58410-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nazaré', 'Nazare', '58152-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nazarezinho', 'Nazarezinho', '58817-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora do Livramento', 'Nossa Senhora Do Livramento', '58304-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Floresta', 'Nova Floresta', '58178-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Olinda', 'Nova Olinda', '58798-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Palmeira', 'Nova Palmeira', '58184-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Núcleo N 2', 'Nucleo N 2', '58814-500', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Núcleo N 3', 'Nucleo N 3', '58814-600', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Odilândia', 'Odilandia', '58304-600', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olho D'' Água', 'Olho D'' Agua', '58760-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olivedos', 'Olivedos', '58160-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Velho', 'Ouro Velho', '58560-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parari', 'Parari', '58575-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passagem', 'Passagem', '58734-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Patos', 'Patos', NULL, 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulista', 'Paulista', '58860-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Branca', 'Pedra Branca', '58790-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Lavrada', 'Pedra Lavrada', '58180-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedras de Fogo', 'Pedras De Fogo', '58328-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Régis', 'Pedro Regis', '58273-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pelo Sinal', 'Pelo Sinal', '58996-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pereiros', 'Pereiros', '58814-700', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piancó', 'Pianco', '58765-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Picuí', 'Picui', '58187-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pilar', 'Pilar', '58338-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pilões', 'Piloes', '58393-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pilõezinhos', 'Piloezinhos', '58210-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pindurão', 'Pindurao', '58533-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pio X', 'Pio X', '58545-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirauá', 'Piraua', '58415-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirpirituba', 'Pirpirituba', '58213-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pitanga de Estrada', 'Pitanga De Estrada', '58286-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pitimbu', 'Pitimbu', '58324-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pocinhos', 'Pocinhos', '58150-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço Dantas', 'Poco Dantas', '58933-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço de José de Moura', 'Poco De Jose De Moura', '58908-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pombal', 'Pombal', '58840-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porteirinha de Pedra', 'Porteirinha De Pedra', '58114-400', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prata', 'Prata', '58550-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Princesa Isabel', 'Princesa Isabel', '58755-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Puxinanã', 'Puxinana', '58115-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Queimadas', 'Queimadas', '58440-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quixabá', 'Quixaba', '58733-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quixadá', 'Quixada', '58917-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Remígio', 'Remigio', '58398-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riachão', 'Riachao', '58235-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riachão do Poço', 'Riachao Do Poco', '58348-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho de Santo Antônio', 'Riacho De Santo Antonio', '58465-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho dos Cavalos', 'Riacho Dos Cavalos', '58870-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeira', 'Ribeira', '58304-700', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Tinto', 'Rio Tinto', '58297-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rua Nova', 'Rua Nova', '58257-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salema', 'Salema', '58298-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salgadinho', 'Salgadinho', '58650-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salgado de São Félix', 'Salgado De Sao Felix', '58370-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cecília de Umbuzeiro', 'Santa Cecilia De Umbuzeiro', '58428-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz', 'Santa Cruz', '58824-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Gertrudes', 'Santa Gertrudes', '58709-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Helena', 'Santa Helena', '58925-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Inês', 'Santa Ines', '58978-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia', 'Santa Luzia', '58600-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia do Cariri', 'Santa Luzia Do Cariri', '58582-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria', 'Santa Maria', '58525-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita', 'Santa Rita', NULL, 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita', 'Santa Rita', '58919-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Teresinha', 'Santa Teresinha', '58720-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha', 'Santa Terezinha', '58114-600', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana de Mangueira', 'Santana De Mangueira', '58985-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana dos Garrotes', 'Santana Dos Garrotes', '58795-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santarém', 'Santarem', '58928-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo André', 'Santo Andre', '58675-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bento', 'Sao Bento', '58865-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bento de Pombal', 'Sao Bento De Pombal', '58857-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos de Pombal', 'Sao Domingos De Pombal', '58853-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos do Cariri', 'Sao Domingos Do Cariri', '58485-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco', 'Sao Francisco', '58818-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo', 'Sao Goncalo', '58814-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João Bosco', 'Sao Joao Bosco', '58916-500', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Cariri', 'Sao Joao Do Cariri', '58590-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Rio do Peixe', 'Sao Joao Do Rio Do Peixe', '58910-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Tigre', 'Sao Joao Do Tigre', '58520-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Lagoa Tapada', 'Sao Jose Da Lagoa Tapada', '58815-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Mata', 'Sao Jose Da Mata', '58113-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José de Caiana', 'Sao Jose De Caiana', '58784-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José de Espinharas', 'Sao Jose De Espinharas', '58723-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José de Marimbas', 'Sao Jose De Marimbas', '58938-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José de Piranhas', 'Sao Jose De Piranhas', '58940-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José de Princesa', 'Sao Jose De Princesa', '58758-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Bonfim', 'Sao Jose Do Bonfim', '58725-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Brejo do Cruz', 'Sao Jose Do Brejo Do Cruz', '58893-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Sabugi', 'Sao Jose Do Sabugi', '58610-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José dos Cordeiros', 'Sao Jose Dos Cordeiros', '58570-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José dos Ramos', 'Sao Jose Dos Ramos', '58339-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Mamede', 'Sao Mamede', '58625-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel de Taipú', 'Sao Miguel De Taipu', '58334-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '58828-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião de Lagoa de Roca', 'Sao Sebastiao De Lagoa De Roca', '58119-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Umbuzeiro', 'Sao Sebastiao Do Umbuzeiro', '58510-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapé', 'Sape', '58340-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Seridó', 'Serido', '58159-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente do Seridó', 'Sao Vicente Do Serido', '58158-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Branca', 'Serra Branca', '58580-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra da Raiz', 'Serra Da Raiz', '58260-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Grande', 'Serra Grande', '58955-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Redonda', 'Serra Redonda', '58385-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serraria', 'Serraria', '58395-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sertãozinho', 'Sertaozinho', '58268-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sobrado', 'Sobrado', '58342-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Solânea', 'Solanea', '58225-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Soledade', 'Soledade', '58155-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sossego', 'Sossego', '58177-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sucuru', 'Sucuru', '58586-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sumé', 'Sume', '58540-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo de Santana', 'Campo De Santana', '58240-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tambauzinho', 'Tambauzinho', '58304-800', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taperoá', 'Taperoa', '58680-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tavares', 'Tavares', '58753-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teixeira', 'Teixeira', '58735-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tenório', 'Tenorio', '58665-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Triunfo', 'Triunfo', '58920-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uiraúna', 'Uirauna', '58915-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umari', 'Umari', '58913-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umbuzeiro', 'Umbuzeiro', '58420-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea', 'Varzea', '58620-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea Comprida', 'Varzea Comprida', '58850-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea Nova', 'Varzea Nova', '58304-500', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vazante', 'Vazante', '58997-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vieirópolis', 'Vieiropolis', '58822-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Serrana', 'Vista Serrana', '58710-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Zabelê', 'Zabele', '58515-000', 'PB');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abreu e Lima', 'Abreu E Lima', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Afogados da Ingazeira', 'Afogados Da Ingazeira', '56800-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Afrânio', 'Afranio', '56360-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Agrestina', 'Agrestina', '55495-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Fria', 'Agua Fria', '55155-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Preta', 'Agua Preta', '55550-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas Belas', 'Aguas Belas', '55340-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Airi', 'Airi', '56410-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alagoinha', 'Alagoinha', '55260-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Albuquerque Né', 'Albuquerque Ne', '56610-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Algodões', 'Algodoes', '56625-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aliança', 'Alianca', '55890-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Altinho', 'Altinho', '55490-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amaraji', 'Amaraji', '55515-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ameixas', 'Ameixas', '55658-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angelim', 'Angelim', '55430-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apoti', 'Apoti', '55625-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araçoiaba', 'Aracoiaba', '53690-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araripina', 'Araripina', '56280-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arcoverde', 'Arcoverde', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aripibu', 'Aripibu', '55524-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arizona', 'Arizona', '56365-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra de Farias', 'Barra De Farias', '55172-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra de Guabiraba', 'Barra De Guabiraba', '55690-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra de São Pedro', 'Barra De Sao Pedro', '56205-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Brejo', 'Barra Do Brejo', '55332-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Chata', 'Barra Do Chata', '55498-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Jardim', 'Barra Do Jardim', '55496-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Riachão', 'Barra Do Riachao', '55672-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Sirinhaém', 'Barra Do Sirinhaem', '55585-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiros', 'Barreiros', '55560-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Batateira', 'Batateira', '55445-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belém de Maria', 'Belem De Maria', '55440-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belém de São Francisco', 'Belem De Sao Francisco', '56440-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belo Jardim', 'Belo Jardim', '55150-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bengalas', 'Bengalas', '55652-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bentivi', 'Bentivi', '55685-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bernardo Vieira', 'Bernardo Vieira', '56922-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Betânia', 'Betania', '56670-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bezerros', 'Bezerros', '55660-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bizarra', 'Bizarra', '55735-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boas Novas', 'Boas Novas', '55662-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bodocó', 'Bodoco', '56220-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Conselho', 'Bom Conselho', '55330-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jardim', 'Bom Jardim', '55730-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Nome', 'Bom Nome', '56970-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonfim', 'Bonfim', '56710-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonito', 'Bonito', '55680-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejão', 'Brejao', '55325-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejinho', 'Brejinho', '56740-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo da Madre de Deus', 'Brejo Da Madre De Deus', '55170-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buenos Aires', 'Buenos Aires', '55845-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buíque', 'Buique', '56520-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabanas', 'Cabanas', '55383-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabo de Santo Agostinho', 'Cabo De Santo Agostinho', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabrobó', 'Cabrobo', '56180-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira do Roberto', 'Cachoeira Do Roberto', '56370-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeirinha', 'Cachoeirinha', '55380-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caetés', 'Caetes', '55360-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiçarinha da Penha', 'Caicarinha Da Penha', '56916-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Calçado', 'Calcado', '55375-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caldeirões', 'Caldeiroes', '55338-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Calumbi', 'Calumbi', '56930-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camaragibe', 'Camaragibe', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camela', 'Camela', '55595-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camocim de São Félix', 'Camocim De Sao Felix', '55665-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camutanga', 'Camutanga', '55930-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canaã', 'Canaa', '56880-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canhotinho', 'Canhotinho', '55420-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capoeiras', 'Capoeiras', '55365-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraíba', 'Caraiba', '56393-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraibeiras', 'Caraibeiras', '56485-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carapotos', 'Carapotos', '55110-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carice', 'Carice', '55928-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carima', 'Carima', '55564-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caririmirim', 'Caririmirim', '56155-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carnaíba', 'Carnaiba', '56820-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carnaubeira da Penha', 'Carnaubeira Da Penha', '56420-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carneiro', 'Carneiro', '56533-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carpina', 'Carpina', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carqueja', 'Carqueja', '56415-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caruaru', 'Caruaru', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Casinhas', 'Casinhas', '55755-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catende', 'Catende', '55400-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catimbaú', 'Catimbau', '56537-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catolé', 'Catole', '55759-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cedro', 'Cedro', '56130-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chã de Alegria', 'Cha De Alegria', '55835-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chã do Rocha', 'Cha Do Rocha', '55748-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chã Grande', 'Cha Grande', '55636-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cimbres', 'Cimbres', '55205-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Clarana', 'Clarana', '56227-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cocau', 'Cocau', '56223-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cocau', 'Cocau', '55575-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição das Crioulas', 'Conceicao Das Crioulas', '56115-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Condado', 'Condado', '55940-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Correntes', 'Correntes', '55315-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cortês', 'Cortes', '55525-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Couro D''Antas', 'Couro D''Antas', '55121-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristália', 'Cristalia', '56340-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruanji', 'Cruanji', '55875-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzes', 'Cruzes', '55473-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cuiambuca', 'Cuiambuca', '55533-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cumaru', 'Cumaru', '55655-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cupira', 'Cupira', '55460-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curral Queimado', 'Curral Queimado', '56335-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Custódia', 'Custodia', '56640-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dois Leões', 'Dois Leoes', '55633-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dormentes', 'Dormentes', '56355-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Entroncamento', 'Entroncamento', '55453-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Escada', 'Escada', '55500-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espírito Santo', 'Espirito Santo', '55374-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Exu', 'Exu', '56230-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda Nova', 'Fazenda Nova', '55175-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Feira Nova', 'Feira Nova', '55715-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Feitoria', 'Feitoria', '56228-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fernando de Noronha', 'Fernando De Noronha', '53990-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ferreiros', 'Ferreiros', '55880-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flores', 'Flores', '56850-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floresta', 'Floresta', '56400-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frei Miguelinho', 'Frei Miguelinho', '55780-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frexeiras', 'Frexeiras', '55505-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gameleira', 'Gameleira', '55530-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Garanhuns', 'Garanhuns', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Glória do Goitá', 'Gloria Do Goita', '55620-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goiana', 'Goiana', '55900-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gonçalves Ferreira', 'Goncalves Ferreira', '55105-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Granito', 'Granito', '56160-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gravatá', 'Gravata', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gravatá do Ibiapina', 'Gravata Do Ibiapina', '55795-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Grotão', 'Grotao', '55275-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guanumbi', 'Guanumbi', '56535-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Henrique Dias', 'Henrique Dias', '56620-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iateca', 'Iateca', '55353-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iati', 'Iati', '55345-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibimirim', 'Ibimirim', '56580-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibirajuba', 'Ibirajuba', '55390-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiranga', 'Ibiranga', '55929-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiratinga', 'Ibiratinga', '55588-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitiranga', 'Ibitiranga', '56825-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibó', 'Ibo', '56450-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Icaiçara', 'Icaicara', '56165-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igapó', 'Igapo', '55322-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igarapeassu', 'Igarapeassu', '55455-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igarapeba', 'Igarapeba', '55412-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igarassu', 'Igarassu', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguaraci', 'Iguaraci', '56840-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inajá', 'Inaja', '56560-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ingazeira', 'Ingazeira', '56830-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipojuca', 'Ipojuca', '55590-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipubi', 'Ipubi', '56260-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipuera', 'Ipuera', '56145-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iraguaçu', 'Iraguacu', '56890-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irajaí', 'Irajai', '56845-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iratama', 'Iratama', '55304-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itacuruba', 'Itacuruba', '56430-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaíba', 'Itaiba', '56550-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itamaracá', 'Itamaraca', '53900-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itambé', 'Itambe', '55920-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapetim', 'Itapetim', '56720-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapissuma', 'Itapissuma', '53700-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaquitinga', 'Itaquitinga', '55950-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ituguaçu', 'Ituguacu', '55493-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iuiteporã', 'Iuitepora', '55682-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jabitaca', 'Jabitaca', '56848-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaboatão dos Guararapes', 'Jaboatao Dos Guararapes', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japecanga', 'Japecanga', '55287-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaqueira', 'Jaqueira', '55409-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jataúba', 'Jatauba', '55180-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jatiúca', 'Jatiuca', '56885-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jatobá', 'Jatoba', '56470-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jenipapo', 'Jenipapo', '55258-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Alfredo', 'Joao Alfredo', '55720-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joaquim Nabuco', 'Joaquim Nabuco', '55535-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('José da Costa', 'Jose Da Costa', '55534-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('José Mariano', 'Jose Mariano', '55522-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juçaral', 'Jucaral', '54570-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jucati', 'Jucati', '55398-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jupi', 'Jupi', '55395-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jurema', 'Jurema', '55480-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jutaí', 'Jutai', '56390-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa', 'Lagoa', '56350-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa de São José', 'Lagoa De Sao Jose', '55336-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Barro', 'Lagoa Do Barro', '56284-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Carro', 'Lagoa Do Carro', '55820-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Itaenga', 'Lagoa Do Itaenga', '55840-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Ouro', 'Lagoa Do Ouro', '55320-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Souza', 'Lagoa Do Souza', '55458-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa dos Gatos', 'Lagoa Dos Gatos', '55450-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Grande', 'Lagoa Grande', '56395-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laje de São José', 'Laje De Sao Jose', '55465-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laje Grande', 'Laje Grande', '55402-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajedo', 'Lajedo', '55385-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajedo do Cedro', 'Lajedo Do Cedro', '55108-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Limoeiro', 'Limoeiro', '55700-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Livramento do Tiúma', 'Livramento Do Tiuma', '55878-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luanda', 'Luanda', '56918-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macaparana', 'Macaparana', '55865-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Machados', 'Machados', '55740-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macujé', 'Macuje', '55898-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manari', 'Manari', '56565-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mandacaia', 'Mandacaia', '55174-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mandacaru', 'Mandacaru', '55646-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maniçoba', 'Manicoba', '55135-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maraial', 'Maraial', '55405-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maravilha', 'Maravilha', '56650-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mimoso', 'Mimoso', '55225-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miracica', 'Miracica', '55303-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirandiba', 'Mirandiba', '56980-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morais', 'Morais', '56287-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moreilândia', 'Moreilandia', '56150-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moreno', 'Moreno', '54800-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moxotó', 'Moxoto', '56585-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mulungu', 'Mulungu', '55255-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Murupé', 'Murupe', '55855-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mutuca', 'Mutuca', '55210-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nascente', 'Nascente', '56285-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nazaré da Mata', 'Nazare Da Mata', '55800-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Negras', 'Negras', '56555-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora da Luz', 'Nossa Senhora Da Luz', '54749-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora do Carmo', 'Nossa Senhora Do Carmo', '55634-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora do Ó', 'Nossa Senhora Do O', '55592-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Cruz', 'Nova Cruz', '53660-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olho D''Água de Dentro', 'Olho D''Agua De Dentro', '55423-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oratório', 'Oratorio', '55758-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ori', 'Ori', '56148-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Orobó', 'Orobo', '55745-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Orocó', 'Oroco', '56170-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouricuri', 'Ouricuri', '56200-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pajeú', 'Pajeu', '56920-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmares', 'Palmares', '55540-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeirina', 'Palmeirina', '55310-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Panelas', 'Panelas', '55470-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pão de Açúcar', 'Pao De Acucar', '55798-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pão de Açúcar do Poção', 'Pao De Acucar Do Pocao', '55245-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Papagaio', 'Papagaio', '55215-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paquevira', 'Paquevira', '55425-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pará', 'Para', '55198-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranatama', 'Paranatama', '55355-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parnamirim', 'Parnamirim', '56163-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passagem do Tó', 'Passagem Do To', '55185-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passira', 'Passira', '55650-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pau Ferro', 'Pau Ferro', '55418-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paudalho', 'Paudalho', '55825-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulista', 'Paulista', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra', 'Pedra', '55280-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Perpétuo Socorro', 'Perpetuo Socorro', '55265-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pesqueira', 'Pesqueira', '55200-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Petrolândia', 'Petrolandia', '56460-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Petrolina', 'Petrolina', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirituba', 'Pirituba', '55618-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poção', 'Pocao', '55240-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poção de Afrânio', 'Pocao De Afranio', '56375-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço Comprido', 'Poco Comprido', '55317-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço Fundo', 'Poco Fundo', '55195-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pombos', 'Pombos', '55630-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontas de Pedra', 'Pontas De Pedra', '55908-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte dos Carvalhos', 'Ponte Dos Carvalhos', '54580-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Primavera', 'Primavera', '55510-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quipapá', 'Quipapa', '55415-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quitimbu', 'Quitimbu', '56660-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quixabá', 'Quixaba', '56828-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rainha Isabel', 'Rainha Isabel', '55334-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rajada', 'Rajada', '56345-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rancharia', 'Rancharia', '56282-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Recife', 'Recife', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho das Almas', 'Riacho Das Almas', '55120-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho do Meio', 'Riacho Do Meio', '56705-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho Fechado', 'Riacho Fechado', '55145-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho Pequeno', 'Riacho Pequeno', '56445-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão', 'Ribeirao', '55520-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio da Barra', 'Rio Da Barra', '56615-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Formoso', 'Rio Formoso', '55570-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sairé', 'Saire', '55695-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salgadinho', 'Salgadinho', '55675-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salgueiro', 'Salgueiro', '56000-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saloá', 'Saloa', '55350-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salobro', 'Salobro', '55220-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sanharó', 'Sanharo', '55250-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz', 'Santa Cruz', '56215-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz da Baixa Verde', 'Santa Cruz Da Baixa Verde', '56895-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz do Capibaribe', 'Santa Cruz Do Capibaribe', '55190-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Filomena', 'Santa Filomena', '56210-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria da Boa Vista', 'Santa Maria Da Boa Vista', '56380-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria do Cambucá', 'Santa Maria Do Cambuca', '55765-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita', 'Santa Rita', '56770-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha', 'Santa Terezinha', '56750-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha', 'Santa Terezinha', '55552-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana de São Joaquim', 'Santana De Sao Joaquim', '55674-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Agostinho', 'Santo Agostinho', '54590-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio das Queimadas', 'Santo Antonio Das Queimadas', '55485-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio dos Palmares', 'Santo Antonio Dos Palmares', '55548-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Benedito do Sul', 'Sao Benedito Do Sul', '55410-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bento do Una', 'Sao Bento Do Una', '55370-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Caetano do Navio', 'Sao Caetano Do Navio', '56680-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Caitano', 'Sao Caitano', '55130-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos', 'Sao Domingos', '55178-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João', 'Sao Joao', '55435-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim do Monte', 'Sao Joaquim Do Monte', '55670-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José', 'Sao Jose', '55475-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Coroa Grande', 'Sao Jose Da Coroa Grande', '55565-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Belmonte', 'Sao Jose Do Belmonte', '56950-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Egito', 'Sao Jose Do Egito', '56700-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Lázaro', 'Sao Lazaro', '55478-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Lourenço da Mata', 'Sao Lourenco Da Mata', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '55302-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente', 'Sao Vicente', '56730-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente Ferrer', 'Sao Vicente Ferrer', '55860-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapucarana', 'Sapucarana', '55661-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Branca', 'Serra Branca', '56265-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra do Vento', 'Serra Do Vento', '55160-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Talhada', 'Serra Talhada', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrita', 'Serrita', '56140-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrolândia', 'Serrolandia', '56270-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sertânia', 'Sertania', '56600-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sertãozinho de Baixo', 'Sertaozinho De Baixo', '55408-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Siriji', 'Siriji', '55863-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sirinhaém', 'Sirinhaem', '55580-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sítio dos Nunes', 'Sitio Dos Nunes', '56860-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Solidão', 'Solidao', '56795-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Surubim', 'Surubim', '55750-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabira', 'Tabira', '56780-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabocas', 'Tabocas', '56240-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tacaimbó', 'Tacaimbo', '55140-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tacaratu', 'Tacaratu', '56480-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tamandaré', 'Tamandare', '55578-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tamboatá', 'Tamboata', '55733-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapiraim', 'Tapiraim', '55138-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquaritinga do Norte', 'Taquaritinga Do Norte', '55790-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tara', 'Tara', '55285-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tauapiranga', 'Tauapiranga', '56925-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tejucupapo', 'Tejucupapo', '55905-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terezinha', 'Terezinha', '55305-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terra Nova', 'Terra Nova', '56190-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timbaúba', 'Timbauba', '55870-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timorante', 'Timorante', '56234-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Toritama', 'Toritama', '55125-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tracunhaém', 'Tracunhaem', '55805-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trapiá', 'Trapia', '55122-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Ladeiras', 'Tres Ladeiras', '53670-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trindade', 'Trindade', '56250-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Triunfo', 'Triunfo', '56870-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupanaci', 'Tupanaci', '56990-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupanatinga', 'Tupanatinga', '56540-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupaóca', 'Tupaoca', '55895-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tuparetama', 'Tuparetama', '56760-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umãs', 'Umas', '56105-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umburetama', 'Umburetama', '55746-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Upatininga', 'Upatininga', '55896-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urimama', 'Urimama', '56386-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uruçu-Mirim', 'Urucu-Mirim', '55648-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urucubá', 'Urucuba', '55705-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vasques', 'Vasques', '56110-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Veneza', 'Veneza', '56168-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Venturosa', 'Venturosa', '55270-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Verdejante', 'Verdejante', '56120-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vertente do Lério', 'Vertente Do Lerio', '55760-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vertentes', 'Vertentes', '55770-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vicência', 'Vicencia', '55850-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nova', 'Vila Nova', '55757-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Viração', 'Viracao', '56236-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vitória de Santo Antão', 'Vitoria De Santo Antao', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Volta do Moxotó', 'Volta Do Moxoto', '56475-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xexéu', 'Xexeu', '55555-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xucuru', 'Xucuru', '55165-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Zé Gomes', 'Ze Gomes', '56245-000', 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acauã', 'Acaua', '64748-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Agricolândia', 'Agricolandia', '64440-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Branca', 'Agua Branca', '64460-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alagoinha do Piauí', 'Alagoinha Do Piaui', '64655-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alegrete do Piauí', 'Alegrete Do Piaui', '64675-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Longá', 'Alto Longa', '64360-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Altos', 'Altos', '64290-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvorada do Gurguéia', 'Alvorada Do Gurgueia', '64923-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amarante', 'Amarante', '64400-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angical do Piauí', 'Angical Do Piaui', '64410-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anísio de Abreu', 'Anisio De Abreu', '64780-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Almeida', 'Antonio Almeida', '64855-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aroazes', 'Aroazes', '64310-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arraial', 'Arraial', '64480-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Assunção do Piauí', 'Assuncao Do Piaui', '64333-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Avelino Lopes', 'Avelino Lopes', '64965-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baixa Grande do Ribeiro', 'Baixa Grande Do Ribeiro', '64868-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra D''Alcântara', 'Barra D''Alcantara', '64528-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barras', 'Barras', '64100-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiras do Piauí', 'Barreiras Do Piaui', '64990-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barro Duro', 'Barro Duro', '64455-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Batalha', 'Batalha', '64190-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista do Piauí', 'Bela Vista Do Piaui', '64705-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belém do Piauí', 'Belem Do Piaui', '64678-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Beneditinos', 'Beneditinos', '64380-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bertolínia', 'Bertolinia', '64870-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Betânia do Piauí', 'Betania Do Piaui', '64753-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Hora', 'Boa Hora', '64108-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bocaina', 'Bocaina', '64630-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus', 'Bom Jesus', '64900-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Princípio do Piauí', 'Bom Principio Do Piaui', '64225-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonfim do Piauí', 'Bonfim Do Piaui', '64775-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boqueirão do Piauí', 'Boqueirao Do Piaui', '64283-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brasileira', 'Brasileira', '64265-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo do Piauí', 'Brejo Do Piaui', '64895-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buriti dos Lopes', 'Buriti Dos Lopes', '64230-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buriti dos Montes', 'Buriti Dos Montes', '64345-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabeceiras do Piauí', 'Cabeceiras Do Piaui', '64105-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cajazeiras do Piauí', 'Cajazeiras Do Piaui', '64514-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cajueiro da Praia', 'Cajueiro Da Praia', '64222-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caldeirão Grande do Piauí', 'Caldeirao Grande Do Piaui', '64695-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campinas do Piauí', 'Campinas Do Piaui', '64730-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Alegre do Fidalgo', 'Campo Alegre Do Fidalgo', '64767-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Grande do Piauí', 'Campo Grande Do Piaui', '64578-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Largo do Piauí', 'Campo Largo Do Piaui', '64148-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Maior', 'Campo Maior', '64280-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canavieira', 'Canavieira', '64833-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canto do Buriti', 'Canto Do Buriti', '64890-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capitão de Campos', 'Capitao De Campos', '64270-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capitão Gervásio Oliveira', 'Capitao Gervasio Oliveira', '64763-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caracol', 'Caracol', '64795-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraúbas do Piauí', 'Caraubas Do Piaui', '64233-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caridade do Piauí', 'Caridade Do Piaui', '64590-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Castelo do Piauí', 'Castelo Do Piaui', '64340-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cocal', 'Cocal', '64235-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cocal de Telha', 'Cocal De Telha', '64278-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cocal dos Alves', 'Cocal Dos Alves', '64238-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coivaras', 'Coivaras', '64335-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia do Gurguéia', 'Colonia Do Gurgueia', '64885-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia do Piauí', 'Colonia Do Piaui', '64516-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Canindé', 'Conceicao Do Caninde', '64740-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel José Dias', 'Coronel Jose Dias', '64793-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corrente', 'Corrente', '64980-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristalândia do Piauí', 'Cristalandia Do Piaui', '64995-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristino Castro', 'Cristino Castro', '64920-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curimatá', 'Curimata', '64960-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Currais', 'Currais', '64905-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curral Novo do Piauí', 'Curral Novo Do Piaui', '64595-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curralinhos', 'Curralinhos', '64453-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Demerval Lobão', 'Demerval Lobao', '64390-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dirceu Arcoverde', 'Dirceu Arcoverde', '64785-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Expedito Lopes', 'Dom Expedito Lopes', '64620-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Inocêncio', 'Dom Inocencio', '64790-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Domingos Mourão', 'Domingos Mourao', '64250-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Elesbão Veloso', 'Elesbao Veloso', '64325-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eliseu Martins', 'Eliseu Martins', '64880-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esperantina', 'Esperantina', '64180-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fartura do Piauí', 'Fartura Do Piaui', '64788-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flores do Piauí', 'Flores Do Piaui', '64815-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floresta do Piauí', 'Floresta Do Piaui', '64563-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floriano', 'Floriano', '64800-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Francinópolis', 'Francinopolis', '64520-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Francisco Ayres', 'Francisco Ayres', '64475-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Francisco Macedo', 'Francisco Macedo', '64683-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Francisco Santos', 'Francisco Santos', '64645-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fronteiras', 'Fronteiras', '64690-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Geminiano', 'Geminiano', '64613-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gilbués', 'Gilbues', '64930-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guadalupe', 'Guadalupe', '64840-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaribas', 'Guaribas', '64798-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Hugo Napoleão', 'Hugo Napoleao', '64470-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilha Grande', 'Ilha Grande', '64224-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhuma', 'Inhuma', '64535-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipiranga do Piauí', 'Ipiranga Do Piaui', '64540-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Isaías Coelho', 'Isaias Coelho', '64570-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itainópolis', 'Itainopolis', '64565-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaueira', 'Itaueira', '64820-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacobina do Piauí', 'Jacobina Do Piaui', '64755-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaicós', 'Jaicos', '64575-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim do Mulato', 'Jardim Do Mulato', '64495-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jatobá do Piauí', 'Jatoba Do Piaui', '64275-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jerumenha', 'Jerumenha', '64830-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Costa', 'Joao Costa', '64765-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joaquim Pires', 'Joaquim Pires', '64170-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joca Marques', 'Joca Marques', '64165-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('José de Freitas', 'Jose De Freitas', '64110-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juazeiro do Piauí', 'Juazeiro Do Piaui', '64343-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Júlio Borges', 'Julio Borges', '64963-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jurema', 'Jurema', '64782-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Alegre', 'Lagoa Alegre', '64138-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa de São Francisco', 'Lagoa De Sao Francisco', '64258-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Barro do Piauí', 'Lagoa Do Barro Do Piaui', '64768-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Piauí', 'Lagoa Do Piaui', '64388-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Sítio', 'Lagoa Do Sitio', '64308-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoinha do Piauí', 'Lagoinha Do Piaui', '64465-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Landri Sales', 'Landri Sales', '64850-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luís Correia', 'Luis Correia', '64220-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luzilândia', 'Luzilandia', '64160-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Madeiro', 'Madeiro', '64168-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manoel Emídio', 'Manoel Emidio', '64875-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marcolândia', 'Marcolandia', '64685-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marcos Parente', 'Marcos Parente', '64845-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Massapê do Piauí', 'Massape Do Piaui', '64573-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matias Olímpio', 'Matias Olimpio', '64150-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miguel Alves', 'Miguel Alves', '64130-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miguel Leão', 'Miguel Leao', '64445-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Milton Brandão', 'Milton Brandao', '64253-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monsenhor Gil', 'Monsenhor Gil', '64450-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monsenhor Hipólito', 'Monsenhor Hipolito', '64650-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre do Piauí', 'Monte Alegre Do Piaui', '64940-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro Cabeça no Tempo', 'Morro Cabeca No Tempo', '64968-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro do Chapéu do Piauí', 'Morro Do Chapeu Do Piaui', '64178-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Murici dos Portelas', 'Murici Dos Portelas', '64175-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nazaré do Piauí', 'Nazare Do Piaui', '64825-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora de Nazaré', 'Nossa Senhora De Nazare', '64288-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora dos Remédios', 'Nossa Senhora Dos Remedios', '64140-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Santa Rita', 'Nova Santa Rita', '64764-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Nilo', 'Novo Nilo', '64125-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Oriente do Piauí', 'Novo Oriente Do Piaui', '64530-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Santo Antônio', 'Novo Santo Antonio', '64365-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oeiras', 'Oeiras', '64500-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olho D''Água do Piauí', 'Olho D''Agua Do Piaui', '64468-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Marcos', 'Padre Marcos', '64680-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paes Landim', 'Paes Landim', '64710-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pajeú do Piauí', 'Pajeu Do Piaui', '64898-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeira do Piauí', 'Palmeira Do Piaui', '64925-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeirais', 'Palmeirais', '64420-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paquetá', 'Paqueta', '64618-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parnaguá', 'Parnagua', '64970-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parnaíba', 'Parnaiba', NULL, 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passagem Franca do Piauí', 'Passagem Franca Do Piaui', '64395-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Patos do Piauí', 'Patos Do Piaui', '64580-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulistana', 'Paulistana', '64750-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pavussu', 'Pavussu', '64838-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro II', 'Pedro Ii', '64255-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Laurentino', 'Pedro Laurentino', '64728-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Picos', 'Picos', '64600-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pimenteiras', 'Pimenteiras', '64320-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pio IX', 'Pio Ix', '64660-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piracuruca', 'Piracuruca', '64240-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piripiri', 'Piripiri', '64260-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto', 'Porto', '64145-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Alegre do Piauí', 'Porto Alegre Do Piaui', '64858-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prata do Piauí', 'Prata Do Piaui', '64370-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Queimada Nova', 'Queimada Nova', '64758-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Redenção do Gurguéia', 'Redencao Do Gurgueia', '64915-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Regeneração', 'Regeneracao', '64490-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho Frio', 'Riacho Frio', '64975-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeira do Piauí', 'Ribeira Do Piaui', '64725-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeiro Gonçalves', 'Ribeiro Goncalves', '64865-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Grande do Piauí', 'Rio Grande Do Piaui', '64835-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz do Piauí', 'Santa Cruz Do Piaui', '64545-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz dos Milagres', 'Santa Cruz Dos Milagres', '64315-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Filomena', 'Santa Filomena', '64945-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luz', 'Santa Luz', '64910-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa do Piauí', 'Santa Rosa Do Piaui', '64518-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Piauí', 'Santana Do Piaui', '64615-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio de Lisboa', 'Santo Antonio De Lisboa', '64640-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio dos Milagres', 'Santo Antonio Dos Milagres', '64438-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Inácio do Piauí', 'Santo Inacio Do Piaui', '64560-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Braz do Piauí', 'Sao Braz Do Piaui', '64783-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Félix do Piauí', 'Sao Felix Do Piaui', '64375-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco de Assis do Piauí', 'Sao Francisco De Assis Do Piaui', '64745-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco do Piauí', 'Sao Francisco Do Piaui', '64550-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo do Gurguéia', 'Sao Goncalo Do Gurgueia', '64993-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo do Piauí', 'Sao Goncalo Do Piaui', '64435-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Canabrava', 'Sao Joao Da Canabrava', '64635-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Fronteira', 'Sao Joao Da Fronteira', '64243-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Serra', 'Sao Joao Da Serra', '64350-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Varjota', 'Sao Joao Da Varjota', '64510-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Arraial', 'Sao Joao Do Arraial', '64155-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Piauí', 'Sao Joao Do Piaui', '64760-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Divino', 'Sao Jose Do Divino', '64245-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Peixe', 'Sao Jose Do Peixe', '64555-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Piauí', 'Sao Jose Do Piaui', '64625-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Julião', 'Sao Juliao', '64670-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Lourenço do Piauí', 'Sao Lourenco Do Piaui', '64778-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luís do Piauí', 'Sao Luis Do Piaui', '64638-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel da Baixa Grande', 'Sao Miguel Da Baixa Grande', '64378-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel do Fidalgo', 'Sao Miguel Do Fidalgo', '64558-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel do Tapuio', 'Sao Miguel Do Tapuio', '64330-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro do Piauí', 'Sao Pedro Do Piaui', '64430-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Raimundo Nonato', 'Sao Raimundo Nonato', '64770-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sebastião Barros', 'Sebastiao Barros', '64985-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sebastião Leal', 'Sebastiao Leal', '64873-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sigefredo Pacheco', 'Sigefredo Pacheco', '64285-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Simões', 'Simoes', '64585-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Simplício Mendes', 'Simplicio Mendes', '64700-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Socorro do Piauí', 'Socorro Do Piaui', '64720-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sussuapara', 'Sussuapara', '64610-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tamboril do Piauí', 'Tamboril Do Piaui', '64893-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tanque do Piauí', 'Tanque Do Piaui', '64512-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teresina', 'Teresina', NULL, 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('União', 'Uniao', '64120-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uruçuí', 'Urucui', '64860-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valença do Piauí', 'Valenca Do Piaui', '64300-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea Branca', 'Varzea Branca', '64773-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea Grande', 'Varzea Grande', '64525-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vera Mendes', 'Vera Mendes', '64568-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nova do Piauí', 'Vila Nova Do Piaui', '64688-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Wall Ferraz', 'Wall Ferraz', '64548-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abapã', 'Abapa', '84185-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abatiá', 'Abatia', '86460-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acampamento das Minas', 'Acampamento Das Minas', '84277-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Açungui', 'Acungui', '83550-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Adhemar de Barros', 'Adhemar De Barros', '87895-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Adrianópolis', 'Adrianopolis', '83490-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Agostinho', 'Agostinho', '84194-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Azul', 'Agua Azul', '83770-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Boa', 'Agua Boa', '87145-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Branca', 'Agua Branca', '85139-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Mineral', 'Agua Mineral', '85126-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Vermelha', 'Agua Vermelha', '84197-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Agudos do Sul', 'Agudos Do Sul', '83850-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alecrim', 'Alecrim', '84284-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alexandra', 'Alexandra', '83250-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Almirante Tamandaré', 'Almirante Tamandare', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Altamira do Paraná', 'Altamira Do Parana', '85280-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Altaneira', 'Altaneira', '87108-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Alegre', 'Alto Alegre', '86695-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Alegre', 'Alto Alegre', '87523-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Alegre do Iguaçu', 'Alto Alegre Do Iguacu', '85794-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Amparo', 'Alto Amparo', '84277-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto do Amparo', 'Alto Do Amparo', '84305-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Pará', 'Alto Para', '85823-950', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Paraná', 'Alto Parana', '87750-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Piquiri', 'Alto Piquiri', '87580-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Porã', 'Alto Pora', '86875-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Sabiá', 'Alto Sabia', '85138-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Santa Fé', 'Alto Santa Fe', '85931-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto São João', 'Alto Sao Joao', '87323-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Altônia', 'Altonia', '87550-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvorada do Iguaçu', 'Alvorada Do Iguacu', '85872-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvorada do Sul', 'Alvorada Do Sul', '86150-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amaporã', 'Amapora', '87850-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amorinha', 'Amorinha', '84910-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ampére', 'Ampere', '85640-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anahy', 'Anahy', '85425-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Andirá', 'Andira', '86380-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Andorinhas', 'Andorinhas', '84194-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angai', 'Angai', '84538-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ângulo', 'Angulo', '86755-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antas', 'Antas', '85322-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antas', 'Antas', '84277-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antonina', 'Antonina', '83370-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Brandão de Oliveira', 'Antonio Brandao De Oliveira', '86213-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Olinto', 'Antonio Olinto', '83980-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anunciação', 'Anunciacao', '85654-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida do Oeste', 'Aparecida Do Oeste', '87455-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apiaba', 'Apiaba', '84433-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apucarana', 'Apucarana', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aquidaban', 'Aquidaban', '86995-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aranha', 'Aranha', '83419-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arapongas', 'Arapongas', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arapoti', 'Arapoti', '84990-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arapuã', 'Arapua', '86884-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arapuan', 'Arapuan', '87385-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ararapira', 'Ararapira', '83393-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araucária', 'Araucaria', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areia Branca dos Assis', 'Areia Branca Dos Assis', '83810-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areias', 'Areias', '84198-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aricanduva', 'Aricanduva', '86719-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ariranha do Ivaí', 'Ariranha Do Ivai', '86880-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aroeira', 'Aroeira', '85822-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arquimedes', 'Arquimedes', '85824-750', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Assaí', 'Assai', '86220-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Assis Chateaubriand', 'Assis Chateaubriand', '85935-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Astorga', 'Astorga', '86730-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Atalaia', 'Atalaia', '87630-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aurora do Iguaçu', 'Aurora Do Iguacu', '85878-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bairro Cachoeira', 'Bairro Cachoeira', '85137-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bairro do Felisberto', 'Bairro Do Felisberto', '84277-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bairro Limoeiro', 'Bairro Limoeiro', '86102-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Balsa Nova', 'Balsa Nova', '83650-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bandeirantes', 'Bandeirantes', '86360-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bandeirantes d''Oeste', 'Bandeirantes D''Oeste', '87368-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Banhado', 'Banhado', '85138-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão de Lucena', 'Barao De Lucena', '87610-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barbosa Ferraz', 'Barbosa Ferraz', '86960-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Bonita', 'Barra Bonita', '85609-100', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Bonita', 'Barra Bonita', '85245-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Jacaré', 'Barra Do Jacare', '86385-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Grande', 'Barra Grande', '85584-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Grande', 'Barra Grande', '85752-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Grande', 'Barra Grande', '84125-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Santa Salete', 'Barra Santa Salete', '85265-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barracão', 'Barracao', '85700-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barras', 'Barras', '87316-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiro', 'Barreiro', '85822-950', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiro', 'Barreiro', '85136-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiro', 'Barreiro', '84380-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiro das Frutas', 'Barreiro Das Frutas', '87315-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiros', 'Barreiros', '86817-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barrinha', 'Barrinha', '84197-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barro Preto', 'Barro Preto', '85822-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barro Preto', 'Barro Preto', '86119-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barro Preto', 'Barro Preto', '83153-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bateias', 'Bateias', '83648-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baulândia', 'Baulandia', '85613-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista', 'Bela Vista', '85406-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista', 'Bela Vista', '85267-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista do Caroba', 'Bela Vista Do Caroba', '85745-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista do Ivaí', 'Bela Vista Do Ivai', '86953-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista do Paraíso', 'Bela Vista Do Paraiso', '86130-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista do Piquiri', 'Bela Vista Do Piquiri', '87347-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista do Tapiracui', 'Bela Vista Do Tapiracui', '87440-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bentópolis', 'Bentopolis', '86625-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bernardelli', 'Bernardelli', '87805-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Betaras', 'Betaras', '83531-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bituruna', 'Bituruna', '84640-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Esperança', 'Boa Esperanca', '87390-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Esperança', 'Boa Esperanca', '87317-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Esperança do Iguaçu', 'Boa Esperanca Do Iguacu', '85680-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Ventura de São Roque', 'Boa Ventura De Sao Roque', '85225-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', '83649-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', '85514-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', '84125-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', '85926-850', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', '85258-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista da Aparecida', 'Boa Vista Da Aparecida', '85780-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bocaina', 'Bocaina', '84125-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bocaiúva do Sul', 'Bocaiuva Do Sul', '83450-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jardim do Sul', 'Bom Jardim Do Sul', '84465-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus do Sul', 'Bom Jesus Do Sul', '85708-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Progresso', 'Bom Progresso', '86728-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Retiro', 'Bom Retiro', '85823-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Retiro', 'Bom Retiro', '85122-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Retiro', 'Bom Retiro', '85514-250', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Retiro', 'Bom Retiro', '85175-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Sucesso', 'Bom Sucesso', '86940-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Sucesso', 'Bom Sucesso', '85139-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Sucesso do Sul', 'Bom Sucesso Do Sul', '85515-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Borda do Campo', 'Borda Do Campo', '83425-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Borman', 'Borman', '85405-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Borrazópolis', 'Borrazopolis', '86925-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Botuquara', 'Botuquara', '84126-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bourbonia', 'Bourbonia', '86963-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Braganey', 'Braganey', '85430-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bragantina', 'Bragantina', '85937-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brasilândia do Sul', 'Brasilandia Do Sul', '87595-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bugre', 'Bugre', '83660-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bulcão', 'Bulcao', '84193-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabrito', 'Cabrito', '87729-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cacatu', 'Cacatu', '83375-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira', 'Cachoeira', '85823-750', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira de Cima', 'Cachoeira De Cima', '83380-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira de São José', 'Cachoeira De Sao Jose', '83181-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira do Espírito Santo', 'Cachoeira Do Espirito Santo', '86415-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeirinha', 'Cachoeirinha', '85139-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeirinha', 'Cachoeirinha', '85514-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cadeadinho', 'Cadeadinho', '84518-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caetano Mendes', 'Caetano Mendes', '84315-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cafeara', 'Cafeara', '86640-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cafeeiros', 'Cafeeiros', '87405-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cafelândia', 'Cafelandia', '85415-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cafezal do Sul', 'Cafezal Do Sul', '87565-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caitá', 'Caita', '83920-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Califórnia', 'California', '86820-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Calógeras', 'Calogeras', '84995-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cambará', 'Cambara', '86390-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cambé', 'Cambe', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cambiju', 'Cambiju', '84127-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cambira', 'Cambira', '86890-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campestrinho', 'Campestrinho', '83729-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campina', 'Campina', '83649-350', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campina', 'Campina', '85107-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campina', 'Campina', '83159-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campina da Lagoa', 'Campina Da Lagoa', '87345-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campina do Miranguava', 'Campina Do Miranguava', '83154-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campina do Simão', 'Campina Do Simao', '85148-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campina dos Furtados', 'Campina Dos Furtados', '83161-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campina Grande do Sul', 'Campina Grande Do Sul', '83430-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campinas', 'Campinas', '83649-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Bonito', 'Campo Bonito', '85450-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo do Meio', 'Campo Do Meio', '84128-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo do Tenente', 'Campo Do Tenente', '83870-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Largo', 'Campo Largo', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Largo da Roseira', 'Campo Largo Da Roseira', '83183-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Magro', 'Campo Magro', '83535-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Mourão', 'Campo Mourao', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cândido de Abreu', 'Candido De Abreu', '84470-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Candói', 'Candoi', '85140-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canela', 'Canela', '85612-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cantagalo', 'Cantagalo', '85160-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canzianópolis', 'Canzianopolis', '85735-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capanema', 'Capanema', '85760-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão Alto', 'Capao Alto', '84196-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão Alto', 'Capao Alto', '85138-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão Bonito', 'Capao Bonito', '85138-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão da Lagoa', 'Capao Da Lagoa', '85120-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão Grande', 'Capao Grande', '84127-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão Rico', 'Capao Rico', '85121-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capitão Leônidas Marques', 'Capitao Leonidas Marques', '85790-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capivara', 'Capivara', '83534-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capoeirinha', 'Capoeirinha', '84199-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cara Pintado', 'Cara Pintado', '85106-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cará-Cará', 'Cara-Cara', '84126-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carajá', 'Caraja', '85837-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carambeí', 'Carambei', '84145-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caramuru', 'Caramuru', '86199-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caratuva', 'Caratuva', '84998-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carazinho', 'Carazinho', '84127-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carbonera', 'Carbonera', '87483-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carlópolis', 'Carlopolis', '86420-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Casa Nova', 'Casa Nova', '84194-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cascatinha', 'Cascatinha', '86199-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Castro', 'Castro', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catanduvas', 'Catanduvas', '85470-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catanduvas', 'Catanduvas', '84199-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catanduvas do Sul', 'Catanduvas Do Sul', '83740-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catarinenses', 'Catarinenses', '87724-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caxambu', 'Caxambu', '84194-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Centenário', 'Centenario', '84126-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Centenário do Sul', 'Centenario Do Sul', '86630-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Central Lupion', 'Central Lupion', '85823-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Centralito', 'Centralito', '85823-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Centro Novo', 'Centro Novo', '85754-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerne', 'Cerne', '83649-450', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerrado Grande', 'Cerrado Grande', '84126-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerro Azul', 'Cerro Azul', '83570-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerro Velho', 'Cerro Velho', '84127-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Céu Azul', 'Ceu Azul', '85840-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chopinzinho', 'Chopinzinho', '85560-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cianorte', 'Cianorte', '87200-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cidade Gaúcha', 'Cidade Gaucha', '87820-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cintra Pimentel', 'Cintra Pimentel', '87975-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Clevelândia', 'Clevelandia', '85530-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coitinho', 'Coitinho', '85137-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colombo', 'Colombo', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Acioli', 'Colonia Acioli', '83151-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Castelhanos', 'Colonia Castelhanos', '83165-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Castrolânda', 'Colonia Castrolanda', '84196-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Centenário', 'Colonia Centenario', '85822-550', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Cristina', 'Colonia Cristina', '83729-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Dom Carlos', 'Colonia Dom Carlos', '85514-100', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Esperança', 'Colonia Esperanca', '85822-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia General Carneiro', 'Colonia General Carneiro', '84662-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Iapó', 'Colonia Iapo', '84193-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Melissa', 'Colonia Melissa', '85822-650', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Murici', 'Colonia Murici', '83185-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Padre Paulo', 'Colonia Padre Paulo', '83855-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Pereira', 'Colonia Pereira', '83251-850', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Santos Andrade', 'Colonia Santos Andrade', '83162-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia São José', 'Colonia Sao Jose', '85823-650', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Sapucaí', 'Colonia Sapucai', '85822-750', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Saúde', 'Colonia Saude', '86118-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Tapera', 'Colonia Tapera', '84127-100', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colorado', 'Colorado', '86690-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Comur', 'Comur', '87870-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição', 'Conceicao', '84196-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conchas Velhas', 'Conchas Velhas', '84126-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conciolândia', 'Conciolandia', '85743-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Congonhas', 'Congonhas', '86305-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Congonhinhas', 'Congonhinhas', '86320-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conselheiro Mairinck', 'Conselheiro Mairinck', '86480-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conselheiro Zacarias', 'Conselheiro Zacarias', '86440-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Contenda', 'Contenda', '83730-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Copacabana do Norte', 'Copacabana Do Norte', '87195-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corbélia', 'Corbelia', '85420-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cornélio Procópio', 'Cornelio Procopio', '86300-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Domingos Soares', 'Coronel Domingos Soares', '85557-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Firmino Martins', 'Coronel Firmino Martins', '85536-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Vivida', 'Coronel Vivida', '85550-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Correia de Freitas', 'Correia De Freitas', '86816-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corumbataí do Sul', 'Corumbatai Do Sul', '86970-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corvo', 'Corvo', '85111-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Costeira', 'Costeira', '83729-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Covó', 'Covo', '85545-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coxilha Rica', 'Coxilha Rica', '85582-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristo Rei', 'Cristo Rei', '85763-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristo Rei', 'Cristo Rei', '87728-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruz Machado', 'Cruz Machado', '84620-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzeiro do Iguaçu', 'Cruzeiro Do Iguacu', '85598-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzeiro do Norte', 'Cruzeiro Do Norte', '86285-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzeiro do Oeste', 'Cruzeiro Do Oeste', '87400-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzeiro do Sul', 'Cruzeiro Do Sul', '87650-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzmaltina', 'Cruzmaltina', '86855-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cunhaporanga', 'Cunhaporanga', '84193-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curitiba', 'Curitiba', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curiúva', 'Curiuva', '84280-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curucaca', 'Curucaca', '85138-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Deputado José Afonso', 'Deputado Jose Afonso', '87726-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Despique', 'Despique', '83158-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dez de Maio', 'Dez De Maio', '85920-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Diamante d''Oeste', 'Diamante D''Oeste', '85896-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Diamante do Norte', 'Diamante Do Norte', '87990-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Diamante do Sul', 'Diamante Do Sul', '85408-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doce Grande', 'Doce Grande', '83843-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dois Irmãos', 'Dois Irmaos', '85571-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dois Irmãos', 'Dois Irmaos', '85923-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dois Marcos', 'Dois Marcos', '85926-550', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dois Vizinhos', 'Dois Vizinhos', '85660-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Rodrigo', 'Dom Rodrigo', '83649-650', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dorizon', 'Dorizon', '84574-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Douradina', 'Douradina', '87485-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doutor Antônio Paranhos', 'Doutor Antonio Paranhos', '85579-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doutor Camargo', 'Doutor Camargo', '87155-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doutor Ernesto', 'Doutor Ernesto', '85926-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doutor Oliveira Castro', 'Doutor Oliveira Castro', '85985-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doutor Ulysses', 'Doutor Ulysses', '83590-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eduardo Xavier da Silva', 'Eduardo Xavier Da Silva', '84210-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Emboguaçu', 'Emboguacu', '83251-250', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Emboque', 'Emboque', '83319-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Emboque', 'Emboque', '83150-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Encantado d''Oeste', 'Encantado D''Oeste', '85936-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Encruzilhada', 'Encruzilhada', '85138-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Encruzilhada', 'Encruzilhada', '85514-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Enéas Marques', 'Eneas Marques', '85630-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro Beltrão', 'Engenheiro Beltrao', '87270-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Entre Rios', 'Entre Rios', '85108-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Entre Rios do Oeste', 'Entre Rios Do Oeste', '85988-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esperança do Norte', 'Esperanca Do Norte', '86155-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esperança Nova', 'Esperanca Nova', '87545-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espigão Alto do Iguaçu', 'Espigao Alto Do Iguacu', '85465-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espírito Santo', 'Espirito Santo', '86106-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estação General Lúcio', 'Estacao General Lucio', '83729-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estação Roça Nova', 'Estacao Roca Nova', '83319-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Europa', 'Europa', '83251-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Euzébio de Oliveira', 'Euzebio De Oliveira', '84912-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faisqueira', 'Faisqueira', '84279-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Farol', 'Farol', '87325-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faxina', 'Faxina', '83163-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faxinal', 'Faxinal', '86840-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faxinal do Céu', 'Faxinal Do Ceu', '85180-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faxinal dos Elias', 'Faxinal Dos Elias', '85124-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faxinal Santa Cruz', 'Faxinal Santa Cruz', '84128-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda do Brigadeiro', 'Fazenda Do Brigadeiro', '85824-850', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda dos Barbosas', 'Fazenda Dos Barbosas', '85137-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda Jangada', 'Fazenda Jangada', '85824-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda Rio Grande', 'Fazenda Rio Grande', '83820-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda Salmo 23', 'Fazenda Salmo 23', '87523-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazendinha', 'Fazendinha', '85609-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Felpudo', 'Felpudo', '83649-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fênix', 'Fenix', '86950-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fernandes Pinheiro', 'Fernandes Pinheiro', '84535-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fernão Dias', 'Fernao Dias', '86765-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ferraria', 'Ferraria', '83644-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ferreiras', 'Ferreiras', '84125-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Figueira', 'Figueira', '84285-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Figueira do Oeste', 'Figueira Do Oeste', '87277-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fiusas', 'Fiusas', '85123-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flor da Serra', 'Flor Da Serra', '85886-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flor da Serra do Sul', 'Flor Da Serra Do Sul', '85618-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floraí', 'Florai', '87185-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floresta', 'Floresta', '87120-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Florestópolis', 'Florestopolis', '86165-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floriano', 'Floriano', '87105-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flórida', 'Florida', '86780-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Florópolis', 'Floropolis', '87668-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fluviópolis', 'Fluviopolis', '83930-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Formigone', 'Formigone', '87523-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Formosa do Oeste', 'Formosa Do Oeste', '85830-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Foz do Iguaçu', 'Foz Do Iguacu', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Foz do Jordão', 'Foz Do Jordao', '85145-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Francisco Alves', 'Francisco Alves', '87570-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Francisco Beltrão', 'Francisco Beltrao', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Francisco Frederico Teixeira Guimarães', 'Francisco Frederico Teixeira Guimaraes', '85556-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frei Timóteo', 'Frei Timoteo', '86215-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fueros', 'Fueros', '85116-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fundão', 'Fundao', '84194-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gamadinho', 'Gamadinho', '85824-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gamela', 'Gamela', '83156-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gaúcha', 'Gaucha', '85609-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gavião', 'Gaviao', '85325-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gavião', 'Gaviao', '85678-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('General Carneiro', 'General Carneiro', '84660-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('General Osório', 'General Osorio', '85927-550', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Geremia Lunardelli', 'Geremia Lunardelli', '87333-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Godoy Moreira', 'Godoy Moreira', '86938-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goioerê', 'Goioere', '87360-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goioxim', 'Goioxim', '85162-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Góis', 'Gois', '85103-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gonçalves Júnior', 'Goncalves Junior', '84507-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Graciosa', 'Graciosa', '87722-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Grandes Rios', 'Grandes Rios', '86845-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaiporã', 'Guaipora', '87567-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaíra', 'Guaira', '85980-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guairaçá', 'Guairaca', '87880-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guairaçá', 'Guairaca', '85113-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guairaçá', 'Guairaca', '86114-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guajuvira', 'Guajuvira', '83725-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guamiranga', 'Guamiranga', '84435-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guamirim', 'Guamirim', '84510-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guapirama', 'Guapirama', '86465-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaporé', 'Guapore', '85407-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaporema', 'Guaporema', '87810-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guará', 'Guara', '85110-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraci', 'Guaraci', '86620-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaragi', 'Guaragi', '84120-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraituba', 'Guaraituba', '83418-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarani', 'Guarani', '85380-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraniaçu', 'Guaraniacu', '85400-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarapuava', 'Guarapuava', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarapuavinha', 'Guarapuavinha', '85609-150', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraqueçaba', 'Guaraquecaba', '83390-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guararema', 'Guararema', '84193-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaratuba', 'Guaratuba', '83280-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraúna', 'Guarauna', '84534-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaravera', 'Guaravera', '86120-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guardamoria', 'Guardamoria', '84277-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Harmonia', 'Harmonia', '84275-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Herculândia', 'Herculandia', '87527-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Herval Grande', 'Herval Grande', '85326-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Herveira', 'Herveira', '87348-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Herveira', 'Herveira', '85360-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Hidrelétrica Itaipu', 'Hidreletrica Itaipu', '85873-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Honório Serpa', 'Honorio Serpa', '85548-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iarama', 'Iarama', '87523-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibaiti', 'Ibaiti', '84900-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibema', 'Ibema', '85478-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiaci', 'Ibiaci', '86143-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiporã', 'Ibipora', '86200-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Içara', 'Icara', '86744-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Icaraíma', 'Icaraima', '87530-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Icatu', 'Icatu', '87935-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igrejinha', 'Igrejinha', '85127-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguaraçu', 'Iguaracu', '86750-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguatemi', 'Iguatemi', '87103-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguatu', 'Iguatu', '85423-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguiporã', 'Iguipora', '85972-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilha do Mel', 'Ilha Do Mel', '83251-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilha dos Valadares', 'Ilha Dos Valadares', '83252-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Imbaú', 'Imbau', '84250-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Imbauzinho', 'Imbauzinho', '84279-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Imbituva', 'Imbituva', '84430-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inácio Martins', 'Inacio Martins', '85155-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inajá', 'Inaja', '87670-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Independência', 'Independencia', '85514-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indianópolis', 'Indianopolis', '87210-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inspetor Carvalho', 'Inspetor Carvalho', '83155-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Invernada', 'Invernada', '84197-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Invernadinha', 'Invernadinha', '85129-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iolópolis', 'Iolopolis', '85578-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipiranga', 'Ipiranga', '84450-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipiranga', 'Ipiranga', '83729-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipiranga', 'Ipiranga', '85926-750', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iporã', 'Ipora', '87560-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iracema do Oeste', 'Iracema Do Oeste', '85833-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irapuan', 'Irapuan', '87267-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irati', 'Irati', '84500-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irerê', 'Irere', '86115-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iretama', 'Iretama', '87280-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaguajé', 'Itaguaje', '86670-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaiacoca', 'Itaiacoca', '84110-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaipulândia', 'Itaipulandia', '85880-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itambaracá', 'Itambaraca', '86375-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itambé', 'Itambe', '87175-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itambé', 'Itambe', '83649-150', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapanhacanga', 'Itapanhacanga', '84196-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapara', 'Itapara', '84515-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapejara d''Oeste', 'Itapejara D''Oeste', '85580-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaperuçu', 'Itaperucu', '83560-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaqui', 'Itaqui', '83649-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaúna do Sul', 'Itauna Do Sul', '87980-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itinga', 'Itinga', '83251-350', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ivaí', 'Ivai', '84460-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ivailândia', 'Ivailandia', '87275-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ivaiporã', 'Ivaipora', '86870-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ivaitinga', 'Ivaitinga', '87620-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ivaté', 'Ivate', '87525-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ivatuba', 'Ivatuba', '87130-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaborandi', 'Jaborandi', '87523-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaboti', 'Jaboti', '84930-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaboticabal', 'Jaboticabal', '84128-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaburu', 'Jaburu', '84126-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacaré', 'Jacare', '85609-450', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacarezinho', 'Jacarezinho', '86400-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaciaba', 'Jaciaba', '84420-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacutinga', 'Jacutinga', '85607-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacutinga', 'Jacutinga', '85164-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacutinga', 'Jacutinga', '86878-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacutinga', 'Jacutinga', '85653-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguapitã', 'Jaguapita', '86610-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguariaíva', 'Jaguariaiva', '84200-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jandaia do Sul', 'Jandaia Do Sul', '86900-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jangada', 'Jangada', '87569-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jangada do Sul', 'Jangada Do Sul', '84664-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Janiópolis', 'Janiopolis', '87380-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japira', 'Japira', '84920-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japurá', 'Japura', '87225-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaracatiá', 'Jaracatia', '87364-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim', 'Jardim', '86107-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim Alegre', 'Jardim Alegre', '86860-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim Olinda', 'Jardim Olinda', '87690-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim Paredão', 'Jardim Paredao', '87552-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardinópolis', 'Jardinopolis', '86335-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jataizinho', 'Jataizinho', '86210-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Javacaé', 'Javacae', '83649-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jesuítas', 'Jesuitas', '85835-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joá', 'Joa', '86457-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joaquim Távora', 'Joaquim Tavora', '86455-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jordãozinho', 'Jordaozinho', '85138-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('José Lacerda', 'Jose Lacerda', '84330-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juciara', 'Juciara', '86923-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jundiaí do Sul', 'Jundiai Do Sul', '86470-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juranda', 'Juranda', '87355-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jussara', 'Jussara', '87230-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juvinópolis', 'Juvinopolis', '85821-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Kaloré', 'Kalore', '86920-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('km 30', 'Km 30', '84279-100', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa', 'Lagoa', '84193-100', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa', 'Lagoa', '84279-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Bonita', 'Lagoa Bonita', '84196-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa dos Ribas', 'Lagoa Dos Ribas', '84197-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Dourada', 'Lagoa Dourada', '84127-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Seca', 'Lagoa Seca', '85137-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Verde', 'Lagoa Verde', '83848-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoinha', 'Lagoinha', '84279-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado', 'Lajeado', '84198-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado', 'Lajeado', '84125-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado', 'Lajeado', '83910-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado Bonito', 'Lajeado Bonito', '84360-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado Grande', 'Lajeado Grande', '85132-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lambari', 'Lambari', '84295-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lapa', 'Lapa', '83750-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laranja Azeda', 'Laranja Azeda', '84277-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laranjal', 'Laranjal', '85275-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laranjeiras do Sul', 'Laranjeiras Do Sul', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lavra', 'Lavra', '83649-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lavrinha', 'Lavrinha', '85102-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lavrinha', 'Lavrinha', '84928-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Leópolis', 'Leopolis', '86330-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lerroville', 'Lerroville', '86123-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lidianópolis', 'Lidianopolis', '86865-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lindoeste', 'Lindoeste', '85826-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Linha Giacomini', 'Linha Giacomini', '85926-650', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Loanda', 'Loanda', '87900-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lobato', 'Lobato', '86790-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Londrina', 'Londrina', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lopei', 'Lopei', '85927-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lovat', 'Lovat', '87520-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luar', 'Luar', '86931-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luiziana', 'Luiziana', '87290-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lunardelli', 'Lunardelli', '86935-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lupionópolis', 'Lupionopolis', '86635-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macaco', 'Macaco', '84198-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macucos', 'Macucos', '85134-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mairá', 'Maira', '86638-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maitá', 'Maita', '85137-100', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mallet', 'Mallet', '84570-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Malu', 'Malu', '87245-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mamborê', 'Mambore', '87340-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mandaçaia', 'Mandacaia', '85138-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mandaguaçu', 'Mandaguacu', '87160-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mandaguari', 'Mandaguari', '86975-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mandiocaba', 'Mandiocaba', '87729-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mandirituba', 'Mandirituba', '83800-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manfrinópolis', 'Manfrinopolis', '85628-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mangueirinha', 'Mangueirinha', '85540-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manoel Ribas', 'Manoel Ribas', '85260-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marabá', 'Maraba', '87458-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maracanã', 'Maracana', '84197-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marajó', 'Marajo', '85412-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maravilha', 'Maravilha', '86110-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maravilha', 'Maravilha', '85775-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marcelino', 'Marcelino', '83168-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marcionópolis', 'Marcionopolis', '85720-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marechal Cândido Rondon', 'Marechal Candido Rondon', '85960-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Margarida', 'Margarida', '85974-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maria Helena', 'Maria Helena', '87480-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maria Luiza', 'Maria Luiza', '83251-750', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marialva', 'Marialva', '86990-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mariental', 'Mariental', '83760-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marilândia do Sul', 'Marilandia Do Sul', '86825-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marilena', 'Marilena', '87960-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marilu', 'Marilu', '87282-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mariluz', 'Mariluz', '87470-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marimbondo', 'Marimbondo', '84943-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maringá', 'Maringa', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mariópolis', 'Mariopolis', '85525-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maripá', 'Maripa', '85955-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maristela', 'Maristela', '87753-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mariza', 'Mariza', '86947-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marmelândia', 'Marmelandia', '85778-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marmeleiro', 'Marmeleiro', '85615-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marquês de Abrantes', 'Marques De Abrantes', '83485-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marquinho', 'Marquinho', '85168-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marrecas', 'Marrecas', '85112-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Martins', 'Martins', '83729-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marumbi', 'Marumbi', '86910-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matelândia', 'Matelandia', '85887-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matinhos', 'Matinhos', '83260-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matinhos', 'Matinhos', '85117-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mato Queimado', 'Mato Queimado', '84127-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mato Rico', 'Mato Rico', '85240-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mauá da Serra', 'Maua Da Serra', '86828-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Medianeira', 'Medianeira', '85884-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Meia-Lua', 'Meia-Lua', '83533-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Memória', 'Memoria', '85927-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mendeslândia', 'Mendeslandia', '86685-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mercedes', 'Mercedes', '85998-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirador', 'Mirador', '87840-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miranda', 'Miranda', '84279-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirante do Piquiri', 'Mirante Do Piquiri', '87590-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miraselva', 'Miraselva', '86615-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Missal', 'Missal', '85890-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monjolinho', 'Monjolinho', '84370-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Real', 'Monte Real', '86435-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moreira Sales', 'Moreira Sales', '87370-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morretes', 'Morretes', '83350-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro Alto', 'Morro Alto', '83157-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro Inglês', 'Morro Ingles', '83251-650', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Munhoz de Melo', 'Munhoz De Melo', '86760-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Natingui', 'Natingui', '84390-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nilza', 'Nilza', '87562-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nordestina', 'Nordestina', '87855-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora Aparecida', 'Nossa Senhora Aparecida', '86383-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora da Aparecida', 'Nossa Senhora Da Aparecida', '86607-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora da Candelária', 'Nossa Senhora Da Candelaria', '86365-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora das Graças', 'Nossa Senhora Das Gracas', '86680-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora de Lourdes', 'Nossa Senhora De Lourdes', '85824-650', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora do Carmo', 'Nossa Senhora Do Carmo', '85514-550', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Aliança do Ivaí', 'Nova Alianca Do Ivai', '87790-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Altamira', 'Nova Altamira', '86842-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova América da Colina', 'Nova America Da Colina', '86230-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Amoreira', 'Nova Amoreira', '86826-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Aurora', 'Nova Aurora', '85410-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Bilac', 'Nova Bilac', '87188-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Brasília', 'Nova Brasilia', '87262-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Brasília', 'Nova Brasilia', '85926-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Brasília do Itararé', 'Nova Brasilia Do Itarare', '86425-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Cantu', 'Nova Cantu', '87330-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Concórdia', 'Nova Concordia', '85609-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Concórdia', 'Nova Concordia', '85927-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Esperança', 'Nova Esperanca', '87600-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Esperança do Sudoeste', 'Nova Esperanca Do Sudoeste', '85635-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Fátima', 'Nova Fatima', '86310-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Laranjeiras', 'Nova Laranjeiras', '85350-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Londrina', 'Nova Londrina', '87970-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Lourdes', 'Nova Lourdes', '85572-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Olímpia', 'Nova Olimpia', '87490-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Prata do Iguaçu', 'Nova Prata Do Iguacu', '85685-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Riqueza', 'Nova Riqueza', '85729-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Santa Bárbara', 'Nova Santa Barbara', '86250-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Santa Rosa', 'Nova Santa Rosa', '85930-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Tebas', 'Nova Tebas', '85250-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Tirol', 'Nova Tirol', '83319-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Videira', 'Nova Videira', '85926-950', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Horizonte', 'Novo Horizonte', '85822-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Horizonte', 'Novo Horizonte', '85978-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Itacolomi', 'Novo Itacolomi', '86895-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Jardim', 'Novo Jardim', '84923-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Sarandi', 'Novo Sarandi', '85927-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Sobradinho', 'Novo Sobradinho', '85925-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Três Passos', 'Novo Tres Passos', '85975-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olaria', 'Olaria', '85824-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olaria', 'Olaria', '84277-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olho Agudo', 'Olho Agudo', '83160-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olho d''Água', 'Olho D''Agua', '84198-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oroité', 'Oroite', '87564-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ortigueira', 'Ortigueira', '84350-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ourilândia', 'Ourilandia', '86968-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ourizona', 'Ourizona', '87170-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Verde do Oeste', 'Ouro Verde Do Oeste', '85933-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Verde do Piquiri', 'Ouro Verde Do Piquiri', '85422-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Ponciano', 'Padre Ponciano', '85559-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paiçandu', 'Paicandu', '87140-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paiol de Baixo', 'Paiol De Baixo', '83440-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paiol Queimado', 'Paiol Queimado', '84197-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmas', 'Palmas', '85555-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeira', 'Palmeira', '84130-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeirinha', 'Palmeirinha', '84196-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeirinha', 'Palmeirinha', '85118-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmira', 'Palmira', '84155-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmital', 'Palmital', '85270-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmital', 'Palmital', '84196-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmital de São Silvestre', 'Palmital De Sao Silvestre', '83646-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmitópolis', 'Palmitopolis', '85413-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palotina', 'Palotina', '85950-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Panema', 'Panema', '86358-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pangaré', 'Pangare', '83845-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Papagaios Novos', 'Papagaios Novos', '84135-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraíso do Norte', 'Paraiso Do Norte', '87780-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraná d''Oeste', 'Parana D''Oeste', '87375-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranacity', 'Paranacity', '87660-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranagi', 'Paranagi', '86345-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranaguá', 'Paranagua', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranapoema', 'Paranapoema', '87680-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranavaí', 'Paranavai', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passa Una', 'Passa Una', '83729-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo da Ilha', 'Passo Da Ilha', '85514-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo dos Pupos', 'Passo Dos Pupos', '84126-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo Fundo', 'Passo Fundo', '83649-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo Liso', 'Passo Liso', '85330-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pato Bragado', 'Pato Bragado', '85948-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pato Branco', 'Pato Branco', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Patos Velhos', 'Patos Velhos', '84410-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pau d''Alho do Sul', 'Pau D''Alho Do Sul', '86224-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paula Freitas', 'Paula Freitas', '84630-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulistânia', 'Paulistania', '87588-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulo Frontin', 'Paulo Frontin', '84635-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Peabiru', 'Peabiru', '87250-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Branca do Araraquara', 'Pedra Branca Do Araraquara', '83290-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedras', 'Pedras', '84193-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Lustosa', 'Pedro Lustosa', '85198-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pelado', 'Pelado', '85128-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Perobal', 'Perobal', '87538-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pérola', 'Perola', '87540-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pérola d''Oeste', 'Perola D''Oeste', '85740-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pérola Independente', 'Perola Independente', '85958-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piassuguera', 'Piassuguera', '83251-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piên', 'Pien', '83860-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinaré', 'Pinare', '84625-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhais', 'Pinhais', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhal de São Bento', 'Pinhal De Sao Bento', '85727-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhalão', 'Pinhalao', '84925-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhalzinho', 'Pinhalzinho', '86818-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhalzinho', 'Pinhalzinho', '85824-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhalzinho', 'Pinhalzinho', '85634-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhalzinho', 'Pinhalzinho', '85167-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhalzinho', 'Pinhalzinho', '85190-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhão', 'Pinhao', '85170-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinheiro', 'Pinheiro', '85767-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piquirivaí', 'Piquirivai', '87318-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piracema', 'Piracema', '87729-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piraí do Sul', 'Pirai Do Sul', '84240-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirapó', 'Pirapo', '86818-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piraquara', 'Piraquara', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piriquitos', 'Piriquitos', '84105-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pitanga', 'Pitanga', '85200-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pitangueiras', 'Pitangueiras', '86613-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pitangui', 'Pitangui', '84125-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planaltina do Paraná', 'Planaltina Do Parana', '87860-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planalto', 'Planalto', '85750-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pocinho', 'Pocinho', '86962-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pocinho', 'Pocinho', '84125-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poema', 'Poema', '85255-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponta do Pasto', 'Ponta Do Pasto', '83251-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponta Grossa', 'Ponta Grossa', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontal do Paraná', 'Pontal Do Parana', '83255-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porecatu', 'Porecatu', '86160-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Portão', 'Portao', '85824-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porteira Preta', 'Porteira Preta', '86955-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Amazonas', 'Porto Amazonas', '84140-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Barreiro', 'Porto Barreiro', '85345-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Belo', 'Porto Belo', '85874-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Brasílio', 'Porto Brasilio', '87940-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Camargo', 'Porto Camargo', '87532-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto de Cima', 'Porto De Cima', '83360-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Meira', 'Porto Meira', '85874-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Mendes', 'Porto Mendes', '85976-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Rico', 'Porto Rico', '87950-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto San Juan', 'Porto San Juan', '85874-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Santana', 'Porto Santana', '85348-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto São Carlos', 'Porto Sao Carlos', '87775-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto São José', 'Porto Sao Jose', '87957-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Vitória', 'Porto Vitoria', '84610-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prado Ferreira', 'Prado Ferreira', '86618-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pranchita', 'Pranchita', '85730-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prata', 'Prata', '86198-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prata Um', 'Prata Um', '84277-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Castelo Branco', 'Presidente Castelo Branco', '87180-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Kennedy', 'Presidente Kennedy', '85587-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Primeiro de Maio', 'Primeiro De Maio', '86140-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Progresso', 'Progresso', '85609-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prudentópolis', 'Prudentopolis', '84400-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pulinópolis', 'Pulinopolis', '87165-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quatiguá', 'Quatigua', '86450-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quatro Barras', 'Quatro Barras', '83420-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quatro Pontes', 'Quatro Pontes', '85940-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quebra Freio', 'Quebra Freio', '85514-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quedas do Iguaçu', 'Quedas Do Iguacu', '85460-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Queimados', 'Queimados', '85137-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Querência do Norte', 'Querencia Do Norte', '87930-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quinta do Sol', 'Quinta Do Sol', '87265-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quinzópolis', 'Quinzopolis', '86355-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quitandinha', 'Quitandinha', '83840-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ramilândia', 'Ramilandia', '85888-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rancho Alegre', 'Rancho Alegre', '86290-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rancho Alegre d''Oeste', 'Rancho Alegre D''Oeste', '87395-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Realeza', 'Realeza', '85770-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rebouças', 'Reboucas', '84550-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Região dos Valos', 'Regiao Dos Valos', '84279-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Reianópolis', 'Reianopolis', '84230-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Renascença', 'Renascenca', '85610-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Reserva', 'Reserva', '84320-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Reserva do Iguaçu', 'Reserva Do Iguacu', '85195-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Retiro', 'Retiro', '84197-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Retiro Grande', 'Retiro Grande', '83649-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão Bonito', 'Ribeirao Bonito', '86847-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão Claro', 'Ribeirao Claro', '86410-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão do Pinhal', 'Ribeirao Do Pinhal', '86490-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão do Pinheiro', 'Ribeirao Do Pinheiro', '84194-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Abaixo', 'Rio Abaixo', '84193-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Bom', 'Rio Bom', '86830-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Bonito', 'Rio Bonito', '87575-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Bonito do Iguaçu', 'Rio Bonito Do Iguacu', '85340-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Branco do Ivaí', 'Rio Branco Do Ivai', '86848-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Branco do Sul', 'Rio Branco Do Sul', '83540-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Claro do Sul', 'Rio Claro Do Sul', '84577-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio da Prata', 'Rio Da Prata', '85655-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio da Prata', 'Rio Da Prata', '85370-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio das Antas', 'Rio Das Antas', '85823-550', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio das Mortes', 'Rio Das Mortes', '85130-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio das Pedras', 'Rio Das Pedras', '85131-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio das Pedras', 'Rio Das Pedras', '83251-550', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio das Pombas', 'Rio Das Pombas', '83251-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio do Mato', 'Rio Do Mato', '85609-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio do Salto', 'Rio Do Salto', '85824-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Negro', 'Rio Negro', '83880-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Novo', 'Rio Novo', '85822-850', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Novo', 'Rio Novo', '84340-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Pinheiro', 'Rio Pinheiro', '85526-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Quatorze', 'Rio Quatorze', '85609-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Saltinho', 'Rio Saltinho', '85823-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Saudade', 'Rio Saudade', '85609-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Verde', 'Rio Verde', '87357-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Roberto Silveira', 'Roberto Silveira', '87524-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Roça Velha', 'Roca Velha', '84126-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Roça Velha', 'Roca Velha', '83164-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rolândia', 'Rolandia', '86600-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Romeópolis', 'Romeopolis', '86887-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Roncador', 'Roncador', '87320-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rondinha', 'Rondinha', '85119-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rondon', 'Rondon', '87800-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rosário do Ivaí', 'Rosario Do Ivai', '86850-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sabáudia', 'Sabaudia', '86720-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sagrada Família', 'Sagrada Familia', '85756-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salgado Filho', 'Salgado Filho', '85620-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salles de Oliveira', 'Salles De Oliveira', '87349-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saltinho do Oeste', 'Saltinho Do Oeste', '87585-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salto do Itararé', 'Salto Do Itarare', '84945-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salto do Lontra', 'Salto Do Lontra', '85670-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salto Portão', 'Salto Portao', '85823-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Samambaia', 'Samambaia', '85138-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Amélia', 'Santa Amelia', '86370-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cecília do Pavão', 'Santa Cecilia Do Pavao', '86225-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Clara', 'Santa Clara', '84194-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz de Monte Castelo', 'Santa Cruz De Monte Castelo', '87920-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Eliza', 'Santa Eliza', '87521-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Esmeralda', 'Santa Esmeralda', '87925-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Fé', 'Santa Fe', '86770-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Fé do Pirapó', 'Santa Fe Do Pirapo', '86994-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Helena', 'Santa Helena', '85892-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Inês', 'Santa Ines', '86660-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Isabel do Ivaí', 'Santa Isabel Do Ivai', '87910-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Izabel do Oeste', 'Santa Izabel Do Oeste', '85650-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Lúcia', 'Santa Lucia', '85795-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Lurdes', 'Santa Lurdes', '86199-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia da Alvorada', 'Santa Luzia Da Alvorada', '86934-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Margarida', 'Santa Margarida', '86135-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Margarida', 'Santa Margarida', '86104-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria', 'Santa Maria', '87755-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria do Oeste', 'Santa Maria Do Oeste', '85230-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria do Rio do Peixe', 'Santa Maria Do Rio Do Peixe', '86323-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Mariana', 'Santa Mariana', '86350-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Mônica', 'Santa Monica', '87915-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Quitéria', 'Santa Quiteria', '83649-100', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Quitéria', 'Santa Quiteria', '84194-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita', 'Santa Rita', '84197-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita', 'Santa Rita', '85514-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita do Oeste', 'Santa Rita Do Oeste', '85995-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa', 'Santa Rosa', '85609-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Tereza do Oeste', 'Santa Tereza Do Oeste', '85825-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha de Itaipu', 'Santa Terezinha De Itaipu', '85875-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Zélia', 'Santa Zelia', '86742-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana', 'Santana', '84623-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Itararé', 'Santana Do Itarare', '84970-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio', 'Santo Antonio', '84194-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio', 'Santo Antonio', '85323-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio da Platina', 'Santo Antonio Da Platina', '86430-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Caiuá', 'Santo Antonio Do Caiua', '87730-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Iratim', 'Santo Antonio Do Iratim', '84650-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Palmital', 'Santo Antonio Do Palmital', '86835-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Paraíso', 'Santo Antonio Do Paraiso', '86315-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Sudoeste', 'Santo Antonio Do Sudoeste', '85710-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Inácio', 'Santo Inacio', '86650-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Rei', 'Santo Rei', '87335-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bento', 'Sao Bento', '87316-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Braz', 'Sao Braz', '85823-850', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Braz', 'Sao Braz', '85514-450', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Camilo', 'Sao Camilo', '85952-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Carlos do Ivaí', 'Sao Carlos Do Ivai', '87770-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Cirilo', 'Sao Cirilo', '84193-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Clemente', 'Sao Clemente', '85894-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Cristovão', 'Sao Cristovao', '87729-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Cristovão', 'Sao Cristovao', '84609-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos', 'Sao Domingos', '86819-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos', 'Sao Domingos', '86859-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos', 'Sao Domingos', '84608-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco', 'Sao Francisco', '85562-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco', 'Sao Francisco', '85101-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco', 'Sao Francisco', '87523-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco de Imbaú', 'Sao Francisco De Imbau', '86325-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco de Sales', 'Sao Francisco De Sales', '85534-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gabriel', 'Sao Gabriel', '86199-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gabriel', 'Sao Gabriel', '83419-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gotardo', 'Sao Gotardo', '85514-150', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Jerônimo da Serra', 'Sao Jeronimo Da Serra', '86270-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João', 'Sao Joao', '85570-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João', 'Sao Joao', '87553-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João', 'Sao Joao', '87317-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João', 'Sao Joao', '85324-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João d''Oeste', 'Sao Joao D''Oeste', '85823-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Boa Vista', 'Sao Joao Da Boa Vista', '87523-100', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Caiuá', 'Sao Joao Do Caiua', '87740-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Ivaí', 'Sao Joao Do Ivai', '86930-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Pinhal', 'Sao Joao Do Pinhal', '86273-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Triunfo', 'Sao Joao Do Triunfo', '84150-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim', 'Sao Joaquim', '86718-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim', 'Sao Joaquim', '85139-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim do Pontal', 'Sao Joaquim Do Pontal', '86378-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Jorge do Oeste', 'Sao Jorge Do Oeste', '85575-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Jorge do Ivaí', 'Sao Jorge Do Ivai', '87190-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Jorge do Patrocínio', 'Sao Jorge Do Patrocinio', '87555-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José', 'Sao Jose', '86905-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José', 'Sao Jose', '85235-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Boa Vista', 'Sao Jose Da Boa Vista', '84980-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José das Palmeiras', 'Sao Jose Das Palmeiras', '85898-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Iguaçu', 'Sao Jose Do Iguacu', '85879-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Itavo', 'Sao Jose Do Itavo', '85883-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Ivaí', 'Sao Jose Do Ivai', '87913-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José dos Pinhais', 'Sao Jose Dos Pinhais', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Judas Tadeu', 'Sao Judas Tadeu', '86318-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Leonardo', 'Sao Leonardo', '86103-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Lourenço', 'Sao Lourenco', '84196-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Lourenço', 'Sao Lourenco', '87205-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz', 'Sao Luiz', '87317-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz', 'Sao Luiz', '85765-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz', 'Sao Luiz', '85563-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz', 'Sao Luiz', '85538-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz', 'Sao Luiz', '86117-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz', 'Sao Luiz', '86998-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz', 'Sao Luiz', '87475-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz', 'Sao Luiz', '83251-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz do Purunã', 'Sao Luiz Do Puruna', '83670-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Manoel do Paraná', 'Sao Manoel Do Parana', '87215-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Marcos', 'Sao Marcos', '86101-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Marcos', 'Sao Marcos', '83175-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Martinho', 'Sao Martinho', '86609-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Mateus do Sul', 'Sao Mateus Do Sul', '83900-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel', 'Sao Miguel', '83729-100', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel', 'Sao Miguel', '85609-350', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel', 'Sao Miguel', '85924-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel do Cambui', 'Sao Miguel Do Cambui', '86996-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel do Iguaçu', 'Sao Miguel Do Iguacu', '85877-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Paulo', 'Sao Paulo', '85926-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '85645-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '86817-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '83649-050', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '85109-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '87729-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro do Florido', 'Sao Pedro Do Florido', '85725-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro do Iguaçu', 'Sao Pedro Do Iguacu', '85929-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro do Ivaí', 'Sao Pedro Do Ivai', '86945-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro do Paraná', 'Sao Pedro Do Parana', '87955-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro Lopei', 'Sao Pedro Lopei', '85822-500', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pio X', 'Sao Pio X', '85608-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Roque', 'Sao Roque', '85667-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Roque', 'Sao Roque', '85977-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Roque', 'Sao Roque', '85773-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Roque do Pinhal', 'Sao Roque Do Pinhal', '86458-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Salvador', 'Sao Salvador', '85643-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião', 'Sao Sebastiao', '84198-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião', 'Sao Sebastiao', '83580-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião', 'Sao Sebastiao', '85139-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião', 'Sao Sebastiao', '83152-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião', 'Sao Sebastiao', '84277-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião da Amoreira', 'Sao Sebastiao Da Amoreira', '86240-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Silvestre', 'Sao Silvestre', '87408-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Tomé', 'Sao Tome', '87220-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Valentim', 'Sao Valentim', '85668-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente', 'Sao Vicente', '87263-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapé', 'Sape', '84938-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapopema', 'Sapopema', '84290-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sarandi', 'Sarandi', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sarandi', 'Sarandi', '85652-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saudade do Iguaçu', 'Saudade Do Iguacu', '85568-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sede Alvorada', 'Sede Alvorada', '85822-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sede Chaparral', 'Sede Chaparral', '85927-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sede Nova Sant''Ana', 'Sede Nova Sant''Ana', '85577-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sede Progresso', 'Sede Progresso', '85609-250', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sede Progresso', 'Sede Progresso', '85588-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Selva', 'Selva', '86108-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sengés', 'Senges', '84220-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senhor Bom Jesus dos Gramados', 'Senhor Bom Jesus Dos Gramados', '85528-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra dos Dourados', 'Serra Dos Dourados', '87518-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Negra', 'Serra Negra', '83395-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serranópolis do Iguaçu', 'Serranopolis Do Iguacu', '85885-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serraria Klas', 'Serraria Klas', '84128-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrinha', 'Serrinha', '86199-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrinha', 'Serrinha', '87316-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrinha', 'Serrinha', '84199-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sertaneja', 'Sertaneja', '86340-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sertanópolis', 'Sertanopolis', '86170-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sertãozinho', 'Sertaozinho', '87272-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sete Saltos de Cima', 'Sete Saltos De Cima', '84127-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silvolândia', 'Silvolandia', '87315-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Siqueira Belo', 'Siqueira Belo', '85705-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Siqueira Campos', 'Siqueira Campos', '84940-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Socavão', 'Socavao', '84190-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Socorro', 'Socorro', '85139-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sulina', 'Sulina', '85565-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sumaré', 'Sumare', '87720-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sussui', 'Sussui', '87274-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sutis', 'Sutis', '86122-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taipa', 'Taipa', '85115-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tamarana', 'Tamarana', '86125-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tambarutaca', 'Tambarutaca', '83251-450', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tamboara', 'Tamboara', '87760-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tanque Grande', 'Tanque Grande', '84196-100', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapejara', 'Tapejara', '87430-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapira', 'Tapira', '87830-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapui', 'Tapui', '85927-850', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquara', 'Taquara', '84193-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquari dos Polacos', 'Taquari Dos Polacos', '84126-100', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquari dos Russos', 'Taquari Dos Russos', '84126-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquaruna', 'Taquaruna', '86113-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teixeira Soares', 'Teixeira Soares', '84530-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Telêmaco Borba', 'Telemaco Borba', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teolândia', 'Teolandia', '85514-350', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tereza Breda', 'Tereza Breda', '86964-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tereza Cristina', 'Tereza Cristina', '84490-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terra Boa', 'Terra Boa', '87240-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terra Nova', 'Terra Nova', '86275-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terra Rica', 'Terra Rica', '87890-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terra Roxa', 'Terra Roxa', '85990-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tibagi', 'Tibagi', '84300-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tijucas do Sul', 'Tijucas Do Sul', '83190-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tijuco Preto', 'Tijuco Preto', '83532-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tijuco Preto', 'Tijuco Preto', '84193-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timbu Velho', 'Timbu Velho', '83419-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tindiquera', 'Tindiquera', '83729-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tiradentes', 'Tiradentes', '85514-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tiradentes', 'Tiradentes', '85625-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Toledo', 'Toledo', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tomaz Coelho', 'Tomaz Coelho', '83729-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tomazina', 'Tomazina', '84935-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Barras do Paraná', 'Tres Barras Do Parana', '85485-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Bicos', 'Tres Bicos', '84480-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Bocas', 'Tres Bocas', '85926-900', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Capões', 'Tres Capoes', '85137-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Córregos', 'Tres Corregos', '83642-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Lagoas', 'Tres Lagoas', '85874-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Pinheiros', 'Tres Pinheiros', '85137-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Placas', 'Tres Placas', '87523-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Triângulo', 'Triangulo', '87276-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trindade', 'Trindade', '84125-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Triolândia', 'Triolandia', '86495-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tronco', 'Tronco', '84197-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tunas do Paraná', 'Tunas Do Parana', '83480-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tuneiras do Oeste', 'Tuneiras Do Oeste', '87450-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupãssi', 'Tupassi', '85945-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupinambá', 'Tupinamba', '86746-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Turvo', 'Turvo', '85150-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubaldino Taques', 'Ubaldino Taques', '85558-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubauna', 'Ubauna', '86932-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubiratã', 'Ubirata', '85440-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umuarama', 'Umuarama', NULL, 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('União', 'Uniao', '85321-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('União da Vitória', 'Uniao Da Vitoria', '84600-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('União do Oeste', 'Uniao Do Oeste', '85656-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uniflor', 'Uniflor', '87640-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uraí', 'Urai', '86280-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Usina', 'Usina', '87316-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uvaia', 'Uvaia', '84115-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valentins', 'Valentins', '84127-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valério', 'Valerio', '85758-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargeado', 'Vargeado', '84198-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vassoural', 'Vassoural', '84916-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ventania', 'Ventania', '84345-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vera Cruz do Oeste', 'Vera Cruz Do Oeste', '85845-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vera Guarani', 'Vera Guarani', '84638-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Verê', 'Vere', '85585-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vida Nova', 'Vida Nova', '84293-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vidigal', 'Vidigal', '87208-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Alta', 'Vila Alta', '87528-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Diniz', 'Vila Diniz', '86857-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila dos Roldos', 'Vila Dos Roldos', '85514-800', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Flórida', 'Vila Florida', '85926-700', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Gandhi', 'Vila Gandhi', '86142-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Guay', 'Vila Guay', '84914-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nova', 'Vila Nova', '85218-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nova', 'Vila Nova', '85926-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nova de Florença', 'Vila Nova De Florenca', '86278-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Paraíso', 'Vila Paraiso', '85573-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Reis', 'Vila Reis', '86819-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Rica do Ivaí', 'Vila Rica Do Ivai', '87534-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Roberto Brzezinski', 'Vila Roberto Brzezinski', '87315-300', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Silva Jardim', 'Vila Silva Jardim', '87665-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Velha', 'Vila Velha', '84128-200', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Virmond', 'Virmond', '85390-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Alegre', 'Vista Alegre', '85554-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Alegre', 'Vista Alegre', '85633-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Bonita', 'Vista Bonita', '83649-250', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vitória', 'Vitoria', '85139-400', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vitorino', 'Vitorino', '85520-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Warta', 'Warta', '86105-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Wenceslau Braz', 'Wenceslau Braz', '84950-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xambrê', 'Xambre', '87535-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xaxim', 'Xaxim', '85927-600', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Yolanda', 'Yolanda', '85445-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('4º. Centenário', '4º. Centenario', '87365-000', 'PR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abarracamento', 'Abarracamento', '27670-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abraão', 'Abraao', '23960-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Afonso Arinos', 'Afonso Arinos', '25875-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Agulhas Negras', 'Agulhas Negras', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amparo', 'Amparo', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Andrade Pinto', 'Andrade Pinto', '27770-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angra dos Reis', 'Angra Dos Reis', '23900-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anta', 'Anta', '25882-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aperibé', 'Aperibe', '28495-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araruama', 'Araruama', '28970-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areal', 'Areal', '25845-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Armação de Búzios', 'Armacao De Buzios', '28950-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arraial do Cabo', 'Arraial Do Cabo', '28930-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arrozal', 'Arrozal', '27185-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Avelar', 'Avelar', '26980-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bacaxá', 'Bacaxa', '28993-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baltazar', 'Baltazar', '28473-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Banquete', 'Banquete', '28662-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão de Juparana', 'Barao De Juparana', '27640-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barcelos', 'Barcelos', '28220-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Alegre', 'Barra Alegre', '28666-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra de Macaé', 'Barra De Macae', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra de São João', 'Barra De Sao Joao', '28880-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Piraí', 'Barra Do Pirai', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Mansa', 'Barra Mansa', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Seca', 'Barra Seca', '28240-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belford Roxo', 'Belford Roxo', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bemposta', 'Bemposta', '25840-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Esperança', 'Boa Esperanca', '28810-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Sorte', 'Boa Sorte', '28525-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Ventura', 'Boa Ventura', '28340-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jardim', 'Bom Jardim', '28660-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus do Itabapoana', 'Bom Jesus Do Itabapoana', '28360-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus do Querendo', 'Bom Jesus Do Querendo', '28388-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabo Frio', 'Cabo Frio', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabuçu', 'Cabucu', '24860-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeiras de Macacu', 'Cachoeiras De Macacu', '28680-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeiros', 'Cachoeiros', '27990-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Calheiros', 'Calheiros', '28368-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cambiasca', 'Cambiasca', '28425-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cambuci', 'Cambuci', '28430-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo do Coelho', 'Campo Do Coelho', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos dos Goytacazes', 'Campos Dos Goytacazes', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos Elíseos', 'Campos Eliseos', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cantagalo', 'Cantagalo', '28500-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carabuçu', 'Carabucu', '28372-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carapebus', 'Carapebus', '27998-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cardoso Moreira', 'Cardoso Moreira', '28180-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carmo', 'Carmo', '28640-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cascatinha', 'Cascatinha', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Casimiro de Abreu', 'Casimiro De Abreu', '28860-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cava', 'Cava', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coelho da Rocha', 'Coelho Da Rocha', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia', 'Colonia', '28420-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Comendador Levy Gasparian', 'Comendador Levy Gasparian', '25870-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Comendador Venâncio', 'Comendador Venancio', '28348-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição de Jacareí', 'Conceicao De Jacarei', '23885-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição de Macabu', 'Conceicao De Macabu', '28740-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conrado', 'Conrado', '26920-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conselheiro Paulino', 'Conselheiro Paulino', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conservatória', 'Conservatoria', '27655-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cordeiro', 'Cordeiro', '28540-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coroa Grande', 'Coroa Grande', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Correas', 'Correas', '25600-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córrego da Prata', 'Corrego Da Prata', '28642-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córrego do Ouro', 'Corrego Do Ouro', '27980-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Correntezas', 'Correntezas', '28830-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cunhambebe', 'Cunhambebe', '23907-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dorândia', 'Dorandia', '27160-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dores de Macabu', 'Dores De Macabu', '28115-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doutor Elias', 'Doutor Elias', '28757-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doutor Loreti', 'Doutor Loreti', '28772-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Duas Barras', 'Duas Barras', '28650-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Duque de Caxias', 'Duque De Caxias', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro Passos', 'Engenheiro Passos', '27555-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro Paulo de Frontin', 'Engenheiro Paulo De Frontin', '26650-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro Pedreira', 'Engenheiro Pedreira', '26000-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrada Nova', 'Estrada Nova', '28590-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Euclidelândia', 'Euclidelandia', '28520-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Falcão', 'Falcao', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floriano', 'Floriano', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fumaça', 'Fumaca', '27550-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Funil', 'Funil', '28440-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gaviões', 'Gavioes', '28825-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Getulândia', 'Getulandia', '27465-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Glicério', 'Glicerio', '27985-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goitacazes', 'Goitacazes', '28110-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Portela', 'Governador Portela', '26910-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guapimirim', 'Guapimirim', '25940-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guia de Pacobaíba', 'Guia De Pacobaiba', '25930-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitiguaçu', 'Ibitiguacu', '28485-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitioca', 'Ibitioca', '28120-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibituporanga', 'Ibituporanga', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguaba Grande', 'Iguaba Grande', '28960-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Imbariê', 'Imbarie', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inconfidência', 'Inconfidencia', '25865-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhomirim', 'Inhomirim', '25935-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inoã', 'Inoa', '24910-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipiabás', 'Ipiabas', '27170-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipiiba', 'Ipiiba', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipuca', 'Ipuca', '28405-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itabapoana', 'Itabapoana', '28245-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaboraí', 'Itaborai', '24800-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itacurussá', 'Itacurussa', '23880-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaguaí', 'Itaguai', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaipava', 'Itaipava', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaipu', 'Itaipu', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itajara', 'Itajara', '28345-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Italva', 'Italva', '28250-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itambi', 'Itambi', '24850-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaocara', 'Itaocara', '28570-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaperuna', 'Itaperuna', '28300-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itatiaia', 'Itatiaia', '27580-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacuecanga', 'Jacuecanga', '23905-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguarembé', 'Jaguarembe', '28575-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jamapará', 'Jamapara', '25887-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japeri', 'Japeri', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japuíba', 'Japuiba', '28685-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laje do Muriaé', 'Laje Do Muriae', '28350-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laranjais', 'Laranjais', '28580-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lídice', 'Lidice', '27475-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lumiar', 'Lumiar', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macabuzinho', 'Macabuzinho', '28745-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macaé', 'Macae', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macuco', 'Macuco', '28545-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Magé', 'Mage', '25900-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mambucaba', 'Mambucaba', '23908-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mangaratiba', 'Mangaratiba', '23860-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maniva', 'Maniva', '28235-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manoel Ribeiro', 'Manoel Ribeiro', '24920-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manuel Duarte', 'Manuel Duarte', '27690-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marangatu', 'Marangatu', '28476-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maricá', 'Marica', '24900-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mendes', 'Mendes', '26700-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mesquita', 'Mesquita', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miguel Pereira', 'Miguel Pereira', '26900-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miracema', 'Miracema', '28460-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monera', 'Monera', '28655-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monjolo', 'Monjolo', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre', 'Monte Alegre', '28490-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Verde', 'Monte Verde', '28445-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monumento', 'Monumento', '27190-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morangaba', 'Morangaba', '28125-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro do Côco', 'Morro Do Coco', '28178-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro Grande', 'Morro Grande', '28975-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mussurepe', 'Mussurepe', '28143-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Natividade', 'Natividade', '28380-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Neves', 'Neves', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nhunguaçu', 'Nhunguacu', '25998-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nilópolis', 'Nilopolis', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Niterói', 'Niteroi', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora da Aparecida', 'Nossa Senhora Da Aparecida', '25886-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora da Penha', 'Nossa Senhora Da Penha', '28335-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora do Amparo', 'Nossa Senhora Do Amparo', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Friburgo', 'Nova Friburgo', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Iguaçu', 'Nova Iguacu', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olinda', 'Olinda', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ourânia', 'Ourania', '28383-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Papucaia', 'Papucaia', '28695-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paquequer Pequeno', 'Paquequer Pequeno', '25996-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paracambi', 'Paracambi', '26600-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraíba do Sul', 'Paraiba Do Sul', '25850-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraíso do Tobias', 'Paraiso Do Tobias', '28463-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraoquena', 'Paraoquena', '28483-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parapeúna', 'Parapeuna', '27650-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parati', 'Parati', '23970-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parati Mirim', 'Parati Mirim', '23972-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passa Três', 'Passa Tres', '27470-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paty do Alferes', 'Paty Do Alferes', '26950-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Selada', 'Pedra Selada', '27560-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro do Rio', 'Pedro Do Rio', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Penedo', 'Penedo', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pentagna', 'Pentagna', '27645-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Petrópolis', 'Petropolis', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piabetá', 'Piabeta', '25915-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pião', 'Piao', '25884-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinheiral', 'Pinheiral', '27197-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pipeiras', 'Pipeiras', '28225-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piraí', 'Pirai', '27175-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirangaí', 'Pirangai', '27565-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirapetinga de Bom Jesus', 'Pirapetinga De Bom Jesus', '28365-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porciúncula', 'Porciuncula', '28390-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Portela', 'Portela', '28595-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto das Caixas', 'Porto Das Caixas', '24870-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Real', 'Porto Real', '27570-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Velho do Cunha', 'Porto Velho Do Cunha', '28644-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Posse', 'Posse', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Praia de Araçatiba', 'Praia De Aracatiba', '23965-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pureza', 'Pureza', '28415-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Purilândia', 'Purilandia', '28396-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quartéis', 'Quarteis', '28835-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quatis', 'Quatis', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Queimados', 'Queimados', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quissamã', 'Quissama', '28735-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Raposo', 'Raposo', '28333-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Renascença', 'Renascenca', '28774-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Resende', 'Resende', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Retiro do Muriaé', 'Retiro Do Muriae', '28330-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rialto', 'Rialto', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão de São Joaquim', 'Ribeirao De Sao Joaquim', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Bonito', 'Rio Bonito', '28800-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Claro', 'Rio Claro', '27460-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio das Flores', 'Rio Das Flores', '27660-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio das Ostras', 'Rio Das Ostras', '28890-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio de Janeiro', 'Rio De Janeiro', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riograndina', 'Riograndina', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rosal', 'Rosal', '28370-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sacra Família do Tinguá', 'Sacra Familia Do Tingua', '26660-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salutaris', 'Salutaris', '25855-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sambaetiba', 'Sambaetiba', '24880-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sampaio Correia', 'Sampaio Correia', '28997-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sana', 'Sana', '27995-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Clara', 'Santa Clara', '28398-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz', 'Santa Cruz', '28480-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz da Serra', 'Santa Cruz Da Serra', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Isabel', 'Santa Isabel', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Isabel do Rio Preto', 'Santa Isabel Do Rio Preto', '27657-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria', 'Santa Maria', '28155-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria Madalena', 'Santa Maria Madalena', '28770-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita da Floresta', 'Santa Rita Da Floresta', '28510-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santanésia', 'Santanesia', '27195-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Aleixo', 'Santo Aleixo', '25920-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Amaro de Campos', 'Santo Amaro De Campos', '28140-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio de Pádua', 'Santo Antonio De Padua', '28470-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Imbé', 'Santo Antonio Do Imbe', '28778-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Eduardo', 'Santo Eduardo', '28160-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Fidélis', 'Sao Fidelis', '28400-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco de Itabapoana', 'Sao Francisco De Itabapoana', '28230-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo', 'Sao Goncalo', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Barra', 'Sao Joao Da Barra', '28200-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João de Meriti', 'Sao Joao De Meriti', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Paraíso', 'Sao Joao Do Paraiso', '28450-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João Marcos', 'Sao Joao Marcos', '27472-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim', 'Sao Joaquim', '28195-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José de Ubá', 'Sao Jose De Uba', '28455-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Ribeirão', 'Sao Jose Do Ribeirao', '28664-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Turvo', 'Sao Jose Do Turvo', '27165-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Vale do Rio Preto', 'Sao Jose Do Vale Do Rio Preto', '25780-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Mateus', 'Sao Mateus', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro da Aldeia', 'Sao Pedro Da Aldeia', '28940-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião de Campos', 'Sao Sebastiao De Campos', '28145-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Alto', 'Sao Sebastiao Do Alto', '28550-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Paraíba', 'Sao Sebastiao Do Paraiba', '28530-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião dos Ferreiros', 'Sao Sebastiao Dos Ferreiros', '27705-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente de Paula', 'Sao Vicente De Paula', '28980-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapucaia', 'Sapucaia', '25880-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saquarema', 'Saquarema', '28990-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saracuruna', 'Saracuruna', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sebastião de Lacerda', 'Sebastiao De Lacerda', '27720-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Seropédica', 'Seropedica', '23890-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrinha', 'Serrinha', '28118-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sete Pontes', 'Sete Pontes', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silva Jardim', 'Silva Jardim', '28820-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sodrelândia', 'Sodrelandia', '28760-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sossego', 'Sossego', '28777-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Subaio', 'Subaio', '28690-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sumidouro', 'Sumidouro', '28637-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Suruí', 'Surui', '25925-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taboas', 'Taboas', '27665-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tamoios', 'Tamoios', '28927-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tanguá', 'Tangua', '24890-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapera', 'Tapera', '28767-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tarituba', 'Tarituba', '23975-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teresópolis', 'Teresopolis', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tocos', 'Tocos', '28148-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trajano de Morais', 'Trajano De Morais', '28750-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Travessão', 'Travessao', '28175-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Irmãos', 'Tres Irmaos', '28435-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Rios', 'Tres Rios', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Triunfo', 'Triunfo', '28779-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valão do Barro', 'Valao Do Barro', '28555-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valença', 'Valenca', '27600-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargem Alegre', 'Vargem Alegre', '27155-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Varre-Sai', 'Varre-Sai', '28375-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vassouras', 'Vassouras', '27700-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Venda das Flores', 'Venda Das Flores', '28466-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Venda das Pedras', 'Venda Das Pedras', '24885-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila da Grama', 'Vila Da Grama', '28765-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila do Frade', 'Vila Do Frade', '23903-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Muriqui', 'Vila Muriqui', '23870-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nova de Campos', 'Vila Nova De Campos', '28165-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Visconde de Imbé', 'Visconde De Imbe', '28755-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Volta Redonda', 'Volta Redonda', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Werneck', 'Werneck', '25860-000', 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xerém', 'Xerem', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Acari', 'Acari', '59370-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Açu', 'Acu', '59650-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Afonso Bezerra', 'Afonso Bezerra', '59510-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Nova', 'Agua Nova', '59995-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alexandria', 'Alexandria', '59965-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Almino Afonso', 'Almino Afonso', '59760-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto do Rodrigues', 'Alto Do Rodrigues', '59507-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angicos', 'Angicos', '59515-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Martins', 'Antonio Martins', '59870-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apodi', 'Apodi', '59700-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areia Branca', 'Areia Branca', '59655-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arez', 'Arez', '59170-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baía Formosa', 'Baia Formosa', '59194-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão de Serra Branca', 'Barao De Serra Branca', '59522-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baraúna', 'Barauna', '59695-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barcelona', 'Barcelona', '59410-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belo Horizonte', 'Belo Horizonte', '59558-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bento Fernandes', 'Bento Fernandes', '59555-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Saúde', 'Boa Saude', '59260-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bodó', 'Bodo', '59528-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus', 'Bom Jesus', '59270-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejinho', 'Brejinho', '59219-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiçara do Norte', 'Caicara Do Norte', '59592-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiçara do Rio do Vento', 'Caicara Do Rio Do Vento', '59540-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caicó', 'Caico', '59300-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Grande', 'Campo Grande', '59680-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Redondo', 'Campo Redondo', '59230-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canguaretama', 'Canguaretama', '59190-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraúbas', 'Caraubas', '59780-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carnaúba dos Dantas', 'Carnauba Dos Dantas', '59374-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carnaubais', 'Carnaubais', '59665-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ceará-Mirim', 'Ceara-Mirim', '59570-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerro Corá', 'Cerro Cora', '59395-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Ezequiel', 'Coronel Ezequiel', '59220-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel João Pessoa', 'Coronel Joao Pessoa', '59930-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córrego de São Mateus', 'Corrego De Sao Mateus', '59265-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzeta', 'Cruzeta', '59375-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Currais Novos', 'Currais Novos', '59380-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doutor Severiano', 'Doutor Severiano', '59910-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Encanto', 'Encanto', '59905-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Equador', 'Equador', '59355-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espírito Santo', 'Espirito Santo', '59180-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espírito Santo do Oeste', 'Espirito Santo Do Oeste', '59660-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Extremoz', 'Extremoz', '59575-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Felipe Guerra', 'Felipe Guerra', '59795-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fernando Pedroza', 'Fernando Pedroza', '59517-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Firmamento', 'Firmamento', '59538-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Florânia', 'Florania', '59335-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Francisco Dantas', 'Francisco Dantas', '59902-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frutuoso Gomes', 'Frutuoso Gomes', '59890-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Galinhos', 'Galinhos', '59596-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gameleira', 'Gameleira', '59568-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goianinha', 'Goianinha', '59173-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Dix-Sept Rosado', 'Governador Dix-Sept Rosado', '59790-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Grossos', 'Grossos', '59675-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guamaré', 'Guamare', '59598-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ielmo Marinho', 'Ielmo Marinho', '59490-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igreja Nova', 'Igreja Nova', '59299-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipanguaçu', 'Ipanguacu', '59508-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipiranga', 'Ipiranga', '59275-500', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipueira', 'Ipueira', '59315-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itajá', 'Itaja', '59513-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaú', 'Itau', '59855-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaçanã', 'Jacana', '59225-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jandaíra', 'Jandaira', '59594-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Janduís', 'Janduis', '59690-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japi', 'Japi', '59213-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim de Angicos', 'Jardim De Angicos', '59544-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim de Piranhas', 'Jardim De Piranhas', '59324-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim do Seridó', 'Jardim Do Serido', '59343-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Câmara', 'Joao Camara', '59550-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Dias', 'Joao Dias', '59880-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('José da Penha', 'Jose Da Penha', '59980-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jucurutu', 'Jucurutu', '59330-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jundiá', 'Jundia', '59188-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa D''Anta', 'Lagoa D''Anta', '59227-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa de Pedras', 'Lagoa De Pedras', '59244-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa de Velhos', 'Lagoa De Velhos', '59430-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Nova', 'Lagoa Nova', '59390-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Salgada', 'Lagoa Salgada', '59247-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajes', 'Lajes', '59535-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajes Pintadas', 'Lajes Pintadas', '59235-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lucrécia', 'Lucrecia', '59805-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luís Gomes', 'Luis Gomes', '59940-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macaíba', 'Macaiba', '59280-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macau', 'Macau', '59500-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Major Felipe', 'Major Felipe', '59985-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Major Sales', 'Major Sales', '59945-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marcelino Vieira', 'Marcelino Vieira', '59970-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Martins', 'Martins', '59800-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mata de São Braz', 'Mata De Sao Braz', '59958-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maxaranguape', 'Maxaranguape', '59580-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Messias Targino', 'Messias Targino', '59775-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montanhas', 'Montanhas', '59198-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre', 'Monte Alegre', '59182-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte das Gameleiras', 'Monte Das Gameleiras', '59217-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mossoró', 'Mossoro', NULL, 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Natal', 'Natal', NULL, 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nísia Floresta', 'Nisia Floresta', '59164-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Cruz', 'Nova Cruz', '59215-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olho-D''Água do Borges', 'Olho-D''Agua Do Borges', '59730-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Branco', 'Ouro Branco', '59347-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraná', 'Parana', '59950-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parazinho', 'Parazinho', '59586-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parelhas', 'Parelhas', '59360-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parnamirim', 'Parnamirim', '59150-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passa e Fica', 'Passa E Fica', '59218-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passagem', 'Passagem', '59259-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Patu', 'Patu', '59770-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pau dos Ferros', 'Pau Dos Ferros', '59900-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Grande', 'Pedra Grande', '59588-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Preta', 'Pedra Preta', '59547-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Avelino', 'Pedro Avelino', '59530-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Velho', 'Pedro Velho', '59196-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pendências', 'Pendencias', '59504-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pilões', 'Piloes', '59960-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço Branco', 'Poco Branco', '59560-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Portalegre', 'Portalegre', '59810-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto do Mangue', 'Porto Do Mangue', '59668-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pureza', 'Pureza', '59582-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rafael Fernandes', 'Rafael Fernandes', '59990-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rafael Godeiro', 'Rafael Godeiro', '59740-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho da Cruz', 'Riacho Da Cruz', '59820-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho de Santana', 'Riacho De Santana', '59987-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riachuelo', 'Riachuelo', '59470-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio do Fogo', 'Rio Do Fogo', '59578-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rodolfo Fernandes', 'Rodolfo Fernandes', '59830-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rosário', 'Rosario', '59885-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ruy Barbosa', 'Ruy Barbosa', '59420-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salva Vida', 'Salva Vida', '59803-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz', 'Santa Cruz', '59200-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Fé', 'Santa Fe', '59187-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria', 'Santa Maria', '59464-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Teresa', 'Santa Teresa', '59526-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Matos', 'Santana Do Matos', '59520-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Seridó', 'Santana Do Serido', '59350-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio', 'Santo Antonio', '59255-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Potengi', 'Santo Antonio Do Potengi', '59298-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bento do Norte', 'Sao Bento Do Norte', '59590-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bento do Trairi', 'Sao Bento Do Trairi', '59210-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bernardo', 'Sao Bernardo', '59943-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Fernando', 'Sao Fernando', '59327-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco do Oeste', 'Sao Francisco Do Oeste', '59908-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Geraldo', 'Sao Geraldo', '59785-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gonçalo do Amarante', 'Sao Goncalo Do Amarante', '59290-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Sabugi', 'Sao Joao Do Sabugi', '59310-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Passagem', 'Sao Jose Da Passagem', '59524-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José de Mipibu', 'Sao Jose De Mipibu', '59162-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Campestre', 'Sao Jose Do Campestre', '59275-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Seridó', 'Sao Jose Do Serido', '59378-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel', 'Sao Miguel', '59920-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel de Touros', 'Sao Miguel De Touros', '59585-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Paulo do Potengi', 'Sao Paulo Do Potengi', '59460-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '59480-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Rafael', 'Sao Rafael', '59518-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Tomé', 'Sao Tome', '59400-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente', 'Sao Vicente', '59340-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Elói de Souza', 'Senador Eloi De Souza', '59250-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Georgino Avelino', 'Senador Georgino Avelino', '59168-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Caiada', 'Serra Caiada', '59245-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra da Tapuia', 'Serra Da Tapuia', '59445-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra de São Bento', 'Serra De Sao Bento', '59214-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra do Mel', 'Serra Do Mel', '59663-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Negra do Norte', 'Serra Negra Do Norte', '59318-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrinha', 'Serrinha', '59258-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrinha dos Pintos', 'Serrinha Dos Pintos', '59808-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Severiano Melo', 'Severiano Melo', '59856-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sítio Novo', 'Sitio Novo', '59440-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taboleiro Grande', 'Taboleiro Grande', '59840-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taipu', 'Taipu', '59565-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tangará', 'Tangara', '59240-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tenente Ananias', 'Tenente Ananias', '59955-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tenente Laurentino Cruz', 'Tenente Laurentino Cruz', '59338-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tibau', 'Tibau', '59678-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tibau do Sul', 'Tibau Do Sul', '59178-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timbaúba dos Batistas', 'Timbauba Dos Batistas', '59320-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Touros', 'Touros', '59584-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trairi', 'Trairi', '59242-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Triunfo Potiguar', 'Triunfo Potiguar', '59685-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umarizal', 'Umarizal', '59865-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Upanema', 'Upanema', '59670-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea', 'Varzea', '59185-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Venha-Ver', 'Venha-Ver', '59925-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vera Cruz', 'Vera Cruz', '59184-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Viçosa', 'Vicosa', '59815-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Flor', 'Vila Flor', '59192-000', 'RN');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abunã', 'Abuna', '78929-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alta Alegre dos Parecis', 'Alta Alegre Dos Parecis', '78994-800', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alta Floresta do Oeste', 'Alta Floresta Do Oeste', '78994-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Paraíso', 'Alto Paraiso', '78956-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvorada do Oeste', 'Alvorada Do Oeste', '78969-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buritis', 'Buritis', '78967-800', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabixi', 'Cabixi', '78999-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cacaulândia', 'Cacaulandia', '78944-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cacoal', 'Cacoal', NULL, 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Calama', 'Calama', '78925-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Novo de Rondônia', 'Campo Novo De Rondonia', '78967-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Candeias do Jamari', 'Candeias Do Jamari', '78938-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Castanheiras', 'Castanheiras', '78992-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerejeiras', 'Cerejeiras', '78997-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chupinguaia', 'Chupinguaia', '78995-800', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colorado do Oeste', 'Colorado Do Oeste', '78996-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corumbiara', 'Corumbiara', '78966-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Costa Marques', 'Costa Marques', '78971-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cujubim', 'Cujubim', '78945-800', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espigão D''Oeste', 'Espigao D''Oeste', '78983-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Jorge Teixeira', 'Governador Jorge Teixeira', '78946-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guajará Mirim', 'Guajara Mirim', '78957-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaci Paraná', 'Jaci Parana', '78927-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapuã do Oeste', 'Itapua Do Oeste', '78937-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaru', 'Jaru', '78940-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ji-Paraná', 'Ji-Parana', NULL, 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Machadinho D''Oeste', 'Machadinho D''Oeste', '78948-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marco Rondon', 'Marco Rondon', '78985-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ministro Andreazza', 'Ministro Andreazza', '78981-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirante da Serra', 'Mirante Da Serra', '78949-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Negro', 'Monte Negro', '78965-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Brasilândia D''Oeste', 'Nova Brasilandia D''Oeste', '78974-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Mamoré', 'Nova Mamore', '78939-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova União', 'Nova Uniao', '78953-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Vida', 'Nova Vida', '78935-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Horizonte do Oeste', 'Novo Horizonte Do Oeste', '78991-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Preto do Oeste', 'Ouro Preto Do Oeste', '78950-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parecis', 'Parecis', '78989-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedras Negras', 'Pedras Negras', '78972-500', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pimenta Bueno', 'Pimenta Bueno', '78984-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pimenteiras do Oeste', 'Pimenteiras Do Oeste', '78998-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Velho', 'Porto Velho', NULL, 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Médici', 'Presidente Medici', '78968-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Primavera de Rondônia', 'Primavera De Rondonia', '78988-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Príncipe da Beira', 'Principe Da Beira', '78972-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Crespo', 'Rio Crespo', '78945-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riozinho', 'Riozinho', '78980-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rolim de Moura', 'Rolim De Moura', '78987-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia do Oeste', 'Santa Luzia Do Oeste', '78993-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Felipe D''Oeste', 'Sao Felipe D''Oeste', '78986-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco do Guaporé', 'Sao Francisco Do Guapore', '78973-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel do Guaporé', 'Sao Miguel Do Guapore', '78970-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Seringueiras', 'Seringueiras', '78990-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabajara', 'Tabajara', '78936-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teixeirópolis', 'Teixeiropolis', '78954-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Theobroma', 'Theobroma', '78947-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urupá', 'Urupa', '78955-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vale do Anari', 'Vale Do Anari', '78948-800', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vale do Paraíso', 'Vale Do Paraiso', '78959-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Extrema', 'Vila Extrema', '78928-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vilhena', 'Vilhena', '78995-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Alegre do Abunã', 'Vista Alegre Do Abuna', '78926-000', 'RO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Alegre', 'Alto Alegre', '69350-000', 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amajarí', 'Amajari', '69343-000', 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', NULL, 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonfim', 'Bonfim', '69380-000', 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cantá', 'Canta', '69390-000', 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caracaraí', 'Caracarai', '69360-000', 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caroebe', 'Caroebe', '69378-000', 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iracema', 'Iracema', '69348-000', 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mucajaí', 'Mucajai', '69340-000', 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Normandia', 'Normandia', '69355-000', 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pacaraima', 'Pacaraima', '69345-000', 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rorainópolis', 'Rorainopolis', '69373-000', 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Baliza', 'Sao Joao Da Baliza', '69375-000', 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz', 'Sao Luiz', '69370-000', 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uiramutá', 'Uiramuta', '69358-000', 'RR');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aceguá', 'Acegua', '96445-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Afonso Rodrigues', 'Afonso Rodrigues', '97825-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Santa', 'Agua Santa', '99965-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas Claras', 'Aguas Claras', '94760-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Agudo', 'Agudo', '96540-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ajuricaba', 'Ajuricaba', '98750-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Albardão', 'Albardao', '96670-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alecrim', 'Alecrim', '98950-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alegrete', 'Alegrete', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alegria', 'Alegria', '98905-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alfredo Brenner', 'Alfredo Brenner', '98210-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Almirante Tamandaré do Sul', 'Almirante Tamandare Do Sul', '99523-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alpestre', 'Alpestre', '98480-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Alegre', 'Alto Alegre', '99430-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Alegre', 'Alto Alegre', '96380-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto da União', 'Alto Da Uniao', '98713-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Feliz', 'Alto Feliz', '95773-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Paredão', 'Alto Paredao', '96853-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Recreio', 'Alto Recreio', '99673-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Uruguai', 'Alto Uruguai', '98630-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvorada', 'Alvorada', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amaral Ferrador', 'Amaral Ferrador', '96635-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ametista do Sul', 'Ametista Do Sul', '98465-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('André da Rocha', 'Andre Da Rocha', '95310-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anta Gorda', 'Anta Gorda', '95980-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Kerpel', 'Antonio Kerpel', '98583-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Prado', 'Antonio Prado', '95250-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arambaré', 'Arambare', '96178-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araricá', 'Ararica', '93880-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aratiba', 'Aratiba', '99770-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arco Verde', 'Arco Verde', '95186-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arco-Íris', 'Arco-Iris', '98393-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arroio Canoas', 'Arroio Canoas', '95733-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arroio do Meio', 'Arroio Do Meio', '95940-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arroio do Padre', 'Arroio Do Padre', '96155-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arroio do Sal', 'Arroio Do Sal', '95585-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arroio do Só', 'Arroio Do So', '97165-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arroio do Tigre', 'Arroio Do Tigre', '96950-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arroio dos Ratos', 'Arroio Dos Ratos', '96740-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arroio Grande', 'Arroio Grande', '96330-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arroio Grande', 'Arroio Grande', '97120-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arroio Grande', 'Arroio Grande', '99455-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Árvore Só', 'Arvore So', '96240-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arvorezinha', 'Arvorezinha', '95995-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Atafona', 'Atafona', '98830-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Atiaçu', 'Atiacu', '99565-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Augusto Pestana', 'Augusto Pestana', '98740-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Áurea', 'Aurea', '99835-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Avelino Paranhos', 'Avelino Paranhos', '99425-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Azevedo Sodré', 'Azevedo Sodre', '97330-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bacupari', 'Bacupari', '95549-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bagé', 'Bage', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baliza', 'Baliza', '99833-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Balneário Pinhal', 'Balneario Pinhal', '95599-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Banhado do Colégio', 'Banhado Do Colegio', '96188-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão', 'Barao', '95730-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão de Cotegipe', 'Barao De Cotegipe', '99740-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão do Triunfo', 'Barao Do Triunfo', '96735-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Guarita', 'Barra Do Guarita', '98530-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Ouro', 'Barra Do Ouro', '95532-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Quaraí', 'Barra Do Quarai', '97538-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Ribeiro', 'Barra Do Ribeiro', '96790-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Rio Azul', 'Barra Do Rio Azul', '99795-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Funda', 'Barra Funda', '99585-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barracão', 'Barracao', '95370-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreirinho', 'Barreirinho', '99575-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiro', 'Barreiro', '98712-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barro Preto', 'Barro Preto', '98753-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barro Vermelho', 'Barro Vermelho', '96526-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barro Vermelho', 'Barro Vermelho', '94340-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barros Cassal', 'Barros Cassal', '99360-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Basílio', 'Basilio', '96320-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista', 'Bela Vista', '99885-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista', 'Bela Vista', '99135-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista', 'Bela Vista', '96912-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista', 'Bela Vista', '98605-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Beluno', 'Beluno', '97620-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Benjamin Constant do Sul', 'Benjamin Constant Do Sul', '99650-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bento Gonçalves', 'Bento Goncalves', '95700-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bexiga', 'Bexiga', '96680-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Esperança', 'Boa Esperanca', '95693-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', '95751-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', '96850-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista', 'Boa Vista', '96177-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista das Missões', 'Boa Vista Das Missoes', '98335-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista do Buricá', 'Boa Vista Do Burica', '98918-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista do Cadeado', 'Boa Vista Do Cadeado', '98118-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Machadinho', 'Machadinho', '99880-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista do Incra', 'Boa Vista Do Incra', '98120-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista do Sul', 'Boa Vista Do Sul', '95727-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boca do Monte', 'Boca Do Monte', '97170-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boi Preto', 'Boi Preto', '99555-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bojuru', 'Bojuru', '96228-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jardim', 'Bom Jardim', '96578-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus', 'Bom Jesus', '95290-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Princípio', 'Bom Principio', '95765-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Progresso', 'Bom Progresso', '98575-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Retiro', 'Bom Retiro', '95495-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Retiro do Guaíba', 'Bom Retiro Do Guaiba', '92800-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Retiro do Sul', 'Bom Retiro Do Sul', '95870-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonito', 'Bonito', '96181-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boqueirão', 'Boqueirao', '95830-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boqueirão', 'Boqueirao', '96175-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boqueirão do Leão', 'Boqueirao Do Leao', '95920-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bororé', 'Borore', '97653-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bossoroca', 'Bossoroca', '97850-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Botucaraí', 'Botucarai', '96935-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Braga', 'Braga', '98560-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brochier', 'Brochier', '95790-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buriti', 'Buriti', '98825-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Butiá', 'Butia', '96750-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Butiás', 'Butias', '96293-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caçapava do Sul', 'Cacapava Do Sul', '96570-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cacequi', 'Cacequi', '97450-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira do Sul', 'Cachoeira Do Sul', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeirinha', 'Cachoeirinha', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cacique Doble', 'Cacique Doble', '99860-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cadorna', 'Cadorna', '95987-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caibaté', 'Caibate', '97930-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiçara', 'Caicara', '98440-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camaquã', 'Camaqua', '96180-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camargo', 'Camargo', '99165-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cambará do Sul', 'Cambara Do Sul', '95480-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campestre Baixo', 'Campestre Baixo', '95752-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campestre da Serra', 'Campestre Da Serra', '95255-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campina das Missões', 'Campina Das Missoes', '98975-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campina Redonda', 'Campina Redonda', '99405-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campinas', 'Campinas', '98255-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campinas do Sul', 'Campinas Do Sul', '99660-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Bom', 'Campo Bom', '93700-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Branco', 'Campo Branco', '95926-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo do Meio', 'Campo Do Meio', '99185-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Novo', 'Campo Novo', '98570-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Novo', 'Campo Novo', '99372-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Santo', 'Campo Santo', '98585-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Seco', 'Campo Seco', '97592-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Vicente', 'Campo Vicente', '93893-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos Borges', 'Campos Borges', '99435-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Candelária', 'Candelaria', '96930-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cândido Freire', 'Candido Freire', '98880-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cândido Godói', 'Candido Godoi', '98970-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Candiota', 'Candiota', '96495-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canela', 'Canela', '95680-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canguçu', 'Cangucu', '96600-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canhembora', 'Canhembora', '97270-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canoas', 'Canoas', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canudos do Vale', 'Canudos Do Vale', '95933-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capané', 'Capane', '96524-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão Bonito do Sul', 'Capao Bonito Do Sul', '95308-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão Bonito', 'Capao Bonito', '99447-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão Comprido', 'Capao Comprido', '96295-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão da Canoa', 'Capao Da Canoa', '95555-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão da Porteira', 'Capao Da Porteira', '94770-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão do Cedro', 'Capao Do Cedro', '95304-500', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão do Cipó', 'Capao Do Cipo', '97753-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão do Leão', 'Capao Do Leao', '96160-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capela de Santana', 'Capela De Santana', '95745-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capela Velha', 'Capela Velha', '96183-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capinzal', 'Capinzal', '99686-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capitão', 'Capitao', '95935-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capivari do Sul', 'Capivari Do Sul', '95552-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capivarita', 'Capivarita', '96695-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capo-Erê', 'Capo-Ere', '99717-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capoeira Grande', 'Capoeira Grande', '98525-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraá', 'Caraa', '95515-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carajá Seival', 'Caraja Seival', '96580-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carazinho', 'Carazinho', '99500-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carlos Barbosa', 'Carlos Barbosa', '95185-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carlos Gomes', 'Carlos Gomes', '99825-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carovi', 'Carovi', '97733-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Casca', 'Casca', '99260-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cascata', 'Cascata', '98922-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cascata', 'Cascata', '96140-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caseiros', 'Caseiros', '95315-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Castelinho', 'Castelinho', '98405-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catuípe', 'Catuipe', '98770-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cavajureta', 'Cavajureta', '97440-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caverá', 'Cavera', '97594-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caxias do Sul', 'Caxias Do Sul', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cazuza Ferreira', 'Cazuza Ferreira', '95450-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cedro Marcado', 'Cedro Marcado', '98520-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Centenário', 'Centenario', '99838-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Centenário', 'Centenario', '98313-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Centro Linha Brasil', 'Centro Linha Brasil', '95808-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerrito', 'Cerrito', '96395-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerrito Alegre', 'Cerrito Alegre', '96105-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerrito do Ouro ou Vila do Cerrito', 'Cerrito Do Ouro Ou Vila Do Cerrito', '97370-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerro Alto', 'Cerro Alto', '98943-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerro Branco', 'Cerro Branco', '96535-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerro Claro', 'Cerro Claro', '97403-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerro do Martins', 'Cerro Do Martins', '96575-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerro do Roque', 'Cerro Do Roque', '96753-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerro Grande', 'Cerro Grande', '98340-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerro Grande do Sul', 'Cerro Grande Do Sul', '96770-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerro Largo', 'Cerro Largo', '97900-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chapada', 'Chapada', '99530-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chapada', 'Chapada', '95425-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Charqueadas', 'Charqueadas', '96745-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Charrua', 'Charrua', '99960-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chiapeta', 'Chiapeta', '98760-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chicolomã', 'Chicoloma', '95508-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chimarrão', 'Chimarrao', '95312-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chorão', 'Chorao', '98720-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chuí', 'Chui', '96255-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chuvisca', 'Chuvisca', '96193-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cidreira', 'Cidreira', '95595-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cinqüentenário', 'Cinquentenario', '98946-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ciríaco', 'Ciriaco', '99970-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Clara', 'Clara', '97415-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Clemente Argolo', 'Clemente Argolo', '95302-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coimbra', 'Coimbra', '98868-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colinas', 'Colinas', '95895-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia das Almas', 'Colonia Das Almas', '98775-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Medeiros', 'Colonia Medeiros', '98916-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Municipal', 'Colonia Municipal', '98844-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Nova', 'Colonia Nova', '96439-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia São João', 'Colonia Sao Joao', '98122-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Z-3', 'Colonia Z-3', '96130-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coloninha', 'Coloninha', '96980-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colorado', 'Colorado', '99460-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Comandai', 'Comandai', '98841-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Condor', 'Condor', '98290-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Consolata', 'Consolata', '98914-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Constantina', 'Constantina', '99680-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coqueiro Baixo', 'Coqueiro Baixo', '95955-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coqueiros do Sul', 'Coqueiros Do Sul', '99528-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cordilheira', 'Cordilheira', '96528-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coroados', 'Coroados', '98598-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Barros', 'Coronel Barros', '98735-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Bicaco', 'Coronel Bicaco', '98580-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Finzito', 'Coronel Finzito', '98395-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Pilar', 'Coronel Pilar', '95726-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Teixeira', 'Coronel Teixeira', '99805-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cortado', 'Cortado', '96550-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Costa da Cadeia', 'Costa Da Cadeia', '95855-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Costão', 'Costao', '95882-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cotiporã', 'Cotipora', '95335-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coxilha', 'Coxilha', '99145-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coxilha Grande', 'Coxilha Grande', '95223-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cr-1', 'Cr-1', '95547-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Crissiumal', 'Crissiumal', '98640-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristal', 'Cristal', '96195-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristal do Sul', 'Cristal Do Sul', '98368-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Criúva', 'Criuva', '95143-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruz Alta', 'Cruz Alta', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzaltense', 'Cruzaltense', '99665-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzeiro', 'Cruzeiro', '98478-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzeiro do Sul', 'Cruzeiro Do Sul', '95930-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curral Alto', 'Curral Alto', '96245-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curumim', 'Curumim', '95558-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Daltro Filho', 'Daltro Filho', '95888-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Daltro Filho', 'Daltro Filho', '95724-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Daltro Filho', 'Daltro Filho', '98515-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dário Lassance', 'Dario Lassance', '96444-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('David Canabarro', 'David Canabarro', '99980-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Delfina', 'Delfina', '95884-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Deodoro', 'Deodoro', '95810-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Depósito', 'Deposito', '99420-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Derrubadas', 'Derrubadas', '98528-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dezesseis de Novembro', 'Dezesseis De Novembro', '97845-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dilermando de Aguiar', 'Dilermando De Aguiar', '97180-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divino', 'Divino', '98474-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dois Irmãos', 'Dois Irmaos', '93950-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dois Irmãos das Missões', 'Dois Irmaos Das Missoes', '98385-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dois Lajeados', 'Dois Lajeados', '99220-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Sul', 'Sao Jose Do Sul', '95748-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Feliciano', 'Dom Feliciano', '96190-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Feliciano', 'Dom Feliciano', '94350-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Pedrito', 'Dom Pedrito', '96450-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dom Pedro de Alcântara', 'Dom Pedro De Alcantara', '95568-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dona Francisca', 'Dona Francisca', '97280-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dona Otília', 'Dona Otilia', '97973-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dourado', 'Dourado', '99775-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bozano', 'Bozano', '98733-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doutor Edgardo Pereira Velho', 'Doutor Edgardo Pereira Velho', '96280-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doutor Maurício Cardoso', 'Doutor Mauricio Cardoso', '98925-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doutor Ricardo', 'Doutor Ricardo', '95967-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eldorado do Sul', 'Eldorado Do Sul', '92990-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eletra', 'Eletra', '95435-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Encantado', 'Encantado', '95960-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Encruzilhada', 'Encruzilhada', '97665-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Encruzilhada do Sul', 'Encruzilhada Do Sul', '96610-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenho Velho', 'Engenho Velho', '99698-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Entre Rios do Sul', 'Entre Rios Do Sul', '99645-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Entre-Ijuís', 'Entre-Ijuis', '98855-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Entrepelado', 'Entrepelado', '95605-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Erebango', 'Erebango', '99920-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Erechim', 'Erechim', '99700-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ernestina', 'Ernestina', '99140-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ernesto Alves', 'Ernesto Alves', '97750-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Erval Grande', 'Erval Grande', '99750-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Erval Seco', 'Erval Seco', '98390-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Erveiras', 'Erveiras', '96868-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esmeralda', 'Esmeralda', '95380-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esperança do Sul', 'Esperanca Do Sul', '98635-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espigão', 'Espigao', '94740-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espigão Alto', 'Espigao Alto', '95375-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espinilho Grande', 'Espinilho Grande', '98173-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espírito Santo', 'Espirito Santo', '98907-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espumoso', 'Espumoso', '99400-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esquina Araújo', 'Esquina Araujo', '98917-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esquina Bom Sucesso', 'Esquina Bom Sucesso', '98777-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esquina Gaúcha', 'Esquina Gaucha', '98655-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esquina Gaúcha', 'Esquina Gaucha', '98857-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esquina Ipiranga', 'Esquina Ipiranga', '98885-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esquina Piratini', 'Esquina Piratini', '97865-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estação', 'Estacao', '99930-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estância Grande', 'Estancia Grande', '94890-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estância Velha', 'Estancia Velha', '93600-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esteio', 'Esteio', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esteira', 'Esteira', '95218-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estreito', 'Estreito', '96227-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrela', 'Estrela', '95880-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrela', 'Estrela', '95227-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrela Velha', 'Estrela Velha', '96990-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eugênio de Castro', 'Eugenio De Castro', '98860-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Evangelista', 'Evangelista', '99262-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fagundes Varela', 'Fagundes Varela', '95333-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fão', 'Fao', '95914-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faria Lemos', 'Faria Lemos', '95713-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Farinhas', 'Farinhas', '98490-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Farrapos', 'Farrapos', '99872-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Farroupilha', 'Farroupilha', '95180-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faxinal', 'Faxinal', '99357-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faxinal do Soturno', 'Faxinal Do Soturno', '97220-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faxinalzinho', 'Faxinalzinho', '99655-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda Fialho', 'Fazenda Fialho', '95608-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda Souza', 'Fazenda Souza', '95125-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda Vilanova', 'Fazenda Vilanova', '95875-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Feliz', 'Feliz', '95770-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ferreira', 'Ferreira', '96521-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flores da Cunha', 'Flores Da Cunha', '95270-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floresta', 'Floresta', '98710-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floresta', 'Floresta', '98613-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floriano Peixoto', 'Floriano Peixoto', '99910-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flórida', 'Florida', '97725-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fontoura Xavier', 'Fontoura Xavier', '99370-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Formigueiro', 'Formigueiro', '97210-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Formosa', 'Formosa', '96871-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Forninho', 'Forninho', '96583-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Forquetinha', 'Forquetinha', '95937-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fortaleza dos Valos', 'Fortaleza Dos Valos', '98125-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frederico Westphalen', 'Frederico Westphalen', '98400-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frei Sebastião', 'Frei Sebastiao', '95551-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Freire', 'Freire', '96390-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Garibaldi', 'Garibaldi', '95720-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Garibaldina', 'Garibaldina', '95723-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Garruchos', 'Garruchos', '97690-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gaurama', 'Gaurama', '99830-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('General Câmara', 'General Camara', '95820-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gentil', 'Gentil', '99160-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Getúlio Vargas', 'Getulio Vargas', '99900-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Giruá', 'Girua', '98870-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Glória', 'Gloria', '95565-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Glorinha', 'Glorinha', '94380-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goio-En', 'Goio-En', '99752-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gramado', 'Gramado', '95670-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gramado dos Loureiros', 'Gramado Dos Loureiros', '99605-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gramado São Pedro', 'Gramado Sao Pedro', '99375-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gramado Xavier', 'Gramado Xavier', '96875-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gravataí', 'Gravatai', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guabiju', 'Guabiju', '95355-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaíba', 'Guaiba', '92500-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guajuviras', 'Guajuviras', '92455-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaporé', 'Guapore', '99200-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarani das Missões', 'Guarani Das Missoes', '97950-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guassupi', 'Guassupi', '97408-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Harmonia', 'Harmonia', '95785-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Herval', 'Herval', '96310-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Herveiras', 'Herveiras', '96888-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Hidráulica', 'Hidraulica', '96163-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Horizontina', 'Horizontina', '98920-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Hulha Negra', 'Hulha Negra', '96460-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Humaitá', 'Humaita', '98670-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibarama', 'Ibarama', '96925-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibaré', 'Ibare', '97395-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiaçá', 'Ibiaca', '99940-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiraiaras', 'Ibiraiaras', '95305-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibirapuitã', 'Ibirapuita', '99320-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibirubá', 'Ibiruba', '98200-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igrejinha', 'Igrejinha', '95650-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igrejinha', 'Igrejinha', '99515-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ijucapirama', 'Ijucapirama', '97763-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ijuí', 'Ijui', '98700-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilha dos Marinheiros', 'Ilha Dos Marinheiros', '96223-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilópolis', 'Ilopolis', '95990-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Imbé', 'Imbe', '95625-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Imigrante', 'Imigrante', '95885-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Independência', 'Independencia', '98915-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inhacorá', 'Inhacora', '98765-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipê', 'Ipe', '95240-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipiranga', 'Ipiranga', '94370-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipiranga do Sul', 'Ipiranga Do Sul', '99925-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipuaçu', 'Ipuacu', '98445-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iraí', 'Irai', '98460-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iruí', 'Irui', '96655-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaara', 'Itaara', '97185-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itacolomi', 'Itacolomi', '94330-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itacurubi', 'Itacurubi', '97685-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itacurubi', 'Itacurubi', '97720-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaí', 'Itai', '98717-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaimbezinho', 'Itaimbezinho', '95296-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itão', 'Itao', '97660-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapuã', 'Itapua', '94750-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapucá', 'Itapuca', '95997-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapucá', 'Itapuca', '95983-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaqui', 'Itaqui', '97650-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itati', 'Itati', '95538-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itatiba do Sul', 'Itatiba Do Sul', '99760-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaúba', 'Itauba', '96960-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ituim', 'Ituim', '95225-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ivaí', 'Ivai', '97855-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ivorá', 'Ivora', '98160-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ivoti', 'Ivoti', '93900-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaboticaba', 'Jaboticaba', '98350-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacuizinho', 'Jacuizinho', '99457-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacutinga', 'Jacutinga', '99730-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguarão', 'Jaguarao', '96300-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguarete', 'Jaguarete', '99715-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguari', 'Jaguari', '97760-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jansen', 'Jansen', '95181-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaquirana', 'Jaquirana', '95420-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jari', 'Jari', '98175-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jazidas ou Capela São Vicente', 'Jazidas Ou Capela Sao Vicente', '97380-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Arregui', 'Joao Arregui', '97530-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Rodrigues', 'Joao Rodrigues', '96665-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joça Tavares', 'Joca Tavares', '96435-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jóia', 'Joia', '98180-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('José Otávio', 'Jose Otavio', '96431-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juá', 'Jua', '95430-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Júlio de Castilhos', 'Julio De Castilhos', '98130-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Bonita do Sul', 'Lagoa Bonita Do Sul', '96920-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa dos Três Cantos', 'Lagoa Dos Tres Cantos', '99495-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Vermelha', 'Lagoa Vermelha', '95300-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoão', 'Lagoao', '99340-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado', 'Lajeado', '95900-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado Bonito', 'Lajeado Bonito', '95338-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado Bonito', 'Lajeado Bonito', '98685-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado Cerne', 'Lajeado Cerne', '98845-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado do Bugre', 'Lajeado Do Bugre', '98320-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado Grande', 'Lajeado Grande', '98650-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado Grande', 'Lajeado Grande', '95440-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lara', 'Lara', '98603-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laranjeira', 'Laranjeira', '98455-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lava-Pés', 'Lava-Pes', '97735-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lavras do Sul', 'Lavras Do Sul', '97390-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Leonel Rocha', 'Leonel Rocha', '98333-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Liberato Salzano', 'Liberato Salzano', '99690-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lindolfo Collor', 'Lindolfo Collor', '93940-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Linha Comprida', 'Linha Comprida', '95754-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Linha Nova', 'Linha Nova', '95768-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Linha Vitória', 'Linha Vitoria', '99513-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Loreto', 'Loreto', '97430-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maçambará', 'Macambara', '97645-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Magistério', 'Magisterio', '95597-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mampituba', 'Mampituba', '95572-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manchinha', 'Manchinha', '98912-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mangueiras', 'Mangueiras', '97596-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manoel Viana', 'Manoel Viana', '97640-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maquiné', 'Maquine', '95530-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maratá', 'Marata', '95793-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marau', 'Marau', '99150-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marcelino Ramos', 'Marcelino Ramos', '99800-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marcorama', 'Marcorama', '95725-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mariana Pimentel', 'Mariana Pimentel', '92900-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mariano Moro', 'Mariano Moro', '99790-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mariante', 'Mariante', '95815-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mariápolis', 'Mariapolis', '95527-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marques de Souza', 'Marques De Souza', '95923-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mata', 'Mata', '97410-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matarazzo', 'Matarazzo', '96370-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mato Castelhano', 'Mato Castelhano', '99180-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mato Grande', 'Mato Grande', '98890-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mato Leitão', 'Mato Leitao', '95835-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mato Queimado', 'Mato Queimado', '97935-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mauá', 'Maua', '96335-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mauá', 'Maua', '98730-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maximiliano de Almeida', 'Maximiliano De Almeida', '99890-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Medianeira', 'Medianeira', '98755-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Minas do Leão', 'Minas Do Leao', '96755-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miraguaí', 'Miraguai', '98540-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miraguaia', 'Miraguaia', '95510-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirim', 'Mirim', '96250-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirim', 'Mirim', '99815-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montauri', 'Montauri', '99255-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre', 'Monte Alegre', '95828-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre', 'Monte Alegre', '97730-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre dos Campos', 'Monte Alegre Dos Campos', '95236-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alverne', 'Monte Alverne', '96859-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Belo do Sul', 'Monte Belo Do Sul', '95718-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Bonito', 'Monte Bonito', '96115-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montenegro', 'Montenegro', '95780-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mormaço', 'Mormaco', '99315-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morrinhos', 'Morrinhos', '96720-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morrinhos do Sul', 'Morrinhos Do Sul', '95577-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro Alto', 'Morro Alto', '95534-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro Azul', 'Morro Azul', '95583-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro Redondo', 'Morro Redondo', '96150-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro Reuter', 'Morro Reuter', '93990-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morungava', 'Morungava', '94360-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mostardas', 'Mostardas', '96270-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muçum', 'Mucum', '95970-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muitos Capões', 'Muitos Capoes', '95230-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muliterno', 'Muliterno', '99990-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Não-Me-Toque', 'Nao-Me-Toque', '99470-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nazaré', 'Nazare', '97745-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nicolau Vergueiro', 'Nicolau Vergueiro', '99175-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nonoai', 'Nonoai', '99600-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora Aparecida', 'Nossa Senhora Aparecida', '98260-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora da Conceição', 'Nossa Senhora Da Conceicao', '95763-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Alvorada', 'Nova Alvorada', '95985-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Araçá', 'Nova Araca', '95350-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Bassano', 'Nova Bassano', '95340-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Boa Vista', 'Nova Boa Vista', '99580-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Bréscia', 'Nova Brescia', '95950-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Candelária', 'Nova Candelaria', '98919-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Esperança do Sul', 'Nova Esperanca Do Sul', '97770-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Hartz', 'Nova Hartz', '93890-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Milano', 'Nova Milano', '95182-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Pádua', 'Nova Padua', '95275-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Palma', 'Nova Palma', '97250-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Petrópolis', 'Nova Petropolis', '95150-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Prata', 'Nova Prata', '95320-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Ramada', 'Nova Ramada', '98758-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Roma do Sul', 'Nova Roma Do Sul', '95260-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Santa Rita', 'Nova Santa Rita', '92480-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Sardenha', 'Nova Sardenha', '95183-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Barreiro', 'Novo Barreiro', '98338-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Cabrais', 'Novo Cabrais', '96545-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Hamburgo', 'Novo Hamburgo', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Horizonte', 'Novo Horizonte', '99448-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Machado', 'Novo Machado', '98955-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Planalto', 'Novo Planalto', '98688-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Tiradentes', 'Novo Tiradentes', '98370-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oliva', 'Oliva', '95135-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oralina', 'Oralina', '99449-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Osório', 'Osorio', '95520-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Osvaldo Cruz', 'Osvaldo Cruz', '98403-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Osvaldo Kroeff', 'Osvaldo Kroeff', '95485-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Otávio Rocha', 'Otavio Rocha', '95272-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pacheca', 'Pacheca', '96185-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padilha', 'Padilha', '95610-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Gonzales', 'Padre Gonzales', '98620-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paim Filho', 'Paim Filho', '99850-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmares do Sul', 'Palmares Do Sul', '95540-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmas', 'Palmas', '96437-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeira das Missões', 'Palmeira Das Missoes', '98300-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmitinho', 'Palmitinho', '98430-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pampeiro', 'Pampeiro', '97585-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Panambi', 'Panambi', '98280-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pântano Grande', 'Pantano Grande', '96690-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraí', 'Parai', '95360-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraíso do Sul', 'Paraiso Do Sul', '96530-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pareci Novo', 'Pareci Novo', '95783-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parobé', 'Parobe', '95630-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passa Sete', 'Passa Sete', '96908-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passinhos', 'Passinhos', '95525-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo Burmann', 'Passo Burmann', '98776-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo da Areia', 'Passo Da Areia', '94780-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo da Caveira', 'Passo Da Caveira', '94335-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo das Pedras', 'Passo Das Pedras', '96165-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo do Adão', 'Passo Do Adao', '96675-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo do Sabão', 'Passo Do Sabao', '94730-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo do Sobrado', 'Passo Do Sobrado', '96685-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo Fundo', 'Passo Fundo', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo Novo', 'Passo Novo', '97555-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo Raso', 'Passo Raso', '95850-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulo Bento', 'Paulo Bento', '99718-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pavão', 'Pavao', '96168-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paverama', 'Paverama', '95865-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedras Altas', 'Pedras Altas', '96487-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedreiras', 'Pedreiras', '96340-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Garcia', 'Pedro Garcia', '98565-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Osório', 'Pedro Osorio', '96360-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Paiva', 'Pedro Paiva', '98593-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pejuçara', 'Pejucara', '98270-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pelotas', 'Pelotas', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Picada Café', 'Picada Cafe', '95175-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhal', 'Pinhal', '98345-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhal', 'Pinhal', '95873-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhal', 'Pinhal', '96898-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhal', 'Pinhal', '99307-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhal Alto', 'Pinhal Alto', '95160-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhal da Serra', 'Pinhal Da Serra', '95390-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhal Grande', 'Pinhal Grande', '98150-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhalzinho', 'Pinhalzinho', '99754-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhalzinho', 'Pinhalzinho', '99695-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinheirinho do Vale', 'Pinheirinho Do Vale', '98435-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinheiro Machado', 'Pinheiro Machado', '96470-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinheiro Machado', 'Pinheiro Machado', '97990-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinheiro Marcado', 'Pinheiro Marcado', '99520-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinto Bandeira', 'Pinto Bandeira', '95717-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piraí', 'Pirai', '96443-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirapó', 'Pirapo', '97885-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piratini', 'Piratini', '96490-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pitanga', 'Pitanga', '98926-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planalto', 'Planalto', '98470-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planalto', 'Planalto', '98645-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Plano Alto', 'Plano Alto', '97515-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço das Antas', 'Poco Das Antas', '95740-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Polígono do Erval', 'Poligono Do Erval', '99353-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pólo Petroquímico de Triunfo', 'Polo Petroquimico De Triunfo', '95853-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontão', 'Pontao', '99190-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte Preta', 'Ponte Preta', '99735-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Portão', 'Portao', '93180-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Alegre', 'Porto Alegre', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Batista', 'Porto Batista', '95845-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Lucena', 'Porto Lucena', '98980-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Mauá', 'Porto Maua', '98947-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Vera Cruz', 'Porto Vera Cruz', '98985-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Xavier', 'Porto Xavier', '98995-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pouso Novo', 'Pouso Novo', '95945-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Povo Novo', 'Povo Novo', '96224-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Povoado Tozzo', 'Povoado Tozzo', '99763-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pranchada', 'Pranchada', '98928-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pratos', 'Pratos', '98936-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Lucena', 'Presidente Lucena', '93945-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Progresso', 'Progresso', '95925-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Progresso', 'Progresso', '96970-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Progresso', 'Progresso', '98911-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Progresso', 'Progresso', '99678-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Protásio Alves', 'Protasio Alves', '95345-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pulador', 'Pulador', '99130-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Putinga', 'Putinga', '95975-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quaraí', 'Quarai', '97560-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quaraim', 'Quaraim', '98913-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quatro Irmãos', 'Quatro Irmaos', '99720-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quevedos', 'Quevedos', '98140-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quilombo', 'Quilombo', '96145-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quinta', 'Quinta', '96222-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quintão', 'Quintao', '95548-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quinze de Novembro', 'Quinze De Novembro', '98230-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quitéria', 'Quiteria', '96730-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rancho Velho', 'Rancho Velho', '95543-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Redentora', 'Redentora', '98550-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Refugiado', 'Refugiado', '95215-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Relvado', 'Relvado', '95965-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Restinga Seca', 'Restinga Seca', '97200-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Restinga Seca', 'Restinga Seca', '98829-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rincão de São Pedro', 'Rincao De Sao Pedro', '97815-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rincão Del Rei', 'Rincao Del Rei', '96660-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rincão do Cristóvão Pereira', 'Rincao Do Cristovao Pereira', '96275-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rincão do Meio', 'Rincao Do Meio', '97680-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rincão do Segredo', 'Rincao Do Segredo', '99510-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rincão Doce', 'Rincao Doce', '99475-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rincão dos Kroeff', 'Rincao Dos Kroeff', '95410-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rincão dos Mendes', 'Rincao Dos Mendes', '98832-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rincão Vermelho', 'Rincao Vermelho', '97975-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Azul', 'Rio Azul', '99773-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Branco', 'Rio Branco', '95322-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio da Ilha', 'Rio Da Ilha', '95614-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio dos Índios', 'Rio Dos Indios', '99610-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Grande', 'Rio Grande', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Pardinho', 'Rio Pardinho', '96856-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Pardo', 'Rio Pardo', '96640-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Telha', 'Rio Telha', '99943-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Tigre', 'Rio Tigre', '99845-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Toldo', 'Rio Toldo', '99904-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riozinho', 'Riozinho', '95695-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Roca Sales', 'Roca Sales', '95735-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rodeio Bonito', 'Rodeio Bonito', '98360-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rolador', 'Rolador', '97843-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rolante', 'Rolante', '95690-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rolantinho da Figueira', 'Rolantinho Da Figueira', '95692-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ronda Alta', 'Ronda Alta', '99670-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rondinha', 'Rondinha', '99590-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Roque Gonzales', 'Roque Gonzales', '97970-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rosário', 'Rosario', '98745-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rosário do Sul', 'Rosario Do Sul', '97590-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sagrada Família', 'Sagrada Familia', '98330-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saicã', 'Saica', '97455-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saldanha Marinho', 'Saldanha Marinho', '98250-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saltinho', 'Saltinho', '99765-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saltinho', 'Saltinho', '98365-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salto', 'Salto', '98725-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salto do Jacuí', 'Salto Do Jacui', '99440-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salvador das Missões', 'Salvador Das Missoes', '97940-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salvador do Sul', 'Salvador Do Sul', '95750-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sananduva', 'Sananduva', '99840-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sant''auta', 'Sant''Auta', '96186-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Bárbara', 'Santa Barbara', '96585-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Bárbara', 'Santa Barbara', '99245-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Bárbara do Sul', 'Santa Barbara Do Sul', '98240-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Catarina', 'Santa Catarina', '97945-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cecília do Sul', 'Santa Cecilia Do Sul', '99952-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Clara do Ingaí', 'Santa Clara Do Ingai', '98234-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Clara do Sul', 'Santa Clara Do Sul', '95915-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cristina', 'Santa Cristina', '95640-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz', 'Santa Cruz', '98476-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz da Concórdia', 'Santa Cruz Da Concordia', '95620-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz do Sul', 'Santa Cruz Do Sul', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Flora', 'Santa Flora', '97160-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Inês', 'Santa Ines', '97820-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Izabel do Sul', 'Santa Izabel Do Sul', '96350-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Lúcia', 'Santa Lucia', '98722-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Lúcia do Piaí', 'Santa Lucia Do Piai', '95130-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luíza', 'Santa Luiza', '95187-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia', 'Santa Luzia', '95301-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria', 'Santa Maria', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria do Herval', 'Santa Maria Do Herval', '93995-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita do Sul', 'Santa Rita Do Sul', '96187-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa', 'Santa Rosa', '98900-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa', 'Santa Rosa', '95544-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Silvana', 'Santa Silvana', '96110-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Teresinha', 'Santa Teresinha', '98319-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Tereza', 'Santa Tereza', '95715-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Tereza', 'Santa Tereza', '98778-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Vitória do Palmar', 'Santa Vitoria Do Palmar', '96230-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana', 'Santana', '99550-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana', 'Santana', '99756-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana', 'Santana', '98728-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana da Boa Vista', 'Santana Da Boa Vista', '96590-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do Livramento', 'Santana Do Livramento', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santiago', 'Santiago', '97700-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Amaro do Sul', 'Santo Amaro Do Sul', '95823-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Ângelo', 'Santo Angelo', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio', 'Santo Antonio', '97915-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio', 'Santo Antonio', '98718-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio', 'Santo Antonio', '98594-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio da Patrulha', 'Santo Antonio Da Patrulha', '95500-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio das Missões', 'Santo Antonio Das Missoes', '97870-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio de Castro', 'Santo Antonio De Castro', '95188-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Bom Retiro', 'Santo Antonio Do Bom Retiro', '98220-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Palma', 'Santo Antonio Do Palma', '99265-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Planalto', 'Santo Antonio Do Planalto', '99525-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Augusto', 'Santo Augusto', '98590-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Cristo', 'Santo Cristo', '98960-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Expedito do Sul', 'Santo Expedito Do Sul', '99895-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Inácio', 'Santo Inacio', '95298-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bento', 'Sao Bento', '99518-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bom Jesus', 'Sao Bom Jesus', '98394-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Borja', 'Sao Borja', '97670-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Carlos', 'Sao Carlos', '97598-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos do Sul', 'Sao Domingos Do Sul', '99270-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco', 'Sao Francisco', '97913-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco de Assis', 'Sao Francisco De Assis', '97610-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco de Paula', 'Sao Francisco De Paula', '95400-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gabriel', 'Sao Gabriel', '97300-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Jerônimo', 'Sao Jeronimo', '96700-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João', 'Sao Joao', '98555-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João Batista', 'Sao Joao Batista', '98853-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João Bosco', 'Sao Joao Bosco', '99975-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Urtiga', 'Sao Joao Da Urtiga', '99855-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Polesine', 'Sao Joao Do Polesine', '97230-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Jorge', 'Sao Jorge', '95365-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José', 'Sao Jose', '98477-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José', 'Sao Jose', '97875-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Glória', 'Sao Jose Da Gloria', '99355-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José das Missões', 'Sao Jose Das Missoes', '98325-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José de Castro', 'Sao Jose De Castro', '95722-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Centro', 'Sao Jose Do Centro', '99480-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Herval', 'Sao Jose Do Herval', '99380-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Hortêncio', 'Sao Jose Do Hortencio', '95755-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Inhacorá', 'Sao Jose Do Inhacora', '98958-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Norte', 'Sao Jose Do Norte', '96225-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Ouro', 'Sao Jose Do Ouro', '99870-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José dos Ausentes', 'Sao Jose Dos Ausentes', '95280-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Leopoldo', 'Sao Leopoldo', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Lourenço das Missões', 'Sao Lourenco Das Missoes', '97840-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Lourenço do Sul', 'Sao Lourenco Do Sul', '96170-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luís Rei', 'Sao Luis Rei', '99865-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz', 'Sao Luiz', '98472-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz Gonzaga', 'Sao Luiz Gonzaga', '97800-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Manuel', 'Sao Manuel', '95220-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Marcos', 'Sao Marcos', '95190-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Marcos', 'Sao Marcos', '97535-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Martinho', 'Sao Martinho', '98690-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Martinho da Serra', 'Sao Martinho Da Serra', '97190-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel', 'Sao Miguel', '99540-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel das Missões', 'Sao Miguel Das Missoes', '98865-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Nicolau', 'Sao Nicolau', '97880-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Paulo', 'Sao Paulo', '95244-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Paulo das Missões', 'Sao Paulo Das Missoes', '97980-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '95714-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro das Missões', 'Sao Pedro Das Missoes', '98323-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro da Serra', 'Sao Pedro Da Serra', '95758-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro do Butiá', 'Sao Pedro Do Butia', '97920-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro do Iraxim', 'Sao Pedro Do Iraxim', '99875-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro do Sul', 'Sao Pedro Do Sul', '97400-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Roque', 'Sao Roque', '99125-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião', 'Sao Sebastiao', '95385-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião', 'Sao Sebastiao', '95307-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Caí', 'Sao Sebastiao Do Cai', '95760-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sepé', 'Sao Sepe', '97340-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Simão', 'Sao Simao', '96285-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Valentim', 'Sao Valentim', '99640-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Valentim', 'Sao Valentim', '98917-500', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Valentim do Sul', 'Sao Valentim Do Sul', '99240-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Valério do Sul', 'Sao Valerio Do Sul', '98595-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vendelino', 'Sao Vendelino', '95795-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente do Sul', 'Sao Vicente Do Sul', '97420-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapiranga', 'Sapiranga', '93800-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapucaia do Sul', 'Sapucaia Do Sul', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sarandi', 'Sarandi', '99560-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Scharlau', 'Scharlau', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Seberi', 'Seberi', '98380-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Seca', 'Seca', '95140-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sede Aurora', 'Sede Aurora', '98232-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sede Nova', 'Sede Nova', '98675-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Segredo', 'Segredo', '96910-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Segredo', 'Segredo', '95242-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Seival', 'Seival', '96441-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Selbach', 'Selbach', '99450-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Senador Salgado Filho', 'Senador Salgado Filho', '98895-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sentinela do Sul', 'Sentinela Do Sul', '96765-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serafim Schmidt', 'Serafim Schmidt', '96894-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serafina Corrêa', 'Serafina Correa', '99250-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sério', 'Serio', '95918-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra dos Gregórios', 'Serra Dos Gregorios', '95388-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrinha', 'Serrinha', '97810-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sertão', 'Sertao', '99170-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sertão Santana', 'Sertao Santana', '92850-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sertãozinho', 'Sertaozinho', '98485-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sete de Setembro', 'Sete De Setembro', '97960-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sete de Setembro', 'Sete De Setembro', '99758-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sete de Setembro', 'Sete De Setembro', '98903-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sete Lagoas', 'Sete Lagoas', '99768-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Severiano de Almeida', 'Severiano De Almeida', '99810-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silva Jardim', 'Silva Jardim', '99253-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silveira', 'Silveira', '95285-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silveira Martins', 'Silveira Martins', '97195-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sinimbu', 'Sinimbu', '96890-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sírio', 'Sirio', '98962-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sítio Gabriel', 'Sitio Gabriel', '98543-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sobradinho', 'Sobradinho', '96900-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Soledade', 'Soledade', '99300-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Souza Ramos', 'Souza Ramos', '99908-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Suspiro', 'Suspiro', '97320-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabaí', 'Tabai', '95863-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabajara', 'Tabajara', '99445-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taim', 'Taim', '96221-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tainhas', 'Tainhas', '95405-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tamanduá', 'Tamandua', '96915-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tanque', 'Tanque', '99876-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapejara', 'Tapejara', '99950-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapera', 'Tapera', '99490-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapera', 'Tapera', '96297-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapes', 'Tapes', '96760-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquara', 'Taquara', '95600-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquari', 'Taquari', '95860-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquarichim', 'Taquarichim', '97765-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquaruçu do Sul', 'Taquarucu Do Sul', '98410-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tavares', 'Tavares', '96290-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tenente Portela', 'Tenente Portela', '98500-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terra de Areia', 'Terra De Areia', '95535-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tesouras', 'Tesouras', '99535-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teutônia', 'Teutonia', '95890-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tiaraju', 'Tiaraju', '97310-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timbaúva', 'Timbauva', '97860-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tiradentes do Sul', 'Tiradentes Do Sul', '98680-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Toropi', 'Toropi', '97418-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Toroquá', 'Toroqua', '97630-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Torquato Severo', 'Torquato Severo', '96455-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Torres', 'Torres', '95560-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Torrinhas', 'Torrinhas', '96485-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Touro Passo', 'Touro Passo', '97595-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tramandaí', 'Tramandai', '95590-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Travesseiro', 'Travesseiro', '95948-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trentin', 'Trentin', '98355-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Arroios', 'Tres Arroios', '99725-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Barras', 'Tres Barras', '99778-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Cachoeiras', 'Tres Cachoeiras', '95580-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Coroas', 'Tres Coroas', '95660-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três de Maio', 'Tres De Maio', '98910-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Forquilhas', 'Tres Forquilhas', '95575-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Palmeiras', 'Tres Palmeiras', '99675-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Passos', 'Tres Passos', '98600-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Vendas', 'Tres Vendas', '96511-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trindade do Sul', 'Trindade Do Sul', '99615-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Triunfo', 'Triunfo', '95840-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tronqueiras', 'Tronqueiras', '98545-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tucunduva', 'Tucunduva', '98930-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tuiuti', 'Tuiuti', '95710-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tunas', 'Tunas', '99330-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Túnel Verde', 'Tunel Verde', '95598-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupanci do Sul', 'Tupanci Do Sul', '99878-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupanciretã', 'Tupancireta', '98170-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupancy ou Vila Block', 'Tupancy Ou Vila Block', '97350-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupandi', 'Tupandi', '95775-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupantuba', 'Tupantuba', '97743-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tuparendi', 'Tuparendi', '98940-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupi Silveira', 'Tupi Silveira', '96465-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupinambá', 'Tupinamba', '95304-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Turuçu', 'Turucu', '96148-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Turvinho', 'Turvinho', '98588-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubiretama', 'Ubiretama', '98898-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umbu', 'Umbu', '97460-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('União da Serra', 'Uniao Da Serra', '99215-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Unistalda', 'Unistalda', '97755-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uruguaiana', 'Uruguaiana', NULL, 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vacacai', 'Vacacai', '97305-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vacaria', 'Vacaria', '95200-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valdastico', 'Valdastico', '95964-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vale do Rio Cai', 'Vale Do Rio Cai', '95170-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vale do Sol', 'Vale Do Sol', '96878-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vale Real', 'Vale Real', '95778-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vale Veneto', 'Vale Veneto', '97235-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vale Verde', 'Vale Verde', '95833-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vanini', 'Vanini', '99290-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Venâncio Aires', 'Venancio Aires', '95800-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vera Cruz', 'Vera Cruz', '96880-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Veranópolis', 'Veranopolis', '95330-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vertentes', 'Vertentes', '97520-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vespasiano Correa', 'Vespasiano Correa', '95972-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Viadutos', 'Viadutos', '99820-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vicente Dutra', 'Vicente Dutra', '98450-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Victor Graeff', 'Victor Graeff', '99350-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Bender', 'Vila Bender', '98660-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Cruz', 'Vila Cruz', '97260-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Flores', 'Vila Flores', '95334-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Langaro', 'Vila Langaro', '99955-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Laranjeira', 'Vila Laranjeira', '98968-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Maria', 'Vila Maria', '99155-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nova do Sul', 'Vila Nova Do Sul', '97385-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Rica', 'Vila Rica', '99545-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Seca', 'Vila Seca', '98847-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Turvo', 'Vila Turvo', '98573-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Alegre', 'Vista Alegre', '98415-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Alegre', 'Vista Alegre', '99465-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Alegre do Prata', 'Vista Alegre Do Prata', '95325-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Gaúcha', 'Vista Gaucha', '98535-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vitória', 'Vitoria', '99945-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vitória das Missões', 'Vitoria Das Missoes', '98850-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Volta Alegre', 'Volta Alegre', '99410-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Volta Fechada', 'Volta Fechada', '99785-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Volta Grande', 'Volta Grande', '98495-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xadrez', 'Xadrez', '99522-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Xingu', 'Novo Xingu', '99687-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abdon Batista', 'Abdon Batista', '89636-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abelardo Luz', 'Abelardo Luz', '89830-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Agrolândia', 'Agrolandia', '88420-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Agronômica', 'Agronomica', '89188-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Doce', 'Agua Doce', '89654-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas Brancas', 'Aguas Brancas', '88655-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas Claras', 'Aguas Claras', '89320-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas de Chapecó', 'Aguas De Chapeco', '89883-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas Frias', 'Aguas Frias', '89843-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas Mornas', 'Aguas Mornas', '88150-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aguti', 'Aguti', '88280-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aiurê', 'Aiure', '88892-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alfredo Wagner', 'Alfredo Wagner', '88450-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Alegre', 'Alto Alegre', '89666-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Bela Vista', 'Alto Bela Vista', '89730-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto da Serra', 'Alto Da Serra', '89816-300', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anchieta', 'Anchieta', '89970-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angelina', 'Angelina', '88460-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anita Garibaldi', 'Anita Garibaldi', '88590-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anitápolis', 'Anitapolis', '88475-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anta Gorda', 'Anta Gorda', '89564-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Antônio Carlos', 'Antonio Carlos', '88180-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apiúna', 'Apiuna', '89135-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arabutã', 'Arabuta', '89740-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araquari', 'Araquari', '89245-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araranguá', 'Ararangua', '88900-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Armazém', 'Armazem', '88740-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arnópolis', 'Arnopolis', '88452-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arroio Trinta', 'Arroio Trinta', '89590-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arvoredo', 'Arvoredo', '89778-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ascurra', 'Ascurra', '89138-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Atalanta', 'Atalanta', '88410-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aterrado Torto', 'Aterrado Torto', '89173-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aurora', 'Aurora', '89186-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Azambuja', 'Azambuja', '88725-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baia Alta', 'Baia Alta', '89685-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Balneário Arroio do Silva', 'Balneario Arroio Do Silva', '88914-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Balneário Barra do Sul', 'Balneario Barra Do Sul', '89247-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Balneário Camboriú', 'Balneario Camboriu', '88330-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Balneário Gaivota', 'Balneario Gaivota', '88955-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Balneário Morro dos Conventos', 'Balneario Morro Dos Conventos', '88911-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bandeirante', 'Bandeirante', '89905-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Bonita', 'Barra Bonita', '89909-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Clara', 'Barra Clara', '88465-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra da Lagoa', 'Barra Da Lagoa', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra da Prata', 'Barra Da Prata', '89149-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Fria', 'Barra Fria', '89615-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Grande', 'Barra Grande', '89696-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Velha', 'Barra Velha', '88390-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barreiros', 'Barreiros', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barro Branco', 'Barro Branco', '88882-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bateias de Baixo', 'Bateias De Baixo', '89294-600', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista', 'Bela Vista', '89628-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista do Sul', 'Bela Vista Do Sul', '89310-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista do Toldo', 'Bela Vista Do Toldo', '89478-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Belmonte', 'Belmonte', '89925-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Benedito Novo', 'Benedito Novo', '89124-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Biguaçu', 'Biguacu', '88160-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Blumenau', 'Blumenau', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bocaína do Sul', 'Bocaina Do Sul', '88538-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boiteuxburgo', 'Boiteuxburgo', '88265-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jardim da Serra', 'Bom Jardim Da Serra', '88640-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus', 'Bom Jesus', '89824-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus do Oeste', 'Bom Jesus Do Oeste', '89873-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Retiro', 'Bom Retiro', '88680-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Sucesso', 'Bom Sucesso', '89566-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bombinhas', 'Bombinhas', '88215-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Botuverá', 'Botuvera', '88370-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Braço do Norte', 'Braco Do Norte', '88750-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Braço do Trombudo', 'Braco Do Trombudo', '89178-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brunópolis', 'Brunopolis', '89634-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brusque', 'Brusque', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caçador', 'Cacador', '89500-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira de Fátima', 'Cachoeira De Fatima', '88993-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira do Bom Jesus', 'Cachoeira Do Bom Jesus', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caibi', 'Caibi', '89888-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Calmon', 'Calmon', '89430-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Camboriú', 'Camboriu', '88340-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cambuinzal', 'Cambuinzal', '89822-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campeche', 'Campeche', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campinas', 'Campinas', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Alegre', 'Campo Alegre', '89294-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Belo do Sul', 'Campo Belo Do Sul', '88580-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Erê', 'Campo Ere', '89980-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos Novos', 'Campos Novos', '89620-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canasvieiras', 'Canasvieiras', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canelinha', 'Canelinha', '88230-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canoas', 'Canoas', '88688-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canoinhas', 'Canoinhas', '89460-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão Alto', 'Capao Alto', '88548-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capinzal', 'Capinzal', '89665-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capivari de Baixo', 'Capivari De Baixo', '88745-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraíba', 'Caraiba', '89772-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catanduvas', 'Catanduvas', '89670-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catuíra', 'Catuira', '88453-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caxambu do Sul', 'Caxambu Do Sul', '89880-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cedro Alto', 'Cedro Alto', '89122-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Celso Ramos', 'Celso Ramos', '88598-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerro Negro', 'Cerro Negro', '88585-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chapadão do Lageado', 'Chapadao Do Lageado', '88407-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chapecó', 'Chapeco', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Claraíba', 'Claraiba', '88275-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cocal do Sul', 'Cocal Do Sul', '88845-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colônia Santa Tereza', 'Colonia Santa Tereza', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Concórdia', 'Concordia', '89700-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cordilheira Alta', 'Cordilheira Alta', '89819-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Freitas', 'Coronel Freitas', '89840-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Martins', 'Coronel Martins', '89837-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Correia Pinto', 'Correia Pinto', '88535-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corupá', 'Corupa', '89280-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Criciúma', 'Criciuma', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cunha Porã', 'Cunha Pora', '89890-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cunhataí', 'Cunhatai', '89886-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curitibanos', 'Curitibanos', '89520-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dal Pai', 'Dal Pai', '89626-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dalbérgia', 'Dalbergia', '89143-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Descanso', 'Descanso', '89910-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dionísio Cerqueira', 'Dionisio Cerqueira', '89950-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dona Emma', 'Dona Emma', '89155-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Doutor Pedrinho', 'Doutor Pedrinho', '89126-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenho Velho', 'Engenho Velho', '89720-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Enseada de Brito', 'Enseada De Brito', '88139-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Entre Rios', 'Entre Rios', '89862-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ermo', 'Ermo', '88935-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Erval Velho', 'Erval Velho', '89613-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espinilho', 'Espinilho', '89622-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estação Cocal', 'Estacao Cocal', '88835-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Faxinal dos Guedes', 'Faxinal Dos Guedes', '89694-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda Zandavalli', 'Fazenda Zandavalli', '89817-500', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Felipe Schmidt', 'Felipe Schmidt', '89473-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Figueira', 'Figueira', '89816-400', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flor do Sertão', 'Flor Do Sertao', '89878-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Florianópolis', 'Florianopolis', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Formosa do Sul', 'Formosa Do Sul', '89859-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Forquilhinha', 'Forquilhinha', '88850-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fragosos', 'Fragosos', '89294-800', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fraiburgo', 'Fraiburgo', '89580-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frederico Wastner', 'Frederico Wastner', '89994-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frei Rogério', 'Frei Rogerio', '89530-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Galvão', 'Galvao', '89838-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Garcia', 'Garcia', '88463-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Garopaba', 'Garopaba', '88495-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Garuva', 'Garuva', '89248-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gaspar', 'Gaspar', '89110-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goio-En', 'Goio-En', '89816-200', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Governador Celso Ramos', 'Governador Celso Ramos', '88190-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Grão Pará', 'Grao Para', '88890-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Grápia', 'Grapia', '89907-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gravatal', 'Gravatal', '88735-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guabiruba', 'Guabiruba', '88360-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaporanga', 'Guaporanga', '88165-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraciaba', 'Guaraciaba', '89920-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaramirim', 'Guaramirim', '89270-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarujá do Sul', 'Guaruja Do Sul', '89940-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guatá', 'Guata', '88884-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guatambú', 'Guatambu', '89817-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Hercílio Luz', 'Hercilio Luz', '88913-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Herciliópolis', 'Herciliopolis', '89657-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Herval D'' Oeste', 'Herval D'' Oeste', '89610-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiam', 'Ibiam', '89652-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibicaré', 'Ibicare', '89640-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibicuí', 'Ibicui', '89631-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibirama', 'Ibirama', '89140-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Içara', 'Icara', '88820-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilhota', 'Ilhota', '88320-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Imaruí', 'Imarui', '88770-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Imbituba', 'Imbituba', '88780-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Imbuia', 'Imbuia', '88440-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indaial', 'Indaial', '89130-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Índios', 'Indios', '88533-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ingleses do Rio Vermelho', 'Ingleses Do Rio Vermelho', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Invernada', 'Invernada', '88895-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iomerê', 'Iomere', '89558-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipira', 'Ipira', '89669-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipoméia', 'Ipomeia', '89555-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iporã do Oeste', 'Ipora Do Oeste', '89899-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipuaçu', 'Ipuacu', '89832-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipumirim', 'Ipumirim', '89790-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iraceminha', 'Iraceminha', '89891-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irakitan', 'Irakitan', '89646-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irani', 'Irani', '89680-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iraputã', 'Iraputa', '89344-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irati', 'Irati', '89856-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irineópolis', 'Irineopolis', '89440-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itá', 'Ita', '89760-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaió', 'Itaio', '89348-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaiópolis', 'Itaiopolis', '89340-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itajaí', 'Itajai', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itajubá', 'Itajuba', '89913-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapema', 'Itapema', '88220-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapiranga', 'Itapiranga', '89896-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapoã', 'Itapoa', '89249-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapocu', 'Itapocu', '89246-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itoupava', 'Itoupava', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ituporanga', 'Ituporanga', '88400-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaborá', 'Jabora', '89677-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacinto Machado', 'Jacinto Machado', '88950-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguaruna', 'Jaguaruna', '88715-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaraguá do Sul', 'Jaragua Do Sul', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardinópolis', 'Jardinopolis', '89848-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joaçaba', 'Joacaba', '89600-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joinville', 'Joinville', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('José Boiteux', 'Jose Boiteux', '89145-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jupiá', 'Jupia', '89839-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lacerdópolis', 'Lacerdopolis', '89660-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lages', 'Lages', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa', 'Lagoa', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa da Estiva', 'Lagoa Da Estiva', '88595-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laguna', 'Laguna', '88790-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado Grande', 'Lajeado Grande', '89828-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laurentino', 'Laurentino', '89170-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lauro Müller', 'Lauro Muller', '88880-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Leão', 'Leao', '89632-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lebon Régis', 'Lebon Regis', '89515-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Leoberto Leal', 'Leoberto Leal', '88445-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lindóia do Sul', 'Lindoia Do Sul', '89735-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Linha das Palmeiras', 'Linha Das Palmeiras', '89785-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lontras', 'Lontras', '89182-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lourdes', 'Lourdes', '89568-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luiz Alves', 'Luiz Alves', '89115-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luzerna', 'Luzerna', '89609-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Machados', 'Machados', '88378-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macieira', 'Macieira', '89518-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mafra', 'Mafra', '89300-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Major Gercino', 'Major Gercino', '88260-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Major Vieira', 'Major Vieira', '89480-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maracajá', 'Maracaja', '88915-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marari', 'Marari', '89648-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maratá', 'Marata', '89836-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maravilha', 'Maravilha', '89874-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marcílio Dias', 'Marcilio Dias', '89465-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marechal Bormann', 'Marechal Bormann', '89816-100', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marema', 'Marema', '89860-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mariflor', 'Mariflor', '89933-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marombas', 'Marombas', '89635-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marombas Bossardi', 'Marombas Bossardi', '89528-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Massaranduba', 'Massaranduba', '89108-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matos Costa', 'Matos Costa', '89420-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Meleiro', 'Meleiro', '88920-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirador', 'Mirador', '89153-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirim', 'Mirim', '88787-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirim Doce', 'Mirim Doce', '89194-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Modelo', 'Modelo', '89872-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mondaí', 'Mondai', '89893-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre', 'Monte Alegre', '88348-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Carlo', 'Monte Carlo', '89618-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Castelo', 'Monte Castelo', '89380-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro Chato', 'Morro Chato', '88934-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro da Fumaça', 'Morro Da Fumaca', '88830-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro do Meio', 'Morro Do Meio', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro Grande', 'Morro Grande', '88925-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Navegantes', 'Navegantes', '88375-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora de Caravaggio', 'Nossa Senhora De Caravaggio', '88868-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Cultura', 'Nova Cultura', '89375-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Erechim', 'Nova Erechim', '89865-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Guarita', 'Nova Guarita', '88964-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Itaberaba', 'Nova Itaberaba', '89818-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Petrópolis', 'Nova Petropolis', '89607-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Teutônia', 'Nova Teutonia', '89775-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Trento', 'Nova Trento', '88270-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Veneza', 'Nova Veneza', '88865-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Horizonte', 'Novo Horizonte', '89998-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Orleans', 'Orleans', '88870-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Otacílio Costa', 'Otacilio Costa', '88540-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro', 'Ouro', '89663-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Verde', 'Ouro Verde', '89834-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Verde', 'Ouro Verde', '89923-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paial', 'Paial', '89765-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Painel', 'Painel', '88543-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palhoça', 'Palhoca', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palma Sola', 'Palma Sola', '89985-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeira', 'Palmeira', '88545-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmitos', 'Palmitos', '89887-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pântano do Sul', 'Pantano Do Sul', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Papanduva', 'Papanduva', '89370-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraíso', 'Paraiso', '89906-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo de Torres', 'Passo De Torres', '88980-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passo Manso', 'Passo Manso', '89192-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Passos Maia', 'Passos Maia', '89687-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paula Pereira', 'Paula Pereira', '89470-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulo Lopes', 'Paulo Lopes', '88490-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedras Grandes', 'Pedras Grandes', '88720-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Penha', 'Penha', '88385-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pericó', 'Perico', '88615-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Peritiba', 'Peritiba', '89750-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pescaria Brava', 'Pescaria Brava', '88798-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Petrolândia', 'Petrolandia', '88430-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piçarras', 'Picarras', '88380-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pindotiba', 'Pindotiba', '88873-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhalzinho', 'Pinhalzinho', '89870-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinheiral', 'Pinheiral', '88268-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinheiro Preto', 'Pinheiro Preto', '89570-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinheiros', 'Pinheiros', '89476-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirabeiraba', 'Pirabeiraba', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piratuba', 'Piratuba', '89667-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planalto', 'Planalto', '89728-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planalto Alegre', 'Planalto Alegre', '89882-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço Preto', 'Poco Preto', '89450-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pomerode', 'Pomerode', '89107-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte Alta', 'Ponte Alta', '88550-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte Alta do Norte', 'Ponte Alta Do Norte', '89535-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte Serrada', 'Ponte Serrada', '89683-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Belo', 'Porto Belo', '88210-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto União', 'Porto Uniao', '89400-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pouso Redondo', 'Pouso Redondo', '89172-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Praia Grande', 'Praia Grande', '88990-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prata', 'Prata', '89904-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Castelo Branco', 'Presidente Castelo Branco', '89745-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Getúlio', 'Presidente Getulio', '89150-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Juscelino', 'Presidente Juscelino', '89992-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Kennedy', 'Presidente Kennedy', '89725-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Nereu', 'Presidente Nereu', '89184-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Princesa', 'Princesa', '89935-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quarta Linha', 'Quarta Linha', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quilombo', 'Quilombo', '89850-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quilômetro Doze', 'Quilometro Doze', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rancho Queimado', 'Rancho Queimado', '88470-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ratones', 'Ratones', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Residência Fuck', 'Residencia Fuck', '89384-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão da Ilha', 'Ribeirao Da Ilha', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão Pequeno', 'Ribeirao Pequeno', '88794-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Antinha', 'Rio Antinha', '88435-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Bonito', 'Rio Bonito', '88405-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio D''Una', 'Rio D''Una', '88775-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio da Anta', 'Rio Da Anta', '89346-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio da Luz', 'Rio Da Luz', '89250-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio das Antas', 'Rio Das Antas', '89550-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio das Furnas', 'Rio Das Furnas', '88872-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio do Campo', 'Rio Do Campo', '89198-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio do Oeste', 'Rio Do Oeste', '89180-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio do Sul', 'Rio Do Sul', '89160-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio dos Bugres', 'Rio Dos Bugres', '88403-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio dos Cedros', 'Rio Dos Cedros', '89121-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Fortuna', 'Rio Fortuna', '88760-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Maina', 'Rio Maina', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Negrinho', 'Rio Negrinho', '89295-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Preto do Sul', 'Rio Preto Do Sul', '89315-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Rufino', 'Rio Rufino', '88658-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riqueza', 'Riqueza', '89895-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rodeio', 'Rodeio', '89136-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Romelândia', 'Romelandia', '89908-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sai', 'Sai', '89243-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salete', 'Salete', '89196-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saltinho', 'Saltinho', '89981-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salto Veloso', 'Salto Veloso', '89595-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sanga da Toca', 'Sanga Da Toca', '88912-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sangão', 'Sangao', '88717-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cecília', 'Santa Cecilia', '89540-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz do Timbó', 'Santa Cruz Do Timbo', '89410-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Helena', 'Santa Helena', '89915-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Helena', 'Santa Helena', '89608-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Izabel', 'Santa Izabel', '88620-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Lúcia', 'Santa Lucia', '89664-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Lúcia', 'Santa Lucia', '89887-500', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria', 'Santa Maria', '89125-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa de Lima', 'Santa Rosa De Lima', '88763-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa do Sul', 'Santa Rosa Do Sul', '88965-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha', 'Santa Terezinha', '89199-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha do Progresso', 'Santa Terezinha Do Progresso', '89983-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha do Salto', 'Santa Terezinha Do Salto', '88531-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santiago do Sul', 'Santiago Do Sul', '89854-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Amaro da Imperatriz', 'Santo Amaro Da Imperatriz', '88140-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio de Lisboa', 'Santo Antonio De Lisboa', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bento Baixo', 'Sao Bento Baixo', '88867-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bento do Sul', 'Sao Bento Do Sul', '89290-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bernardino', 'Sao Bernardino', '89982-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bonifácio', 'Sao Bonifacio', '88485-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Carlos', 'Sao Carlos', '89885-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Cristóvão', 'Sao Cristovao', '89495-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Cristóvão do Sul', 'Sao Cristovao Do Sul', '89533-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Defende', 'Sao Defende', '88800-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos', 'Sao Domingos', '89835-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco do Sul', 'Sao Francisco Do Sul', '89240-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Gabriel', 'Sao Gabriel', '88712-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João Batista', 'Sao Joao Batista', '88240-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Itaperiú', 'Sao Joao Do Itaperiu', '88395-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Oeste', 'Sao Joao Do Oeste', '89897-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Rio Vermelho', 'Sao Joao Do Rio Vermelho', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Sul', 'Sao Joao Do Sul', '88970-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim', 'Sao Joaquim', '88600-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José', 'Sao Jose', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Cedro', 'Sao Jose Do Cedro', '89930-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Cerrito', 'Sao Jose Do Cerrito', '88570-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Laranjal', 'Sao Jose Do Laranjal', '89892-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Leonardo', 'Sao Leonardo', '88455-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Lourenço do Oeste', 'Sao Lourenco Do Oeste', '89990-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Ludgero', 'Sao Ludgero', '88730-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Martinho', 'Sao Martinho', '88765-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel do Oeste', 'Sao Miguel Do Oeste', '89900-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel da Boa Vista', 'Sao Miguel Da Boa Vista', '89879-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel da Serra', 'Sao Miguel Da Serra', '89415-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro de Alcântara', 'Sao Pedro De Alcantara', '88125-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro Tobias', 'Sao Pedro Tobias', '89960-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Roque', 'Sao Roque', '89996-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Arvoredo', 'Sao Sebastiao Do Arvoredo', '88610-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Sul', 'Sao Sebastiao Do Sul', '89517-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapiranga', 'Sapiranga', '88923-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saudades', 'Saudades', '89868-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Schroeder', 'Schroeder', '89275-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Seara', 'Seara', '89770-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sede Oldemburg', 'Sede Oldemburg', '89887-700', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Alta', 'Serra Alta', '89871-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Siderópolis', 'Sideropolis', '88860-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sombrio', 'Sombrio', '88960-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sorocaba do Sul', 'Sorocaba Do Sul', '88170-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sul Brasil', 'Sul Brasil', '89855-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taió', 'Taio', '89190-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tangará', 'Tangara', '89642-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquara Verde', 'Taquara Verde', '89513-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquaras', 'Taquaras', '88474-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tigipió', 'Tigipio', '88245-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tigrinhos', 'Tigrinhos', '89875-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tijucas', 'Tijucas', '88200-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timbé do Sul', 'Timbe Do Sul', '88940-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timbó', 'Timbo', '89120-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timbó Grande', 'Timbo Grande', '89545-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Barras', 'Tres Barras', '89490-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Treviso', 'Treviso', '88862-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Treze de Maio', 'Treze De Maio', '88710-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Treze Tílias', 'Treze Tilias', '89650-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trombudo Central', 'Trombudo Central', '89176-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tubarão', 'Tubarao', NULL, 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tunápolis', 'Tunapolis', '89898-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupitinga', 'Tupitinga', '89630-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Turvo', 'Turvo', '88930-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('União do Oeste', 'Uniao Do Oeste', '89845-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urubici', 'Urubici', '88650-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uruguai', 'Uruguai', '89668-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urupema', 'Urupema', '88625-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urussanga', 'Urussanga', '88840-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargeão', 'Vargeao', '89690-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargem', 'Vargem', '89638-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargem Bonita', 'Vargem Bonita', '89675-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargem do Cedro', 'Vargem Do Cedro', '88766-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vidal Ramos', 'Vidal Ramos', '88443-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Videira', 'Videira', '89560-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Conceição', 'Vila Conceicao', '88975-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila de Volta Grande', 'Vila De Volta Grande', '89298-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Milani', 'Vila Milani', '89836-500', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nova', 'Vila Nova', '88782-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vítor Meireles', 'Vitor Meireles', '89148-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Witmarsum', 'Witmarsum', '89157-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xanxerê', 'Xanxere', '89820-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xavantina', 'Xavantina', '89780-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xaxim', 'Xaxim', '89825-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Zortéa', 'Zortea', '89633-000', 'SC');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Altos Verdes', 'Altos Verdes', '49555-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amparo de São Francisco', 'Amparo De Sao Francisco', '49920-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aquidabã', 'Aquidaba', '49790-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aracaju', 'Aracaju', NULL, 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arauá', 'Araua', '49220-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areia Branca', 'Areia Branca', '49580-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areia Branca', 'Areia Branca', '49099-400', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra dos Coqueiros', 'Barra Dos Coqueiros', '49140-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barracas', 'Barracas', '49710-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boquim', 'Boquim', '49360-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo Grande', 'Brejo Grande', '49995-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo do Brito', 'Campo Do Brito', '49520-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canhoba', 'Canhoba', '49880-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canindé de São Francisco', 'Caninde De Sao Francisco', '49820-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capela', 'Capela', '49700-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carira', 'Carira', '49550-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carmópolis', 'Carmopolis', '49740-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cedro de São João', 'Cedro De Sao Joao', '49930-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristinápolis', 'Cristinapolis', '49270-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cumbe', 'Cumbe', '49660-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divina Pastora', 'Divina Pastora', '49650-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estância', 'Estancia', '49200-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Feira Nova', 'Feira Nova', '49670-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frei Paulo', 'Frei Paulo', '49514-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gararu', 'Gararu', '49830-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('General Maynard', 'General Maynard', '49750-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Graccho Cardoso', 'Graccho Cardoso', '49860-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilha das Flores', 'Ilha Das Flores', '49990-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indiaroba', 'Indiaroba', '49250-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itabaiana', 'Itabaiana', '49500-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itabaianinha', 'Itabaianinha', '49290-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itabi', 'Itabi', '49870-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaporanga D''Ajuda', 'Itaporanga D''Ajuda', '49120-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japaratuba', 'Japaratuba', '49960-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Japoatã', 'Japoata', '49950-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagarto', 'Lagarto', '49400-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Funda', 'Lagoa Funda', '49835-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laranjeiras', 'Laranjeiras', '49170-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macambira', 'Macambira', '49565-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Malhada dos Bois', 'Malhada Dos Bois', '49940-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Malhador', 'Malhador', '49570-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maruim', 'Maruim', '49770-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miranda', 'Miranda', '49702-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moita Bonita', 'Moita Bonita', '49560-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre de Sergipe', 'Monte Alegre De Sergipe', '49690-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mosqueiro', 'Mosqueiro', '49099-700', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muribeca', 'Muribeca', '49780-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Neópolis', 'Neopolis', '49980-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora Aparecida', 'Nossa Senhora Aparecida', '49540-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora da Glória', 'Nossa Senhora Da Gloria', '49680-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora das Dores', 'Nossa Senhora Das Dores', '49600-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora de Lourdes', 'Nossa Senhora De Lourdes', '49890-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora do Socorro', 'Nossa Senhora Do Socorro', '49160-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pacatuba', 'Pacatuba', '49970-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmares', 'Palmares', '49325-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Mole', 'Pedra Mole', '49512-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedras', 'Pedras', '49704-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedrinhas', 'Pedrinhas', '49350-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhão', 'Pinhao', '49517-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirambu', 'Pirambu', '49190-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço Redondo', 'Poco Redondo', '49810-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poço Verde', 'Poco Verde', '49490-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto da Folha', 'Porto Da Folha', '49800-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Propriá', 'Propria', '49900-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riachão do Dantas', 'Riachao Do Dantas', '49320-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riachuelo', 'Riachuelo', '49130-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirópolis', 'Ribeiropolis', '49530-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rosário do Catete', 'Rosario Do Catete', '49760-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salgado', 'Salgado', '49390-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Samambaia', 'Samambaia', '49310-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Luzia do Itanhy', 'Santa Luzia Do Itanhy', '49230-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa de Lima', 'Santa Rosa De Lima', '49640-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana do São Francisco', 'Santana Do Sao Francisco', '49985-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Amaro das Brotas', 'Santo Amaro Das Brotas', '49180-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Cristóvão', 'Sao Cristovao', '49100-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Domingos', 'Sao Domingos', '49525-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco', 'Sao Francisco', '49945-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José', 'Sao Jose', '49099-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Mateus da Palestina', 'Sao Mateus Da Palestina', '49840-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel do Aleixo', 'Sao Miguel Do Aleixo', '49535-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Simão Dias', 'Simao Dias', '49480-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Siriri', 'Siriri', '49630-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Telha', 'Telha', '49910-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tobias Barreto', 'Tobias Barreto', '49300-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tomar do Geru', 'Tomar Do Geru', '49280-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Umbaúba', 'Umbauba', '49260-000', 'SE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Adamantina', 'Adamantina', '17800-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Adolfo', 'Adolfo', '15230-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Agisse', 'Agisse', '19610-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Água Vermelha', 'Agua Vermelha', '13578-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aguaí', 'Aguai', '13860-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas da Prata', 'Aguas Da Prata', '13890-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas de Lindóia', 'Aguas De Lindoia', '13940-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas de Santa Bárbara', 'Aguas De Santa Barbara', '18770-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Águas de São Pedro', 'Aguas De Sao Pedro', '13525-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Agudos', 'Agudos', '17120-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Agulha', 'Agulha', '15945-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ajapi', 'Ajapi', '13508-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alambari', 'Alambari', '18220-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alberto Moreira', 'Alberto Moreira', '14788-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aldeia', 'Aldeia', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aldeia de Carapicuíba', 'Aldeia De Carapicuiba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alfredo Guedes', 'Alfredo Guedes', '18688-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alfredo Marcondes', 'Alfredo Marcondes', '19180-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Altair', 'Altair', '15430-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Altinópolis', 'Altinopolis', '14350-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Alegre', 'Alto Alegre', '16310-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Porã', 'Alto Pora', '14480-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alumínio', 'Aluminio', '18125-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Álvares Florence', 'Alvares Florence', '15540-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Álvares Machado', 'Alvares Machado', '19160-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Álvaro de Carvalho', 'Alvaro De Carvalho', '17410-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvinlândia', 'Alvinlandia', '17430-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amadeu Amaral', 'Amadeu Amaral', '17530-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amandaba', 'Amandaba', '16820-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ameliópolis', 'Ameliopolis', '19140-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Americana', 'Americana', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Américo Brasiliense', 'Americo Brasiliense', '14820-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Américo de Campos', 'Americo De Campos', '15550-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Amparo', 'Amparo', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ana Dias', 'Ana Dias', '11770-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Analândia', 'Analandia', '13550-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anápolis', 'Anapolis', '17685-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Andes', 'Andes', '14715-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Andradina', 'Andradina', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angatuba', 'Angatuba', '18240-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anhembi', 'Anhembi', '18620-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anhumas', 'Anhumas', '19580-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anhumas', 'Anhumas', '13435-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida', 'Aparecida', '12570-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida D''Oeste', 'Aparecida D''Oeste', '15735-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida de Monte Alto', 'Aparecida De Monte Alto', '15915-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida de São Manuel', 'Aparecida De Sao Manuel', '18655-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida do Bonito', 'Aparecida Do Bonito', '15783-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apiaí', 'Apiai', '18320-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apiaí-Mirim', 'Apiai-Mirim', '18309-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arabela', 'Arabela', '17925-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aracaçu', 'Aracacu', '18295-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araçaíba', 'Aracaiba', '18323-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araçariguama', 'Aracariguama', '18147-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araçatuba', 'Aracatuba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araçoiaba da Serra', 'Aracoiaba Da Serra', '18190-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aramina', 'Aramina', '14550-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arandu', 'Arandu', '18710-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arapeí', 'Arapei', '12870-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araraquara', 'Araraquara', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araras', 'Araras', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araxás', 'Araxas', '19310-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arcadas', 'Arcadas', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arco-Íris', 'Arco-Iris', '17630-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arealva', 'Arealva', '17160-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areias', 'Areias', '12820-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Areiópolis', 'Areiopolis', '18670-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ariranha', 'Ariranha', '15960-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ariri', 'Ariri', '11995-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Artemis', 'Artemis', '13432-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Artur Nogueira', 'Artur Nogueira', '13160-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arujá', 'Aruja', '07400-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aspásia', 'Aspasia', '15763-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Assis', 'Assis', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Assistência', 'Assistencia', '13509-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Atibaia', 'Atibaia', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Atlântida', 'Atlantida', '17840-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Auriflama', 'Auriflama', '15350-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Avaí', 'Avai', '16680-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Avanhandava', 'Avanhandava', '16360-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Avaré', 'Avare', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Avencas', 'Avencas', '17532-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bacaetava', 'Bacaetava', '18565-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bacuriti', 'Bacuriti', '16520-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bady Bassitt', 'Bady Bassitt', '15115-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Baguaçu', 'Baguacu', '15405-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bairro Alto', 'Bairro Alto', '12190-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Balbinos', 'Balbinos', '16640-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bálsamo', 'Balsamo', '15140-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bananal', 'Bananal', '12850-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bandeirantes D''Oeste', 'Bandeirantes D''Oeste', '15367-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão Ataliba Nogueira', 'Barao Ataliba Nogueira', '13986-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão de Antonina', 'Barao De Antonina', '18490-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barão de Geraldo', 'Barao De Geraldo', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barbosa', 'Barbosa', '16350-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bariri', 'Bariri', '17250-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Bonita', 'Barra Bonita', '17340-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Chapéu', 'Barra Do Chapeu', '18325-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Turvo', 'Barra Do Turvo', '11955-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra Dourada', 'Barra Dourada', '15125-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barrânia', 'Barrania', '13775-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barretos', 'Barretos', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barrinha', 'Barrinha', '14860-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barueri', 'Barueri', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bastos', 'Bastos', '17690-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Batatais', 'Batatais', '14300-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Batatuba', 'Batatuba', '12975-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Batista Botelho', 'Batista Botelho', '18794-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bauru', 'Bauru', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bebedouro', 'Bebedouro', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Floresta', 'Bela Floresta', '15374-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bela Vista São-Carlense', 'Bela Vista Sao-Carlense', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bento de Abreu', 'Bento De Abreu', '16790-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bernardino de Campos', 'Bernardino De Campos', '18960-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bertioga', 'Bertioga', '11250-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bilac', 'Bilac', '16210-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Birigüi', 'Birigui', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Biritiba-Mirim', 'Biritiba-Mirim', '08940-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Biritiba-Ussu', 'Biritiba-Ussu', '08890-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Esperança do Sul', 'Boa Esperanca Do Sul', '14930-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista dos Andradas', 'Boa Vista Dos Andradas', '15545-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boa Vista Paulista', 'Boa Vista Paulista', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bocaina', 'Bocaina', '17240-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bofete', 'Bofete', '18590-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boituva', 'Boituva', '18550-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Fim do Bom Jesus', 'Bom Fim Do Bom Jesus', '13319-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus dos Perdões', 'Bom Jesus Dos Perdoes', '12955-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Retiro da Esperança', 'Bom Retiro Da Esperanca', '18243-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Sucesso de Itararé', 'Bom Sucesso De Itarare', '18475-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bonfim Paulista', 'Bonfim Paulista', '14110-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Borá', 'Bora', '19740-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Boracéia', 'Boraceia', '17270-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Borborema', 'Borborema', '14955-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Borebi', 'Borebi', '18675-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Botafogo', 'Botafogo', '14718-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Botelho', 'Botelho', '15953-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Botucatu', 'Botucatu', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Botujuru', 'Botujuru', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Braço', 'Braco', '11980-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bragança Paulista', 'Braganca Paulista', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brás Cubas', 'Bras Cubas', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brasitânia', 'Brasitania', '15617-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Braúna', 'Brauna', '16290-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejo Alegre', 'Brejo Alegre', '16265-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brodowski', 'Brodowski', '14340-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brotas', 'Brotas', '17380-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bueno de Andrada', 'Bueno De Andrada', '14812-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buri', 'Buri', '18290-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buritama', 'Buritama', '15290-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buritizal', 'Buritizal', '14570-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabrália Paulista', 'Cabralia Paulista', '17480-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cabreúva', 'Cabreuva', '13315-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caçapava', 'Cacapava', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira de Emas', 'Cachoeira De Emas', '13645-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeira Paulista', 'Cachoeira Paulista', '12630-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caconde', 'Caconde', '13770-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cafelândia', 'Cafelandia', '16500-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cafesópolis', 'Cafesopolis', '16530-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiabu', 'Caiabu', '19530-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caibura', 'Caibura', '11210-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caieiras', 'Caieiras', '07700-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caiuá', 'Caiua', '19450-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cajamar', 'Cajamar', '07750-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cajati', 'Cajati', '11950-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cajobi', 'Cajobi', '15410-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cajuru', 'Cajuru', '14240-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cambaquara', 'Cambaquara', '11640-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cambaratiba', 'Cambaratiba', '14945-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campestrinho', 'Campestrinho', '13785-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campina de Fora', 'Campina De Fora', '18434-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campina do Monte Alegre', 'Campina Do Monte Alegre', '18245-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campinal', 'Campinal', '19490-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campinas', 'Campinas', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campo Limpo Paulista', 'Campo Limpo Paulista', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos de Cunha', 'Campos De Cunha', '12540-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos do Jordão', 'Campos Do Jordao', '12460-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos Novos Paulista', 'Campos Novos Paulista', '19960-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cananéia', 'Cananeia', '11990-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canas', 'Canas', '12615-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Candia', 'Candia', '14185-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cândido Mota', 'Candido Mota', '19880-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cândido Rodrigues', 'Candido Rodrigues', '15930-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canguera', 'Canguera', '18145-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canitar', 'Canitar', '18990-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capão Bonito', 'Capao Bonito', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capela do Alto', 'Capela Do Alto', '18195-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capivari', 'Capivari', '13360-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capivari da Mata', 'Capivari Da Mata', '14508-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caporanga', 'Caporanga', '18915-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Capuava', 'Capuava', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caraguatatuba', 'Caraguatatuba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carapicuíba', 'Carapicuiba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cardeal', 'Cardeal', '13355-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cardoso', 'Cardoso', '15570-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cardoso', 'Cardoso', '15843-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caruara', 'Caruara', '11200-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Casa Branca', 'Casa Branca', '13700-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cássia dos Coqueiros', 'Cassia Dos Coqueiros', '14260-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Castilho', 'Castilho', '16920-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catanduva', 'Catanduva', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catiguá', 'Catigua', '15870-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Catucaba', 'Catucaba', '12150-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caucaia do Alto', 'Caucaia Do Alto', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cedral', 'Cedral', '15895-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerqueira César', 'Cerqueira Cesar', '18760-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cerquilho', 'Cerquilho', '18520-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cesário Lange', 'Cesario Lange', '18285-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cezar de Souza', 'Cezar De Souza', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Charqueada', 'Charqueada', '13515-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chavantes', 'Chavantes', '18970-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cipó-Guaçu', 'Cipo-Guacu', '06930-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Clarinia', 'Clarinia', '18905-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Clementina', 'Clementina', '16250-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cocaes', 'Cocaes', '18227-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colina', 'Colina', '14770-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colômbia', 'Colombia', '14795-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição de Monte Alegre', 'Conceicao De Monte Alegre', '19710-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conchal', 'Conchal', '13835-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conchas', 'Conchas', '18570-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cordeirópolis', 'Cordeiropolis', '13490-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coroados', 'Coroados', '16260-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Goulart', 'Coronel Goulart', '19165-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Coronel Macedo', 'Coronel Macedo', '18745-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corredeira', 'Corredeira', '16610-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Córrego Rico', 'Corrego Rico', '14896-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Corumbataí', 'Corumbatai', '13540-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cosmópolis', 'Cosmopolis', '13150-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cosmorama', 'Cosmorama', '15530-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Costa Machado', 'Costa Machado', '19265-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cotia', 'Cotia', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cravinhos', 'Cravinhos', '14140-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristais Paulista', 'Cristais Paulista', '14460-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruz das Posses', 'Cruz Das Posses', '14179-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzália', 'Cruzalia', '19860-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cruzeiro', 'Cruzeiro', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cubatão', 'Cubatao', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cuiabá Paulista', 'Cuiaba Paulista', '19270-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cunha', 'Cunha', '12530-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Curupá', 'Curupa', '14915-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dalas', 'Dalas', '15725-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Descalvado', 'Descalvado', '13690-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Diadema', 'Diadema', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dirce Reis', 'Dirce Reis', '15715-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dirceu', 'Dirceu', '17537-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divinolândia', 'Divinolandia', '13780-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dobrada', 'Dobrada', '15980-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dois Córregos', 'Dois Corregos', '17300-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dolcinópolis', 'Dolcinopolis', '15740-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Domélia', 'Domelia', '17123-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dourado', 'Dourado', '13590-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dracena', 'Dracena', '17900-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Duartina', 'Duartina', '17470-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dumont', 'Dumont', '14120-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Duplo Céu', 'Duplo Ceu', '15472-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Echaporã', 'Echapora', '19830-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eldorado', 'Eldorado', '11960-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eleutério', 'Eleuterio', '13988-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Elias Fausto', 'Elias Fausto', '13350-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Elisiário', 'Elisiario', '15823-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Embaúba', 'Embauba', '15425-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Embu', 'Embu', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Embu-Guaçu', 'Embu-Guacu', '06900-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Emilianópolis', 'Emilianopolis', '19350-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eneida', 'Eneida', '19130-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro Balduíno', 'Engenheiro Balduino', '15154-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro Coelho', 'Engenheiro Coelho', '13165-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro Maia', 'Engenheiro Maia', '18445-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Engenheiro Schmidt', 'Engenheiro Schmidt', '15104-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esmeralda', 'Esmeralda', '15795-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esperança D''Oeste', 'Esperanca D''Oeste', '19535-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espigão', 'Espigao', '19575-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espírito Santo do Pinhal', 'Espirito Santo Do Pinhal', '13990-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Espírito Santo do Turvo', 'Espirito Santo Do Turvo', '18935-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estiva Gerbi', 'Estiva Gerbi', '13857-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrela D''Oeste', 'Estrela D''Oeste', '15650-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Estrela do Norte', 'Estrela Do Norte', '19230-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Euclides da Cunha Paulista', 'Euclides Da Cunha Paulista', '19275-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Eugênio de Melo', 'Eugenio De Melo', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fartura', 'Fartura', '18870-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fátima', 'Fatima', '16490-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fátima Paulista', 'Fatima Paulista', '15757-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fazenda Velha', 'Fazenda Velha', '18288-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fernando Prestes', 'Fernando Prestes', '15940-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fernandópolis', 'Fernandopolis', '15600-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fernão', 'Fernao', '17455-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ferraz de Vasconcelos', 'Ferraz De Vasconcelos', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flora Rica', 'Flora Rica', '17870-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floreal', 'Floreal', '15320-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Floresta do Sul', 'Floresta Do Sul', '19120-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Flórida Paulista', 'Florida Paulista', '17830-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Florínia', 'Florinia', '19870-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Franca', 'Franca', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Francisco Morato', 'Francisco Morato', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Franco da Rocha', 'Franco Da Rocha', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Frutal do Campo', 'Frutal Do Campo', '19885-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gabriel Monteiro', 'Gabriel Monteiro', '16220-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gália', 'Galia', '17450-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Garça', 'Garca', '17400-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gardênia', 'Gardenia', '19620-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gastão Vidigal', 'Gastao Vidigal', '15330-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gavião Peixoto', 'Gaviao Peixoto', '14813-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('General Salgado', 'General Salgado', '15300-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Getulina', 'Getulina', '16450-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Glicério', 'Glicerio', '16270-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gramadinho', 'Gramadinho', '18218-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guachos', 'Guachos', '19510-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaianas', 'Guaianas', '17285-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaiçara', 'Guaicara', '16430-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaimbê', 'Guaimbe', '16480-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaíra', 'Guaira', '14790-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guamium', 'Guamium', '13431-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guapiaçu', 'Guapiacu', '15110-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guapiara', 'Guapiara', '18310-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guapiranga', 'Guapiranga', '16420-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guará', 'Guara', '14580-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraçaí', 'Guaracai', '16980-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraci', 'Guaraci', '15420-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraciaba D''Oeste', 'Guaraciaba D''Oeste', '17935-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarani D''Oeste', 'Guarani D''Oeste', '15680-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarantã', 'Guaranta', '16570-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarapiranga', 'Guarapiranga', '13585-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarapuá', 'Guarapua', '17310-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guararapes', 'Guararapes', '16700-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guararema', 'Guararema', '08900-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaratinguetá', 'Guaratingueta', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guareí', 'Guarei', '18250-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guariba', 'Guariba', '14840-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guariroba', 'Guariroba', '15903-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarizinho', 'Guarizinho', '18420-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarujá', 'Guaruja', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guarulhos', 'Guarulhos', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guatapará', 'Guatapara', '14115-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guzolândia', 'Guzolandia', '15355-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Herculândia', 'Herculandia', '17650-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Holambra', 'Holambra', '13825-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Holambra II', 'Holambra Ii', '18725-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Hortolândia', 'Hortolandia', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iacanga', 'Iacanga', '17180-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iacri', 'Iacri', '17680-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iaras', 'Iaras', '18775-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibaté', 'Ibate', '14815-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiporanga', 'Ibiporanga', '15175-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibirá', 'Ibira', '15860-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibirarema', 'Ibirarema', '19940-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitinga', 'Ibitinga', '14940-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitiruna', 'Ibitiruna', '13434-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitiúva', 'Ibitiuva', '14760-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibitu', 'Ibitu', '14789-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ibiúna', 'Ibiuna', '18150-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Icém', 'Icem', '15460-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ida Iolanda', 'Ida Iolanda', '15195-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iepê', 'Iepe', '19640-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igaçaba', 'Igacaba', '14475-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igaraçu do Tietê', 'Igaracu Do Tiete', '17350-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igaraí', 'Igarai', '13750-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igarapava', 'Igarapava', '14540-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Igaratá', 'Igarata', '12350-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iguape', 'Iguape', '11920-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilha Comprida', 'Ilha Comprida', '11925-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilha Diana', 'Ilha Diana', '11230-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilha Solteira', 'Ilha Solteira', '15385-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilhabela', 'Ilhabela', '11630-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indaiá do Aguapeí', 'Indaia Do Aguapei', '17835-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indaiatuba', 'Indaiatuba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indiana', 'Indiana', '19560-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Indiaporã', 'Indiapora', '15690-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ingás', 'Ingas', '15448-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Inúbia Paulista', 'Inubia Paulista', '17760-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipaussu', 'Ipaussu', '18950-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iperó', 'Ipero', '18560-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipeúna', 'Ipeuna', '13537-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipiguá', 'Ipigua', '15108-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iporanga', 'Iporanga', '18330-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipuã', 'Ipua', '14610-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iracemápolis', 'Iracemapolis', '13495-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irapé', 'Irape', '18980-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irapuã', 'Irapua', '14990-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Irapuru', 'Irapuru', '17880-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaberá', 'Itabera', '18440-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaboa', 'Itaboa', '18433-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaí', 'Itai', '18730-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaiuba', 'Itaiuba', '15153-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itajobi', 'Itajobi', '15840-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaju', 'Itaju', '17260-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itanhaém', 'Itanhaem', '11740-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaóca', 'Itaoca', '18360-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapecerica da Serra', 'Itapecerica Da Serra', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapetininga', 'Itapetininga', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapeuna', 'Itapeuna', '11970-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapeva', 'Itapeva', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapevi', 'Itapevi', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapira', 'Itapira', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapirapuã Paulista', 'Itapirapua Paulista', '18385-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itápolis', 'Itapolis', '14900-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaporanga', 'Itaporanga', '18480-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapuí', 'Itapui', '17230-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapura', 'Itapura', '15390-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaquaquecetuba', 'Itaquaquecetuba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaqueri da Serra', 'Itaqueri Da Serra', '13535-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itararé', 'Itarare', '18460-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itariri', 'Itariri', '11760-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itatiba', 'Itatiba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itatinga', 'Itatinga', '18690-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itirapina', 'Itirapina', '13530-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itirapuã', 'Itirapua', '14420-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itobi', 'Itobi', '13715-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itororó do Paranapanema', 'Itororo Do Paranapanema', '19208-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itu', 'Itu', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itupeva', 'Itupeva', '13295-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ituverava', 'Ituverava', '14500-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Iubatinga', 'Iubatinga', '19540-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaborandi', 'Jaborandi', '14775-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaboticabal', 'Jaboticabal', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacaré', 'Jacare', '13318-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacareí', 'Jacarei', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaci', 'Jaci', '15155-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaciporã', 'Jacipora', '17910-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacuba', 'Jacuba', '17170-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jacupiranga', 'Jacupiranga', '11940-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jafa', 'Jafa', '17405-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaguariúna', 'Jaguariuna', '13820-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jales', 'Jales', '15700-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jamaica', 'Jamaica', '17905-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jambeiro', 'Jambeiro', '12270-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jandira', 'Jandira', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim Belval', 'Jardim Belval', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim Presidente Dutra', 'Jardim Presidente Dutra', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim Santa Luzia', 'Jardim Santa Luzia', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardim Silveira', 'Jardim Silveira', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jardinópolis', 'Jardinopolis', '14680-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jarinu', 'Jarinu', '13240-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jatobá', 'Jatoba', '16330-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaú', 'Jau', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jeriquara', 'Jeriquara', '14450-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joanópolis', 'Joanopolis', '12980-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('João Ramalho', 'Joao Ramalho', '19680-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Joaquim Egídio', 'Joaquim Egidio', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jordanésia', 'Jordanesia', '07760-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('José Bonifácio', 'Jose Bonifacio', '15200-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juliânia', 'Juliania', '17660-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Júlio Mesquita', 'Julio Mesquita', '17550-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jumirim', 'Jumirim', '18535-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jundiaí', 'Jundiai', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jundiapeba', 'Jundiapeba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Junqueira', 'Junqueira', '15152-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Junqueirópolis', 'Junqueiropolis', '17890-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juquiá', 'Juquia', '11800-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juquiratiba', 'Juquiratiba', '18575-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juquitiba', 'Juquitiba', '06950-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juritis', 'Juritis', '16280-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jurucê', 'Juruce', '14690-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jurupeba', 'Jurupeba', '15475-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jurupema', 'Jurupema', '15905-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lácio', 'Lacio', '17539-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Azul', 'Lagoa Azul', '17705-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa Branca', 'Lagoa Branca', '13705-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoinha', 'Lagoinha', '12130-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laranjal Paulista', 'Laranjal Paulista', '18500-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Laras', 'Laras', '18505-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lauro Penteado', 'Lauro Penteado', '16255-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lavínia', 'Lavinia', '16850-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lavrinhas', 'Lavrinhas', '12760-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lençóis Paulista', 'Lencois Paulista', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Limeira', 'Limeira', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lindóia', 'Lindoia', '13950-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lins', 'Lins', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lobo', 'Lobo', '18695-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lorena', 'Lorena', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lourdes', 'Lourdes', '15285-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Louveira', 'Louveira', '13290-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lucélia', 'Lucelia', '17780-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lucianópolis', 'Lucianopolis', '17475-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luís Antônio', 'Luis Antonio', '14210-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luiziânia', 'Luiziania', '16340-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lupércio', 'Lupercio', '17420-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lusitânia', 'Lusitania', '14898-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lutécia', 'Lutecia', '19750-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macatuba', 'Macatuba', '17290-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macaubal', 'Macaubal', '15270-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macedônia', 'Macedonia', '15620-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Macucos', 'Macucos', '16460-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Magda', 'Magda', '15310-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mailasqui', 'Mailasqui', '18143-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mairinque', 'Mairinque', '18120-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mairiporã', 'Mairipora', '07600-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Major Prado', 'Major Prado', '16150-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Manduri', 'Manduri', '18780-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mangaratu', 'Mangaratu', '15442-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marabá Paulista', 'Maraba Paulista', '19430-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maraçaí', 'Maracai', '19840-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marapoama', 'Marapoama', '15845-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marcondésia', 'Marcondesia', '14733-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maresias', 'Maresias', '11620-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mariápolis', 'Mariapolis', '17810-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marília', 'Marilia', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marinópolis', 'Marinopolis', '15730-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maristela', 'Maristela', '18510-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Martim Francisco', 'Martim Francisco', '13817-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Martinho Prado Júnior', 'Martinho Prado Junior', '13855-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Martinópolis', 'Martinopolis', '19500-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Matão', 'Matao', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mauá', 'Maua', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mendonça', 'Mendonca', '15220-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Meridiano', 'Meridiano', '15625-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mesópolis', 'Mesopolis', '15748-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miguelópolis', 'Miguelopolis', '14530-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mineiros do Tietê', 'Mineiros Do Tiete', '17320-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mira Estrela', 'Mira Estrela', '15580-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miracatu', 'Miracatu', '11850-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miraluz', 'Miraluz', '15128-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirandópolis', 'Mirandopolis', '16800-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirante do Paranapanema', 'Mirante Do Paranapanema', '19260-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirassol', 'Mirassol', '15130-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirassolândia', 'Mirassolandia', '15145-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mococa', 'Mococa', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mogi das Cruzes', 'Mogi Das Cruzes', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mogi-Guaçu', 'Mogi-Guacu', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mogi-Mirim', 'Mogi-Mirim', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mombuca', 'Mombuca', '13380-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monções', 'Moncoes', '15275-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mongaguá', 'Mongagua', '11730-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Montalvão', 'Montalvao', '19110-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alegre do Sul', 'Monte Alegre Do Sul', '13910-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Alto', 'Monte Alto', '15910-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Aprazível', 'Monte Aprazivel', '15150-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Azul Paulista', 'Monte Azul Paulista', '14730-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Cabrão', 'Monte Cabrao', '11220-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Castelo', 'Monte Castelo', '17960-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Mor', 'Monte Mor', '13190-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Verde Paulista', 'Monte Verde Paulista', '15417-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monteiro Lobato', 'Monteiro Lobato', '12250-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Moreira César', 'Moreira Cesar', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro Agudo', 'Morro Agudo', '14640-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morro do Alto', 'Morro Do Alto', '18219-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Morungaba', 'Morungaba', '13260-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mostardas', 'Mostardas', '13915-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Motuca', 'Motuca', '14835-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mourão', 'Mourao', '17815-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Murutinga do Sul', 'Murutinga Do Sul', '16950-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nantes', 'Nantes', '19645-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Narandiba', 'Narandiba', '19220-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Natividade da Serra', 'Natividade Da Serra', '12180-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nazaré Paulista', 'Nazare Paulista', '12960-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Neves Paulista', 'Neves Paulista', '15120-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nhandeara', 'Nhandeara', '15190-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nipoã', 'Nipoa', '15240-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nogueira', 'Nogueira', '16690-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora do Remédio', 'Nossa Senhora Do Remedio', '08980-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Alexandria', 'Nova Alexandria', '19882-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Aliança', 'Nova Alianca', '15210-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova América', 'Nova America', '14904-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Aparecida', 'Nova Aparecida', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Campina', 'Nova Campina', '18435-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Canaã Paulista', 'Nova Canaa Paulista', '15773-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Castilho', 'Nova Castilho', '15313-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Europa', 'Nova Europa', '14920-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Granada', 'Nova Granada', '15440-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Guataporanga', 'Nova Guataporanga', '17950-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Independência', 'Nova Independencia', '16940-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Itapirema', 'Nova Itapirema', '15215-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Luzitânia', 'Nova Luzitania', '15340-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Odessa', 'Nova Odessa', '13460-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Pátria', 'Nova Patria', '19330-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Veneza', 'Nova Veneza', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novais', 'Novais', '15885-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Cravinhos', 'Novo Cravinhos', '17585-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Horizonte', 'Novo Horizonte', '14960-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nuporanga', 'Nuporanga', '14670-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oásis', 'Oasis', '17932-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ocauçu', 'Ocaucu', '17540-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Óleo', 'Oleo', '18790-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Olímpia', 'Olimpia', '15400-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oliveira Barros', 'Oliveira Barros', '11860-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Onda Branca', 'Onda Branca', '15445-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Onda Verde', 'Onda Verde', '15450-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oriente', 'Oriente', '17570-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Orindiúva', 'Orindiuva', '15480-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Orlândia', 'Orlandia', '14620-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Osasco', 'Osasco', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oscar Bressane', 'Oscar Bressane', '19770-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Osvaldo Cruz', 'Osvaldo Cruz', '17700-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ourinhos', 'Ourinhos', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Fino Paulista', 'Ouro Fino Paulista', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouro Verde', 'Ouro Verde', '17920-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ouroeste', 'Ouroeste', '15685-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pacaembu', 'Pacaembu', '17860-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Padre Nóbrega', 'Padre Nobrega', '17533-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palestina', 'Palestina', '15470-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmares Paulista', 'Palmares Paulista', '15828-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeira D''Oeste', 'Palmeira D''Oeste', '15720-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeiras de São Paulo', 'Palmeiras De Sao Paulo', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmital', 'Palmital', '19970-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Panorama', 'Panorama', '17980-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraguaçu Paulista', 'Paraguacu Paulista', '19700-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraibuna', 'Paraibuna', '12260-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraíso', 'Paraiso', '15825-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraisolândia', 'Paraisolandia', '13517-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranabi', 'Paranabi', '11650-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranapanema', 'Paranapanema', '18720-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranapiacaba', 'Paranapiacaba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranapuã', 'Paranapua', '15745-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parapuã', 'Parapua', '17730-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pardinho', 'Pardinho', '18640-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pariquera-Açu', 'Pariquera-Acu', '11930-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parisi', 'Parisi', '15525-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parnaso', 'Parnaso', '17620-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Parque Meia Lua', 'Parque Meia Lua', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paruru', 'Paruru', '18155-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Patrocínio Paulista', 'Patrocinio Paulista', '14415-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulicéia', 'Pauliceia', '17990-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulínia', 'Paulinia', '13140-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulistânia', 'Paulistania', '17150-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulo de Faria', 'Paulo De Faria', '15490-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paulópolis', 'Paulopolis', '17583-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pederneiras', 'Pederneiras', '17280-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Bela', 'Pedra Bela', '12990-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedra Branca de Itararé', 'Pedra Branca De Itarare', '18465-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedranópolis', 'Pedranopolis', '15630-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedregulho', 'Pedregulho', '14470-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedreira', 'Pedreira', '13920-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedrinhas Paulista', 'Pedrinhas Paulista', '19865-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Barros', 'Pedro Barros', '11855-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro de Toledo', 'Pedro De Toledo', '11790-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Penápolis', 'Penapolis', '16300-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pereira Barreto', 'Pereira Barreto', '15370-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pereiras', 'Pereiras', '18580-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Peruíbe', 'Peruibe', '11750-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piacatu', 'Piacatu', '16230-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Picinguaba', 'Picinguaba', '11690-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piedade', 'Piedade', '18170-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pilar do Sul', 'Pilar Do Sul', '18185-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pindamonhangaba', 'Pindamonhangaba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pindorama', 'Pindorama', '15830-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinhalzinho', 'Pinhalzinho', '12995-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pinheiros', 'Pinheiros', '12770-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pioneiros', 'Pioneiros', '14590-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piquerobi', 'Piquerobi', '19410-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piquete', 'Piquete', '12620-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piracaia', 'Piracaia', '12970-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piracicaba', 'Piracicaba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piraju', 'Piraju', '18800-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirajuí', 'Pirajui', '16600-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirambóia', 'Piramboia', '18630-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirangi', 'Pirangi', '15820-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirapitingui', 'Pirapitingui', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirapora do Bom Jesus', 'Pirapora Do Bom Jesus', '06550-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirapozinho', 'Pirapozinho', '19200-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pirassununga', 'Pirassununga', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piratininga', 'Piratininga', '17490-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pitangueiras', 'Pitangueiras', '14750-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planalto', 'Planalto', '15260-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planalto', 'Planalto', '16915-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Planalto do Sul', 'Planalto Do Sul', '19295-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Platina', 'Platina', '19990-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poá', 'Poa', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Poloni', 'Poloni', '15160-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Polvilho', 'Polvilho', '07770-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pompéia', 'Pompeia', '17580-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pongaí', 'Pongai', '16660-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontal', 'Pontal', '14180-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontalinda', 'Pontalinda', '15718-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontes Gestal', 'Pontes Gestal', '15560-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Populina', 'Populina', '15670-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porangaba', 'Porangaba', '18260-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Feliz', 'Porto Feliz', '18540-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Ferreira', 'Porto Ferreira', '13660-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Novo', 'Porto Novo', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Potim', 'Potim', '12525-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Potirendaba', 'Potirendaba', '15105-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Potunduva', 'Potunduva', '17220-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pracinha', 'Pracinha', '17790-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pradínia', 'Pradinia', '16606-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pradópolis', 'Pradopolis', '14850-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Praia Grande', 'Praia Grande', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pratânia', 'Pratania', '18660-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Alves', 'Presidente Alves', '16670-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Bernardes', 'Presidente Bernardes', '19300-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Epitácio', 'Presidente Epitacio', '19470-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Prudente', 'Presidente Prudente', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Venceslau', 'Presidente Venceslau', '19400-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Primavera', 'Primavera', '19274-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Promissão', 'Promissao', '16370-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prudêncio e Moraes', 'Prudencio E Moraes', '15307-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quadra', 'Quadra', '18255-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quatá', 'Quata', '19780-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Queiroz', 'Queiroz', '17590-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Queluz', 'Queluz', '12800-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quintana', 'Quintana', '17670-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Quiririm', 'Quiririm', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rafard', 'Rafard', '13370-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rancharia', 'Rancharia', '19600-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rechan', 'Rechan', '18217-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Redenção da Serra', 'Redencao Da Serra', '12170-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Regente Feijó', 'Regente Feijo', '19570-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Reginópolis', 'Reginopolis', '17190-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Registro', 'Registro', '11900-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Restinga', 'Restinga', '14430-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riacho Grande', 'Riacho Grande', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeira', 'Ribeira', '18380-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão Bonito', 'Ribeirao Bonito', '13580-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão Branco', 'Ribeirao Branco', '18430-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão Corrente', 'Ribeirao Corrente', '14445-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão do Sul', 'Ribeirao Do Sul', '19930-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão dos Índios', 'Ribeirao Dos Indios', '19380-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão Grande', 'Ribeirao Grande', '18315-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão Pires', 'Ribeirao Pires', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeirão Preto', 'Ribeirao Preto', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeiro do Vale', 'Ribeiro Do Vale', '16710-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ribeiro dos Santos', 'Ribeiro Dos Santos', '15408-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rifaina', 'Rifaina', '14490-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rincão', 'Rincao', '14830-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rinópolis', 'Rinopolis', '17740-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio das Pedras', 'Rio Das Pedras', '13390-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Grande da Serra', 'Rio Grande Da Serra', '09450-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riolândia', 'Riolandia', '15495-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riversul', 'Riversul', '18470-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Roberto', 'Roberto', '15835-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rosália', 'Rosalia', '17535-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rosana', 'Rosana', '19273-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Roseira', 'Roseira', '12580-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rubiácea', 'Rubiacea', '16750-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rubião Júnior', 'Rubiao Junior', '18618-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rubinéia', 'Rubineia', '15790-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ruilândia', 'Ruilandia', '15135-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sabaúna', 'Sabauna', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sabino', 'Sabino', '16440-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sagres', 'Sagres', '17710-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sales', 'Sales', '14980-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sales Oliveira', 'Sales Oliveira', '14660-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salesópolis', 'Salesopolis', '08970-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salmourão', 'Salmourao', '17720-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Saltinho', 'Saltinho', '13440-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salto', 'Salto', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salto de Pirapora', 'Salto De Pirapora', '18160-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salto do Avanhandava', 'Salto Do Avanhandava', '15208-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Salto Grande', 'Salto Grande', '19920-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sandovalina', 'Sandovalina', '19250-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Adélia', 'Santa Adelia', '15950-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Albertina', 'Santa Albertina', '15750-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa América', 'Santa America', '16455-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Bárbara D''Oeste', 'Santa Barbara D''Oeste', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Branca', 'Santa Branca', '12380-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Clara D''Oeste', 'Santa Clara D''Oeste', '15785-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz da Conceição', 'Santa Cruz Da Conceicao', '13625-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz da Esperança', 'Santa Cruz Da Esperanca', '14250-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz da Estrela', 'Santa Cruz Da Estrela', '13675-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taguaí', 'Taguai', '18890-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz das Palmeiras', 'Santa Cruz Das Palmeiras', '13650-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz do Rio Pardo', 'Santa Cruz Do Rio Pardo', '18900-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz dos Lopes', 'Santa Cruz Dos Lopes', '18468-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Ernestina', 'Santa Ernestina', '15970-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Eudóxia', 'Santa Eudoxia', '13579-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Fé do Sul', 'Santa Fe Do Sul', '15775-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Gertrudes', 'Santa Gertrudes', '13510-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Isabel', 'Santa Isabel', '07500-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Isabel do Marinheiro', 'Santa Isabel Do Marinheiro', '15635-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Lúcia', 'Santa Lucia', '14825-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Margarida Paulista', 'Santa Margarida Paulista', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria da Serra', 'Santa Maria Da Serra', '17370-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria do Gurupá', 'Santa Maria Do Gurupa', '16380-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Mercedes', 'Santa Mercedes', '17940-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita D''Oeste', 'Santa Rita D''Oeste', '15780-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita do Passa Quatro', 'Santa Rita Do Passa Quatro', '13670-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita do Ribeira', 'Santa Rita Do Ribeira', '11870-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa de Viterbo', 'Santa Rosa De Viterbo', '14270-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Salete', 'Santa Salete', '15768-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Teresinha de Piracicaba', 'Santa Teresinha De Piracicaba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana da Ponte Pensa', 'Santana Da Ponte Pensa', '15765-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santana de Parnaíba', 'Santana De Parnaiba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santelmo', 'Santelmo', '17288-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Anastácio', 'Santo Anastacio', '19360-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo André', 'Santo Andre', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio da Alegria', 'Santo Antonio Da Alegria', '14390-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio da Estiva', 'Santo Antonio Da Estiva', '16603-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio de Posse', 'Santo Antonio De Posse', '13830-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Aracanguá', 'Santo Antonio Do Aracangua', '16130-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Jardim', 'Santo Antonio Do Jardim', '13995-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Paranapanema', 'Santo Antonio Do Paranapanema', '19890-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Pinhal', 'Santo Antonio Do Pinhal', '12450-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio Paulista', 'Santo Antonio Paulista', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Expedito', 'Santo Expedito', '19190-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santópolis do Aguapeí', 'Santopolis Do Aguapei', '16240-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santos', 'Santos', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Benedito da Cachoeirinha', 'Sao Benedito Da Cachoeirinha', '14505-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Benedito das Areias', 'Sao Benedito Das Areias', '13755-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bento do Sapucaí', 'Sao Bento Do Sapucai', '12490-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bernardo do Campo', 'Sao Bernardo Do Campo', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Berto', 'Sao Berto', '18785-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Caetano do Sul', 'Sao Caetano Do Sul', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Carlos', 'Sao Carlos', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco', 'Sao Francisco', '15710-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco da Praia', 'Sao Francisco Da Praia', '11610-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Francisco Xavier', 'Sao Francisco Xavier', '12249-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João da Boa Vista', 'Sao Joao Da Boa Vista', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João das Duas Pontes', 'Sao Joao Das Duas Pontes', '15640-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João de Iracema', 'Sao Joao De Iracema', '15315-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João de Itaguaçu', 'Sao Joao De Itaguacu', '15855-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Marinheiro', 'Sao Joao Do Marinheiro', '15575-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Pau d''Alho', 'Sao Joao Do Pau D''Alho', '17970-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João Novo', 'Sao Joao Novo', '18140-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Joaquim da Barra', 'Sao Joaquim Da Barra', '14600-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José da Bela Vista', 'Sao Jose Da Bela Vista', '14440-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José das Laranjeiras', 'Sao Jose Das Laranjeiras', '19845-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Barreiro', 'Sao Jose Do Barreiro', '12830-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Rio Pardo', 'Sao Jose Do Rio Pardo', '13720-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José do Rio Preto', 'Sao Jose Do Rio Preto', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José dos Campos', 'Sao Jose Dos Campos', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Lourenço da Serra', 'Sao Lourenco Da Serra', '06890-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Lourenço do Turvo', 'Sao Lourenco Do Turvo', '15999-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz do Paraitinga', 'Sao Luiz Do Paraitinga', '12140-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Luiz do Guaricanga', 'Sao Luiz Do Guaricanga', '16675-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Manuel', 'Sao Manuel', '18650-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Martinho D''Oeste', 'Sao Martinho D''Oeste', '16320-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel Arcanjo', 'Sao Miguel Arcanjo', '18230-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Paulo', 'Sao Paulo', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro', 'Sao Pedro', '13520-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro do Turvo', 'Sao Pedro Do Turvo', '18940-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Roque', 'Sao Roque', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Roque da Fartura', 'Sao Roque Da Fartura', '13895-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião', 'Sao Sebastiao', '11600-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião da Grama', 'Sao Sebastiao Da Grama', '13790-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião da Serra', 'Sao Sebastiao Da Serra', '17390-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Silvestre de Jacareí', 'Sao Silvestre De Jacarei', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Simão', 'Sao Simao', '14200-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Vicente', 'Sao Vicente', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sapezal', 'Sapezal', '19720-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sarapuí', 'Sarapui', '18225-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sarutaiá', 'Sarutaia', '18840-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sebastianópolis do Sul', 'Sebastianopolis Do Sul', '15180-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Azul', 'Serra Azul', '14230-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serra Negra', 'Serra Negra', '13930-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Serrana', 'Serrana', '14150-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sertãozinho', 'Sertaozinho', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sete Barras', 'Sete Barras', '11910-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Severínia', 'Severinia', '14735-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silvânia', 'Silvania', '15990-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silveiras', 'Silveiras', '12690-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Simões', 'Simoes', '16510-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Simonsen', 'Simonsen', '15515-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Socorro', 'Socorro', '13960-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sodrélia', 'Sodrelia', '18910-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Solemar', 'Solemar', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sorocaba', 'Sorocaba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sousas', 'Sousas', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sud Mennucci', 'Sud Mennucci', '15360-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Suinana', 'Suinana', '15437-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sumaré', 'Sumare', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sussui', 'Sussui', '19975-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Suzanápolis', 'Suzanapolis', '15380-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Suzano', 'Suzano', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabajara', 'Tabajara', '16855-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabapuã', 'Tabapua', '15880-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tabatinga', 'Tabatinga', '14910-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taboão da Serra', 'Taboao Da Serra', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taciba', 'Taciba', '19590-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taiaçu', 'Taiacu', '14725-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taiacupeba', 'Taiacupeba', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taiúva', 'Taiuva', '14720-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Talhado', 'Talhado', '15102-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tambaú', 'Tambau', '13710-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tanabi', 'Tanabi', '15170-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapinas', 'Tapinas', '14907-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapiraí', 'Tapirai', '18180-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tapiratiba', 'Tapiratiba', '13760-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquaral', 'Taquaral', '14765-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquaritinga', 'Taquaritinga', '15900-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquarituba', 'Taquarituba', '18740-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquarivaí', 'Taquarivai', '18425-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tarabai', 'Tarabai', '19210-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tarumã', 'Taruma', '19820-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tatuí', 'Tatui', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taubaté', 'Taubate', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tecainda', 'Tecainda', '19505-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tejupá', 'Tejupa', '18830-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Teodoro Sampaio', 'Teodoro Sampaio', '19280-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Termas de Ibirá', 'Termas De Ibira', '15868-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terra Nova D''Oeste', 'Terra Nova D''Oeste', '17945-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Terra Roxa', 'Terra Roxa', '14745-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tibiriçá', 'Tibirica', '17110-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tibiriçá do Paranapanema', 'Tibirica Do Paranapanema', '18810-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tietê', 'Tiete', '18530-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timburi', 'Timburi', '18860-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Toledo', 'Toledo', '17627-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Torre de Pedra', 'Torre De Pedra', '18265-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Torrinha', 'Torrinha', '17360-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trabiju', 'Trabiju', '14935-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tremembé', 'Tremembe', '12120-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Alianças', 'Tres Aliancas', '16830-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Fronteiras', 'Tres Fronteiras', '15770-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Pontes', 'Tres Pontes', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Três Vendas', 'Tres Vendas', '17621-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tuiuti', 'Tuiuti', '12930-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tujuguaba', 'Tujuguaba', '13839-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupã', 'Tupa', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupi', 'Tupi', '13428-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupi Paulista', 'Tupi Paulista', '17930-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Turiba do Sul', 'Turiba Do Sul', '18450-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Turiúba', 'Turiuba', '15280-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Turmalina', 'Turmalina', '15755-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Turvínia', 'Turvinia', '14716-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubarana', 'Ubarana', '15225-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubatuba', 'Ubatuba', '11680-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ubirajara', 'Ubirajara', '17440-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uchoa', 'Uchoa', '15890-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('União Paulista', 'Uniao Paulista', '15250-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Universo', 'Universo', '17623-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urânia', 'Urania', '15760-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Uru', 'Uru', '16650-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Urupês', 'Urupes', '15850-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ururai', 'Ururai', '15955-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Utinga', 'Utinga', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vale Formoso', 'Vale Formoso', '14970-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valentim Gentil', 'Valentim Gentil', '15520-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valinhos', 'Valinhos', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Valparaíso', 'Valparaiso', '16880-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vanglória', 'Vangloria', '17282-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargem', 'Vargem', '12935-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargem Grande do Sul', 'Vargem Grande Do Sul', '13880-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vargem Grande Paulista', 'Vargem Grande Paulista', '06730-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Varpa', 'Varpa', '17625-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Várzea Paulista', 'Varzea Paulista', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Venda Branca', 'Venda Branca', '13707-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vera Cruz', 'Vera Cruz', '17560-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vicente de Carvalho', 'Vicente De Carvalho', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vicentinópolis', 'Vicentinopolis', '16140-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Dirce', 'Vila Dirce', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Nery', 'Vila Nery', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vila Xavier', 'Vila Xavier', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vinhedo', 'Vinhedo', '13280-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Viradouro', 'Viradouro', '14740-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vista Alegre do Alto', 'Vista Alegre Do Alto', '15920-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vitória Brasil', 'Vitoria Brasil', '15705-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vitoriana', 'Vitoriana', '18619-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Votorantim', 'Votorantim', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Votuporanga', 'Votuporanga', NULL, 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Zacarias', 'Zacarias', '15265-000', 'SP');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Abreulândia', 'Abreulandia', '77693-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aguiarnópolis', 'Aguiarnopolis', '77908-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aliança do Tocantins', 'Alianca Do Tocantins', '77455-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Almas', 'Almas', '77310-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alvorada', 'Alvorada', '77480-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Anajanópolis', 'Anajanopolis', '77712-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ananás', 'Ananas', '77890-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Angico', 'Angico', '77905-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aparecida do Rio Negro', 'Aparecida Do Rio Negro', '77620-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Apinajé', 'Apinaje', '77393-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aragaçuí', 'Aragacui', '77683-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aragominas', 'Aragominas', '77845-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araguacema', 'Araguacema', '77690-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araguaçu', 'Araguacu', '77475-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araguaína', 'Araguaina', NULL, 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araguanã', 'Araguana', '77855-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Araguatins', 'Araguatins', '77950-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arapoema', 'Arapoema', '77780-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arraias', 'Arraias', '77330-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Augustinópolis', 'Augustinopolis', '77960-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Aurora do Tocantins', 'Aurora Do Tocantins', '77325-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Axixá do Tocantins', 'Axixa Do Tocantins', '77930-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Babaçulândia', 'Babaculandia', '77870-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bandeirantes do Tocantins', 'Bandeirantes Do Tocantins', '77783-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Grota', 'Barra Do Grota', '77835-600', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barra do Ouro', 'Barra Do Ouro', '77765-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Barrolândia', 'Barrolandia', '77665-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bernardo Sayão', 'Bernardo Sayao', '77755-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus do Tocantins', 'Bom Jesus Do Tocantins', '77714-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brasilândia', 'Brasilandia', '77837-400', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brasilândia do Tocantins', 'Brasilandia Do Tocantins', '77735-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Brejinho de Nazaré', 'Brejinho De Nazare', '77560-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Buriti do Tocantins', 'Buriti Do Tocantins', '77995-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cachoeirinha', 'Cachoeirinha', '77915-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campos Lindos', 'Campos Lindos', '77777-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cana Brava', 'Cana Brava', '77333-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cariri do Tocantins', 'Cariri Do Tocantins', '77453-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carmolândia', 'Carmolandia', '77840-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Carrasco Bonito', 'Carrasco Bonito', '77985-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cartucho', 'Cartucho', '77772-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Caseara', 'Caseara', '77680-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Centenário', 'Centenario', '77723-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chapada da Areia', 'Chapada Da Areia', '77575-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chapada da Natividade', 'Chapada Da Natividade', '77378-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cocalândia', 'Cocalandia', '77836-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cocalinho', 'Cocalinho', '77839-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colinas do Tocantins', 'Colinas Do Tocantins', '77760-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colméia', 'Colmeia', '77725-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Combinado', 'Combinado', '77350-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conceição do Tocantins', 'Conceicao Do Tocantins', '77305-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Correinha', 'Correinha', '77836-200', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Couto de Magalhães', 'Couto De Magalhaes', '77750-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Craolândia', 'Craolandia', '77774-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cristalândia', 'Cristalandia', '77490-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Crixás', 'Crixas', '77449-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Crixás do Tocantins', 'Crixas Do Tocantins', '77463-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Darcinópolis', 'Darcinopolis', '77910-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dianópolis', 'Dianopolis', '77300-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Divinópolis do Tocantins', 'Divinopolis Do Tocantins', '77670-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Dois Irmãos do Tocantins', 'Dois Irmaos Do Tocantins', '77685-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Duerê', 'Duere', '77485-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Escondido', 'Escondido', '77836-600', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Esperantina', 'Esperantina', '77993-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fátima', 'Fatima', '77555-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Figueirópolis', 'Figueiropolis', '77465-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Filadélfia', 'Filadelfia', '77795-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Formoso do Araguaia', 'Formoso Do Araguaia', '77470-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Fortaleza do Tabocão', 'Fortaleza Do Tabocao', '77708-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goianorte', 'Goianorte', '77695-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Goiatins', 'Goiatins', '77770-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Guaraí', 'Guarai', '77700-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Gurupi', 'Gurupi', NULL, 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ilha Barreira Branca', 'Ilha Barreira Branca', '77837-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipueiras', 'Ipueiras', '77553-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itacajá', 'Itacaja', '77720-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaguatins', 'Itaguatins', '77920-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itapiratins', 'Itapiratins', '77718-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itaporã do Tocantins', 'Itapora Do Tocantins', '77740-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaú do Tocantins', 'Jau Do Tocantins', '77450-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Juarina', 'Juarina', '77753-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jussara', 'Jussara', '77837-100', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa da Confusão', 'Lagoa Da Confusao', '77493-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lagoa do Tocantins', 'Lagoa Do Tocantins', '77613-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lajeado', 'Lajeado', '77645-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lavandeira', 'Lavandeira', '77328-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Lizarda', 'Lizarda', '77630-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Luzinópolis', 'Luzinopolis', '77903-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Marianópolis do Tocantins', 'Marianopolis Do Tocantins', '77675-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mateiros', 'Mateiros', '77593-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Maurilândia do Tocantins', 'Maurilandia Do Tocantins', '77918-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miracema do Tocantins', 'Miracema Do Tocantins', '77650-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mirandópolis', 'Mirandopolis', '77702-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Miranorte', 'Miranorte', '77660-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte do Carmo', 'Monte Do Carmo', '77585-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Lindo', 'Monte Lindo', '77776-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Monte Santo do Tocantins', 'Monte Santo Do Tocantins', '77673-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Mosquito', 'Mosquito', '77913-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Muricilândia', 'Muricilandia', '77850-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Natal', 'Natal', '77953-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Natividade', 'Natividade', '77370-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nazaré', 'Nazare', '77895-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Olinda', 'Nova Olinda', '77790-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Rosalândia', 'Nova Rosalandia', '77495-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Acordo', 'Novo Acordo', '77610-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Alegre', 'Novo Alegre', '77353-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Horizonte', 'Novo Horizonte', '77839-200', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Novo Jardim', 'Novo Jardim', '77318-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Oliveira de Fátima', 'Oliveira De Fatima', '77558-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmas', 'Palmas', NULL, 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeirante', 'Palmeirante', '77798-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Palmeirópolis', 'Palmeiropolis', '77365-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paraíso do Tocantins', 'Paraiso Do Tocantins', '77600-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paranã', 'Parana', '77360-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pau D'' Arco', 'Pau D'' Arco', '77785-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pé da Serra', 'Pe Da Serra', '77839-400', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Afonso', 'Pedro Afonso', '77710-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pedro Ludovico', 'Pedro Ludovico', '77835-400', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Peixe', 'Peixe', '77460-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Peixe', 'Peixe', '77835-200', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pequizeiro', 'Pequizeiro', '77730-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pilões', 'Piloes', '77836-400', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pindorama do Tocantins', 'Pindorama Do Tocantins', '77380-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Piraquê', 'Piraque', '77888-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pium', 'Pium', '77570-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte Alta do Bom Jesus', 'Ponte Alta Do Bom Jesus', '77315-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ponte Alta do Tocantins', 'Ponte Alta Do Tocantins', '77590-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pontes', 'Pontes', '77838-200', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porãozinho', 'Poraozinho', '77837-200', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Alegre do Tocantins', 'Porto Alegre Do Tocantins', '77395-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Lemos', 'Porto Lemos', '77837-600', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Porto Nacional', 'Porto Nacional', '77500-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Praia Norte', 'Praia Norte', '77970-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Presidente Kennedy', 'Presidente Kennedy', '77745-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Príncipe', 'Principe', '77373-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pugmil', 'Pugmil', '77603-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Recursolândia', 'Recursolandia', '77733-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Riachinho', 'Riachinho', '77893-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio da Conceição', 'Rio Da Conceicao', '77303-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio dos Bois', 'Rio Dos Bois', '77655-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rio Sono', 'Rio Sono', '77635-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sampaio', 'Sampaio', '77980-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sandolândia', 'Sandolandia', '77478-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Fé do Araguaia', 'Santa Fe Do Araguaia', '77848-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria do Tocantins', 'Santa Maria Do Tocantins', '77716-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita do Tocantins', 'Santa Rita Do Tocantins', '77565-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rosa do Tocantins', 'Santa Rosa Do Tocantins', '77375-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Tereza do Tocantins', 'Santa Tereza Do Tocantins', '77615-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Terezinha do Tocantins', 'Santa Terezinha Do Tocantins', '77885-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Bento do Tocantins', 'Sao Bento Do Tocantins', '77958-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Félix do Tocantins', 'Sao Felix Do Tocantins', '77605-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Miguel do Tocantins', 'Sao Miguel Do Tocantins', '77925-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Salvador do Tocantins', 'Sao Salvador Do Tocantins', '77368-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Sebastião do Tocantins', 'Sao Sebastiao Do Tocantins', '77990-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Valério da Natividade', 'Sao Valerio Da Natividade', '77390-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Silvanópolis', 'Silvanopolis', '77580-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sítio Novo do Tocantins', 'Sitio Novo Do Tocantins', '77940-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sucupira', 'Sucupira', '77458-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taguatinga', 'Taguatinga', '77320-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taipas do Tocantins', 'Taipas Do Tocantins', '77308-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Talismã', 'Talisma', '77483-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tamboril', 'Tamboril', '77898-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquaralto', 'Taquaralto', '77270-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Taquarussu do Tocantins', 'Taquarussu Do Tocantins', '77260-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tocantínia', 'Tocantinia', '77640-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tocantinópolis', 'Tocantinopolis', '77900-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupirama', 'Tupirama', '77704-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupiratã', 'Tupirata', '77748-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tupiratins', 'Tupiratins', '77743-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Vênus', 'Venus', '77838-600', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Wanderlândia', 'Wanderlandia', '77860-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Xambioá', 'Xambioa', '77880-000', 'TO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jequiá da Praia', 'Jequia Da Praia', '57244-000', 'AL');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Ipiranga de Goiás', 'Ipiranga De Goias', '76304-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Conquista D''Oeste', 'Conquista D''Oeste', '78254-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Colniza', 'Colniza', '78335-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rondolândia', 'Rondolandia', '78338-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Rita do Trivelato', 'Santa Rita Do Trivelato', '78453-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Santa Helena', 'Nova Santa Helena', '78548-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santo Antônio do Leste', 'Santo Antonio Do Leste', '78628-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nova Nazaré', 'Nova Nazare', '78638-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz do Xingu', 'Santa Cruz Do Xingu', '78664-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bom Jesus do Araguaia', 'Bom Jesus Do Araguaia', '78678-000', 'MT');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Pau D''Arco do Piauí', 'Pau D''Arco Do Piaui', '64295-000', 'PI');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Westfalia', 'Westfalia', '95893-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Margarida do Sul', 'Santa Margarida Do Sul', '97335-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Tio Hugo', 'Tio Hugo', '99345-000', 'RS');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Canaúna', 'Canauna', '63342-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Norte', 'Sao Joao Do Norte', '29537-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Raimundo da Pedra Menina', 'Sao Raimundo Da Pedra Menina', '29588-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Cruz de Irupi', 'Santa Cruz De Irupi', '29399-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São João do Príncipe', 'Sao Joao Do Principe', '29391-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Nossa Senhora de Fátima', 'Nossa Senhora De Fatima', '29957-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Santa Maria de Marechal', 'Santa Maria De Marechal', '29259-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Alto Castelinho', 'Alto Castelinho', '29296-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Prosperidade', 'Prosperidade', '29299-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São José de Fruteiras', 'Sao Jose De Fruteiras', '29298-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Jorge da Barra Seca', 'Sao Jorge Da Barra Seca', '29790-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jurama', 'Jurama', '29793-000', 'ES');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Sucanga', 'Sucanga', '39828-000', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Triângulo', 'Triangulo', '62877-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cedro', 'Cedro', '62878-500', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Patos dos Liberatos', 'Patos Dos Liberatos', '62879-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Campestre', 'Campestre', '62879-500', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Timbaúba dos Marinheiros', 'Timbauba Dos Marinheiros', '62878-000', 'CE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Rialma', 'Rialma', '76310-000', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Jaboatão', 'Jaboatao', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Navarro', 'Navarro', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Cavaleiro', 'Cavaleiro', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Praia da Conceição', 'Praia Da Conceicao', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Paratibe', 'Paratibe', NULL, 'PE');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Chonin de Baixo', 'Chonin De Baixo', '35109-500', 'MG');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('JK', 'Jk', '73818-999', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Bezerra', 'Bezerra', '73817-999', 'GO');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('São Pedro da Serra', 'Sao Pedro Da Serra', NULL, 'RJ');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Arraial D''Ajuda', 'Arraial D''Ajuda', '45816-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Trancoso', 'Trancoso', '45818-000', 'BA');
INSERT INTO staging.i18n_generic_BR (accented, unaccented, zip, state) VALUES ('Itabatã', 'Itabata', '45936-000', 'BA');


--
-- PostgreSQL database dump complete
--

--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = staging, pg_catalog;

--
-- Data for Name: state; Type: TABLE DATA; Schema: staging; Owner: gm-dbo
--

INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('AC', 'Acre', 69900, 69999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('AL', 'Alagoas', 57000, 57999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('AM', 'Amazonas', 69000, 69299);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('AP', 'Amapá', 68900, 68999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('BA', 'Bahia', 40000, 48999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('CE', 'Ceará', 60000, 63999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('DF', 'Distrito Federal', 70000, 72799);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('ES', 'Espírito Santo', 29000, 29999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('GO', 'Goiás', 72800, 72999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('MA', 'Maranhão', 65000, 65999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('MG', 'Minas Gerais', 30000, 39999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('MS', 'Mato Grosso do Sul', 79000, 79999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('MT', 'Mato Grosso', 78000, 78899);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('PA', 'Pará', 66000, 68899);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('PB', 'Paraíba', 58000, 58999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('PE', 'Pernambuco', 50000, 56999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('PI', 'Piauí', 64000, 64999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('PR', 'Paraná', 80000, 87999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('RJ', 'Rio de Janeiro', 20000, 28999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('RN', 'Rio Grande do Norte', 59000, 59999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('RO', 'Rondônia', 78900, 78999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('RR', 'Roraima', 69300, 69399);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('RS', 'Rio Grande do Sul', 90000, 99999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('SC', 'Santa Catarina', 88000, 89999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('SE', 'Sergipe', 49000, 49999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('SP', 'São Paulo', 1000, 19999);
INSERT INTO staging.state (code, name, zip1, zip2) VALUES ('TO', 'Tocantins', 77000, 77999);


--
-- PostgreSQL database dump complete
--

--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = staging, pg_catalog;

--
-- Data for Name: pr; Type: TABLE DATA; Schema: staging; Owner: gm-dbo
--

INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (99, 'Paranavaí', 'A', 'Vila Alta', '87708-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (291, 'Telêmaco Borba', 'AD', 'Bela Vista do Paraíso', '84262-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1033, 'Curitiba', 'Alcindo Fanaya', 'Atuba', '82860-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1367, 'Ponta Grossa', 'Almeida Nogueira', 'Uvaranas', '84030-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2176, 'Curitiba', 'Ângelo Ferro', 'Prado Velho', '80215-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2470, 'Cascavel', 'Antonina', 'Centro', '85812-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2955, 'Curitiba', 'Antônio Moreira Lopes', 'Cajuru', '82980-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3310, 'Londrina', 'Araçatuba', 'Amaro', '86062-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3854, 'Curitiba', 'Artur Hauer', 'Hauer', '81610-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4971, 'Curitiba', 'Benjamin Lins', 'Batel', '80420-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5031, 'Curitiba', 'Benvenuto Gusso', 'Boa Vista', '82540-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5788, 'Curitiba', 'Cacau', 'Uberaba', '81560-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7924, 'Umuarama', 'Cora', 'Zona IV', '87504-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9958, 'Curitiba', 'Dino Bertoldi', 'Tarumã', '82800-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10778, 'Pato Branco', 'dos Canários', 'Planalto', '85509-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11391, 'Toledo', 'Doutor Flores', 'Centro', '85900-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11476, 'Toledo', 'Doutor Jorge Nunes', 'Coopagro', '85903-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11631, 'Curitiba', 'Doutor Pedrosa', 'Centro', '80420-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12344, 'Londrina', 'Emaus', 'Alto da Boa Vista', '86083-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12792, 'Cascavel', 'Erval', 'Canadá', '85813-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13047, 'Londrina', 'Euclides Saladini', 'Assis', '86085-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13400, 'Colombo', 'Felício Kania', 'Jardim Curitiba', '83406-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13799, 'Umuarama', 'Florianópolis', 'Zona V', '87504-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14820, 'Cambé', 'Gemininos', 'Jardim Tupi', '86183-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15018, 'Guarapuava', 'Gerânios', 'Batel', '85015-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15914, 'Cascavel', 'Haiti', 'Brasília', '85815-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17475, 'Londrina', 'Jacarandá', 'Leonor', '86071-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17591, 'Arapongas', 'Jacutinga', 'Centro', '86701-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22027, 'Ponta Grossa', 'M', 'Colônia Dona Luiza', '84043-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23276, 'Curitiba', 'Maria Minelli', 'Taboão', '82130-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23665, 'Londrina', 'Marte', 'Sol', '86070-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23961, 'Londrina', 'Meimei', 'Brasília', '86039-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25441, 'Colombo', 'Odinir Ceccon', 'Capivari', '83415-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26520, 'Cascavel', 'Papagaios', 'Floresta', '85814-760', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26620, 'Guarapuava', 'Paraná', 'Conradinho', '85055-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27250, 'Castro', 'Pedro Canha Salgado', 'Cantagalo', '84178-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27612, 'Castro', 'Percy Pannach Lopes', 'Morada do Sol', '84172-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28286, 'Londrina', 'Pirapó', 'Vila Zanetti', '86025-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28381, 'Londrina', 'Platão', 'Califórnia', '86040-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28470, 'Cascavel', 'Ponta Grossa', 'São Cristóvão', '85816-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28655, 'Ponta Grossa', 'Praia de Laranjeiras', 'Contorno', '84060-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29157, 'Curitiba', 'Professor João Duck Filho', 'Xaxim', '81830-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29319, 'Curitiba', 'Professora Dona Lulu', 'Novo Mundo', '81050-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30115, 'Guarapuava', 'Reseda', 'Batel', '85015-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30939, 'Ponta Grossa', 'Rogério Kloster', 'Uvaranas', '84030-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31026, 'Pato Branco', 'Romilda Aires', 'Menino Deus', '85502-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31783, 'Londrina', 'Santa Lídia', 'Franca', '86027-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31969, 'Curitiba', 'Santo Bozzi', 'Xaxim', '81830-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32116, 'Toledo', 'São Damião', 'Jardim Paraná', '85904-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32568, 'Apucarana', 'Sarandi', 'Barra Funda', '86800-240', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33003, 'Paranavaí', 'Sergipe', 'Centro', '87702-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34059, 'Ponta Grossa', 'Tenente Sady', 'Uvaranas', '84025-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35081, 'Londrina', 'Urai', 'Baldan', '86060-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35763, 'Londrina', 'Vila-Lobos', 'Tucano', '86047-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1, 'Sarandi', '1', 'Jardim Independência III', '87114-265', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2, 'Maringá', '19116', 'Parque Hortência', '87075-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3, 'Maringá', '19117', 'Parque Hortência', '87075-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4, 'Maringá', '19125', 'Conjunto Habitacional João de Barro Thaís', '87075-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5, 'Maringá', '19126', 'Conjunto Habitacional João de Barro Thaís', '87075-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6, 'Maringá', '19127', 'Conjunto Habitacional João de Barro Thaís', '87075-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7, 'Maringá', '19131', 'Jardim Continental', '87070-557', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8, 'Maringá', '19133', 'Gleba Patrimônio Maringá', '87070-559', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9, 'Sarandi', '2', 'Jardim Independência III', '87114-266', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10, 'Maringá', '200', 'Parque Industrial 200', '87035-520', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11, 'Maringá', '20028', 'Jardim Bela Vista', '87060-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12, 'Maringá', '20030', 'Zona 20', '87060-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13, 'Maringá', '20038', 'Jardim Cidade Monções', '87060-557', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14, 'Maringá', '20040', 'Jardim Cidade Monções', '87060-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15, 'Maringá', '20041', 'Jardim Cidade Monções', '87060-396', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16, 'Maringá', '20044', 'Jardim Cidade Monções', '87060-558', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17, 'Maringá', '20045', 'Jardim Cidade Monções', '87060-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18, 'Maringá', '22001', 'Parque Hortência', '87075-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19, 'Maringá', '22002', 'Parque Industrial Mário Bulhões', '87065-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20, 'Maringá', '25204', 'Jardim Ipanema', '87053-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21, 'Maringá', '25223 II', 'Jardim Paraíso', '87053-027', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22, 'Maringá', '25227', 'Parque Tarumã', '87053-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23, 'Maringá', '25231', 'Parque Tarumã', '87053-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24, 'Maringá', '25232', 'Parque Tarumã', '87053-658', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25, 'Maringá', '25241', 'Parque Tarumã', '87053-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26, 'Maringá', '26201', 'Jardim Paraíso', '87053-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27, 'Maringá', '26225', 'Jardim Paraíso', '87053-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28, 'Maringá', '26226', 'Jardim Paraíso', '87053-016', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29, 'Maringá', '27000', 'Jardim Tabaete', '87005-125', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30, 'Maringá', '28119', 'Z-28', '87053-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31, 'Sarandi', '3', 'Jardim Independência III', '87114-267', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32, 'Maringá', '30003', 'Jardim Copacabana', '87023-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33, 'Maringá', '30006', 'Jardim Copacabana', '87023-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34, 'Maringá', '30007', 'Jardim Copacabana', '87023-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35, 'Maringá', '30008', 'Jardim Copacabana', '87023-416', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36, 'Maringá', '31031', 'Portal das Torres', '87025-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (37, 'Maringá', '31032', 'Portal das Torres', '87025-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (38, 'Maringá', '31034', 'Portal das Torres', '87025-658', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (39, 'Maringá', '31035', 'Portal das Torres', '87025-659', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (40, 'Maringá', '31036', 'Jardim Licce', '87025-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (41, 'Maringá', '31039', 'Jardim Licce', '87025-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (42, 'Maringá', '32000', 'Jardim Guararapes', '87045-136', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (43, 'Maringá', '36220', 'Conjunto Residencial Parigot de Souza', '87045-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (44, 'Maringá', '37024', 'Conjunto João de Barro Itaparica', '87043-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (45, 'Maringá', '37209 II', 'Jardim Novo Oásis', '87043-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (46, 'Maringá', '37210 II', 'Jardim Novo Oásis', '87043-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (47, 'Maringá', '37211', 'Loteamento Grajaú', '87043-497', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (48, 'Maringá', '37212', 'Loteamento Grajaú', '87043-498', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (49, 'Maringá', '37213', 'Loteamento Grajaú', '87043-499', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (50, 'Maringá', '37214', 'Loteamento Grajaú', '87043-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (51, 'Maringá', '37221', 'Zona 37', '87043-156', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (52, 'Maringá', '38030', 'Jardim Europa', '87055-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (53, 'Maringá', '38031', 'Conjunto Habitacional Céu Azul', '87055-606', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (54, 'Maringá', '38032', 'Conjunto Habitacional Céu Azul', '87055-607', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (55, 'Maringá', '38033', 'Conjunto Habitacional Céu Azul', '87055-608', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (56, 'Maringá', '39042', 'Conjunto Prolar', '87055-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (57, 'Maringá', '39060', 'Zona 39', '87053-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (58, 'Maringá', '39071', 'Gleba Ribeirão Pinguim', '87053-376', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (59, 'Maringá', '39072', 'Gleba Ribeirão Pinguim', '87053-377', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (60, 'Maringá', '39073', 'Gleba Ribeirão Pinguim', '87053-378', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (61, 'Maringá', '39074', 'Gleba Ribeirão Pinguim', '87053-379', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (62, 'Maringá', '40010', 'Jardim Betel', '87060-107', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (63, 'Maringá', '42103', 'Parque Industrial Bandeirantes', '87070-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (64, 'Maringá', '42200', 'Jardim Nilza', '87065-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (65, 'Maringá', '42201', 'Jardim Nilza', '87065-146', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (66, 'Maringá', '42202', 'Jardim Nilza', '87065-147', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (67, 'Maringá', '43215', 'Jardim Aurora', '87070-234', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (68, 'Maringá', '45012', 'Parque Industrial', '87065-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (69, 'Maringá', '45013', 'Parque Industrial', '87065-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (70, 'Maringá', '46018', 'Jardim Paris', '87083-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (71, 'Maringá', '46022', 'Jardim Paris', '87083-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (72, 'Maringá', '47027', 'Jardim Hanover', '87065-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (73, 'Maringá', '47028', 'Jardim Hanover', '87065-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (74, 'Maringá', '47029', 'Jardim Hanover', '87065-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (75, 'Maringá', '47031', 'Parque Industrial Mário Bulhões', '87065-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (76, 'Maringá', '47032', 'Parque Industrial Mário Bulhões', '87065-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (77, 'Maringá', '48009', 'Jardim Rebouças', '87083-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (78, 'Maringá', '48012', 'Jardim Rebouças', '87083-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (79, 'Maringá', '48016', 'Jardim Paris III', '87083-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (80, 'Maringá', '48017', 'Jardim Paris III', '87083-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (81, 'Maringá', '48019', 'Jardim Paris III', '87083-707', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (82, 'Maringá', '48020', 'Jardim Paris III', '87083-708', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (83, 'Maringá', '48021', 'Jardim Paris III', '87083-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (84, 'Maringá', '48022', 'Jardim Paris III', '87083-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (85, 'Maringá', '48023', 'Jardim Paris III', '87083-709', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (86, 'Maringá', '48024', 'Jardim Império do Sol', '87083-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (87, 'Maringá', '48027', 'Jardim Império do Sol', '87083-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (88, 'Maringá', '48028', 'Jardim Império do Sol', '87083-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (89, 'Maringá', '48029', 'Jardim Império do Sol', '87083-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (90, 'Maringá', '48030', 'Jardim Império do Sol', '87083-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (91, 'Foz do Iguaçu', 'A', 'Conjunto C', '85870-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (92, 'Foz do Iguaçu', 'A', 'Conjunto Residencial Yang Ming', '85854-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (93, 'Francisco Beltrão', 'A', 'Nossa Senhora Aparecida', '85601-815', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (94, 'Ponta Grossa', 'A', 'Contorno', '84060-609', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (95, 'Ponta Grossa', 'A', 'Jardim Carvalho', '84016-709', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (96, 'Ponta Grossa', 'A', 'Oficinas', '84043-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (97, 'Paranavaí', 'A', 'Jardim São Cristóvão', '87702-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (98, 'Paranavaí', 'A', 'Vila Operária', '87708-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (100, 'Ponta Grossa', 'A', 'Colônia Dona Luiza', '84045-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (101, 'Piraquara', 'A', 'Chácara Águas Claras', '83309-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (102, 'Ponta Grossa', 'A', 'Uvaranas', '84032-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (103, 'Ponta Grossa', 'A', 'Uvaranas', '84025-235', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (104, 'Maringá', 'A', 'Loteamento Batel', '87060-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (105, 'Ponta Grossa', 'A', 'Uvaranas', '84026-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (106, 'Ponta Grossa', 'A', 'Chapada', '84062-625', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (107, 'Ponta Grossa', 'A', 'Oficinas', '84036-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (108, 'Ponta Grossa', 'A', 'Uvaranas', '84031-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (109, 'Ponta Grossa', 'A', 'Boa Vista', '84072-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (110, 'Ponta Grossa', 'A', 'Colônia Dona Luiza', '84043-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (111, 'Umuarama', 'A', 'Jardim Carolina', '87501-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (112, 'Umuarama', 'A', 'Parque Industrial II', '87507-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (113, 'Umuarama', 'A', 'Parque Industrial I', '87507-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (114, 'Umuarama', 'A', 'Jardim Shangri-la', '87509-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (115, 'Umuarama', 'A', 'Jardim Colibri', '87506-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (116, 'Umuarama', 'A', 'Núcleo Cruzeiro', '87509-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (117, 'Telêmaco Borba', 'A', 'Bela Vista do Paraíso', '84262-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (118, 'Sarandi', 'A', 'Jardim Castelo', '87112-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (119, 'Campo Largo', 'A', 'Vila Antônio Seguro', '83602-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (120, 'Almirante Tamandaré', 'A', 'Jardim São Caetano', '83507-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (121, 'Almirante Tamandaré', 'A', 'Parque Timbu', '83514-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (122, 'Campo Largo', 'A', 'Jardim Emília', '83607-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (123, 'Campo Largo', 'A', 'Vila Mariano Torres', '83608-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (124, 'Campo Largo', 'A', 'Vila Alzira', '83608-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (125, 'Campo Largo', 'A', 'Jardim Guairacá', '83608-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (126, 'Castro', 'A', 'Vila do Rosário', '84168-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (127, 'Campo Largo', 'A', 'Jardim Três Rios', '83603-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (128, 'Campo Mourão', 'A', 'Distrito Industrial I', '87306-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (129, 'Campo Largo', 'A', 'Jardim Tropical', '83602-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (130, 'Campo Largo', 'A', 'Vila Dom Pedro', '83608-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (131, 'Campo Largo', 'A', 'Vila Santo Onofre', '83608-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (132, 'Almirante Tamandaré', 'A', 'Jardim Marrocos', '83511-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (133, 'Umuarama', 'A I', 'Zona I-A', '87503-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (134, 'Arapongas', 'A-1', 'Jardim Caravelle', '86702-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (135, 'Arapongas', 'A-2', 'Jardim Caravelle', '86701-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (136, 'Arapongas', 'A-3', 'Jardim Caravelle', '86701-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (137, 'Arapongas', 'A-4', 'Jardim Caravelle', '86701-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (138, 'Arapongas', 'A-5', 'Jardim Primavera', '86702-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (139, 'Curitiba', 'Aarão Lamenha de Siqueira', 'Sítio Cercado', '81920-758', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (140, 'Telêmaco Borba', 'AB', 'Bela Vista do Paraíso', '84262-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (141, 'Ponta Grossa', 'Abacateiro', 'Chapada', '84064-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (142, 'Curitiba', 'Abacates', 'Uberaba', '81550-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (143, 'Foz do Iguaçu', 'Abaeté', 'Jardim Nacional', '85862-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (144, 'Londrina', 'Abaeté', 'Antares', '86036-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (145, 'Francisco Beltrão', 'Abaeté', 'São Miguel', '85602-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (146, 'Umuarama', 'Abaeté', 'Jardim Belvedere', '87505-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (147, 'Cascavel', 'Abaeté', 'São Cristóvão', '85816-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (148, 'Foz do Iguaçu', 'Abatia', 'Jardim Belvedere II', '85867-605', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (149, 'Ponta Grossa', 'Abatia', 'Nova Rússia', '84070-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (150, 'Telêmaco Borba', 'Abatia', 'Jardim União', '84266-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (151, 'Curitiba', 'Abatia', 'Pinheirinho', '81880-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (152, 'Almirante Tamandaré', 'Abatiá', 'Loteamento Chico Mendes', '83505-767', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (153, 'Londrina', 'Abdala Jabur', 'Andrade', '86061-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (154, 'Curitiba', 'Abdo Zeghbi', 'Fazendinha', '81330-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (155, 'Paranaguá', 'Abdon Petit Carneiro', 'Padre Jackson', '83221-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (156, 'Guarapuava', 'Abegail R. Rocha', 'Boqueirão', '85020-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (157, 'Guarapuava', 'Abel Alves Loures', 'Bonsucesso', '85045-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (158, 'Pato Branco', 'Abel Bortot', 'Vila Isabel', '85504-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (159, 'Curitiba', 'Abel da Silva Almeida', 'Vila Izabel', '80320-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (160, 'Londrina', 'Abel Favoretto', 'Jardim Alphaville', '86084-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (161, 'Foz do Iguaçu', 'Abel Furlan', 'Loteameto Budel', '85867-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (162, 'Cambé', 'Abel Pereira Nogueira', 'Jardim Vitória', '86184-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (163, 'Ponta Grossa', 'Abel Ricci', 'Contorno', '84052-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (164, 'Colombo', 'Abel Scuissiato', 'Vila Yara', '83408-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (165, 'Curitiba', 'Abel Scuissiato', 'Guaíra', '80630-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (166, 'Londrina', 'Abel Soares Siqueira', 'Santa Rita 1', '86072-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (167, 'Toledo', 'Abelardo Barbosa', 'Pacaembu', '85910-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (168, 'Curitiba', 'Abelardo Barbosa Chacrinha', 'Tatuquara', '81470-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (169, 'Ponta Grossa', 'Abelardo de Brito', 'Ronda', '84050-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (170, 'Foz do Iguaçu', 'Abelardo Luz', 'Loteamento Witt', '85862-517', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (171, 'Curitiba', 'Abelardo Martins', 'Sítio Cercado', '81900-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (172, 'Arapongas', 'Abelheiro', 'Vila Cascata', '86701-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (173, 'Londrina', 'Abelio Benatti', 'Sol', '86070-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (174, 'Curitiba', 'Abelmidio José de Oliveira', 'Novo Mundo', '81050-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (175, 'Guarapuava', 'Abelzinho de Freitas', 'Vila Bela', '85025-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (176, 'Arapongas', 'Abetarda', 'Vila Passos', '86705-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (177, 'Guarapuava', 'Abgail Danguy Borges', 'Conradinho', '85055-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (178, 'Guarapuava', 'Abgail Ribas Rocha', 'Boqueirão', '85020-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (179, 'Curitiba', 'Abib Calixto', 'Mercês', '80510-380', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (180, 'Ponta Grossa', 'Abib Jorge Abib', 'Ronda', '84051-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (181, 'Curitiba', 'Abibe Isfer', 'Vila Izabel', '80240-570', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (182, 'Curitiba', 'Abílio César Borges', 'Bigorrilho', '80730-060', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (183, 'Colombo', 'Abílio Cordeiro', 'Jardim Eldorado', '83402-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (184, 'Ponta Grossa', 'Abílio da Costa Soares', 'Boa Vista', '84072-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (185, 'Curitiba', 'Abílio de Abreu', 'Guabirotuba', '81510-060', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (186, 'Ponta Grossa', 'Abílio de Barros', 'Centro', '84010-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (187, 'Curitiba', 'Abílio de Oliveira Mendes', 'Capão Raso', '81110-090', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (188, 'Ponta Grossa', 'Abílio dos Santos', 'Contorno', '84061-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (189, 'Guarapuava', 'Abílio Fabriciano de Oliveira', 'São Cristóvão', '85060-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (190, 'Araucária', 'Abílio Fruet', 'Centro', '83702-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (191, 'Curitiba', 'Abílio Geronasso', 'Boa Vista', '82510-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (192, 'Ponta Grossa', 'Abílio Holzmann', 'Neves', '84020-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (193, 'Curitiba', 'Abílio Holzmann', 'Novo Mundo', '81050-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (194, 'Guarapuava', 'Abílio Jorge', 'Morro Alto', '85065-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (195, 'Londrina', 'Abílio Justiniano de Queiroz', 'João Paz', '86087-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (196, 'Cambé', 'Abílio Marques Branco', 'Conjunto Residencial Roberto Conceição', '86183-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (197, 'Campo Largo', 'Abílio Monteiro', 'Bom Jesus', '83604-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (198, 'Curitiba', 'Abílio Peixoto', 'Cabral', '80035-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (199, 'Curitiba', 'Abílio Sebastião da Silva', 'Abranches', '82130-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (200, 'Ponta Grossa', 'Abílio Simionato', 'Boa Vista', '84073-177', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (201, 'Londrina', 'Abissalão Bispo dos Santos', 'Jardim Nova Esperança', '86044-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (202, 'Cambé', 'Ablan Abujanra', 'Jardim Santa Mônica', '86184-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (203, 'Curitiba', 'Abóbora', 'Uberaba', '81590-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (204, 'Curitiba', 'Abóbora', 'Uberaba', '81550-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (205, 'Curitiba', 'Aboud Khalil', 'Santa Felicidade', '82410-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (206, 'Guarapuava', 'Abraham Haick', 'Santana', '85070-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (207, 'Curitiba', 'Abraham Leiser Stier', 'Cidade Industrial', '81260-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (208, 'Curitiba', 'Abraham Lincoln', 'Seminário', '80310-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (209, 'Londrina', 'Abrahão Elias', 'Residencial Abussafe', '86037-778', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (210, 'Curitiba', 'Abrahão Kalil Fadel', 'Seminário', '80740-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (211, 'Apucarana', 'Abrahão Nagib Neme', 'Loteamento Sanches dos Santos', '86806-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (212, 'Curitiba', 'Abram Fruse', 'Sítio Cercado', '81920-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (213, 'Toledo', 'Abramo Rottava', 'Parque Residencial Pancera', '85914-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (214, 'Colombo', 'Abran Milan', 'Jardim Monza', '83406-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (215, 'Curitiba', 'Abrão Abib Andraus', 'Cascatinha', '82020-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (216, 'Curitiba', 'Abrão Calixto', 'Tingui', '82600-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (217, 'Colombo', 'Abrão Ferreira da Rocha', 'Jardim Del Rey', '83402-386', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (218, 'Curitiba', 'Abrão Jak Duck', 'Xaxim', '81830-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (219, 'Curitiba', 'Abrão Lerner', 'Campina do Siqueira', '80730-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (220, 'Apucarana', 'Abrão Longo', 'Loteamento Sanches dos Santos', '86806-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (221, 'Guarapuava', 'Abrão Manoel da Silva', 'Bonsucesso', '85045-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (222, 'Curitiba', 'Abrão Mansur', 'Pinheirinho', '81820-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (223, 'Ponta Grossa', 'Abrão Miguel Ajuz', 'Uvaranas', '84030-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (224, 'Curitiba', 'Abrão Winter', 'Xaxim', '81830-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (225, 'Ponta Grossa', 'Abreu de Lima', 'Uvaranas', '84025-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (226, 'Londrina', 'Abricó', 'Jardim Morumbi', '86035-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (227, 'Telêmaco Borba', 'AC', 'Bela Vista do Paraíso', '84262-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (228, 'Telêmaco Borba', 'Acácia', 'Jardim Alegre', '84268-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (229, 'Apucarana', 'Acácia', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (230, 'Cascavel', 'Acácia', 'Parque Verde', '85807-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (231, 'Ponta Grossa', 'Acácia Negra', 'Contorno', '84061-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (232, 'Curitiba', 'Acácio Corrêa', 'Parolin', '80220-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (233, 'Curitiba', 'Acácio Fernandes', 'Tingui', '82600-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (234, 'Cascavel', 'Academia', 'Universitário', '85819-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (235, 'Paranaguá', 'Açaí', 'Vila São Vicente', '83209-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (236, 'Cambé', 'Acaiá', 'Jardim do Café', '86186-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (237, 'Arapongas', 'Acantiso', 'Vila Sampaio', '86705-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (238, 'Londrina', 'Acapulco', 'Santa Rita 1', '86071-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (239, 'Toledo', 'Acapulco', 'Jardim Piccinin', '85904-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (240, 'Arapongas', 'Acaratinga', 'Jardim Bononi', '86703-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (241, 'Foz do Iguaçu', 'Acaray', 'Jardim Itaipu', '85867-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (242, 'Foz do Iguaçu', 'Acari', 'Conjunto A', '85860-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (243, 'Foz do Iguaçu', 'Acaua', 'Conjunto A', '85866-060', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (244, 'Maringá', 'Acaua', 'Jardim Pássaros', '87075-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (245, 'Arapongas', 'Acaua', 'Jardim Cultura', '86707-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (246, 'Castro', 'Acelino Correia Bueno', 'Jardim São Francisco', '84174-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (247, 'Cascavel', 'Acelino de Almeida', 'Cataratas', '85818-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (248, 'Curitiba', 'Acelino Grande', 'Santa Felicidade', '82320-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (249, 'Guarapuava', 'Acelino Palmeiro', 'Jardim das Américas', '85030-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (250, 'São José dos Pinhais', 'Acelyno Alves', 'Ipê', '83055-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (251, 'Foz do Iguaçu', 'Acendino Batista dos Santos', 'Conjunto Residencial Sol de Maio', '85862-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (252, 'Telêmaco Borba', 'Acesita', 'Área 06', '84271-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (253, 'Curitiba', 'Achilles Stenghel', 'Bacacheri', '82515-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (254, 'Londrina', 'Achiro Kawasaki', 'Jardim Tókio', '86063-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (255, 'Curitiba', 'Acil Lourenço da Cruz', 'Uberaba', '81550-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (256, 'Curitiba', 'Acir Macedo Guimarães', 'Abranches', '82220-175', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (257, 'Curitiba', 'Acir Pereira', 'Cidade Industrial', '81170-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (258, 'Sarandi', 'Aclimação', 'Jardim Nova Paulista', '87111-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (259, 'Apucarana', 'Aço', 'Parque Industrial Zona Norte', '86806-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (260, 'Maringá', 'Acopiara', 'Jardim Alvorada', '87035-275', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (261, 'Francisco Beltrão', 'Acre', 'Pinheirinho', '85603-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (262, 'Londrina', 'Acre', 'Centro', '86026-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (263, 'Guarapuava', 'Acre', 'Boqueirão', '85023-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (264, 'Foz do Iguaçu', 'Acre', 'Centro', '85852-240', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (265, 'Paranaguá', 'Acre', 'Vila do Povo', '83209-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (266, 'Piraquara', 'Acre', 'Jardim dos Estados 2', '83308-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (267, 'São José dos Pinhais', 'Acre', 'Boneca do Iguaçu', '83040-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (268, 'Telêmaco Borba', 'Acre', 'Vila Ozorio', '84268-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (269, 'Colombo', 'Acre', 'Vila Guaraci', '83404-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (270, 'Cascavel', 'Acre', 'Country', '85813-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (271, 'Araucária', 'Acre', 'Iguaçu', '83701-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (272, 'Campo Largo', 'Acre', 'Vila Itaqui', '83604-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (273, 'Curitiba', 'Acre', 'Água Verde', '80620-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (274, 'Curitiba', 'Acre', 'Água Verde', '80610-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (275, 'Curitiba', 'Acre', 'Guaíra', '80630-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (276, 'Paranaguá', 'Acrísio Guimarães', 'Centro Histórico', '83203-305', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (277, 'Foz do Iguaçu', 'Açu', 'Cohapar II', '85857-720', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (278, 'Maringá', 'Açucena', 'Jardim Alzira', '87060-156', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (279, 'Pinhais', 'Açucena', 'Jardim Pio XII', '83328-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (280, 'Londrina', 'Açungui', 'Vila Adolfo', '86025-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (281, 'Londrina', 'Açungui', 'Vila Adolfo', '86025-795', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (282, 'Telêmaco Borba', 'Açungui', 'Área 02', '84267-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (283, 'Arapongas', 'Acurana', 'Jardim Santo Antônio', '86705-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (284, 'Londrina', 'Acylino Augusto do Nascimento', 'Portal de Versalhes 2', '86063-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (285, 'Ponta Grossa', 'Acylino Pinto de Carvalho', 'Boa Vista', '84073-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (286, 'Curitiba', 'Acyr Boza', 'Boqueirão', '81670-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (287, 'Piraquara', 'Acyr Gonçalves Martins', 'Vila Ipanema', '83301-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (288, 'Curitiba', 'Acyr Guimarães', 'Água Verde', '80240-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (289, 'Curitiba', 'Acyr Santos', 'Vila Izabel', '80320-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (290, 'Curitiba', 'Acyrdo Rasmussen', 'Santa Cândida', '82720-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (292, 'São José dos Pinhais', 'Ada M. Della Giustina', 'Ipê', '83055-517', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (293, 'Paranaguá', 'Ada Macaggi', 'Campo Grande', '83203-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (294, 'Curitiba', 'Ada Macaggi', 'Bairro Alto', '82820-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (295, 'Apucarana', 'Adail Costa', 'Jardim Marissol', '86807-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (296, 'Curitiba', 'Adair Gelenski', 'Sítio Cercado', '81900-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (297, 'Curitiba', 'Adair Marcondes Negrão', 'Sítio Cercado', '81935-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (298, 'Campo Largo', 'Adalberto Antônio Cescato', 'Vila Ferrari', '83606-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (299, 'Araucária', 'Adalberto Cantele', 'Boqueirão', '83704-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (300, 'Ponta Grossa', 'Adalberto Carvalho de Araújo', 'Uvaranas', '84025-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (301, 'Curitiba', 'Adalberto Carvalho de Araújo', 'Portão', '81070-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (302, 'Londrina', 'Adalberto Carvalho Neves', 'Barbeta', '86078-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (303, 'Pinhais', 'Adalberto de Andrade', 'Vila Maria Antonieta', '83331-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (304, 'Curitiba', 'Adalberto Ferruci Pereira', 'Boqueirão', '81670-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (305, 'Curitiba', 'Adalberto Gil da Silva', 'Santa Quitéria', '80310-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (306, 'Curitiba', 'Adalberto Leal da Silva', 'Alto Boqueirão', '81850-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (307, 'Curitiba', 'Adalberto Navarrete de Andrade', 'Fazendinha', '81320-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (308, 'Curitiba', 'Adalberto Scherer', 'Novo Mundo', '81030-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (309, 'Curitiba', 'Adalberto Tadeu Vorobi', 'Cajuru', '82920-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (310, 'Londrina', 'Adalcimar Regina Guandalini', 'Jardim das Américas', '86076-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (311, 'Londrina', 'Adalcimar Regina Guandalini', 'Jamile Dequech', '86048-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (312, 'Londrina', 'Adalmira Ferreira Martins', 'Cafezal 1', '86049-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (313, 'Cascavel', 'Adalto Ferreira', 'Cascavel Velho', '85818-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (314, 'São José dos Pinhais', 'Adam Smith', 'Aristocrata', '83030-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (315, 'Foz do Iguaçu', 'Adamantina', 'Jardim Ipê III', '85869-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (316, 'Toledo', 'Adão Alves', 'Panorama', '85911-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (317, 'Campo Largo', 'Adão Camilo', 'Vila Campesi', '83604-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (318, 'Curitiba', 'Adão Casemiro Troczinski', 'Barreirinha', '82650-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (319, 'Curitiba', 'Adão de Araújo', 'Cidade Industrial', '81310-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (320, 'Londrina', 'Adão Elias de Moraes', 'Jardim Nova Esperança', '86044-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (321, 'Maringá', 'Adão Elói Trojan', 'Jardim Ipanema', '87053-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (322, 'Apucarana', 'Adão Fabene', 'Vila Regina', '86801-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (323, 'Apucarana', 'Adão Iwankiw', 'Parque Industrial Zona Oeste II', '86800-767', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (324, 'Guarapuava', 'Adão Joel Dala Rosa', 'Boqueirão', '85023-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (325, 'São José dos Pinhais', 'Adão Kaboski', 'Afonso Pena', '83050-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (326, 'Apucarana', 'Adão Kanievski', 'Jardim Paulista', '86811-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (327, 'Curitiba', 'Adão Lauro Vargas', 'Uberaba', '81560-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (328, 'Curitiba', 'Adão Nivaldo de Oliveira', 'Xaxim', '81710-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (329, 'Curitiba', 'Adão Ordakowski', 'Pinheirinho', '81870-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (330, 'Curitiba', 'Adão Paulo Majewski', 'Santo Inácio', '82010-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (331, 'Curitiba', 'Adão Picussa Netto', 'Boqueirão', '81730-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (332, 'Curitiba', 'Adão Pietnoska', 'Guabirotuba', '81510-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (333, 'Guarapuava', 'Adão Pinto Guimarães', 'Vila Bela', '85025-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (334, 'Curitiba', 'Adão Ribeiro dos Santos', 'Cidade Industrial', '81460-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (335, 'Foz do Iguaçu', 'Adão Rolon', 'Jardim Bandeirantes', '85862-447', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (336, 'Curitiba', 'Adão Sobocinski', 'Cristo Rei', '80050-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (337, 'Londrina', 'Adão Valadão de Freitas', 'São Pedro', '86036-300', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (338, 'Araucária', 'Adão Wojcik', 'Tindiquera', '83708-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (339, 'Curitiba', 'Adari Fernando Visinoni', 'Cidade Industrial', '81280-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (340, 'Londrina', 'Adauto Lourenço', 'Portal de Versalhes 3', '86055-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (341, 'São José dos Pinhais', 'Adauto Marineski', 'Miringuava', '83090-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (342, 'Curitiba', 'Adel Karam', 'Tarumã', '82800-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (343, 'Curitiba', 'Adel Raad', 'Capão Raso', '81020-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (344, 'Piraquara', 'Adela Withoef de Souza', 'Guarituba', '83310-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (345, 'Sarandi', 'Adelaide Baldo Zanin', 'Vera Cruz', '87111-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (346, 'Londrina', 'Adelaide Cândida Moraes', 'Residencial Abussafe', '86037-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (347, 'Almirante Tamandaré', 'Adelaide Francisca de Jesus', 'Jardim Mônica', '83505-716', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (348, 'São José dos Pinhais', 'Adelaide Maria Pissaia', 'Braga', '83020-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (349, 'Curitiba', 'Adelaide Mattana Villa', 'Uberaba', '81580-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (350, 'Piraquara', 'Adelaide Schuli de Aguiar', 'Vila Rosa', '83304-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (351, 'Curitiba', 'Adelaide STrêsser Scheleder', 'Jardim Social', '82520-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (352, 'Piraquara', 'Adelaide Teixeira Goes', 'Planta Vila Nova', '83314-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (353, 'Foz do Iguaçu', 'Adelaide Valle Budel', 'Centro', '85851-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (354, 'Francisco Beltrão', 'Adelar José Kunz', 'Nossa Senhora Aparecida', '85601-760', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (355, 'Londrina', 'Adélia Gomes de Sá e Silva', 'Oscavo Santos', '86079-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (356, 'Cascavel', 'Adélia Pasinato', 'Parque São Paulo', '85803-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (357, 'Apucarana', 'Adélia Visioli Barreto', 'Parque Industrial Zona Norte', '86806-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (358, 'Curitiba', 'Adélia Zaninelli Vons', 'Xaxim', '81830-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (359, 'Curitiba', 'Adelina Buffara Nasser', 'Cidade Industrial', '81450-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (360, 'São José dos Pinhais', 'Adelina Carvalho', 'Costeira', '83015-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (361, 'Curitiba', 'Adelina Dutra Sanson', 'Hugo Lange', '80040-430', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (362, 'Londrina', 'Adelina Ferracini Palha', 'Residencial José B Almeida', '86041-816', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (363, 'Curitiba', 'Adelina Ferreira Muller', 'São Braz', '82015-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (364, 'Curitiba', 'Adelina Gasparim Wille', 'Pilarzinho', '82110-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (365, 'Cambé', 'Adelina Girotto', 'Jardim Santa Mônica', '86184-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (366, 'Londrina', 'Adelina Miola Lopes', 'Jardim Santa Fé', '86035-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (367, 'Londrina', 'Adelina Piqueti Barrios', 'Jardim Maracanã', '86056-860', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (368, 'Londrina', 'Adelina Scaramal Cruciol', 'Monte Belo', '86041-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (369, 'Curitiba', 'Adelino Alexandrino Marquezini', 'Atuba', '82860-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (370, 'Cascavel', 'Adelino André Catani', 'Região do Lago', '85819-767', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (371, 'Araucária', 'Adelino Basso', 'Centro', '83702-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (372, 'Londrina', 'Adelino Boer', 'Industrial', '86063-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (373, 'Londrina', 'Adelino Bornia', 'Condomínio Royal Golf Residence', '86055-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (374, 'Campo Mourão', 'Adelino Constantino Miguel', 'Jardim Aeroporto', '87310-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (375, 'Cambé', 'Adelino Costa', 'Vila Atalaia', '86181-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (376, 'Almirante Tamandaré', 'Adelino de Lima', 'Loteamento Maria Cláudia', '83513-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (377, 'Curitiba', 'Adelino de Paula', 'Atuba', '82860-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (378, 'Toledo', 'Adelino Formighieri', 'Conjunto Habitacional São Francisco', '85915-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (379, 'Londrina', 'Adelino Girotto', 'Conjunto Habitacional José Garcia Molina', '86080-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (380, 'Araucária', 'Adelino Hitner', 'Boqueirão', '83704-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (381, 'Toledo', 'Adelino João Dal''Bosco', 'Conjunto Habitacional Britânia', '85903-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (382, 'Ponta Grossa', 'Adelino José Rigoni', 'Chapada', '84062-679', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (383, 'Apucarana', 'Adelino Kele Marques de Lima', 'Loteamento Residencial Miguel Sochacki', '86802-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (384, 'Curitiba', 'Adelino Leal Nunes', 'Novo Mundo', '81020-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (385, 'Apucarana', 'Adelino Onofrio Corrêa', 'Jardim Eldorado', '86802-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (386, 'Araucária', 'Adelino Pires', 'Estação', '83705-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (387, 'Toledo', 'Adelino Prada', 'Coopagro', '85903-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (388, 'Francisco Beltrão', 'Adelino Romani', 'Marrecas', '85601-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (389, 'Cambé', 'Adelino Serino Bocate', 'Chácara Cambé Londrina', '86189-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (390, 'Cambé', 'Adelino Sola', 'Jardim Santa Adelaide', '86192-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (391, 'Curitiba', 'Adelino Vessossi', 'Fazendinha', '81320-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (392, 'Londrina', 'Adelino Vidotti', 'Cafezal', '86045-315', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (393, 'Paranaguá', 'Adélio Corrêa', 'Vila Guarani', '83221-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (394, 'Colombo', 'Adélio Correia', 'Jardim Califórnia', '83403-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (395, 'Piraquara', 'Adélio Gomes de Aguiar', 'Jardim Bom Jesus dos Passos', '83301-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (396, 'Apucarana', 'Adélio Gracioli', 'Jardim Marissol', '86807-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (397, 'Curitiba', 'Adelírio da Veiga', 'Abranches', '82130-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (398, 'Toledo', 'Adelmiro Camarella', 'Jardim Porto Alegre', '85906-707', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (399, 'Curitiba', 'Adelmo Arkanjo Bissi', 'Cachoeira', '82220-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (400, 'Apucarana', 'Adelson Alves Ribeiro', 'Loteamento Jardim Por do Sol', '86801-468', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (401, 'Cascavel', 'Ademar Ângelo Beux', 'Vila Tolentino', '85802-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (402, 'Colombo', 'Ademar Bontorin', 'Jardim Maria José', '83403-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (403, 'Sarandi', 'Ademar Bornia', 'Jardim Independência I', '87114-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (404, 'Sarandi', 'Ademar Bornia', 'Jardim Europa', '87113-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (405, 'Guarapuava', 'Ademar de Barros', 'Jardim das Américas', '85031-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (406, 'Guarapuava', 'Ademar de Barros', 'Morro Alto', '85065-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (407, 'Campo Largo', 'Ademar de Barros', 'Bom Jesus', '83601-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (408, 'Campo Largo', 'Ademar de Barros', 'Vila Nova', '83606-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (409, 'Apucarana', 'Ademar de Barros', 'Vila Formosa', '86802-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (410, 'Cascavel', 'Ademar de Barros', 'São Cristóvão', '85816-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (411, 'Colombo', 'Ademar de Barros', 'Sapopema', '83407-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (412, 'Laranjeiras do Sul', 'Ademar Ferreira Soares', 'Água Verde', '85301-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (413, 'Pato Branco', 'Ademar Rosa', 'Aeroporto', '85503-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (414, 'Pinhais', 'Ademilson Neves de Abreu', 'Jardim Marumby', '83327-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (415, 'Campo Largo', 'Ademir Seguro', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (416, 'Londrina', 'Adenir Maria Rodrigues de Carvalho', 'Conjunto Habitacional João Turquino', '86056-845', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (417, 'Cascavel', 'Adercides Depubel', 'Maria Luiza', '85819-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (418, 'Curitiba', 'Adevina Rodrigues Raquena', 'São Braz', '82315-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (419, 'Londrina', 'Adhemar Felice Weffort', 'Conjunto Novo Amparo 2', '86056-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (420, 'Londrina', 'Adhemar Pereira de Barros', 'Bela Suiça', '86050-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (421, 'Londrina', 'Adhemar Pereira de Barros', 'Bela Suiça', '86047-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (422, 'Piraquara', 'Adhmar Vieira de Araújo', 'Planta O Recanto', '83302-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (423, 'Curitiba', 'Adhmar Vieira de Araújo', 'Uberaba', '81590-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (424, 'Paranavaí', 'Adib Aburad', 'Jardim Paraíso', '87708-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (425, 'Paranavaí', 'Adib Aburad', 'Jardim Ibirapuera', '87705-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (426, 'Curitiba', 'Adib João Sallum', 'Pinheirinho', '81825-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (427, 'Araucária', 'Adilha Saad', 'Porto das Laranjeiras', '83703-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (428, 'Curitiba', 'Adília Alves Betenheuser', 'Alto Boqueirão', '81720-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (429, 'Castro', 'Adília de Mello Beck', 'Jardim das Araucárias', '84174-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (430, 'Ponta Grossa', 'Adílio Ramos', 'Chapada', '84062-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (431, 'Curitiba', 'Adílio Ramos', 'Bairro Alto', '82840-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (432, 'Curitiba', 'Adílio Ramos', 'Bairro Alto', '82820-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (433, 'Toledo', 'Adilson Bier', 'Jardim Modelo', '85906-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (434, 'Ponta Grossa', 'Adilson Sérgio Szayka Matoso', 'Contorno', '84060-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (435, 'Apucarana', 'Adilson Zanoni', 'Jardim Marissol', '86807-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (436, 'Curitiba', 'Adinar dos Santos Ribeiro', 'Fazendinha', '81330-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (437, 'Curitiba', 'Adir Dalabona', 'Orleans', '82300-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (438, 'São José dos Pinhais', 'Adir Pedroso', 'Afonso Pena', '83065-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (439, 'Cambé', 'Adir Souza', 'Jardim Riviera', '86187-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (440, 'Colombo', 'Adis-Abeba', 'Planta Santa Úrsula', '83405-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (441, 'Piraquara', 'Adivino Pereira do Nascimento', 'Planta Belvedere', '83311-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (442, 'Almirante Tamandaré', 'Adjahir de Bonfim Pinto', 'Vila Feliz', '83505-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (443, 'Almirante Tamandaré', 'Adjalme Garcia da Silva', 'Jardim Giannini', '83511-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (444, 'Ponta Grossa', 'Adjaniro Cardon', 'Jardim Carvalho', '84015-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (445, 'Campo Mourão', 'Admar Ferreira Caldas', 'Jardim Francisco Ferreira Albuquerque', '87309-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (446, 'Ponta Grossa', 'Admar Horn', 'Orfãs', '84015-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (447, 'Cascavel', 'Administração', 'Universitário', '85819-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (448, 'Curitiba', 'Adolar Coimbra', 'Sítio Cercado', '81920-739', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (449, 'Toledo', 'Adolfo Adams', 'Panorama', '85912-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (450, 'Londrina', 'Adolfo Barbosa Góis', 'Petrópolis', '86015-435', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (451, 'Londrina', 'Adolfo Bezerra de Menezes', 'San Fernando', '86040-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (452, 'Curitiba', 'Adolfo Bonaroski', 'Cidade Industrial', '81305-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (453, 'Sarandi', 'Adolfo Candiani', 'Vera Cruz', '87111-767', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (454, 'Pato Branco', 'Adolfo Chiquetta', 'La Salle', '85505-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (455, 'Londrina', 'Adolfo Curotto', 'Portal de Versalhes 3', '86055-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (456, 'Curitiba', 'Adolfo de Oliveira Franco', 'Seminário', '80310-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (457, 'Pato Branco', 'Adolfo Domingos Colet', 'Vila Verde', '85506-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (458, 'Londrina', 'Adolfo Franciolli', 'Larangeiras', '86042-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (459, 'Curitiba', 'Adolfo Froese', 'Fazendinha', '81320-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (460, 'Pinhais', 'Adolfo G. Muhlmann', 'Vila Irene Margarida', '83326-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (461, 'Umuarama', 'Adolfo Garcia', 'Zona IV', '87504-385', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (462, 'Umuarama', 'Adolfo Garcia', 'Parque Cidade Jardim', '87506-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (463, 'Cascavel', 'Adolfo Garcia', 'Brasmadeira', '85814-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (464, 'Toledo', 'Adolfo Grepner', 'Sachini', '85903-727', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (465, 'Castro', 'Adolfo Gustavo Lesnau', 'Vila Santa Cruz', '84168-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (466, 'Curitiba', 'Adolfo Henrique Klinger', 'Abranches', '82130-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (467, 'Curitiba', 'Adolfo João Hilário da Veiga', 'Cidade Industrial', '81280-345', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (468, 'Foz do Iguaçu', 'Adolfo Klein', 'Jardim Iguaçu', '85853-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (469, 'Almirante Tamandaré', 'Adolfo Litz', 'Loteamento Marinoni', '83508-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (470, 'Londrina', 'Adolfo Lopes de Oliveira', 'Jardim Vale Azul', '86041-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (471, 'Curitiba', 'Adolfo Lutz', 'Santa Felicidade', '82410-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (472, 'Curitiba', 'Adolfo Matoso dos Santos', 'Boa Vista', '82540-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (473, 'Ponta Grossa', 'Adolfo Novakowski', 'Uvaranas', '84025-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (474, 'Apucarana', 'Adolfo Oliveira Franco', 'Núcleo Habitacional Parigot de Souza', '86802-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (475, 'Apucarana', 'Adolfo Pedroso Silva', 'Jardim Nova América', '86807-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (476, 'Curitiba', 'Adolfo Pikussa', 'Uberaba', '81570-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (477, 'Ponta Grossa', 'Adolfo Postiglione', 'Estrela', '84050-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (478, 'Maringá', 'Adolfo Purpur', 'Cidade Jardim', '87023-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (479, 'Ponta Grossa', 'Adolfo Ranzen', 'Uvaranas', '84030-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (480, 'Curitiba', 'Adolfo Rocha de Almeira', 'Cidade Industrial', '81350-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (481, 'São José dos Pinhais', 'Adolfo Saviski', 'Colônia Rio Grande', '83025-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (482, 'Pinhais', 'Adolfo Sora', 'Loteamento Pineville', '83325-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (483, 'Curitiba', 'Adolfo Stedile', 'Bom Retiro', '80520-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (484, 'Campo Largo', 'Adolfo Vaz da Silva', 'Centro', '83601-355', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (485, 'Curitiba', 'Adolfo Werneck', 'Uberaba', '81560-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (486, 'Curitiba', 'Adolpho Bressan', 'Orleans', '81200-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (487, 'Curitiba', 'Adolpho Melzer', 'Bacacheri', '82600-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (488, 'Foz do Iguaçu', 'Adoniran Barbosa', 'Jardim das Bandeiras', '85864-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (489, 'Toledo', 'Adoniran Barbosa', 'Parque Residencial Gisela', '85905-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (490, 'Cascavel', 'Adoniran Barbosa', 'Brasília', '85815-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (491, 'Curitiba', 'Adorides de Jesus Cruz Camargo', 'Fazendinha', '81320-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (492, 'Londrina', 'Adovaldo José Gomes', 'Jacutinga', '86087-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (493, 'Curitiba', 'Adriana Ceres Zago Bueno', 'Tatuquara', '81470-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (494, 'Curitiba', 'Adriana Ribeiro', 'Cidade Industrial', '81460-178', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (495, 'Londrina', 'Adriano I', 'Jardim Albatroz', '86039-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (496, 'Maringá', 'Adriano José Valente', 'Novo Centro', '87020-037', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (497, 'Curitiba', 'Adriano Lugarini', 'Butiatuvinha', '82400-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (498, 'Londrina', 'Adriano Marino Gomes', 'Monte Belo', '86041-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (499, 'Curitiba', 'Adriano Silva de Oliveira', 'Pinheirinho', '81880-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (500, 'Almirante Tamandaré', 'Adriano Wilson Kotviski', 'Jardim Silvana', '83512-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (501, 'São José dos Pinhais', 'Adrianópolis', 'Cruzeiro', '83010-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (502, 'Telêmaco Borba', 'Adrianópolis', 'Jardim União', '84266-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (503, 'Colombo', 'Adrianópolis', 'Jardim Guilhermina', '83410-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (504, 'Curitiba', 'Adrianópolis', 'Sítio Cercado', '81900-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (505, 'Almirante Tamandaré', 'Adrianópolis', 'Jardim Roma', '83504-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (506, 'Londrina', 'Adriático', 'Jardim Indianápolis', '86010-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (507, 'Londrina', 'Adulcino José Jordão', 'Shangri-La', '86070-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (508, 'Curitiba', 'Ady Lobo Sotto Maior', 'Cajuru', '82930-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (509, 'Curitiba', 'Ady Romaria Conceição Mendonça', 'Uberaba', '81590-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (510, 'Curitiba', 'Adyr Parolim', 'Pinheirinho', '81825-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (511, 'Londrina', 'Aécio Dellarosa', 'Portal de Versalhes 1', '86057-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (512, 'Curitiba', 'Aécio Marcelo Antoniacomi', 'Butiatuvinha', '82400-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (513, 'Pato Branco', 'Aeroporto', 'Aeroporto', '85503-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (514, 'Cascavel', 'Aeroporto', 'Santos Dumont', '85804-810', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (515, 'Curitiba', 'Aeroporto Bacacheri', 'Bacacheri', '82515-180', 'Área', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (516, 'Telêmaco Borba', 'AF', 'Bela Vista do Paraíso', '84262-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (517, 'Curitiba', 'Affife Mansur', 'Novo Mundo', '81050-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (518, 'Apucarana', 'Affonso Alves de Camargo', 'Núcleo Habitacional Parigot de Souza', '86802-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (519, 'Curitiba', 'Affonso Baroni', 'Pilarzinho', '82115-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (520, 'Curitiba', 'Affonso Coelho dos Santos', 'Pilarzinho', '82110-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (521, 'Curitiba', 'Affonso Drulla', 'Cidade Industrial', '81280-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (522, 'Piraquara', 'Affonso Favoretto', 'Vila Fuck', '83305-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (523, 'Campo Largo', 'Affonso Guimarães', 'Vila Nova', '83605-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (524, 'Maringá', 'Affonso Hernandes Bitencourt', 'Recanto dos Magnatas', '87060-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (525, 'Curitiba', 'Affonso Jorge Von Trompowski', 'Sítio Cercado', '81910-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (526, 'Piraquara', 'Affonso Marcos Favoretto', 'Planta Laranjeiras', '83307-290', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (527, 'Almirante Tamandaré', 'Affonso Mathuzcewski', 'Loteamento Marinoni', '83508-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (528, 'Curitiba', 'Affonso Rainoldo Kuhn', 'Pinheirinho', '81820-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (529, 'Curitiba', 'Affonso Rebellato', 'Xaxim', '81710-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (530, 'Campo Largo', 'Afonso Aleixo', 'Vila Gilcy', '83609-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (531, 'Guarapuava', 'Afonso Alves de Camargo', 'Santana', '85070-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (532, 'Guarapuava', 'Afonso Alves de Camargo', 'Centro', '85010-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (533, 'Ponta Grossa', 'Afonso Arinos', 'Uvaranas', '84026-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (534, 'Curitiba', 'Afonso Arinos', 'Capão da Imbuia', '82810-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (535, 'Colombo', 'Afonso Arinos', 'Jardim Milena', '83409-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (536, 'Curitiba', 'Afonso Bail', 'Sítio Cercado', '81920-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (537, 'Curitiba', 'Afonso Bandeira', 'Umbará', '81930-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (538, 'Guarapuava', 'Afonso Botelho', 'Trianon', '85012-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (539, 'Guarapuava', 'Afonso Botelho', 'Trianon', '85015-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (540, 'Guarapuava', 'Afonso Botelho', 'Santana', '85070-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (541, 'Campo Mourão', 'Afonso Botelho', 'Centro', '87300-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (542, 'Campo Mourão', 'Afonso Botelho', 'Centro', '87301-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (543, 'Curitiba', 'Afonso Botelho', 'Água Verde', '80250-050', 'Parque', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (544, 'Apucarana', 'Afonso Caetano de Souza', 'Loteamento Belvedere', '86813-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (545, 'Ponta Grossa', 'Afonso Camargo', 'Jardim Carvalho', '84016-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (546, 'Londrina', 'Afonso Celso', 'Jardim Tatiani', '86070-440', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (547, 'Ponta Grossa', 'Afonso Celso', 'Uvaranas', '84020-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (548, 'Curitiba', 'Afonso Celso', 'Ahú', '80540-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (549, 'Curitiba', 'Afonso Correia de Morais', 'Cajuru', '82900-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (550, 'São José dos Pinhais', 'Afonso de Lima', 'Afonso Pena', '83050-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (551, 'São José dos Pinhais', 'Afonso Dissenha', 'Braga', '83020-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (552, 'Foz do Iguaçu', 'Afonso Ferreira', 'Mutirão', '85858-560', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (553, 'Ponta Grossa', 'Afonso Frederico Lange', 'Uvaranas', '84031-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (554, 'Curitiba', 'Afonso Fruet', 'Fazendinha', '81320-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (555, 'Guarapuava', 'Afonso Godofredo', 'Cascavel', '85025-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (556, 'Curitiba', 'Afonso Gonçalo Arantes', 'Pilarzinho', '82115-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (557, 'Londrina', 'Afonso Jaria', 'Portal de Versalhes 3', '86055-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (558, 'Campo Mourão', 'Afonso Labiak', 'Jardim Aeroporto', '87310-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (559, 'São José dos Pinhais', 'Afonso Leonardo Gondro', 'Bom Jesus', '83025-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (560, 'Curitiba', 'Afonso Lipinski', 'Orleans', '81200-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (561, 'Almirante Tamandaré', 'Afonso M. Lopes', 'Colônia Vila Prado', '83504-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (562, 'Colombo', 'Afonso Motin', 'Vila Santo Antônio', '83413-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (563, 'Pinhais', 'Afonso Muhlmann', 'Vila Irene Margarida', '83326-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (564, 'Curitiba', 'Afonso Nassife', 'Boqueirão', '81670-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (565, 'Ponta Grossa', 'Afonso Ozorio Teixeira', 'Cará-cará', '84032-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (566, 'Curitiba', 'Afonso Pedri', 'Pilarzinho', '80820-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (567, 'Foz do Iguaçu', 'Afonso Pena', 'Parque Presidente', '85863-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (568, 'Londrina', 'Afonso Pena', 'Hedy', '86062-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (569, 'Guarapuava', 'Afonso Pena', 'Boqueirão', '85020-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (570, 'Ponta Grossa', 'Afonso Pena', 'Estrela', '84040-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (571, 'Maringá', 'Afonso Pena', 'Zona 07', '87030-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (572, 'Pinhais', 'Afonso Pena', 'Vila Amélia', '83330-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (573, 'Pato Branco', 'Afonso Pena', 'Anchieta', '85501-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (574, 'Pato Branco', 'Afonso Pena', 'Menino Deus', '85502-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (575, 'Umuarama', 'Afonso Pena', 'Jardim Social', '87506-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (576, 'Telêmaco Borba', 'Afonso Pena', 'Alto das Oliveiras', '84265-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (577, 'Umuarama', 'Afonso Pena', 'Zona V', '87504-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (578, 'Cascavel', 'Afonso Pena', 'Independência', '85813-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (579, 'Cascavel', 'Afonso Pena', 'Centro', '85812-101', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (580, 'Cascavel', 'Afonso Pena', 'Independência', '85813-320', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (581, 'Cascavel', 'Afonso Pena', 'Centro', '85812-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (582, 'Curitiba', 'Afonso Penna', 'Tarumã', '82530-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (583, 'Curitiba', 'Afonso Piotto', 'Cidade Industrial', '81280-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (584, 'Colombo', 'Afonso Strapasson', 'Roseira', '83415-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (585, 'Curitiba', 'Afonso Theolindo Hennequim', 'Guabirotuba', '81510-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (586, 'Ponta Grossa', 'Afonso Vicente', 'Contorno', '84052-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (587, 'Curitiba', 'Afonso Zanon', 'Cidade Industrial', '81250-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (588, 'Curitiba', 'Afonso Zicka', 'Uberaba', '81550-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (589, 'Curitiba', 'Afrânio Peixoto', 'Fazendinha', '81330-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (590, 'Pinhais', 'África', 'Jardim Boa Esperança', '83323-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (591, 'Cascavel', 'África', 'Periolo', '85817-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (592, 'Arapongas', 'Agani', 'Jardim Primavera', '86702-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (593, 'Piraquara', 'Agassis Ribeiro Batista', 'Planta Irmãos Michel', '83304-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (594, 'Foz do Iguaçu', 'Ágata', 'Parque Ouro Verde', '85854-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (595, 'Maringá', 'Ágata', 'Jardim Santa Helena', '87083-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (596, 'Ponta Grossa', 'Ágata', 'Neves', '84021-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (597, 'Umuarama', 'Ágata', 'Conjunto Residencial Ouro Branco', '87508-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (598, 'Cascavel', 'Ágata', 'Esmeralda', '85806-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (599, 'Campo Mourão', 'Ágata', 'Jardim Tropical I', '87310-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (600, 'Curitiba', 'Agathe Bárbara Barz', 'Santa Felicidade', '82020-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (601, 'Curitiba', 'Agenor Antônio Rodrigues', 'Sítio Cercado', '81920-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (602, 'Londrina', 'Agenor dos Santos Cunha', 'Sabará III', '86066-285', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (603, 'Curitiba', 'Agenor Ferrari', 'Sítio Cercado', '81900-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (604, 'Londrina', 'Agenor Garutti', 'Industrial', '86063-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (605, 'São José dos Pinhais', 'Agenor Lino de Oliveira', 'Afonso Pena', '83045-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (606, 'Guarapuava', 'Agenor Maciel Ribas', 'Morro Alto', '85065-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (607, 'Curitiba', 'Agenor Marcola', 'Pilarzinho', '82100-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (608, 'Foz do Iguaçu', 'Agenor Marins', 'Jardim Panorama', '85856-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (609, 'Cascavel', 'Agenor Miotto', 'Cascavel Velho', '85818-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (610, 'Londrina', 'Agenor Paes de Mello', 'Portal de Versalhes 1', '86057-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (611, 'Londrina', 'Agenor Pereira da Silva', 'Conjunto Novo Amparo', '86087-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (612, 'Curitiba', 'Agenor Pierri', 'Cidade Industrial', '81170-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (613, 'Curitiba', 'Agenor Saturnino Ribeiro', 'Alto Boqueirão', '81770-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (614, 'Ponta Grossa', 'Agente Waldemar Pimentel', 'Oficinas', '84045-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (615, 'Curitiba', 'Aghabito Budel', 'Butiatuvinha', '82400-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (616, 'Apucarana', 'Agide Migliari', 'Jardim Kiri', '86802-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (617, 'Curitiba', 'Agílio Leão de Macedo', 'Cidade Industrial', '81350-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (618, 'Piraquara', 'Agisse Santa Rosa', 'Planta Santa Lúcia', '83311-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (619, 'Sarandi', 'Aglacir Binda Albert', 'Parque Alvamar', '87113-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (620, 'Francisco Beltrão', 'Agnaldo Silva', 'Jardim Novo Mundo', '85602-769', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (621, 'Maringá', 'Agnel Canno', 'Conjunto Residencial Itamaraty', '87015-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (622, 'Pinhais', 'Agnella Oleniki dos Santos', 'Planta Vila Bordignon', '83325-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (623, 'Londrina', 'Agnello Theodoro de Paula', 'Tarobá', '86042-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (624, 'Curitiba', 'Agostinho Ângelo Trevisan', 'Uberaba', '81560-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (625, 'Londrina', 'Agostinho dos Santos', 'Leonor', '86071-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (626, 'Pinhais', 'Agostinho dos Santos', 'Vila Maria Antonieta', '83331-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (627, 'Maringá', 'Agostinho dos Santos', 'Conjunto Residencial Cidade Alta', '87053-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (628, 'Cascavel', 'Agostinho dos Santos', 'Brasília', '85815-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (629, 'Apucarana', 'Agostinho dos Santos', 'Núcleo Habitacional Castelo Branco', '86812-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (630, 'Londrina', 'Agostinho Feijó Sanches', 'Santa Mônica', '86079-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (631, 'Piraquara', 'Agostinho Ferreira Araújo', 'Guarituba', '83311-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (632, 'Maringá', 'Agostinho Franco Rocha', 'Conjunto João de Barro Porto Seguro II', '87055-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (633, 'Curitiba', 'Agostinho Grubba', 'Pilarzinho', '82115-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (634, 'Londrina', 'Agostinho Hass', 'Gleba Fazenda Palhano', '86055-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (635, 'Ponta Grossa', 'Agostinho Jorge Buss', 'Orfãs', '84015-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (636, 'Araucária', 'Agostinho Kaiut', 'Tindiquera', '83708-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (637, 'Foz do Iguaçu', 'Agostinho Lavabo Felipe', 'Parque Presidente', '85863-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (638, 'Curitiba', 'Agostinho Leão Júnior', 'Centro', '80030-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (639, 'Londrina', 'Agostinho Marques Gregório', 'Colinas', '86056-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (640, 'Ponta Grossa', 'Agostinho Mathias Pinheiro', 'Neves', '84020-777', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (641, 'Curitiba', 'Agostinho Merlin', 'Portão', '80330-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (642, 'Campo Largo', 'Agostinho Mocelin', 'Vila Ferrari', '83606-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (643, 'Curitiba', 'Agostinho Narezi', 'Vila Izabel', '80320-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (644, 'Paranaguá', 'Agostinho Pereira Alves', 'Bockmann', '83206-287', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (645, 'São José dos Pinhais', 'Agostinho Precoma', 'São Pedro', '83005-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (646, 'Cambé', 'Agostinho Razente', 'Jardim Planalto Verde', '86192-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (647, 'Curitiba', 'Agostinho Ribeiro de Lima', 'Pinheirinho', '81825-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (648, 'Curitiba', 'Agostinho Zaninelli', 'Boa Vista', '82560-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (649, 'Almirante Tamandaré', 'Agricultor Gildo Pinheiro da Luz', 'Loteamento Maria Cláudia', '83513-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (650, 'Araucária', 'Agrimensor Carlos Hasselmann', 'Fazenda Velha', '83703-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (651, 'Maringá', 'Agrimensor Nelson de Souza Figueiredo', 'Cidade Jardim', '87020-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (652, 'Almirante Tamandaré', 'Agrimensor Nicolau Valkir Netto', 'Jardim Monterrey', '83507-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (653, 'Paranaguá', 'Agripino Ferminiano Pereira', 'Jardim Samambaia', '83212-528', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (654, 'Curitiba', 'Agripino Ribeiro de Freitas', 'Cajuru', '82950-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (655, 'Cascavel', 'Agronomia', 'Universitário', '85819-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (656, 'Campo Largo', 'Água Mineral', 'Jardim Paraíso Mineral', '83606-120', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (657, 'Campo Largo', 'Água Mineral', 'Jardim Busmayer', '83606-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (658, 'Maringá', 'Água Verde', 'Residencial Regente', '87045-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (659, 'Curitiba', 'Água Verde', 'Vila Izabel', '80240-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (660, 'Curitiba', 'Água Verde', 'Água Verde', '80620-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (661, 'Ponta Grossa', 'Aguadeiro Felipe', 'Oficinas', '84035-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (662, 'Curitiba', 'Água-doce', 'Cidade Industrial', '81240-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (663, 'Foz do Iguaçu', 'Água-marinha', 'Parque Ouro Verde', '85854-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (664, 'Londrina', 'Água-marinha', 'Lupércio Luppi', '86027-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (665, 'Foz do Iguaçu', 'Água-marinha', 'Parque Ouro Verde', '85855-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (666, 'Ponta Grossa', 'Água-marinha', 'Neves', '84021-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (667, 'Maringá', 'Água-marinha', 'Jardim Real', '87083-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (668, 'Telêmaco Borba', 'Água-marinha', 'Área 10', '84266-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (669, 'Cascavel', 'Água-marinha', 'Esmeralda', '85806-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (670, 'Campo Mourão', 'Água-marinha', 'Jardim Tropical I', '87310-248', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (671, 'Piraquara', 'Águas Claras', 'Chácara Águas Claras', '83308-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (672, 'Curitiba', 'Águas do Passauna', 'São Miguel', '81450-768', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (673, 'Guarapuava', 'Agudos do Sul', 'Jardim das Américas', '85030-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (674, 'São José dos Pinhais', 'Agudos do Sul', 'Afonso Pena', '83045-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (675, 'Telêmaco Borba', 'Agudos do Sul', 'Jardim União', '84266-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (676, 'Curitiba', 'Agudos do Sul', 'Sítio Cercado', '81900-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (677, 'Colombo', 'Aguenelo Berlesi', 'Jardim Paraná', '83412-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (678, 'Londrina', 'Agui Kobayashi', 'Jardim Imagawa', '86080-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (679, 'Umuarama', 'Águia', 'Conjunto Patrimônio Umuarama', '87505-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (680, 'Araucária', 'Águia', 'Capela Velha', '83706-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (681, 'Campo Largo', 'Águia-branca', 'Vila David Antônio', '83609-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (682, 'Campo Largo', 'Águia-do-mar', 'Vila Dona Fina', '83609-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (683, 'Arapongas', 'Águia-pesqueira', 'Jardim Europa', '86707-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (684, 'Arapongas', 'Águia-real', 'Parque Veneza', '86701-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (685, 'Arapongas', 'Águias', 'Vila Nova', '86707-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (686, 'Apucarana', 'Aguimar Dolor Felisbino', 'Núcleo Habitacional Djalma Mendes de Oliveira', '86806-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (687, 'Curitiba', 'Aguinaldo dos Santos Pereira', 'Cajuru', '82930-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (688, 'Ponta Grossa', 'Aguinaldo Guimarães da Cunha', 'Boa Vista', '84073-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (689, 'Ponta Grossa', 'Aguinaldo Sampaio Ribas', 'Nova Rússia', '84070-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (690, 'Araucária', 'Aguinelo Pinto', 'Barigui', '83707-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (691, 'Curitiba', 'Aguiomar Komar Vilharva', 'Uberaba', '81590-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (692, 'Londrina', 'Agulhas Negras', 'Rodocentro', '86065-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (693, 'Curitiba', 'Agustin Cortizo Penelas', 'Sítio Cercado', '81900-739', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (694, 'Londrina', 'Agustinha Maria de Goés', 'Jardim Strass', '86084-827', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (695, 'Londrina', 'Agustinho Zemuner', 'Conjunto Residencial Marajoara', '86080-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (696, 'Londrina', 'Ahmad Naor El Rafihi', 'Avelino A Vieira', '86056-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (697, 'Campo Largo', 'Ahyrdo Francisco Andreassa', 'Vila Andreassa Miranda', '83605-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (698, 'Pato Branco', 'Aida da Costa', 'Cristo Rei', '85506-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (699, 'Almirante Tamandaré', 'Aides Ângelo de Oliveira', 'Jardim Roma', '83504-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (700, 'Curitiba', 'Ailton Cabral Dalavequia', 'Santa Cândida', '82630-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (701, 'São José dos Pinhais', 'Ailton Luiz de Carvalho', 'Ipê', '83055-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (702, 'Colombo', 'Ailton Luiz Nodari', 'Planta Bom Jesus', '83407-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (703, 'Pato Branco', 'Aimoré', 'Centro', '85504-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (704, 'Pato Branco', 'Aimoré', 'Centro', '85505-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (705, 'Paranavaí', 'Aimoré', 'Jardim São Jorge', '87710-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (706, 'Arapongas', 'Aimoré', 'Vila Industrial', '86706-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (707, 'Londrina', 'Aimorés', 'Centro', '86026-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (708, 'Piraquara', 'Aimorés', 'Vila Dalila', '83303-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (709, 'Apucarana', 'Aimorés', 'Núcleo Habitacional Colonial', '86812-416', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (710, 'Cambé', 'Aimorés', 'Jardim Tupi', '86183-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (711, 'Cascavel', 'Aimorés', 'Santa Cruz', '85806-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (712, 'Colombo', 'Aires Fernandes da Silva', 'Jardim João Paulo II', '83402-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (713, 'Campo Mourão', 'Airto Albuquerque', 'Conjunto Residencial Ilha Bela', '87309-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (714, 'Curitiba', 'Airton Camati Christo', 'Pilarzinho', '82100-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (715, 'Curitiba', 'Airton Duma', 'Cidade Industrial', '81460-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (716, 'Curitiba', 'Airton Eloi Maganhotto', 'Umbará', '81930-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (717, 'Curitiba', 'Airton Gallego', 'Pinheirinho', '81870-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (718, 'Foz do Iguaçu', 'Airton Moreira', 'Parque Morumbi IV', '85857-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (719, 'Foz do Iguaçu', 'Airton Moreira', 'Parque Morumbi IV', '85859-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (720, 'São José dos Pinhais', 'Airton Pires Machado', 'Águas Belas', '83010-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (721, 'Foz do Iguaçu', 'Airton Ramos', 'Jardim São Paulo II', '85856-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (722, 'Curitiba', 'Airton Ribeiro Marques', 'Tatuquara', '81880-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (723, 'Curitiba', 'Airton Sozzi', 'Hugo Lange', '80040-420', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (724, 'Arapongas', 'Ajajá', 'Vila Nova', '86701-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (725, 'Campo Mourão', 'Akibono', 'Jardim Lar Paraná', '87305-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (726, 'Londrina', 'Alabama', 'Londrina', '86060-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (727, 'Francisco Beltrão', 'Alabama', 'Antônio de Paiva Cantelmo', '85603-531', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (728, 'Londrina', 'Alabastro', 'Waldemar Hauer', '86030-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (729, 'Telêmaco Borba', 'Alagamar', 'Macopa', '84263-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (730, 'Londrina', 'Alagoas', 'Centro', '86010-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (731, 'Londrina', 'Alagoas', 'Centro', '86020-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (732, 'Guarapuava', 'Alagoas', 'Vila Carli', '85045-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (733, 'Foz do Iguaçu', 'Alagoas', 'Vila Matilde', '85852-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (734, 'Francisco Beltrão', 'Alagoas', 'Alvorada', '85601-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (735, 'Piraquara', 'Alagoas', 'Jardim dos Estados 2', '83308-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (736, 'São José dos Pinhais', 'Alagoas', 'Três Marias', '83030-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (737, 'Ponta Grossa', 'Alagoas', 'Oficinas', '84036-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (738, 'Maringá', 'Alagoas', 'Jardim Alvorada', '87033-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (739, 'Pato Branco', 'Alagoas', 'La Salle', '85505-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (740, 'Paranaguá', 'Alagoas', 'Vila do Povo', '83209-629', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (741, 'Umuarama', 'Alagoas', 'Zona II', '87502-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (742, 'Telêmaco Borba', 'Alagoas', 'Vila Ozorio', '84268-350', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (743, 'Campo Largo', 'Alagoas', 'Vila Itaqui', '83604-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (744, 'Araucária', 'Alagoas', 'Iguaçu', '83701-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (745, 'Castro', 'Alagoas', 'Centro', '84165-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (746, 'Colombo', 'Alagoas', 'Jardim Jalisco', '83404-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (747, 'Curitiba', 'Alagoas', 'Portão', '80610-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (748, 'Curitiba', 'Alagoas', 'Guaíra', '80630-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (749, 'Telêmaco Borba', 'Alagoinhas', 'Área 02', '84267-480', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (750, 'Londrina', 'Alaíde Silva', 'Milton Gavetti', '86078-120', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (751, 'Pinhais', 'Alamanda', 'Jardim Pio XII', '83328-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (752, 'Ponta Grossa', 'Alamenda', 'Colônia Dona Luiza', '84043-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (753, 'Pinhais', 'Álamo', 'Jardim Pio XII', '83328-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (754, 'Cascavel', 'Álamo', 'Parque Verde', '85807-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (755, 'Londrina', 'Alan José Elias Godoy', 'Conjunto Professora Hilda Mandarino', '86080-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (756, 'Londrina', 'Alan Santa Maria', 'Residencial Portal do Sol', '86082-777', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (757, 'Curitiba', 'Alaor Darci Conduta', 'Ganchinho', '81935-330', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (758, 'Curitiba', 'Alaor Vicente Daros', 'Alto Boqueirão', '81850-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (759, 'Apucarana', 'Alarico Damas Soares', 'Jardim Paraíso', '86807-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (760, 'Ponta Grossa', 'Alarico Francisco Franca', 'Neves', '84020-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (761, 'Guarapuava', 'Alasca', 'Morro Alto', '85067-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (762, 'Colombo', 'Alasca', 'Jardim Bela Vista', '83404-710', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (763, 'Curitiba', 'Alayde Mainheriche da Cruz', 'Santa Cândida', '82710-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (764, 'Londrina', 'Alba Bertoleti Clivati', 'Alto da Boa Vista', '86083-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (765, 'Maringá', 'Alba Guimarães', 'Zona 07', '87020-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (766, 'Cascavel', 'Alba Vieira', 'Cataratas', '85818-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (767, 'Londrina', 'Albânia', 'Igapó', '86046-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (768, 'Londrina', 'Albano Finotti', 'Dom Pedro I', '86089-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (769, 'Paranaguá', 'Albano Müller', 'Serraria do Rocha', '83221-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (770, 'Curitiba', 'Albano Reis', 'Bom Retiro', '80520-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (771, 'Curitiba', 'Albano Reis', 'Ahú', '80530-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (772, 'Apucarana', 'Albano Rizzo', 'Jardim Flamingos', '86811-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (773, 'Guarapuava', 'Albano Teixeira', 'Industrial', '85053-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (774, 'Ponta Grossa', 'Albari de Almeida', 'Colônia Dona Luiza', '84043-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (775, 'Foz do Iguaçu', 'Albary Calderary Ferreira', 'Loteamento Universitário das Américas', '85870-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (776, 'Ponta Grossa', 'Albary Justus', 'Boa Vista', '84072-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (777, 'Londrina', 'Albatroz', 'Jacomo Violin', '86088-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (778, 'Guarapuava', 'Albatroz', 'Batel', '85015-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (779, 'Maringá', 'Albatroz', 'Jardim Olímpico', '87070-331', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (780, 'Ponta Grossa', 'Albatroz', 'Colônia Dona Luiza', '84046-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (781, 'Araucária', 'Albatroz', 'Estação', '83705-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (782, 'Arapongas', 'Albatroz', 'Vila Nova', '86707-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (783, 'Campo Mourão', 'Albatroz', 'Conjunto Habitacional Milton Luiz Pereira', '87306-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (784, 'Curitiba', 'Albatroz', 'Bacacheri', '82515-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (785, 'Arapongas', 'Albatroz-real', 'Conjunto Del Condor', '86703-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (786, 'Curitiba', 'Albenir Amatuzzi', 'Cidade Industrial', '81350-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (787, 'Cascavel', 'Alberi Antônio Richardi', 'Cancelli', '85811-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (788, 'Curitiba', 'Alberico Figueira', 'Seminário', '80240-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (789, 'Curitiba', 'Albérico Flores Bueno', 'Bairro Alto', '82840-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (790, 'Curitiba', 'Albérico Flores Bueno', 'Bairro Alto', '82820-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (791, 'Araucária', 'Alberico Talamini', 'Cachoeira', '83701-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (792, 'Londrina', 'Albert Antônio Sallum', 'Colinas', '86056-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (793, 'Guarapuava', 'Albert Einstein', 'Santa Cruz', '85015-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (794, 'Londrina', 'Albert Einstein', 'Industrial', '86063-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (795, 'Ponta Grossa', 'Albert Einstein', 'Uvaranas', '84032-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (796, 'Cascavel', 'Albert Einstein', 'Interlagos', '85814-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (797, 'Toledo', 'Albert Hubner', 'Vila Industrial', '85905-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (798, 'Curitiba', 'Albert Sabin', 'Umbará', '81930-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (799, 'Curitiba', 'Albertina de Oliveira Barreto', 'Cidade Industrial', '81230-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (800, 'Piraquara', 'Albertina Primo Schmitz', 'Planta Cruzeiro', '83304-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (801, 'Curitiba', 'Albertino Gonçalves Cordeiro', 'Cidade Industrial', '81170-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (802, 'Londrina', 'Alberto Amaro Ferreira', 'Jacutinga', '86087-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (803, 'Ponta Grossa', 'Alberto Ansbach', 'Uvaranas', '84026-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (804, 'Ponta Grossa', 'Alberto Ansbach', 'Neves', '84021-580', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (805, 'Curitiba', 'Alberto Antônio Pereira', 'Novo Mundo', '81050-675', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (806, 'Curitiba', 'Alberto Bahr', 'Tarumã', '82530-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (807, 'Curitiba', 'Alberto Balhana', 'Santa Felicidade', '82030-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (808, 'Colombo', 'Alberto Bedin', 'Centro Industrial Mauá', '83413-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (809, 'Cascavel', 'Alberto Bernardini de Aragão', 'Santa Felicidade', '85803-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (810, 'Curitiba', 'Alberto Bernarski', 'São Braz', '82315-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (811, 'São José dos Pinhais', 'Alberto Bichebiche', 'Afonso Pena', '83050-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (812, 'Curitiba', 'Alberto Bolliger', 'Juvevê', '80030-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (813, 'Londrina', 'Alberto Bonafini', 'Vale do Reno', '86047-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (814, 'São José dos Pinhais', 'Alberto Bonk', 'Miringuava', '83090-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (815, 'Curitiba', 'Alberto Breowicz', 'Bairro Alto', '82840-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (816, 'Campo Largo', 'Alberto Bulow', 'Loteameto Miranda', '83605-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (817, 'Guarapuava', 'Alberto Carvalho Filho', 'Bonsucesso', '85060-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (818, 'Campo Largo', 'Alberto Cavalim', 'Vila Nova', '83605-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (819, 'Curitiba', 'Alberto Corrêa Regnier', 'Cidade Industrial', '81350-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (820, 'Curitiba', 'Alberto da Silva', 'Cidade Industrial', '81305-270', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (821, 'Guarapuava', 'Alberto de Oliveira', 'Industrial', '85053-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (822, 'Maringá', 'Alberto de Oliveira', 'Zona 06', '87015-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (823, 'Ponta Grossa', 'Alberto de Oliveira', 'Nova Rússia', '84070-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (824, 'Ponta Grossa', 'Alberto de Oliveira', 'Nova Rússia', '84071-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (825, 'Curitiba', 'Alberto de Oliveira', 'Bairro Alto', '82820-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (826, 'Curitiba', 'Alberto dos Santos', 'Cidade Industrial', '81350-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (827, 'Curitiba', 'Alberto Edart', 'Atuba', '82630-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (828, 'Telêmaco Borba', 'Alberto Elerth Filho', 'Jardim Bom Jesus', '84262-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (829, 'Curitiba', 'Alberto Erthal', 'São Lourenço', '82210-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (830, 'Colombo', 'Alberto Estare', 'Sapopema', '83407-165', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (831, 'Curitiba', 'Alberto Ferreira', 'Cidade Industrial', '81450-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (832, 'Paranaguá', 'Alberto Ferreira dos Santos', 'Divinéia', '83212-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (833, 'Curitiba', 'Alberto Folloni', 'Ahú', '80540-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (834, 'Curitiba', 'Alberto Folloni', 'Juvevê', '80530-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (835, 'Castro', 'Alberto Fontes', 'Invernada do Matadouro', '84174-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (836, 'Curitiba', 'Alberto Francisco Tossin', 'Mossunguê', '81200-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (837, 'Londrina', 'Alberto Francisco Xavier', 'Del Rey', '86045-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (838, 'Londrina', 'Alberto Gazolli', 'Conjunto Habitacional  Alexandre Urbanas', '86037-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (839, 'Curitiba', 'Alberto Gesser', 'Cajuru', '82920-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (840, 'Castro', 'Alberto Gonçalves', 'Vila Santa Cruz', '84168-037', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (841, 'Campo Largo', 'Alberto Gonçalves', 'Jardim Keli Cristina', '83609-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (842, 'Piraquara', 'Alberto Guerra', 'Vila San Remo I', '83301-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (843, 'Curitiba', 'Alberto Hammerschmidt', 'Portão', '81070-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (844, 'Ponta Grossa', 'Alberto Hansen', 'Uvaranas', '84026-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (845, 'Curitiba', 'Alberto Heyn', 'Uberaba', '81560-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (846, 'Guarapuava', 'Alberto Iensen', 'Boqueirão', '85020-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (847, 'Londrina', 'Alberto Ignacio Ferreira', 'Jardim Primavera', '86086-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (848, 'Londrina', 'Alberto Jans', 'Heimtal', '86084-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (849, 'Ponta Grossa', 'Alberto João Klas', 'Uvaranas', '84030-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (850, 'Ponta Grossa', 'Alberto José Mezzomo', 'Uvaranas', '84030-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (851, 'Ponta Grossa', 'Alberto Kampe', 'Uvaranas', '84030-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (852, 'Araucária', 'Alberto Karas', 'Porto das Laranjeiras', '83703-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (853, 'Campo Largo', 'Alberto Kelmes', 'Jardim das Américas', '83601-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (854, 'Curitiba', 'Alberto Klemtz', 'Portão', '80330-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (855, 'Araucária', 'Alberto Kmiecik', 'Estação', '83705-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (856, 'Cambé', 'Alberto Koch', 'Jardim Santo Antônio', '86182-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (857, 'São José dos Pinhais', 'Alberto Koerbel', 'Guatupê', '83065-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (858, 'Guarapuava', 'Alberto Kohler', 'Santana', '85070-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (859, 'Curitiba', 'Alberto Kosop', 'Pinheirinho', '81150-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (860, 'Curitiba', 'Alberto Kramer', 'Capão Raso', '81150-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (861, 'Colombo', 'Alberto Kubis', 'Jardim Moinho Velho', '83403-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (862, 'Curitiba', 'Alberto Leschkau', 'Capão Raso', '81130-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (863, 'Araucária', 'Alberto Lesniowski', 'Costeira', '83709-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (864, 'Toledo', 'Alberto Limbeger', 'Residencial Santa Clara', '85908-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (865, 'Londrina', 'Alberto Liutti', 'Del Rey', '86045-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (866, 'Londrina', 'Alberto Loureiro', 'Conjunto Café', '86038-045', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (867, 'Castro', 'Alberto M. de Mello', 'Jardim Dona Helena', '84178-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (868, 'Curitiba', 'Alberto Magno', 'Santa Cândida', '82630-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (869, 'Colombo', 'Alberto Manika', 'Vila Maria do Rosário', '83413-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (870, 'Curitiba', 'Alberto Manoel Glaser', 'Tingui', '82600-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (871, 'Curitiba', 'Alberto Mansuetto Dallagassa', 'Pinheirinho', '81870-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (872, 'Araucária', 'Alberto Markowicz', 'Thomaz Coelho', '83707-340', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (873, 'Guarapuava', 'Alberto Martini', 'Conradinho', '85055-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (874, 'Colombo', 'Alberto Maschio', 'Vila São Paulo', '83411-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (875, 'Londrina', 'Alberto Maurício Barroso Júnior', 'Colonial', '86047-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (876, 'Laranjeiras do Sul', 'Alberto Minski', 'Vila Industrial', '85303-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (877, 'Guarapuava', 'Alberto Minski', 'Vila Bela', '85025-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (878, 'Foz do Iguaçu', 'Alberto Mogelos', 'Jardim Califórnia', '85867-505', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (879, 'Curitiba', 'Alberto Müller Sobrinho', 'Portão', '81320-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (880, 'Ponta Grossa', 'Alberto Nepomuceno', 'Jardim Carvalho', '84015-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (881, 'Curitiba', 'Alberto Otto', 'Cachoeira', '82710-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (882, 'Londrina', 'Alberto Palma', 'Aquilles Sthengel', '86086-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (883, 'Curitiba', 'Alberto Panek', 'Orleans', '82300-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (884, 'Francisco Beltrão', 'Alberto Pasqualini', 'Cristo Rei', '85602-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (885, 'Curitiba', 'Alberto Pasqualini', 'Uberaba', '81550-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (886, 'Curitiba', 'Alberto Potier', 'Boa Vista', '82560-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (887, 'Londrina', 'Alberto Preto', 'Barbeta', '86078-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (888, 'Foz do Iguaçu', 'Alberto Rangel Batista', 'Pilar Parque Campestre', '85862-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (889, 'Piraquara', 'Alberto Ribeiro', 'Vila Fuck', '83305-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (890, 'Araucária', 'Alberto Rodrigues', 'Iguaçu', '83701-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (891, 'Curitiba', 'Alberto Rodrigues Xavier', 'Cachoeira', '82710-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (892, 'Londrina', 'Alberto Romi', 'Conjunto Café', '86038-025', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (893, 'Curitiba', 'Alberto Rutz', 'Portão', '81320-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (894, 'Curitiba', 'Alberto Sanches Paredes', 'Cidade Industrial', '81280-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (895, 'Ponta Grossa', 'Alberto Scarpin', 'Oficinas', '84045-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (896, 'Curitiba', 'Alberto Schumak', 'Novo Mundo', '81020-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (897, 'Curitiba', 'Alberto Schumann', 'São Braz', '82300-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (898, 'Curitiba', 'Alberto Schweitzer', 'Pinheirinho', '81820-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (899, 'Curitiba', 'Alberto Slud', 'Capão da Imbuia', '82800-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (900, 'Curitiba', 'Alberto Stenzowski', 'Novo Mundo', '81050-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (901, 'Curitiba', 'Alberto Sterion', 'Umbará', '81930-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (902, 'Maringá', 'Alberto Tissei', 'Conjunto Habitacional Requião', '87047-446', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (903, 'Ponta Grossa', 'Alberto Torres', 'Estrela', '84040-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (904, 'Curitiba', 'Alberto Torres', 'Fazendinha', '81330-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (905, 'Ponta Grossa', 'Alberto Tramontin', 'Contorno', '84060-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (906, 'Curitiba', 'Alberto Twardowski', 'Jardim Botânico', '80210-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (907, 'Umuarama', 'Alberto Uliana', 'Jardim dos Príncipes', '87502-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (908, 'Curitiba', 'Alberto Wierbiski', 'São Lourenço', '82210-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (909, 'Curitiba', 'Alberto Zonato', 'Santa Felicidade', '82030-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (910, 'Francisco Beltrão', 'Albina C. Korego', 'Pinheirinho', '85606-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (911, 'Curitiba', 'Albina Lunardon Dariva', 'Boa Vista', '82540-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (912, 'Curitiba', 'Albina Reffo Bocchino', 'Cajuru', '82900-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (913, 'Apucarana', 'Albina Scarpellini Zanon', 'Jardim das Flores V', '86810-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (914, 'Curitiba', 'Albino Beatriz', 'Fanny', '81030-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (915, 'Apucarana', 'Albino Bianchi', 'Vila Social', '86804-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (916, 'Curitiba', 'Albino Blum', 'Barreirinha', '82650-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (917, 'Curitiba', 'Albino Born', 'Bom Retiro', '80520-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (918, 'Curitiba', 'Albino Evaldo Müller', 'Augusta', '81290-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (919, 'Londrina', 'Albino Ferracini', 'Portal de Versalhes 3', '86055-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (920, 'Toledo', 'Albino Franz', 'Residencial Santa Clara', '85907-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (921, 'Curitiba', 'Albino Frederico Foerster', 'Alto Boqueirão', '81770-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (922, 'Apucarana', 'Albino Ganassin', 'Jardim Santos Dumont I', '86812-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (923, 'Curitiba', 'Albino Graf', 'Mercês', '80710-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (924, 'Campo Largo', 'Albino Grande', 'Conjunto Águas Claras', '83602-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (925, 'Curitiba', 'Albino Homann', 'São Braz', '82310-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (926, 'Piraquara', 'Albino José de Souza', 'Planta Cruzeiro', '83304-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (927, 'Curitiba', 'Albino Kaminski', 'Bairro Alto', '82820-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (928, 'Curitiba', 'Albino Kutzek', 'Alto Boqueirão', '81850-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (929, 'Curitiba', 'Albino Marcolino Antunes', 'Sítio Cercado', '81920-750', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (930, 'Cambé', 'Albino Menolli', 'Jardim Riviera', '86187-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (931, 'São José dos Pinhais', 'Albino Moreschi', 'Ouro Fino', '83015-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (932, 'Curitiba', 'Albino Niquele', 'Umbará', '81940-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (933, 'Pato Branco', 'Albino Oldoni', 'Bela Vista', '85509-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (934, 'Curitiba', 'Albino Pavelski', 'Augusta', '81260-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (935, 'Almirante Tamandaré', 'Albino Pavoni', 'Jardim Santa Rita de Cássia', '83506-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (936, 'Curitiba', 'Albino Potulski', 'Santo Inácio', '82300-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (937, 'Curitiba', 'Albino Raschendorfer', 'Vista Alegre', '80810-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (938, 'Toledo', 'Albino Scariot', 'Coopagro', '85903-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (939, 'Londrina', 'Albino Scotton', 'Jardim Burle Marx', '86047-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (940, 'Paranavaí', 'Albino Silva', 'Jardim Canadá', '87708-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (941, 'Ponta Grossa', 'Albino Silva', 'Ronda', '84051-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (942, 'Curitiba', 'Albino Silva', 'São Francisco', '80520-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (943, 'Piraquara', 'Albino Sizanoski', 'Vila Juliana', '83306-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (944, 'Curitiba', 'Albino Stamm', 'Cidade Industrial', '81270-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (945, 'Curitiba', 'Albino Tesserolli', 'Santa Felicidade', '82015-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (946, 'Colombo', 'Albino Wanke', 'Jardim Santa Angélica', '83403-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (947, 'Ponta Grossa', 'Albita', 'Neves', '84021-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (948, 'Curitiba', 'Albo Brunetti', 'Novo Mundo', '81050-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (949, 'Curitiba', 'Albor Pimpão de Almeida', 'Tatuquara', '81470-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (950, 'Ponta Grossa', 'Alcântara Machado', 'Boa Vista', '84072-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (951, 'Telêmaco Borba', 'Alcatraz', 'Vila São Francisco de Assis', '84264-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (952, 'Arapongas', 'Alcatraz', 'Vila Industrial', '86706-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (953, 'Campo Mourão', 'Alcatraz', 'Jardim Izabel', '87309-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (954, 'Campo Largo', 'Alcebíades Affonso Guimarães', 'Jardim São Vicente', '83602-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (955, 'Curitiba', 'Alcebíades de Oliveira', 'Boa Vista', '82200-560', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (956, 'Cascavel', 'Alcebíades G. Domingues', 'Santa Cruz', '85806-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (957, 'Castro', 'Alcebíades Marques de Souza', 'Vila Rio Branco', '84172-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (958, 'Curitiba', 'Alcebíades Merlin', 'Xaxim', '81720-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (959, 'Curitiba', 'Alcebíades Plaisant', 'Água Verde', '80620-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (960, 'Curitiba', 'Alcebíades Ribeiro Padilha', 'Novo Mundo', '81050-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (961, 'Guarapuava', 'Alcebíades Rodrigues', 'Santana', '85070-030', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (962, 'Londrina', 'Alcenir Bueno', 'Cilo 3', '86073-016', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (963, 'Curitiba', 'Alceu Aguida', 'Barreirinha', '82210-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (964, 'Londrina', 'Alceu Amoroso Lima', 'Conjunto Habitacional Violim', '86085-605', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (965, 'Ponta Grossa', 'Alceu Biseto', 'Contorno', '84061-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (966, 'Toledo', 'Alceu C. Pinto', 'Residencial Santa Clara', '85907-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (967, 'Colombo', 'Alceu d''Agostin', 'Jardim Uirapuru', '83406-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (968, 'Foz do Iguaçu', 'Alceu de Amoroso Lima', 'Jardim das Bandeiras', '85864-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (969, 'Ponta Grossa', 'Alceu Dejar Marques Guimarães', 'Ronda', '84051-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (970, 'Curitiba', 'Alceu Dorigo', 'São Braz', '82320-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (971, 'Campo Largo', 'Alceu Fabris', 'Jardim Florestal', '83602-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (972, 'Curitiba', 'Alceu Ferreira', 'Guabirotuba', '81510-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (973, 'Araucária', 'Alceu Galize', 'Tindiquera', '83708-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (974, 'Curitiba', 'Alceu Galize', 'Sítio Cercado', '81925-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (975, 'Piraquara', 'Alceu Gonçalves Muhnlenhoff', 'Vila San Remo I', '83301-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (976, 'Ponta Grossa', 'Alceu Grein Taques', 'Neves', '84020-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (977, 'Ponta Grossa', 'Alceu Martins', 'Uvaranas', '84031-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (978, 'Curitiba', 'Alceu Mileke', 'Cidade Industrial', '81305-400', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (979, 'São José dos Pinhais', 'Alceu Moreschi', 'Planta Quississana', '83085-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (980, 'Apucarana', 'Alceu Sanches Posticho', 'Jardim Espanha', '86802-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (981, 'Paranaguá', 'Alceu Sebastião P. da Costa', 'Parque São João', '83212-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (982, 'Londrina', 'Alceu Segantin', 'Jardim Guararapes', '86038-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (983, 'Ponta Grossa', 'Alcides Alessi', 'Estrela', '84050-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (984, 'Curitiba', 'Alcides Alves de Oliveira', 'Santo Inácio', '82300-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (985, 'Laranjeiras do Sul', 'Alcides Alves Ferreira', 'Vila Industrial', '85303-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (986, 'Londrina', 'Alcides Alvim Rezende', 'Jardim Paris', '86082-067', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (987, 'Maringá', 'Alcides Bueno', 'Conjunto Habitacional Requião', '87047-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (988, 'Maringá', 'Alcides Calvo', 'Conjunto Habitacional Requião', '87047-489', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (989, 'Ponta Grossa', 'Alcides da Silva Rocha', 'Estrela', '84050-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (990, 'São José dos Pinhais', 'Alcides Dal''Negro', 'Bom Jesus', '83025-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (991, 'Curitiba', 'Alcides Darcanchy', 'Santa Felicidade', '82410-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (992, 'Umuarama', 'Alcides de Brito Pratis', 'Jardim Cruzeiro', '87504-578', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (993, 'Apucarana', 'Alcides de Oliveira', 'Jardim Catuaí III', '86802-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (994, 'Campo Mourão', 'Alcides F. Toledo', 'Jardim São Sebastião', '87303-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (995, 'Londrina', 'Alcides Favoretto', 'Jardim Alphaville', '86084-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (996, 'Maringá', 'Alcides Fernandes', 'Zona 03', '87045-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (997, 'Paranavaí', 'Alcides Ferreira e Silva', 'Jardim Santa Eugênia', '87705-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (998, 'Curitiba', 'Alcides Gonçalves da Rocha', 'Atuba', '82630-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (999, 'Campo Mourão', 'Alcides Hauagge', 'Jardim Santa Cruz', '87309-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1000, 'Pinhais', 'Alcides Jazar', 'Conjunto Residencial Inocoop', '83326-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1001, 'Pinhais', 'Alcides José Silveira', 'Jardim Pedro Demeterco', '83324-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1002, 'Londrina', 'Alcides Lisse', 'Jardim Paraty', '86081-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1003, 'Curitiba', 'Alcides Mauro', 'Uberaba', '81560-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1004, 'Foz do Iguaçu', 'Alcides Morello', 'Loteamento Residencial Lagoa Vermelha', '85862-338', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1005, 'São José dos Pinhais', 'Alcides Munhoz', 'São Sebastião', '83075-466', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1006, 'Curitiba', 'Alcides Munhoz', 'Mercês', '80710-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1007, 'Curitiba', 'Alcides Munhoz', 'Mercês', '80810-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1008, 'São José dos Pinhais', 'Alcides Munhoz Neto', 'Guatupê', '83060-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1009, 'Campo Largo', 'Alcides Pacheco', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1010, 'Cascavel', 'Alcides Paese', 'Floresta', '85814-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1011, 'Toledo', 'Alcides Pan', 'Jardim Recanto', '85902-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1012, 'Toledo', 'Alcides Paraíba dos Santos', 'Boa Esperança', '85909-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1013, 'Guarapuava', 'Alcides Rossoni', 'São Cristóvão', '85063-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1014, 'Maringá', 'Alcides Schimitt', 'Parque Tarumã', '87053-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1015, 'Londrina', 'Alcides Simão Santiago', 'Assis', '86085-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1016, 'Curitiba', 'Alcides Terézio de Carvalho', 'Guabirotuba', '81520-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1017, 'São José dos Pinhais', 'Alcides Thomaz de Lima', 'Planta Quississana', '83085-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1018, 'Curitiba', 'Alcides Vasconcelos', 'Atuba', '82860-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1019, 'Londrina', 'Alcides Zaninelli', 'Residencial José Lázaro Gouvea', '86050-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1020, 'Curitiba', 'Alcídio Cubas', 'Novo Mundo', '81020-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1021, 'São José dos Pinhais', 'Alcidio Dissenha', 'Ipê', '83055-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1022, 'São José dos Pinhais', 'Alcídio Rocco', 'Afonso Pena', '83045-160', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1023, 'São José dos Pinhais', 'Alcidio Viana', 'São Pedro', '83005-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1024, 'São José dos Pinhais', 'Alcídio Zaniolo', 'Roseira', '83070-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1025, 'Londrina', 'Alcina Dornellas Monteiro', 'Residencial Abussafe', '86037-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1026, 'Curitiba', 'Alcina Tacla Sabbag', 'Prado Velho', '80215-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1027, 'Curitiba', 'Alcinda Gomes Chagas', 'Parolin', '80220-220', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1028, 'Paranaguá', 'Alcindo Alves', 'Estradinha', '83206-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1029, 'Paranavaí', 'Alcindo Alves de Lima', 'Jardim São Jorge', '87710-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1030, 'Guarapuava', 'Alcindo Cardoso Teixeira', 'Santana', '85070-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1031, 'Guarapuava', 'Alcindo Chaves Ferreira', 'Santana', '85070-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1032, 'Guarapuava', 'Alcindo de Matos', 'Industrial', '85045-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1034, 'Campo Mourão', 'Alcindo Ferreira Toledo', 'Jardim São Sebastião', '87303-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1035, 'Laranjeiras do Sul', 'Alcindo N. Camargo', 'Centro', '85301-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1036, 'Castro', 'Alcindo R. de Moura', 'Núcleo Habitacional Padre Piva', '84178-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1037, 'Ponta Grossa', 'Alcindo Santana Nunes', 'Boa Vista', '84072-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1038, 'Londrina', 'Alcino Carneiro Ribas', 'Jardim Burle Marx', '86047-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1039, 'Londrina', 'Alcino Francisco da Silva', 'Parque Universidade', '86056-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1040, 'Curitiba', 'Alcino Guanabara', 'Hauer', '81610-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1041, 'Curitiba', 'Alcino Guanabara', 'Hauer', '81630-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1042, 'Londrina', 'Alcino Passi', 'Jardim Continental', '86081-189', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1043, 'Guarapuava', 'Alcione Bastos', 'Alto da XV', '85065-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1044, 'Guarapuava', 'Alcione Bastos', 'Centro', '85010-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1045, 'São José dos Pinhais', 'Alcionei Ramos da Rosa', 'Guatupê', '83060-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1046, 'Curitiba', 'Alcioni Camargo de Queiroz', 'Sítio Cercado', '81920-776', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1047, 'Cascavel', 'Alcir da Motta', 'Claudete', '85811-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1048, 'Curitiba', 'Alcir Martins Bastos', 'Fazendinha', '81330-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1049, 'Piraquara', 'Alcy Dombroski', 'Vila Franca', '83305-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1050, 'Ponta Grossa', 'Alda Eberth', 'Neves', '84020-766', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1051, 'Castro', 'Alda Kreling', 'Morada do Sol', '84172-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1052, 'Toledo', 'Alda Scremin', 'Parque Residencial Gisela', '85905-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1053, 'Colombo', 'Alderico de Jesus Ceccon', 'Jardim César Augusto', '83402-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1054, 'Londrina', 'Aldo Armando Tortelli', 'Jamile Dequech', '86048-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1055, 'Apucarana', 'Aldo de Deus Marchiori', 'Vila Operária Stabile', '86811-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1056, 'Apucarana', 'Aldo Golfeto', 'Loteamento Sanches dos Santos', '86806-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1057, 'Curitiba', 'Aldo Kepler da Silva', 'Orleans', '82310-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1058, 'Apucarana', 'Aldo Marcachini', 'Parque Bela Vista', '86803-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1059, 'Curitiba', 'Aldo Pigozzi', 'Cidade Industrial', '81260-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1060, 'Curitiba', 'Aldo Pinheiro', 'Abranches', '82130-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1061, 'Paranaguá', 'Aldo Sant Ana', 'Parque São João', '83212-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1062, 'Almirante Tamandaré', 'Aldo Seronato', 'Jardim Areias', '83514-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1063, 'Ponta Grossa', 'Aldo Vergani', 'Oficinas', '84036-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1064, 'Umuarama', 'Aldredo Volpi', 'Conjunto Residencial Ouro Preto', '87504-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1065, 'Cascavel', 'Alduíno Machado', 'Santos Dumont', '85804-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1066, 'Apucarana', 'Alécia Garutti Pelissari', 'Jardim Aviação', '86812-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1067, 'Curitiba', 'Alécio Masson', 'Alto Boqueirão', '81770-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1068, 'Londrina', 'Alécio Tiossi', 'Leste Oeste', '86037-816', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1069, 'Londrina', 'Alecrim', 'Santa Rita 1', '86071-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1070, 'Pinhais', 'Alecrim', 'Planta Walde Rosi Galvão', '83328-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1071, 'Ponta Grossa', 'Alecrim', 'Neves', '84020-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1072, 'Telêmaco Borba', 'Alecrim', 'Área 01', '84268-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1073, 'Campo Largo', 'Alecrim', 'Vila Dom Pedro II', '83608-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1074, 'Campo Mourão', 'Alecrim', 'Jardim Araucária', '87301-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1075, 'Cascavel', 'Alegrete', 'Canadá', '85813-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1076, 'Curitiba', 'Aleides Vasconcelos', 'Cidade Industrial', '81230-407', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1077, 'Ponta Grossa', 'Aleixo Barszcz', 'Uvaranas', '84031-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1078, 'Curitiba', 'Aleixo Bettega', 'Lindóia', '81010-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1079, 'Almirante Tamandaré', 'Aleixo Broto', 'Vila Bela Vista', '83513-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1080, 'Araucária', 'Aleixo Budziak', 'Cachoeira', '83701-785', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1081, 'Guarapuava', 'Aleixo Garcia', 'Alto Cascavel', '85031-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1082, 'Ponta Grossa', 'Aleixo Garcia', 'Oficinas', '84036-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1083, 'Ponta Grossa', 'Aleixo Garcia', 'Oficinas', '84035-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1084, 'Araucária', 'Aleixo Gotfrid', 'Capela Velha', '83706-710', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1085, 'Curitiba', 'Aleixo Grebos', 'Cidade Industrial', '81230-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1086, 'Curitiba', 'Aleixo Kloss', 'Mossunguê', '81200-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1087, 'Colombo', 'Aleixo Nodari', 'Imbuial', '83415-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1088, 'Araucária', 'Aleixo Panek', 'Thomaz Coelho', '83707-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1089, 'Campo Mourão', 'Aleixo Piovezan', 'Jardim Aeroporto', '87310-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1090, 'Colombo', 'Aleixo Schluga', 'Centro Industrial Mauá', '83413-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1091, 'Curitiba', 'Aleixo Schluga', 'Santa Cândida', '82630-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1092, 'Curitiba', 'Aleixo Skraba', 'Novo Mundo', '81050-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1093, 'Curitiba', 'Aleixo Sprada', 'Tatuquara', '81470-286', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1094, 'Guarapuava', 'Aleixo Thomas', 'Vila Bela', '85025-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1095, 'Araucária', 'Aleixo Trauczysnki', 'Thomaz Coelho', '83707-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1096, 'Colombo', 'Aleixo Walt', 'Jardim Nossa Senhora da Penha', '83402-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1097, 'Araucária', 'Aleixo Wzorek', 'Sabiá', '83708-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1098, 'São José dos Pinhais', 'Aleksander Majczak', 'Colônia Murici', '83085-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1099, 'Curitiba', 'Aleksy Guskow', 'Santa Felicidade', '82410-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1100, 'Ponta Grossa', 'Aleluia', 'Contorno', '84061-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1101, 'Campo Mourão', 'Aleluia', 'Jardim Lar Paraná', '87305-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1102, 'Araucária', 'Aleluia', 'Campina da Barra', '83709-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1103, 'Guarapuava', 'Alemanha', 'Industrial', '85053-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1104, 'Foz do Iguaçu', 'Alemanha', 'Jardim Europa', '85859-315', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1105, 'Londrina', 'Alemanha', 'Igapó', '86046-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1106, 'Toledo', 'Alemanha', 'Jardim Porto Alegre', '85906-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1107, 'Umuarama', 'Alemanha', 'Parque Bonfim', '87507-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1108, 'Almirante Tamandaré', 'Alemanha', 'Vila Graziela', '83505-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1109, 'Cambé', 'Alemanha', 'Jardim Morada do Sol', '86181-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1110, 'Cascavel', 'Alemanha', 'Cascavel Velho', '85818-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1111, 'Maringá', 'Alencar de Oliveira Paiva', 'Vila Esperança', '87020-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1112, 'Londrina', 'Alessandro Volta', 'Industrial', '86063-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1113, 'Curitiba', 'Aléssio Fronza', 'Pilarzinho', '82110-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1114, 'Curitiba', 'Alete Dacheux Stori', 'Jardim das Américas', '81540-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1115, 'Ponta Grossa', 'Alex Félix Arvers', 'Cará-cará', '84043-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1116, 'Curitiba', 'Alex Skorobohaty', 'Campo Comprido', '81230-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1117, 'Londrina', 'Alexander Graham Bell', 'Jamaica', '86063-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1118, 'Maringá', 'Alexander Graham Bell', 'Jardim Ipanema', '87053-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1119, 'Maringá', 'Alexandra', 'Parque Residencial Patrícia', '87040-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1120, 'Apucarana', 'Alexandra', 'Vila Bruna', '86809-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1121, 'Sarandi', 'Alexandra Alves Pereira', 'Jardim Castelo', '87112-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1122, 'Almirante Tamandaré', 'Alexandra Dimitrov', 'Jardim São Carlos', '83507-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1123, 'Sarandi', 'Alexandra Dziuba', 'Parque Alvamar', '87113-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1124, 'Curitiba', 'Alexandra Sarnacka', 'Cidade Industrial', '81280-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1125, 'Apucarana', 'Alexandre Adolfo Grubisi', 'Jardim Figueira', '86801-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1126, 'Londrina', 'Alexandre Albertoni', 'Lago Igapó', '86026-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1127, 'Pinhais', 'Alexandre Alves de Farias', 'Conjunto Residencial Inocoop', '83326-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1128, 'Piraquara', 'Alexandre Alves de Farias', 'Planta Cruzeiro', '83304-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1129, 'Londrina', 'Alexandre Alvino da Silva', 'Conjunto Habitacional José Garcia Molina', '86080-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1130, 'Colombo', 'Alexandre Andretta', 'Jardim Monza', '83406-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1131, 'Curitiba', 'Alexandre Baka', 'São Lourenço', '82200-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1132, 'Apucarana', 'Alexandre Balan', 'Parque Bela Vista', '86803-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1133, 'Apucarana', 'Alexandre Berberi', 'Vila Franko', '86802-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1134, 'Ponta Grossa', 'Alexandre Bohatch', 'Contorno', '84060-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1135, 'Araucária', 'Alexandre Borrazo', 'Centro', '83702-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1136, 'Paranaguá', 'Alexandre Bousquet', 'Campo Grande', '83206-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1137, 'Piraquara', 'Alexandre Brasil', 'Vila Susi', '83304-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1138, 'Colombo', 'Alexandre Cebola', 'Jardim Cruzeiro', '83403-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1139, 'Curitiba', 'Alexandre Dalcuch', 'Bacacheri', '82600-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1140, 'Almirante Tamandaré', 'Alexandre de Cristo', 'Vila Grécia', '83502-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1141, 'Colombo', 'Alexandre de Gusmão', 'Jardim Quitandinha', '83409-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1142, 'Cascavel', 'Alexandre de Gusmão', 'Maria Luiza', '85819-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1143, 'Curitiba', 'Alexandre de Gusmão', 'Jardim Social', '82530-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1144, 'Almirante Tamandaré', 'Alexandre Domacoski', 'Jardim Dona Belizaria', '83513-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1145, 'Curitiba', 'Alexandre Eduardo Klat', 'Abranches', '82130-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1146, 'Maringá', 'Alexandre Fleming', 'Jardim Alvorada', '87035-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1147, 'Piraquara', 'Alexandre Fleming', 'Jardim Primavera', '83302-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1148, 'São José dos Pinhais', 'Alexandre Foggiatto', 'Afonso Pena', '83045-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1149, 'São José dos Pinhais', 'Alexandre Foggiatto Sobrinho', 'Cidade Jardim', '83035-260', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1150, 'Londrina', 'Alexandre Frossard', 'Itapoã', '86043-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1151, 'Londrina', 'Alexandre Garcia de Souza', 'Alto da Boa Vista', '86083-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1152, 'Londrina', 'Alexandre Grossi', 'Colinas', '86056-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1153, 'Colombo', 'Alexandre Guebur', 'Parque São Domingos', '83404-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1154, 'Piraquara', 'Alexandre Gugelmim', 'Vila Juliana', '83306-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1155, 'Pato Branco', 'Alexandre Gusmão', 'São Cristóvão', '85508-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1156, 'Curitiba', 'Alexandre Gutierrez Beltrão', 'Sítio Cercado', '81920-757', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1157, 'Guarapuava', 'Alexandre H. de Carvalho', 'Industrial', '85045-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1158, 'Ponta Grossa', 'Alexandre Herculano', 'Nova Rússia', '84053-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1159, 'Foz do Iguaçu', 'Alexandre Kozievitch', 'Jardim Social I', '85853-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1160, 'Curitiba', 'Alexandre Leocádio Santana', 'Cidade Industrial', '81260-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1161, 'Colombo', 'Alexandre Machado dos Santos', 'Jardim Solimões', '83402-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1162, 'Curitiba', 'Alexandre Marchioro', 'Seminário', '80240-470', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1163, 'Curitiba', 'Alexandre Marcoski', 'São Braz', '82015-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1164, 'Cambé', 'Alexandre Marinelli', 'Jardim Planalto Verde', '86192-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1165, 'Maringá', 'Alexandre Mazzer', 'Vila Esperança', '87020-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1166, 'Cascavel', 'Alexandre Müller', 'Claudete', '85811-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1167, 'Colombo', 'Alexandre Nadolny', 'Jardim Cruzeiro', '83403-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1168, 'Curitiba', 'Alexandre Nadolny', 'Santa Cândida', '82630-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1169, 'Curitiba', 'Alexandre Naldoni', 'Cidade Industrial', '81350-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1170, 'São José dos Pinhais', 'Alexandre Possebon Filho', 'Afonso Pena', '83045-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1171, 'Ponta Grossa', 'Alexandre Rocha F. Carvalhaes', 'Jardim Carvalho', '84016-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1172, 'Araucária', 'Alexandre Romanowski', 'Barigui', '83707-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1173, 'São José dos Pinhais', 'Alexandre Ronkoski', 'Rio Pequeno', '83070-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1174, 'Sarandi', 'Alexandre Rudolf Vas', 'Parque Alvamar II', '87113-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1175, 'Londrina', 'Alexandre Sahyun', 'Jardim Neman Sahyun', '86041-407', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1176, 'Londrina', 'Alexandre Sahyun', 'Conjunto Habitacional José Garcia Molina', '86080-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1177, 'Curitiba', 'Alexandre Salata', 'Guaíra', '81010-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1178, 'Londrina', 'Alexandre Santoro', 'Parigot de Souza 2', '86082-325', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1179, 'Londrina', 'Alexandre Santoro', 'Igarite', '86081-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1180, 'Londrina', 'Alexandre Santoro', 'Estados', '86083-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1181, 'Curitiba', 'Alexandre Schroeder', 'Pilarzinho', '82120-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1182, 'Campo Mourão', 'Alexandre Schumoski', 'Jardim Bandeirantes', '87308-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1183, 'Curitiba', 'Alexandre Sferelli', 'Cidade Industrial', '81450-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1184, 'Campo Mourão', 'Alexandre Tamporoski', 'Jardim Corinthias', '87309-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1185, 'Curitiba', 'Alexandre Toscani Filho', 'Santa Felicidade', '82015-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1186, 'Curitiba', 'Alexandre Von Humboldt', 'Pilarzinho', '82110-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1187, 'Araucária', 'Alexandre Wisocki', 'Fazenda Velha', '83703-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1188, 'São José dos Pinhais', 'Alexandre Zanchetta', 'Campina', '83015-148', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1189, 'Curitiba', 'Alexandrino Alves de Oliveira', 'Sítio Cercado', '81900-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1190, 'Maringá', 'Alexandrita', 'Jardim Brasil', '87083-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1191, 'Ponta Grossa', 'Alexandrita', 'Neves', '84021-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1192, 'Colombo', 'Alexandro Guebur', 'Jardim Modelo', '83405-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1193, 'Curitiba', 'Alexis Barbosa Conceição', 'Santa Cândida', '82640-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1194, 'Londrina', 'Alexsandro César Brito', 'Conjunto Novo Amparo', '86087-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1195, 'Curitiba', 'Alexssandro Gomes Benedito', 'Novo Mundo', '81050-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1196, 'Ponta Grossa', 'Alfa', 'Oficinas', '84043-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1197, 'Campo Largo', 'Alfa Vile', 'Centro', '83601-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1198, 'Londrina', 'Alfazema', 'Alto da Colina', '86050-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1199, 'Ponta Grossa', 'Alfazema', 'Contorno', '84060-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1200, 'Curitiba', 'Alfazema', 'Cachoeira', '82710-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1201, 'Cascavel', 'Alfeneiros', 'Parque Verde', '85807-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1202, 'Cascavel', 'Alfeo Vieiro', 'Claudete', '85811-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1203, 'Curitiba', 'Alferes Alfredo Antônio Muller', 'Bacacheri', '82600-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1204, 'Curitiba', 'Alferes Ângelo Sampaio', 'Água Verde', '80250-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1205, 'Curitiba', 'Alferes Ângelo Sampaio', 'Batel', '80420-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1206, 'Curitiba', 'Alferes Ângelo Sampaio', 'Mercês', '80730-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1207, 'São José dos Pinhais', 'Alferes João Bortoloti', 'Zaniolo', '83025-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1208, 'Curitiba', 'Alferes Marcílio Machado', 'Tingui', '82600-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1209, 'Curitiba', 'Alferes Pedro Magno de Barros', 'Xaxim', '81810-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1210, 'Curitiba', 'Alferes Poli', 'Centro', '80230-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1211, 'Curitiba', 'Alferes Poli', 'Parolin', '80220-051', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1212, 'Curitiba', 'Alferes Poli', 'Rebouças', '80220-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1213, 'Campo Mourão', 'Alfeu de Paula Xavier', 'Jardim Bandeirantes', '87308-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1214, 'Londrina', 'Alfeu Rodrigues de Figueiredo', 'Dom Pedro II', '86073-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1215, 'Londrina', 'Alfieri Faé', 'Parque Industrial Buena Vista', '86032-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1216, 'Ponta Grossa', 'Alfons Willein Stalmach', 'Uvaranas', '84031-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1217, 'Campo Mourão', 'Alfonso Germano Hruschka', 'Conjunto Residencial Piacentini', '87308-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1218, 'Curitiba', 'Alfonso Osvaldo Grellmann', 'Pinheirinho', '81880-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1219, 'Curitiba', 'Alfonso Waldemar Barra', 'Tingui', '82600-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1220, 'Curitiba', 'Alfred Adler', 'Santa Cândida', '82720-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1221, 'Londrina', 'Alfred Bernhard Nobel', 'Industrial', '86063-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1222, 'Curitiba', 'Alfred Nobel', 'Cidade Industrial', '81170-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1223, 'Pinhais', 'Alfredina Maciel Pinto', 'Jardim Triângulo', '83331-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1224, 'Colombo', 'Alfredo Alberti', 'Jardim César Augusto', '83402-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1225, 'Maringá', 'Alfredo Andersen', 'Zona 05', '87015-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1226, 'Cascavel', 'Alfredo Andersen', 'Country', '85813-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1227, 'Curitiba', 'Alfredo Andersen', 'Bigorrilho', '80730-160', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1228, 'Curitiba', 'Alfredo Barcik', 'Cajuru', '82980-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1229, 'Londrina', 'Alfredo Battini', 'San Remo', '86062-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1230, 'Umuarama', 'Alfredo Bernardo', 'Conjunto Residencial Vinte e Oito de Outubro', '87509-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1231, 'Ponta Grossa', 'Alfredo Bochnia', 'Cará-cará', '84032-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1232, 'Maringá', 'Alfredo Braido', 'Jardim Ipanema', '87053-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1233, 'Paranaguá', 'Alfredo Budant', 'Itiberê', '83206-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1234, 'Paranaguá', 'Alfredo Budant', 'Jardim Araçá', '83221-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1235, 'Curitiba', 'Alfredo Bufren', 'Centro', '80020-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1236, 'Araucária', 'Alfredo Charviet', 'Vila Nova', '83703-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1237, 'Araucária', 'Alfredo Charviet', 'Centro', '83702-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1238, 'Colombo', 'Alfredo Chaves', 'Jardim Guadalajara', '83402-190', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1239, 'Curitiba', 'Alfredo Constantino Moro', 'Cidade Industrial', '81260-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1240, 'Curitiba', 'Alfredo Cresto', 'Cajuru', '82950-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1241, 'Cascavel', 'Alfredo Dalmina', 'São Cristóvão', '85813-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1242, 'Castro', 'Alfredo de Oliveira Ávila', 'Jardim das Araucárias', '84174-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1243, 'Curitiba', 'Alfredo de Oliveira Moreira', 'Boa Vista', '82650-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1244, 'Piraquara', 'Alfredo de Souza', 'Guarituba', '83311-306', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1245, 'São José dos Pinhais', 'Alfredo Edson Tod', 'Miringuava', '83090-426', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1246, 'Curitiba', 'Alfredo Eduardo Puglieli', 'Santo Inácio', '82010-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1247, 'Ponta Grossa', 'Alfredo Eugênio Batista Rosas', 'Orfãs', '84015-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1248, 'Guarapuava', 'Alfredo Fabiane', 'Primavera', '85050-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1249, 'Londrina', 'Alfredo Fauro', 'Conjunto Novo Amparo 2', '86056-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1250, 'Apucarana', 'Alfredo Fedrigo', 'Núcleo Habitacional Djalma Mendes de Oliveira', '86806-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1251, 'Ponta Grossa', 'Alfredo Fernandes Correia', 'Contorno', '84061-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1252, 'Ponta Grossa', 'Alfredo Gomes', 'Boa Vista', '84071-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1253, 'Colombo', 'Alfredo Gomes Cordeiro', 'Vila Alto da Cruz II', '83405-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1254, 'Maringá', 'Alfredo Gomes da Silva', 'Parque Residencial Quebec', '87023-495', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1255, 'Ponta Grossa', 'Alfredo Guimarães Vilela', 'Jardim Carvalho', '84015-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1256, 'Cambé', 'Alfredo Guizilini', 'Jardim Planalto Verde', '86192-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1257, 'Curitiba', 'Alfredo Hauer', 'Hauer', '81630-080', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1258, 'Curitiba', 'Alfredo Heisler', 'Bacacheri', '82600-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1259, 'Ponta Grossa', 'Alfredo Hoffmann', 'Boa Vista', '84071-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1260, 'Curitiba', 'Alfredo Jaime Felippe', 'Portão', '81320-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1261, 'Almirante Tamandaré', 'Alfredo José de Freitas', 'Jardim Dona Belizaria', '83513-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1262, 'Curitiba', 'Alfredo José Pinto', 'Fazendinha', '81320-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1263, 'Ponta Grossa', 'Alfredo Justus', 'Chapada', '84062-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1264, 'Ponta Grossa', 'Alfredo Kagemeyer', 'Olarias', '84026-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1265, 'Ponta Grossa', 'Alfredo Kepp', 'Jardim Carvalho', '84015-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1266, 'Curitiba', 'Alfredo Krainski', 'Alto Boqueirão', '81850-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1267, 'Colombo', 'Alfredo Lazarotto', 'Centro', '83414-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1268, 'Toledo', 'Alfredo Leite', 'Panorama', '85911-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1269, 'Castro', 'Alfredo Luiz de Mattos', 'Centro', '84165-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1270, 'Guarapuava', 'Alfredo Maciel', 'Primavera', '85053-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1271, 'Londrina', 'Alfredo Maricato Filho', 'Jardim Alphaville', '86084-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1272, 'Curitiba', 'Alfredo Mazza', 'Lindóia', '81010-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1273, 'Colombo', 'Alfredo Miguel Baduy', 'Sapopema', '83407-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1274, 'São José dos Pinhais', 'Alfredo Mulhsted Filho', 'Afonso Pena', '83065-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1275, 'Piraquara', 'Alfredo Müller', 'Vila Mariana', '83311-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1276, 'Ponta Grossa', 'Alfredo Munhoz', 'Ronda', '84051-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1277, 'Curitiba', 'Alfredo Muraro', 'São João', '82020-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1278, 'Curitiba', 'Alfredo Otto', 'Novo Mundo', '81050-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1279, 'Curitiba', 'Alfredo Parodi', 'Centro', '80010-040', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1280, 'Ponta Grossa', 'Alfredo Pedro Ribas', 'Uvaranas', '84026-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1281, 'Ponta Grossa', 'Alfredo Pietrobelli', 'Boa Vista', '84072-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1282, 'São José dos Pinhais', 'Alfredo Pinto', 'Afonso Pena', '83065-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1283, 'São José dos Pinhais', 'Alfredo Pinto', 'Afonso Pena', '83050-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1284, 'Curitiba', 'Alfredo Pires Furiatti', 'Xaxim', '81710-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1285, 'Maringá', 'Alfredo Pujol', 'Zona 05', '87015-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1286, 'Curitiba', 'Alfredo Pujol', 'Cidade Industrial', '81250-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1287, 'Colombo', 'Alfredo Puppi', 'Vila Ana Maria', '83413-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1288, 'Curitiba', 'Alfredo Rafael da Silva', 'Uberaba', '81560-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1289, 'Londrina', 'Alfredo Rodrigues de Lima', 'Residencial José B Almeida', '86041-827', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1290, 'Londrina', 'Alfredo Rodrigues dos Santos', 'Cafezal', '86045-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1291, 'Maringá', 'Alfredo Rubim', 'Cidade Jardim', '87020-516', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1292, 'Pinhais', 'Alfredo Saliba Smaka', 'Conjunto Residencial Áquila', '83326-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1293, 'Ponta Grossa', 'Alfredo Santana', 'Jardim Carvalho', '84015-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1294, 'Castro', 'Alfredo Schendroski', 'Vila Rio Branco', '84172-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1295, 'Toledo', 'Alfredo Schneider', 'Residencial Santa Clara', '85908-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1296, 'Curitiba', 'Alfredo Schwartz', 'Santo Inácio', '82010-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1297, 'Curitiba', 'Alfredo Scorsin', 'Orleans', '82300-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1298, 'Colombo', 'Alfredo Sílvio Coller', 'Jardim Rio Verde', '83405-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1299, 'Guarapuava', 'Alfredo Souza Gomes', 'Conradinho', '85045-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1300, 'Guarapuava', 'Alfredo Stolz', 'Trianon', '85012-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1301, 'Colombo', 'Alfredo Tomacheschi', 'Jardim Guarujá', '83407-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1302, 'Ponta Grossa', 'Alfredo Trentin', 'Orfãs', '84015-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1303, 'Maringá', 'Alfredo Urbano Rodrigues', 'Conjunto Habitacional Sol Nascente', '87055-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1304, 'Foz do Iguaçu', 'Alfredo Vale de Oliveira', 'Conjunto Residencial Sol de Maio', '85862-586', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1305, 'Curitiba', 'Alfredo Vendramin', 'Tatuquara', '81480-188', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1306, 'Curitiba', 'Alfredo Volpe', 'Santa Felicidade', '82320-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1307, 'São José dos Pinhais', 'Alfredo Vosguerau', 'Afonso Pena', '83065-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1308, 'Araucária', 'Alfredo Voss', 'Costeira', '83709-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1309, 'Curitiba', 'Alfredo Wekerlin', 'Boa Vista', '82200-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1310, 'Curitiba', 'Alfredo Wenske', 'Cabral', '80035-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1311, 'Maringá', 'Alfredo Werner Nyffeler', 'Vila Morangueira', '87030-490', 'Parque', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1312, 'Curitiba', 'Alfredo Xavier de Almeida', 'Guaíra', '81010-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1313, 'Toledo', 'Alfredo Zibetti', 'Jardim Parizzotto', '85914-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1314, 'Londrina', 'Ali Ibrahim Kamar', 'Residencial Abussafe', '86037-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1315, 'Foz do Iguaçu', 'Ali Osman', 'Jardim São Paulo II', '85856-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1316, 'Londrina', 'Alice Abib Sahão', 'Jardim Vale Azul', '86041-750', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1317, 'Curitiba', 'Alice Adélia de Oliveira', 'Cidade Industrial', '81350-618', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1318, 'Curitiba', 'Alice Alves da Cruz e Oliveira', 'Portão', '81070-440', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1319, 'Campo Mourão', 'Alice Alves de Macena', 'Jardim Santa Nilce II', '87308-205', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1320, 'Almirante Tamandaré', 'Alice de Siqueira', 'Jardim do Rocio', '83502-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1321, 'São José dos Pinhais', 'Alice dos Santos Ferreira', 'Guatupê', '83060-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1322, 'Curitiba', 'Alice Furlametto Moret', 'Tatuquara', '81470-025', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1323, 'Londrina', 'Alice Mattar Khater', 'Catuai', '86086-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1324, 'São José dos Pinhais', 'Alice Nascimento Sbrissia', 'Ipê', '83055-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1325, 'Londrina', 'Alice Pereira de Andrade Fernandes', 'Jardim Neman Sahyun', '86041-256', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1326, 'Curitiba', 'Alice Pilotto', 'Mossunguê', '81200-105', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1327, 'São José dos Pinhais', 'Alice Sperling da Cruz', 'Centro', '83005-140', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1328, 'Londrina', 'Alice Sumiko Kajyma', 'Antares', '86036-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1329, 'Curitiba', 'Alice Vauthier Macedo', 'Cidade Industrial', '81350-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1330, 'Curitiba', 'Alice Vilas Boas da Conceição', 'Uberaba', '81590-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1331, 'Cambé', 'Alício Francisco Mafra', 'Jardim Tarobá', '86191-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1332, 'Araucária', 'Alício Machado Borba', 'Vila Nova', '83703-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1333, 'São José dos Pinhais', 'Alifranci Celestino da Silva', 'Planta Quississana', '83085-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1334, 'Curitiba', 'Aline Cordeiro Parigot de Souza', 'Alto da Rua XV', '80050-680', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1335, 'Almirante Tamandaré', 'Alino Ignacio Martins', 'Vila Ajambi', '83504-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1336, 'Londrina', 'Alinor Elias', 'Giovani Lunardelli', '86037-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1337, 'Londrina', 'Aliomar Baleeiro', 'Sebastião de Melo César', '86084-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1338, 'Curitiba', 'Alípia Marques Verchai', 'Portão', '80610-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1339, 'Londrina', 'Alípio Correia Leite Júnior', 'San Conrado', '86038-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1340, 'Colombo', 'Alípio da Silva', 'Vila Maria do Rosário', '83413-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1341, 'Colombo', 'Alípio de Mello Falavinha', 'Jardim Panorama', '83412-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1342, 'Cascavel', 'Alípio de Souza Leal', '14 de Novembro', '85804-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1343, 'Curitiba', 'Alípio Domingues', 'Campo Comprido', '81200-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1344, 'Paranaguá', 'Alípio dos Santos', 'Serraria do Rocha', '83221-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1345, 'Paranaguá', 'Alípio dos Santos', 'Estradinha', '83206-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1346, 'Guarapuava', 'Alípio Marcondes', 'Bonsucesso', '85055-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1347, 'Londrina', 'Alípio Martins Estevan', 'São Vicente', '86046-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1348, 'Londrina', 'Alípio Pereira da Silva', 'Conjunto Professora Hilda Mandarino', '86080-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1349, 'Curitiba', 'Alípio Schamne', 'Uberaba', '81570-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1350, 'Curitiba', 'Alípio Texeira de Moraes', 'Barreirinha', '82710-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1351, 'Curitiba', 'Alírio Pencai', 'Xaxim', '81820-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1352, 'Londrina', 'Allan Kardec', 'Califórnia', '86040-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1353, 'Maringá', 'Allan Kardec', 'Parque Avenida', '87025-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1354, 'Almirante Tamandaré', 'Allan Kardec', 'Jardim Monterrey', '83507-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1355, 'Curitiba', 'Allan Kardec', 'Bom Retiro', '80520-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1356, 'Toledo', 'Allan Kardek', 'Jardim Paraná', '85902-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1357, 'Colombo', 'Allan Kardek', 'Jardim Campo Alto', '83408-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1358, 'Foz do Iguaçu', 'Almada', 'Jardim Amazonas', '85857-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1359, 'Arapongas', 'Alma-de-mestre', 'Conjunto Padre Bernardo Merckel', '86706-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1360, 'Ponta Grossa', 'Almadina', 'Neves', '84021-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1361, 'Ponta Grossa', 'Almadio Diniz', 'Oficinas', '84045-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1362, 'Londrina', 'Almeida Garret', 'São Jorge', '86047-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1363, 'Ponta Grossa', 'Almeida Garret', 'Oficinas', '84036-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1364, 'Foz do Iguaçu', 'Almeida Júnior', 'Jardim Bandeirantes', '85862-448', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1365, 'Umuarama', 'Almeida Júnior', 'Parque Industrial I', '87507-058', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1366, 'Curitiba', 'Almeida Júnior', 'Guabirotuba', '81510-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1368, 'Londrina', 'Almênio Correia Lemos Neto', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1369, 'Apucarana', 'Almerindo Chabude David', 'Jardim Catuaí III', '86802-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1370, 'Curitiba', 'Almerindo Pereira da Silva', 'Santa Felicidade', '82020-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1371, 'Curitiba', 'Almerio Erivan Swarowski', 'Novo Mundo', '81050-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1372, 'Curitiba', 'Almezina Eugênia Ferreira', 'Cidade Industrial', '81460-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1373, 'Toledo', 'Almir Gasperin', 'Jardim La Salle', '85903-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1374, 'Foz do Iguaçu', 'Almir Machado Nunes', 'Jardim São Paulo II', '85856-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1375, 'Curitiba', 'Almir Nelson de Almeida', 'Campo Comprido', '81230-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1376, 'Campo Largo', 'Almir Pereira dos Santos', 'Jardim Florestal', '83602-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1377, 'Curitiba', 'Almir Trova de Oliveira', 'Jardim das Américas', '81530-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1378, 'Londrina', 'Almira de Carvalho Campitelli', 'Jardim Alphaville', '86084-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1379, 'São José dos Pinhais', 'Almirante Alexandrino', 'Afonso Pena', '83050-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1380, 'São José dos Pinhais', 'Almirante Alexandrino', 'Afonso Pena', '83045-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1381, 'São José dos Pinhais', 'Almirante Alexandrino', 'Afonso Pena', '83040-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1382, 'Foz do Iguaçu', 'Almirante Barroso', 'Centro', '85851-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1383, 'Londrina', 'Almirante Barroso', 'Nova', '86015-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1384, 'Guarapuava', 'Almirante Barroso', 'Vila Carli', '85040-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1385, 'Paranavaí', 'Almirante Barroso', 'Jardim São Jorge', '87711-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1386, 'Piraquara', 'Almirante Barroso', 'Jardim Bela Vista', '83301-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1387, 'Ponta Grossa', 'Almirante Barroso', 'Uvaranas', '84020-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1388, 'Toledo', 'Almirante Barroso', 'Centro', '85900-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1389, 'Toledo', 'Almirante Barroso', 'Jardim Planalto', '85905-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1390, 'Almirante Tamandaré', 'Almirante Barroso', 'Vila Grécia', '83502-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1391, 'Cambé', 'Almirante Barroso', 'Vila Guarani', '86182-050', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1392, 'Curitiba', 'Almirante Barroso', 'São Francisco', '80510-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1393, 'Ponta Grossa', 'Almirante Cochrane', 'Oficinas', '84036-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1394, 'Londrina', 'Almirante Crocane', 'Califórnia', '86040-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1395, 'Ponta Grossa', 'Almirante Custódio de Mello', 'Centro', '84010-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1396, 'Guarapuava', 'Almirante Didio Costa', 'Alto da XV', '85065-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1397, 'Guarapuava', 'Almirante Didio Costa', 'Santana', '85070-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1398, 'Curitiba', 'Almirante Didio Costa', 'Jardim das Américas', '81540-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1399, 'Curitiba', 'Almirante Donadello', 'Alto Boqueirão', '81850-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1400, 'Ponta Grossa', 'Almirante Fernando de Noronha', 'Oficinas', '84040-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1401, 'Curitiba', 'Almirante Gonçalves', 'Rebouças', '80230-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1402, 'Curitiba', 'Almirante Gonçalves', 'Rebouças', '80215-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1403, 'Curitiba', 'Almirante Gonçalves', 'Rebouças', '80250-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1404, 'São José dos Pinhais', 'Almirante Pedro Álvares Cabral', 'Boneca do Iguaçu', '83040-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1405, 'Foz do Iguaçu', 'Almirante Tamandaré', 'Centro', '85851-330', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1406, 'Laranjeiras do Sul', 'Almirante Tamandaré', 'Getúlio Vargas', '85304-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1407, 'Guarapuava', 'Almirante Tamandaré', 'Alto Cascavel', '85031-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1408, 'Londrina', 'Almirante Tamandaré', 'Zelina', '86015-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1409, 'Ponta Grossa', 'Almirante Tamandaré', 'Ronda', '84051-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1410, 'Paranavaí', 'Almirante Tamandaré', 'Jardim São Jorge', '87711-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1411, 'São José dos Pinhais', 'Almirante Tamandaré', 'Braga', '83020-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1412, 'Paranaguá', 'Almirante Tamandaré', 'Centro Histórico', '83203-220', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1413, 'Toledo', 'Almirante Tamandaré', 'Conjunto Residencial Rossani', '85901-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1414, 'Toledo', 'Almirante Tamandaré', 'Centro', '85900-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1415, 'Almirante Tamandaré', 'Almirante Tamandaré', 'Jardim Valma', '83507-450', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1416, 'Colombo', 'Almirante Tamandaré', 'Boichininga', '83414-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1417, 'Almirante Tamandaré', 'Almirante Tamandaré', 'Jardim Buenos Aires', '83507-266', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1418, 'Curitiba', 'Almirante Tamandaré', 'Alto da Rua XV', '80050-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1419, 'Curitiba', 'Almirante Tamandaré', 'Alto da Rua XV', '80040-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1420, 'Ponta Grossa', 'Almirante Wandencolk', 'Uvaranas', '84020-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1421, 'Ponta Grossa', 'Almiro Escobar', 'Contorno', '84052-490', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1422, 'Ponta Grossa', 'Alnary Nunes Rocha', 'Estrela', '84050-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1423, 'Curitiba', 'Alodir Dalla Marta', 'Uberaba', '81590-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1424, 'Cascavel', 'Alois Bartinik', 'Brasmadeira', '85813-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1425, 'Pinhais', 'Alois Ervino Krelling', 'Jardim Cláudia', '83326-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1426, 'Toledo', 'Aloísio Anschau', 'Jardim Anápolis', '85905-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1427, 'Londrina', 'Aloísio Gomes de Sá', 'Residencial José B Almeida', '86041-817', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1428, 'Araucária', 'Aloízio Lins', 'Tindiquera', '83708-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1429, 'Londrina', 'Alonso de Ojeda', 'Tomy', '86036-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1430, 'Londrina', 'Alonso Dias Aro', 'Catuai', '86086-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1431, 'Curitiba', 'Alonso Peres Munhoz', 'Campo Comprido', '81240-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1432, 'Curitiba', 'Alozi Donainski', 'Barreirinha', '82220-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1433, 'Toledo', 'Alperico Donin', 'Coopagro', '85903-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1434, 'Pinhais', 'Alphaville', 'Loteamento Alphaville Graciosa', '83327-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1435, 'Curitiba', 'Alphonse Daudet', 'Uberaba', '81570-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1436, 'Cambé', 'Alpineu Dutra de Souza', 'Jardim Santo André', '86185-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1437, 'Apucarana', 'Alta Gracia Hanna Chemouni', 'Jardim Marissol', '86807-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1438, 'São José dos Pinhais', 'Altair Bher', 'Guatupê', '83060-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1439, 'São José dos Pinhais', 'Altair Pereira Barusso', 'Afonso Pena', '83045-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1440, 'Paranaguá', 'Altair Porto Martineli', 'Vila Paranaguá', '83221-049', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1441, 'Curitiba', 'Altair Probst', 'Santa Felicidade', '82015-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1442, 'Ponta Grossa', 'Altamir Starke', 'Contorno', '84060-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1443, 'Foz do Iguaçu', 'Altamira', 'Loteamento Lindóia', '85856-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1444, 'Guarapuava', 'Altamira', 'Boqueirão', '85020-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1445, 'Pato Branco', 'Altamira', 'Bonatto', '85506-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1446, 'Curitiba', 'Altamiro Beviláqua', 'Alto Boqueirão', '81850-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1447, 'Foz do Iguaçu', 'Altamiro Carrilho', 'Jardim Central', '85864-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1448, 'Curitiba', 'Altamiro Machado', 'São Braz', '82015-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1449, 'Guarapuava', 'Altayr Cyro Gubert', 'Vila Bela', '85027-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1450, 'Londrina', 'Altemar Dutra', 'Conjunto Vivi Xavier', '86082-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1451, 'Curitiba', 'Altemar Dutra', 'Tatuquara', '81470-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1452, 'Cascavel', 'Altemar Dutra', 'Brasília', '85815-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1453, 'Curitiba', 'Altemo Bastos Ferreira', 'Cidade Industrial', '81315-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1454, 'Curitiba', 'Altenêncio Gabardo', 'Campina do Siqueira', '80740-105', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1455, 'Cascavel', 'Altério Sordi', 'Presidente', '85818-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1456, 'Curitiba', 'Alterosa', 'Bairro Alto', '82840-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1457, 'Curitiba', 'Altevir Baptista de Lara', 'Barreirinha', '82710-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1458, 'Curitiba', 'Altevir Bassetti', 'Seminário', '80440-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1459, 'Curitiba', 'Altevir Borges', 'Sítio Cercado', '81900-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1460, 'Colombo', 'Altevir Ceccon', 'Jardim das Oliveiras', '83407-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1461, 'São José dos Pinhais', 'Altevir de Lara', 'Afonso Pena', '83045-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1462, 'Curitiba', 'Altevir de Souza Gonçalves', 'Bacacheri', '82600-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1463, 'Curitiba', 'Altevir Ramos de Proença', 'Barreirinha', '82650-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1464, 'Curitiba', 'Althair David de Freitas', 'Cidade Industrial', '81230-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1465, 'Curitiba', 'Altilina de Oliveira Teixeira', 'Atuba', '82860-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1466, 'Paranavaí', 'Altino Alonso', 'Jardim Paraíso', '87707-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1467, 'Curitiba', 'Altino Alves Cordeiro', 'Alto Boqueirão', '81850-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1468, 'Paranavaí', 'Altino da Silva Azeredo', 'Jardim Alvorada do Sul', '87707-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1469, 'Cambé', 'Altino Gorni', 'Jardim Santa Adelaide', '86192-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1470, 'Curitiba', 'Altino Lemos da Silveira', 'Tatuquara', '81470-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1471, 'Piraquara', 'Altivir Schuli de Aguiar', 'Vila Rosa', '83304-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1472, 'Colombo', 'Altivo de Oliveira Gomes Júnior', 'Jardim Guaraituba', '83410-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1473, 'Maringá', 'Alto Curti', 'Jardim América', '87045-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1474, 'Londrina', 'Alto do Araxá', 'Andrade', '86061-070', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1475, 'Maringá', 'Alto Maringá', 'Jardim Kosmos', '87070-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1476, 'Foz do Iguaçu', 'Alto Palmares', 'Jardim Ipanema', '85862-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1477, 'Piraquara', 'Alto Paraíba', 'Jardim Tropical', '83314-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1478, 'Pinhais', 'Alto Paraná', 'Jardim Atuba I', '83326-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1479, 'Ponta Grossa', 'Alto Paraná', 'Nova Rússia', '84053-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1480, 'Pinhais', 'Alto Paraná', 'Jardim Pedro Demeterco', '83324-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1481, 'Pinhais', 'Alto Paraná', 'Planta Portal da Serra', '83325-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1482, 'Telêmaco Borba', 'Alto Paraná', 'Área 06', '84271-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1483, 'Guarapuava', 'Alto Piquiri', 'Boqueirão', '85023-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1484, 'São José dos Pinhais', 'Alto Piquiri', 'Braga', '83020-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1485, 'Colombo', 'Alto Piquiri', 'Jardim São José', '83410-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1486, 'Laranjeiras do Sul', 'Alto São João', 'Vila Industrial', '85303-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1487, 'Guarapuava', 'Altônia', 'Boqueirão', '85023-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1488, 'Londrina', 'Altônia', 'Champagnat', '86062-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1489, 'Pinhais', 'Altônia', 'Jardim Pedro Demeterco', '83324-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1490, 'Telêmaco Borba', 'Altônia', 'Alto das Oliveiras', '84266-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1491, 'Campo Mourão', 'Altônia', 'Conjunto Habitacional Parigot de Souza', '87310-608', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1492, 'Curitiba', 'Altônia', 'Alto Boqueirão', '81830-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1493, 'Foz do Iguaçu', 'Aluísio Azevedo', 'Jardim Jupira', '85865-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1494, 'Francisco Beltrão', 'Aluísio de Azevedo', 'São Miguel', '85602-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1495, 'Guarapuava', 'Aluísio de Azevedo', 'São Cristóvão', '85060-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1496, 'Pinhais', 'Aluísio de Azevedo', 'Núcleo Colonial de Pinhais', '83321-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1497, 'Ponta Grossa', 'Aluísio de Azevedo', 'Olarias', '84035-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1498, 'Cascavel', 'Aluísio de Azevedo', 'Alto Alegre', '85805-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1499, 'Colombo', 'Aluísio de Azevedo', 'Planta Santa Úrsula', '83405-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1500, 'Foz do Iguaçu', 'Aluisio Ferreira Souza', 'Jardim Florença', '85867-489', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1501, 'Foz do Iguaçu', 'Aluísio Ferreira Souza', 'Jardim Florença', '85867-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1502, 'Curitiba', 'Aluízio de Azevedo', 'Abranches', '82220-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1503, 'Paranaguá', 'Aluízio Ferreira de Abreu', 'Eldorado', '83206-326', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1504, 'Curitiba', 'Aluízio Finzetto', 'Prado Velho', '80215-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1505, 'Curitiba', 'Aluízio Plombon', 'Santa Felicidade', '82015-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1506, 'Londrina', 'Alumínio', 'Jardim São Francisco de Assis', '86067-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1507, 'Apucarana', 'Alumínio', 'Parque Industrial Zona Norte', '86806-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1508, 'Londrina', 'Alvarenga Peixoto', 'Lago Parque', '86015-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1509, 'Ponta Grossa', 'Alvarenga Peixoto', 'Cará-cará', '84033-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1510, 'Cambé', 'Alvarenga Peixoto', 'Parque Residencial Manela', '86185-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1511, 'Guarapuava', 'Álvares de Azevedo', 'Vila Bela', '85025-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1512, 'São José dos Pinhais', 'Álvares de Azevedo', 'Colônia Rio Grande', '83025-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1513, 'Ponta Grossa', 'Álvares de Azevedo', 'Ronda', '84051-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1514, 'Curitiba', 'Álvares de Azevedo', 'Cidade Industrial', '81250-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1515, 'Curitiba', 'Alvarez de Azevedo', 'Cidade Industrial', '81260-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1516, 'Londrina', 'Álvaro Aloysio de Freitas', 'Parque ABC 2', '86060-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1517, 'Ponta Grossa', 'Álvaro Alvim', 'Jardim Carvalho', '84016-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1518, 'Curitiba', 'Álvaro Alvin', 'Seminário', '80740-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1519, 'Curitiba', 'Álvaro Andrade', 'Portão', '80610-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1520, 'Curitiba', 'Álvaro Bello Sovinski', 'Xaxim', '81710-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1521, 'Curitiba', 'Álvaro Botelho', 'Bacacheri', '82515-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1522, 'Londrina', 'Álvaro Camello de Aguiar', 'Jardim Alphaville', '86084-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1523, 'Guarapuava', 'Álvaro Castanho do Valle', 'Jardim das Américas', '85030-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1524, 'Castro', 'Álvaro de Mello Kiel', 'Jardim das Araucárias', '84174-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1525, 'Paranaguá', 'Álvaro de Souza Vianna', 'Raia', '83203-795', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1526, 'Curitiba', 'Álvaro Eugênio Ponestk', 'Cidade Industrial', '81305-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1527, 'Londrina', 'Álvaro Ferreira Luz', 'Assis', '86085-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1528, 'Londrina', 'Alvaro Godoy', 'São Lourenço', '86043-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1529, 'Londrina', 'Álvaro Grotti', 'Jardim Barcelona', '86073-349', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1530, 'Ponta Grossa', 'Álvaro Holzmann', 'Boa Vista', '84070-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1531, 'Curitiba', 'Álvaro José da Costa', 'Fazendinha', '81330-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1532, 'Araucária', 'Álvaro Linhares Ehlke', 'Sabiá', '83708-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1533, 'Londrina', 'Álvaro Loureiro', 'Giovani Lunardelli', '86037-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1534, 'Curitiba', 'Álvaro Maravalhas', 'Cidade Industrial', '81270-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1535, 'Curitiba', 'Álvaro Moleta', 'Pilarzinho', '82110-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1536, 'Pinhais', 'Álvaro Muhlenhoff', 'Conjunto Residencial Áquila', '83326-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1537, 'Piraquara', 'Álvaro Muhlenhoff', 'Planta Santa Clara', '83306-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1538, 'Laranjeiras do Sul', 'Álvaro Natel de Camargo', 'São Francisco', '85303-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1539, 'Laranjeiras do Sul', 'Álvaro Natel de Camargo', 'Centro', '85301-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1540, 'Laranjeiras do Sul', 'Álvaro Natel de Camargo', 'Água Verde', '85302-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1541, 'Cascavel', 'Álvaro Palma', 'Santa Cruz', '85806-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1542, 'Curitiba', 'Álvaro Ramos', 'Centro Cívico', '80530-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1543, 'São José dos Pinhais', 'Álvaro Rey Poplade', 'Guatupê', '83060-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1544, 'Curitiba', 'Álvaro Ronaldo de Barros Martins', 'Cidade Industrial', '81230-399', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1545, 'Curitiba', 'Álvaro Silva Abelardino', 'Pinheirinho', '81820-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1546, 'Curitiba', 'Álvaro Vardanega', 'Portão', '80330-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1547, 'Foz do Iguaçu', 'Alverina Dias', 'Jardim Porto Belo', '85867-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1548, 'Apucarana', 'Alves', 'Jardim Ponta Grossa', '86805-070', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1549, 'Curitiba', 'Alvim Jareski', 'Cidade Industrial', '81315-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1550, 'Curitiba', 'Alvin Tiboni', 'Cidade Industrial', '81460-166', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1551, 'São José dos Pinhais', 'Alvino Buhrer Machado', 'Braga', '83020-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1552, 'Curitiba', 'Alvino Carlos de Sousa', 'Barreirinha', '82700-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1553, 'Campo Largo', 'Alvino de Quadros', 'Vila Santa Terezinha', '83602-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1554, 'Maringá', 'Alvino Honorato de Almeida', 'Jardim Ivemar', '87065-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1555, 'São José dos Pinhais', 'Alvino M. do Nascimento', 'Braga', '83020-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1556, 'Londrina', 'Alvino Marco Pereira', 'Cafezal', '86045-485', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1557, 'Foz do Iguaçu', 'Alvino Neumann', 'Loteamento Parque do Patriarco', '85854-517', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1558, 'Foz do Iguaçu', 'Alvino Ziemann', 'Parque Morumbi I', '85858-645', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1559, 'Curitiba', 'Alvir Teixeira dos Santos', 'Sítio Cercado', '81920-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1560, 'Laranjeiras do Sul', 'Alvise Hélio Fae', 'São Francisco', '85303-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1561, 'Londrina', 'Alviza Cavalhieri', 'Dom Pedro I', '86089-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1562, 'Londrina', 'Alvizio Jarreta', 'Cafezal 1', '86049-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1563, 'Francisco Beltrão', 'Alvorada', 'Alvorada', '85601-075', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1564, 'Londrina', 'Alvorada', 'Recreio', '86025-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1565, 'Guarapuava', 'Alvorada', 'Vila Bela', '85025-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1566, 'São José dos Pinhais', 'Alvorada', 'Guatupê', '83060-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1567, 'Toledo', 'Alvorada', 'Conjunto Residencial Rossani', '85901-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1568, 'Campo Mourão', 'Alvorada', 'Jardim Lar Paraná', '87305-370', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1569, 'Almirante Tamandaré', 'Alvorada', 'Jardim Apucarana', '83505-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1570, 'Cascavel', 'Alvorada', 'Brasmadeira', '85814-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1571, 'Colombo', 'Alvorada', 'Jardim São José', '83410-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1572, 'Curitiba', 'Alvorada', 'Guabirotuba', '81510-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1573, 'Ponta Grossa', 'Alvorada do Sul', 'Chapada', '84062-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1574, 'São José dos Pinhais', 'Alvorada do Sul', 'Boneca do Iguaçu', '83040-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1575, 'Pinhais', 'Alvorada do Sul', 'Jardim Pedro Demeterco', '83324-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1576, 'Telêmaco Borba', 'Alvorada do Sul', 'Jardim União', '84266-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1577, 'São José dos Pinhais', 'Alvorecer', 'Guatupê', '83060-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1578, 'Apucarana', 'Alzemiro Bassi', 'Núcleo Habitacional Marcos Freire', '86805-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1579, 'Guarapuava', 'Alzemiro Delgado', 'Boqueirão', '85020-708', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1580, 'Ponta Grossa', 'Alzemiro Lopes', 'Contorno', '84052-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1581, 'Colombo', 'Alzenir Toldo', 'Jardim Palmares', '83412-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1582, 'Maringá', 'Alzimeire Pires Milani', 'Parque das Laranjeiras', '87083-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1583, 'Guarapuava', 'Alzino Carazzai', 'Primavera', '85050-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1584, 'Paranaguá', 'Alzira Andrade Dutra', 'Parque São João', '83212-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1585, 'São José dos Pinhais', 'Alzira Berton Pauletto', 'Miringuava', '83090-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1586, 'Pinhais', 'Alzira de Araújo Souza', 'Conjunto Residencial Áquila', '83326-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1587, 'Toledo', 'Alzira Gonçalves Arruda', 'Residencial Santa Clara', '85908-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1588, 'Colombo', 'Alzira Lovato Bontorin', 'Jardim Monza', '83406-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1589, 'São José dos Pinhais', 'Alzira Miranda Koerbel', 'Afonso Pena', '83045-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1590, 'Curitiba', 'Alzira Moraes Pinheiro Machado', 'São Braz', '82015-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1591, 'Curitiba', 'Alzira Neves Garcez', 'Cajuru', '82950-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1592, 'Londrina', 'Alzira Postali Gewehr', 'Aquilles Sthengel', '86086-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1593, 'Maringá', 'Alziro Segantin Filho', 'Jardim Alamar', '87014-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1594, 'Londrina', 'Alziro Zarur', 'San Conrado', '86038-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1595, 'Foz do Iguaçu', 'Alziro Zarur', 'Jardim São Paulo II', '85856-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1596, 'Paranaguá', 'Alziro Zarur', 'Eldorado', '83206-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1597, 'Maringá', 'Alziro Zarur', 'Conjunto Residencial Ney Braga', '87075-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1598, 'Maringá', 'Alziro Zarur', 'Vila Vardelina', '87080-590', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1599, 'Ponta Grossa', 'Alziro Zarur', 'Boa Vista', '84071-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1600, 'Castro', 'Alziro Zarur', 'Núcleo Habitacional Padre Piva', '84178-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1601, 'Almirante Tamandaré', 'Alziro Zarur', 'Jardim Monterrey', '83507-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1602, 'Curitiba', 'Alziro Zarur', 'Sítio Cercado', '81910-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1603, 'Curitiba', 'Amábile Célia Zamprogna', 'Tatuquara', '81470-450', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1604, 'Maringá', 'Amábile Giroldo', 'Zona 04', '87014-280', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1605, 'Curitiba', 'Amabile Scaletti', 'Bigorrilho', '80710-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1606, 'Curitiba', 'Amacio Mazzaropi', 'Santa Cândida', '82640-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1607, 'Curitiba', 'Amadeu Alice', 'Tingui', '82620-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1608, 'Curitiba', 'Amadeu Assad Yassim', 'Bacacheri', '82520-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1609, 'Umuarama', 'Amadeu Boggio Merlo', 'Parque Danielle', '87506-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1610, 'Cambé', 'Amadeu Bogio Merlo', 'Vila Salomé', '86192-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1611, 'Piraquara', 'Amadeu Chimim', 'Vila San Remo I', '83301-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1612, 'Curitiba', 'Amadeu Cipriano da Silva', 'Uberaba', '81580-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1613, 'Londrina', 'Amadeu de Giácomo', 'Portal Norte', '86079-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1614, 'Curitiba', 'Amadeu do Amaral', 'Portão', '80330-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1615, 'Cambé', 'Amadeu José de Souza', 'Jardim Riviera', '86187-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1616, 'Guarapuava', 'Amadeu Karpinski Rocha', 'Bonsucesso', '85035-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1617, 'Ponta Grossa', 'Amadeu Maggi', 'Orfãs', '84015-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1618, 'Londrina', 'Amadeu Medeiros Pulin', 'Caravelle', '86039-135', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1619, 'Londrina', 'Amadeu Mortari', 'Helena', '86026-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1620, 'Curitiba', 'Amadeu Natal', 'Santa Cândida', '82650-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1621, 'Telêmaco Borba', 'Amadeu Pereira Malheiros', 'Jardim Bom Jesus', '84262-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1622, 'Colombo', 'Amadeu Perin', 'Boichininga', '83414-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1623, 'Curitiba', 'Amadeu Piotto', 'Cidade Industrial', '81280-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1624, 'Apucarana', 'Amadeu Pires de Camargo', 'Loteamento Domício Scaramello', '86804-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1625, 'Maringá', 'Amadeu Progiante', 'Zona 01', '87013-310', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1626, 'São José dos Pinhais', 'Amadeus Fagundes', 'Afonso Pena', '83050-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1627, 'Londrina', 'Amado Américo da Silva', 'Conjunto Habitacional  Alexandre Urbanas', '86037-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1628, 'Curitiba', 'Amado Henrique Pereira', 'Guabirotuba', '81510-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1629, 'Paranavaí', 'Amador Aguiar', 'Jardim Canadá', '87708-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1630, 'Paranavaí', 'Amador Aguiar', 'Jardim Ipê', '87707-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1631, 'Paranavaí', 'Amador Aguiar', 'Jardim Estrela', '87706-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1632, 'Paranavaí', 'Amador Alves de Oliveira', 'Jardim América', '87705-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1633, 'Londrina', 'Amador Bueno', 'Vila Ipiranga', '86010-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1634, 'Maringá', 'Amador Bueno', 'Conjunto Residencial Itamaraty', '87015-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1635, 'Telêmaco Borba', 'Amador Bueno', 'Centro', '84261-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1636, 'Curitiba', 'Amador Bueno', 'Cajuru', '82960-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1637, 'Castro', 'Amador Felipe Diniz', 'Água Suja', '84165-665', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1638, 'Apucarana', 'Amador Godoy Rodrigues', 'Vila Residencial Malibu', '86812-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1639, 'Apucarana', 'Amagilda Scarpellini Pereira', 'Jardim das Flores V', '86810-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1640, 'Paranaguá', 'Amália de Oliveira Morais', 'Palmital', '83206-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1641, 'Curitiba', 'Amália Ludwig Dubard', 'Cidade Industrial', '81230-418', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1642, 'Colombo', 'Amália Strapasson de Souza', 'Centro Industrial Mauá', '83413-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1643, 'Londrina', 'Amália Tonon Minatti', 'Del Rey', '86045-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1644, 'Curitiba', 'Amália Túlio Costa', 'Santa Felicidade', '82020-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1645, 'Sarandi', 'Amambai', 'Parque Residencial Bela Vista', '87112-257', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1646, 'Umuarama', 'Amambai', 'Zona I-A', '87501-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1647, 'Pato Branco', 'Amambaí', 'Pinheirinho', '85506-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1648, 'Telêmaco Borba', 'Amambaia', 'Vila Monte Belo', '84262-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1649, 'Arapongas', 'Amanaci', 'Jardim Primavera', '86702-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1650, 'Apucarana', 'Amâncio Bueno de Oliveira', 'Vila São Francisco', '86813-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1651, 'Curitiba', 'Amâncio Moro', 'Alto da Glória', '80030-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1652, 'Ponta Grossa', 'Amanda Cunha Souza', 'Boa Vista', '84072-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1653, 'Toledo', 'Amanda Schoennel', 'Conjunto Habitacional São Francisco', '85915-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1654, 'Arapongas', 'Amandina', 'Conjunto Centauro', '86709-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1655, 'Curitiba', 'Amando Mann', 'Mercês', '80430-010', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1656, 'Ponta Grossa', 'Amante Garcia', 'Jardim Carvalho', '84015-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1657, 'Ponta Grossa', 'Amantino Antunes', 'Jardim Carvalho', '84016-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1658, 'Ponta Grossa', 'Amantino Antunes Mendes', 'Contorno', '84060-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1659, 'Maringá', 'Amantino Clementino Ferreira', 'Conjunto João de Barro I', '87053-135', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1660, 'Curitiba', 'Amantino de Barros Teixeira', 'Barreirinha', '82210-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1661, 'Londrina', 'Amantino Honorato de Carvalho', 'Jardim Acapulco', '86045-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1662, 'Curitiba', 'Amantino Martins', 'Barreirinha', '82700-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1663, 'Almirante Tamandaré', 'Amantino Pereira de Azevedo', 'Jardim Santa Rita de Cássia', '83506-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1664, 'Londrina', 'Amantino Teixeira de Carvalho', 'Centro', '86010-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1665, 'Almirante Tamandaré', 'Amanzor Sales Dias', 'Jardim Parati', '83503-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1666, 'Curitiba', 'Amanzor Soffiatti', 'Cajuru', '82970-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1667, 'Francisco Beltrão', 'Amapá', 'Pinheirinho', '85603-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1668, 'Londrina', 'Amapá', 'Vila Filipin', '86026-450', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1669, 'Guarapuava', 'Amapá', 'Boqueirão', '85023-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1670, 'Londrina', 'Amapá', 'Vila Filipin', '86026-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1671, 'Foz do Iguaçu', 'Amapá', 'Centro', '85851-075', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1672, 'Piraquara', 'Amapá', 'Jardim dos Estados 2', '83308-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1673, 'Pato Branco', 'Amapá', 'Pinheirinho', '85506-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1674, 'Paranavaí', 'Amapá', 'Centro', '87704-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1675, 'Paranavaí', 'Amapá', 'Centro', '87703-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1676, 'São José dos Pinhais', 'Amapá', 'Águas Belas', '83010-590', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1677, 'Paranavaí', 'Amapá', 'Centro', '87705-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1678, 'Telêmaco Borba', 'Amapá', 'Vila Santa Rita', '84263-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1679, 'Umuarama', 'Amapá', 'Zona V', '87504-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1680, 'Campo Largo', 'Amapá', 'Vila Itaqui', '83604-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1681, 'Araucária', 'Amapá', 'Iguaçu', '83701-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1682, 'Cascavel', 'Amapá', 'São Cristóvão', '85816-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1683, 'Colombo', 'Amapá', 'Jardim Jalisco', '83404-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1684, 'Guarapuava', 'Amapora', 'Dos Estados', '85035-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1685, 'Pinhais', 'Amapora', 'Jardim Pedro Demeterco', '83324-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1686, 'Telêmaco Borba', 'Amapora', 'Jardim União', '84266-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1687, 'Guarapuava', 'Amaral Pinheiro', 'Batel', '85015-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1688, 'Ponta Grossa', 'Amaranto Coutinho', 'Colônia Dona Luiza', '84043-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1689, 'Cascavel', 'Amarela', 'Brasília', '85815-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1690, 'Curitiba', 'Amarildo Dalazuana', 'Umbará', '81930-625', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1691, 'Cascavel', 'Amarildo Passos', 'Santa Cruz', '85806-107', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1692, 'Londrina', 'Amarílio Bicalho', 'Jardim Burle Marx', '86047-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1693, 'Campo Mourão', 'Amarilis', 'Jardim Modelo', '87309-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1694, 'Araucária', 'Amarílis', 'Campina da Barra', '83709-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1695, 'Curitiba', 'Amaro de Santa Rita', 'Fanny', '81030-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1696, 'Londrina', 'Amaro Romeu Ramalho', 'Helena', '86027-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1697, 'Umuarama', 'Amaro Tavares', 'Parque Bandeirantes', '87504-688', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1698, 'Umuarama', 'Amaro Tavarez', 'Jardim Cruzeiro', '87504-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1699, 'Maringá', 'Amauracy Cruz de Oliveira', 'Jardim Cerro Azul', '87010-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1700, 'Curitiba', 'Amauri Lange Silvério', 'Pilarzinho', '82120-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1701, 'Curitiba', 'Amauri Mauad Guerios', 'Uberaba', '81560-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1702, 'Curitiba', 'Amauri Petersen', 'Cidade Industrial', '81305-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1703, 'Curitiba', 'Amaury Gabriel Grassi Mattei', 'Santo Inácio', '82010-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1704, 'Paranavaí', 'Amazília Francisca de Oliveira Leite', 'Jardim Canadá', '87708-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1705, 'Campo Largo', 'Amazílio Lavall', 'Jardim Florestal', '83602-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1706, 'Londrina', 'Amazonas', 'Centro', '86026-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1707, 'Francisco Beltrão', 'Amazonas', 'Pinheirinho', '85603-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1708, 'Guarapuava', 'Amazonas', 'Bonsucesso', '85035-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1709, 'Foz do Iguaçu', 'Amazonas', 'Loteamento Campos do Iguaçu', '85857-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1710, 'Londrina', 'Amazonas', 'Centro', '86026-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1711, 'Paranavaí', 'Amazonas', 'Jardim Vera Cruz', '87702-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1712, 'Maringá', 'Amazonas', 'Jardim Alvorada', '87033-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1713, 'São José dos Pinhais', 'Amazonas', 'Silveira da Motta', '83030-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1714, 'Paranavaí', 'Amazonas', 'Centro', '87701-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1715, 'Paranaguá', 'Amazonas', 'Vila do Povo', '83209-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1716, 'Piraquara', 'Amazonas', 'Jardim dos Estados 2', '83308-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1717, 'Piraquara', 'Amazonas', 'Jardim dos Estados 3', '83307-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1718, 'Piraquara', 'Amazonas', 'Jardim dos Estados 1', '83308-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1719, 'Paranavaí', 'Amazonas', 'Jardim Novo Horizonte', '87711-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1720, 'Ponta Grossa', 'Amazonas', 'Estrela', '84040-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1721, 'Toledo', 'Amazonas', 'Jardim Porto Alegre', '85906-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1722, 'Sarandi', 'Amazonas', 'Parque Residencial Nova Aliança', '87111-720', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1723, 'Umuarama', 'Amazonas', 'Zona II', '87501-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1724, 'Telêmaco Borba', 'Amazonas', 'Nossa Senhora de Fátima', '84264-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1725, 'Apucarana', 'Amazonas', 'Jardim Ponta Grossa', '86804-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1726, 'Cascavel', 'Amazonas', 'São Cristóvão', '85813-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1727, 'Araucária', 'Amazonas', 'Iguaçu', '83701-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1728, 'Colombo', 'Amazonas', 'Jardim Jalisco', '83404-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1729, 'Campo Largo', 'Amazonas', 'Vila Itaqui', '83604-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1730, 'Curitiba', 'Amazonas', 'Água Verde', '80610-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1731, 'Curitiba', 'Amazonas de Souza Azevedo', 'Bacacheri', '82520-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1732, 'Guarapuava', 'Amazonas Ferreira Caldas', 'Morro Alto', '85067-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1733, 'Cascavel', 'Amazônia', 'Santa Cruz', '85806-106', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1734, 'Ponta Grossa', 'Amazonita', 'Neves', '84021-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1735, 'Curitiba', 'Amazor Prestes', 'Cidade Industrial', '81460-169', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1736, 'Ponta Grossa', 'Âmbar', 'Neves', '84021-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1737, 'Maringá', 'Âmbar', 'Jardim Brasil', '87083-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1738, 'Guarapuava', 'Ambiassy', 'São Cristóvão', '85063-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1739, 'Curitiba', 'Ambiental Aniello Pierri', 'Água Verde', '80620-320', 'Núcleo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1740, 'Londrina', 'Ambrogio Ferro', 'Jardim Alemanha', '86031-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1741, 'Pato Branco', 'Ambrósio Bez', 'Vila Isabel', '85504-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1742, 'Almirante Tamandaré', 'Ambrósio Bini', 'Vila Prosdócimo', '83506-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1743, 'Ponta Grossa', 'Ambrósio Bricailo', 'Chapada', '84062-687', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1744, 'Maringá', 'Ambrósio Bulla', 'Jardim América', '87045-490', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1745, 'Campo Largo', 'Ambrósio Cequinel', 'Vila Rondinha', '83607-070', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1746, 'Campo Largo', 'Ambrósio Cruzara', 'Vila Torres I', '83609-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1747, 'Campo Largo', 'Ambrósio Elias Andreassa', 'Vila Andreassa Miranda', '83605-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1748, 'Londrina', 'Ambrósio Jorge', 'Alto da Boa Vista', '86083-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1749, 'Foz do Iguaçu', 'Ambrósio Losi', 'Loteamento Universitário das Américas', '85870-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1750, 'Curitiba', 'Ambrósio Milton Scuissiatto', 'Fazendinha', '81330-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1751, 'Curitiba', 'Ambrósio Thomazzi', 'Sítio Cercado', '81900-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1752, 'Curitiba', 'Ambrósio Truchem', 'Capão da Imbuia', '82810-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1753, 'Francisco Beltrão', 'Ameixeira', 'São Cristóvão', '85601-356', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1754, 'Foz do Iguaçu', 'Ameixeira', 'Jardim Mônaco', '85862-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1755, 'Londrina', 'Amélia Baptista Rabello', 'Jardim São Jorge', '86082-806', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1756, 'Toledo', 'Amélia Bianca', 'Jardim Paulista', '85909-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1757, 'Londrina', 'Amélia Donega Spoladore', 'Jardim das Palmeiras', '86083-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1758, 'Londrina', 'Amélia Ferreira Marques', 'Santa Mônica', '86079-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1759, 'Toledo', 'Amélia Gasperim Longni', 'Residencial Santa Clara', '85907-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1760, 'Maringá', 'Amélia Henrique', 'Conjunto Habitacional Requião', '87047-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1761, 'Cascavel', 'Amélia Melo Gomes', 'Brasmadeira', '85813-186', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1762, 'Curitiba', 'Amélia Morais Seixas', 'Cidade Industrial', '81450-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1763, 'Londrina', 'Amélia Riskallah Abib Tauil', 'Indústrias Leves', '86030-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1764, 'Curitiba', 'Amélia Rocio dos Santos', 'Cidade Industrial', '81170-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1765, 'Londrina', 'Amélia Santoro', 'Alto da Boa Vista', '86083-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1766, 'Londrina', 'Amélia Venturini Baggio', 'Jardim Imagawa', '86080-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1767, 'Londrina', 'Amélia Wiesel Rose', 'Jardim Piza', '86073-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1768, 'Londrina', 'Amélio Buranello', 'Jardim Alphaville', '86084-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1769, 'Toledo', 'Amélio Tomé', 'Conjunto Habitacional São Francisco', '85915-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1770, 'Curitiba', 'Amenaide Pereira dos Santos', 'Uberaba', '81580-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1771, 'Curitiba', 'Amendoins', 'Uberaba', '81550-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1772, 'Londrina', 'Amendoinzeiro', 'Leonor', '86071-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1773, 'Paranavaí', 'América', 'Parque Morumbi', '87703-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1774, 'Sarandi', 'América', 'Jardim Ana Eliza', '87111-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1775, 'Umuarama', 'América', 'Jardim Kennedy', '87508-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1776, 'Almirante Tamandaré', 'América', 'Jardim Iracema', '83508-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1777, 'Apucarana', 'América', 'Jardim América', '86807-370', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1778, 'Apucarana', 'América', 'Jardim América', '86807-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1779, 'Guarapuava', 'América Central', 'Santana', '85070-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1780, 'Curitiba', 'América da Costa Sabóia', 'Uberaba', '81580-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1781, 'Guarapuava', 'América do Norte', 'Santana', '85070-556', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1782, 'Pinhais', 'América do Norte', 'Vila Irene Margarida', '83323-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1783, 'Guarapuava', 'América do Sul', 'Santana', '85070-557', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1784, 'Pinhais', 'América do Sul', 'Vila Irene', '83323-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1785, 'Curitiba', 'América Latina', 'Cidade Industrial', '81270-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1786, 'Cambé', 'América Mantovani Serra', 'Jardim Boa Vista', '86191-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1787, 'Londrina', 'América Piquete', 'Jardim Maracanã', '86056-865', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1788, 'Maringá', 'Américo Belay', 'Jardim Imperial', '87023-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1789, 'Maringá', 'Américo Belay', 'Parque das Grevíleas', '87025-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1790, 'Maringá', 'Américo Brasiliense', 'Jardim Alvorada', '87033-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1791, 'Maringá', 'Américo Brasiliense', 'Vila Morangueira', '87030-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1792, 'Sarandi', 'Américo Brasiliense', 'Novo Panorama', '87113-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1793, 'Apucarana', 'Américo Comazzi', 'Jardim Aviação', '86812-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1794, 'Curitiba', 'Américo Firmino de Toledo', 'Uberaba', '81580-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1795, 'Apucarana', 'Américo Hegeto', 'Jardim Ouro Verde', '86805-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1796, 'Foz do Iguaçu', 'Américo Jacomino', 'Jardim Naipi', '85853-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1797, 'Maringá', 'Américo Laerte Bigatão', 'Jardim Andrade', '87035-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1798, 'Londrina', 'Américo Lobo', 'Progresso', '86079-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1799, 'Apucarana', 'Américo Lunardelli', 'Barra Funda', '86800-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1800, 'Curitiba', 'Américo Mattei', 'Tarumã', '82800-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1801, 'Curitiba', 'Américo Pasini', 'Cajuru', '82900-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1802, 'Toledo', 'Américo Schio', 'Coopagro', '85903-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1803, 'Ponta Grossa', 'Américo Silvano', 'Oficinas', '84045-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1804, 'Cambé', 'Américo Vendramel', 'Jardim Boa Vista', '86191-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1805, 'Londrina', 'Américo Vespúcio', 'Aeroporto', '86036-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1806, 'Foz do Iguaçu', 'Américo Vespúcio', 'Jardim Oriente', '85855-130', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1807, 'Ponta Grossa', 'Américo Vespúcio', 'Chapada', '84064-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1808, 'Telêmaco Borba', 'Américo Vespúcio', 'Núcleo Bandeirantes', '84269-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1809, 'Curitiba', 'Américo Vespúcio', 'Lindóia', '81010-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1810, 'Foz do Iguaçu', 'Ametista', 'Parque Ouro Verde', '85854-030', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1811, 'Londrina', 'Ametista', 'Waldemar Hauer', '86030-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1812, 'Maringá', 'Ametista', 'Jardim Real', '87083-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1813, 'Ponta Grossa', 'Ametista', 'Neves', '84021-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1814, 'Umuarama', 'Ametista', 'Conjunto Residencial Ouro Branco', '87508-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1815, 'Telêmaco Borba', 'Ametista', 'Núcleo Bandeirantes', '84269-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1816, 'Cambé', 'Ametista', 'Conjunto Habitacional Cristal', '86182-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1817, 'Cascavel', 'Ametista', 'Esmeralda', '85806-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1818, 'Campo Mourão', 'Ametista', 'Jardim Tropical I', '87310-226', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1819, 'Londrina', 'Amianto', 'Ideal', '86030-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1820, 'Umuarama', 'Amiaraci', 'Jardim San Martim', '87508-128', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1821, 'Maringá', 'Amílcar Vecchi', 'Jardim América', '87045-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1822, 'Sarandi', 'Amílcar Vecchi', 'Parque Alvamar', '87113-330', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1823, 'Curitiba', 'Amilcare Bientinezi', 'Pinheirinho', '81150-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1824, 'Curitiba', 'Amilton Dalledone', 'São Lourenço', '82200-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1825, 'Almirante Tamandaré', 'Amilton Ribeiro', 'Jardim Gerhusa', '83502-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1826, 'Paranaguá', 'Amim Mussi', 'Alvorada', '83206-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1827, 'Piraquara', 'Amim Rieche', 'Jardim Bom Jesus dos Passos', '83301-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1828, 'Curitiba', 'Amintas de Barros', 'Centro', '80060-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1829, 'Paranaguá', 'Amintas Pinho', 'Cruzeiro', '83221-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1830, 'Londrina', 'Aminthas de Barros', 'Ipanema', '86015-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1831, 'São José dos Pinhais', 'Amir Ângelo Moss', 'Afonso Pena', '83065-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1832, 'São José dos Pinhais', 'Amir Luiz Stankevecz', 'Ipê', '83055-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1833, 'São José dos Pinhais', 'Amizade', 'Boneca do Iguaçu', '83045-315', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1834, 'Curitiba', 'Amoras', 'Uberaba', '81540-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1835, 'Piraquara', 'Amore', 'Jardim Esmeralda', '83301-375', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1836, 'Francisco Beltrão', 'Amoreira', 'São Cristóvão', '85601-368', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1837, 'Ponta Grossa', 'Amoreira', 'Contorno', '84061-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1838, 'Ponta Grossa', 'Amoreira', 'Uvaranas', '84025-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1839, 'Curitiba', 'Amoroso Costa', 'Jardim das Américas', '81530-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1840, 'Londrina', 'Amor-perfeito', 'Santo Antônio', '86035-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1841, 'Paranaguá', 'Amor-perfeito', 'Conjunto Nilson Neves', '83215-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1842, 'São José dos Pinhais', 'Amor-perfeito', 'Guatupê', '83060-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1843, 'Almirante Tamandaré', 'Amor-perfeito', 'Loteamento Nova Morada', '83504-690', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1844, 'Apucarana', 'Amor-perfeito', 'Jardim das Flores I', '86810-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1845, 'Araucária', 'Amor-perfeito', 'Campina da Barra', '83709-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1846, 'Curitiba', 'Amosis Correia de Freitas', 'Uberaba', '81560-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1847, 'Arapongas', 'Ampelião', 'Vila Rugna', '86705-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1848, 'Foz do Iguaçu', 'Ampére', 'Jardim Ipanema', '85862-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1849, 'Guarapuava', 'Ampére', 'Jardim das Américas', '85031-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1850, 'Francisco Beltrão', 'Ampére', 'Marrecas', '85601-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1851, 'Telêmaco Borba', 'Ampére', 'Alto das Oliveiras', '84266-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1852, 'Colombo', 'Ampére', 'Jardim Guaraituba', '83410-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1853, 'Foz do Iguaçu', 'Amsterdã', 'Jardim Liberdade', '85858-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1854, 'Piraquara', 'Amsterdã', 'Holandez', '83312-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1855, 'Curitiba', 'Amurity Rodrigues', 'Uberaba', '81580-175', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1856, 'Umuarama', 'Amyr Bussmann', 'Parque Cidade Jardim', '87506-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1857, 'Curitiba', 'Ana Alzira Pereira', 'Sítio Cercado', '81925-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1858, 'Curitiba', 'Ana Aparecida Lopos Canet', 'Xaxim', '81710-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1859, 'Ponta Grossa', 'Ana Batista Miró Guimarães', 'Nova Rússia', '84070-270', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1860, 'Paranaguá', 'Ana Belinski Guaske', 'Padre Jackson', '83221-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1861, 'Curitiba', 'Ana Berta Roskamp', 'Jardim das Américas', '81530-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1862, 'Curitiba', 'Ana Betezek', 'Pinheirinho', '81870-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1863, 'Curitiba', 'Ana Biscaia de Andrade', 'Sítio Cercado', '81920-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1864, 'Londrina', 'Ana Cândida Bobroff Daros', 'Conjunto Habitacional José Giordano', '86082-520', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1865, 'Londrina', 'Ana Caputo Piacentini', 'Assis', '86085-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1866, 'Londrina', 'Ana Carneiro Faneco', 'Jardim Nova Esperança', '86044-629', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1867, 'Colombo', 'Ana Couto', 'Jardim Samambaia', '83407-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1868, 'Guarapuava', 'Ana de Rocco', 'Morro Alto', '85065-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1869, 'Curitiba', 'Ana de Souza Frandina', 'Santa Cândida', '82620-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1870, 'Colombo', 'Ana de Souza Johnsson', 'Jardim Nossa Senhora da Penha', '83402-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1871, 'Foz do Iguaçu', 'Ana Dotto Sotelo', 'Jardim Porto Belo', '85867-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1872, 'Araucária', 'Ana Dranka Druszcz', 'Boqueirão', '83704-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1873, 'Sarandi', 'Ana Dvoranen', 'Vera Cruz', '87111-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1874, 'Curitiba', 'Ana Félix Hauser', 'Uberaba', '81590-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1875, 'Londrina', 'Ana Francisca Petri', 'Jardim Honda II', '86076-207', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1876, 'Curitiba', 'Ana Gabardo Negrelli', 'Umbará', '81930-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1877, 'Londrina', 'Ana Gil Queiroz', 'Barbeta', '86078-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1878, 'Ponta Grossa', 'Ana Gnata Borsato', 'Cará-cará', '84032-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1879, 'Colombo', 'Ana Haro Pucci', 'Santa Rita', '83412-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1880, 'Toledo', 'Ana Iamchombeck', 'Conjunto Habitacional São Francisco', '85915-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1881, 'Almirante Tamandaré', 'Ana Imoto', 'Jardim Dona Luiza', '83506-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1882, 'Curitiba', 'Ana Jorge de Oliveira Carvalho', 'Alto Boqueirão', '81770-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1883, 'Curitiba', 'Ana Kotovei', 'Umbará', '81930-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1884, 'Pinhais', 'Ana Kozer', 'Vila Maria Antonieta', '83331-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1885, 'Curitiba', 'Ana Lonardoni Laverde', 'Capão da Imbuia', '82810-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1886, 'Guarapuava', 'Ana Luiza Pielak', 'Primavera', '85053-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1887, 'Guarapuava', 'Ana Luiza Quelin da Silva', 'Boqueirão', '85023-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1888, 'Telêmaco Borba', 'Ana Mari', 'Vila Ana Mari', '84263-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1889, 'Guarapuava', 'Ana Maria Alves de Ramos', 'Cascavel', '85040-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1890, 'Curitiba', 'Ana Maria Foggiatto Roda', 'Sítio Cercado', '81935-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1891, 'Ponta Grossa', 'Ana Maria Jarvis', 'Cará-cará', '84043-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1892, 'Foz do Iguaçu', 'Ana Maria Vera', 'Jardim Evangélico', '85870-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1893, 'Sarandi', 'Ana Martha Faltin', 'Parque Alvamar', '87113-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1894, 'Foz do Iguaçu', 'Ana Martins Smaha', 'Parque Presidente II', '85863-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1895, 'Londrina', 'Ana Melluns', 'Nova Olinda', '86073-335', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1896, 'São José dos Pinhais', 'Ana Moretz Miranda', 'Afonso Pena', '83065-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1897, 'Castro', 'Ana Müller', 'Jardim Bela Vista', '84165-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1898, 'Londrina', 'Ana Murge', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1899, 'Londrina', 'Ana Nardo Pillar', 'João Paz', '86087-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1900, 'Apucarana', 'Ana Neri', 'Jardim Albino Biachi', '86802-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1901, 'Paranavaí', 'Ana Neris', 'Jardim São Jorge', '87711-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1902, 'Maringá', 'Ana Neris', 'Jardim Alvorada', '87035-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1903, 'Sarandi', 'Ana Neris', 'Santa Tereza', '87112-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1904, 'Cascavel', 'Ana Neris', 'Alto Alegre', '85805-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1905, 'Colombo', 'Ana Neris', 'Jardim Nossa Senhora de Fátima', '83405-750', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1906, 'Londrina', 'Ana Nery', 'Nova Londres', '86015-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1907, 'Ponta Grossa', 'Ana Nery', 'Uvaranas', '84020-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1908, 'Toledo', 'Ana Pasqualli', 'Jardim Pasqualli', '85905-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1909, 'Colombo', 'Ana Paula Guarda', 'Centro Industrial Mauá', '83413-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1910, 'Apucarana', 'Ana Pietro F. Machado', 'Núcleo Habitacional José Mercadante', '86804-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1911, 'Londrina', 'Ana Porcina de Almeida', 'Portal de Versalhes 2', '86063-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1912, 'Londrina', 'Ana Prieto Fernandes Machado', 'Conjunto Habitacional  Alexandre Urbanas', '86037-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1913, 'Curitiba', 'Ana Ricardo Cordeiro', 'Umbará', '81930-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1914, 'Ponta Grossa', 'Ana Rita', 'Uvaranas', '84026-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1915, 'Ponta Grossa', 'Ana Rita de Araújo Mendes', 'Uvaranas', '84025-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1916, 'Londrina', 'Ana Rodrigues', 'Parigot de Souza 2', '86082-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1917, 'Cambé', 'Ana Romito Ricieri', 'Jardim Silvino', '86187-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1918, 'Umuarama', 'Ana Rosa de Oliveira', 'Jardim Cruzeiro', '87504-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1919, 'Colombo', 'Ana Rosa Prates', 'Vila Santa Helena', '83406-480', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1920, 'Colombo', 'Ana Rosenente Trevisan', 'Parque Industrial Guaraituba', '83411-119', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1921, 'Araucária', 'Ana Saliba Nassar', 'Boqueirão', '83704-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1922, 'Apucarana', 'Ana Serediuk', 'Loteamento Residencial Parque da Raposa II', '86812-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1923, 'Curitiba', 'Ana Sofia Ribeiro', 'Sítio Cercado', '81935-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1924, 'Londrina', 'Ana Stuart', 'Brasília', '86039-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1925, 'Campo Mourão', 'Ana Teodoro de Lima', 'Jardim Modelo', '87309-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1926, 'Curitiba', 'Ana Tosin', 'Portão', '80330-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1927, 'Arapongas', 'Anacã', 'Vila Nova', '86707-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1928, 'Araucária', 'Anacã', 'Capela Velha', '83706-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1929, 'Curitiba', 'Anacleto Cardoso do Amaral', 'Ganchinho', '81935-327', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1930, 'Maringá', 'Anacleto Luiz de Oliveira', 'Vila Marumby', '87005-127', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1931, 'Cascavel', 'Anaconda', 'Pioneiros Catarinenses', '85805-427', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1932, 'Londrina', 'Anai', 'Antares', '86036-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1933, 'Colombo', 'Anai', 'Jardim Curitiba', '83406-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1934, 'Curitiba', 'Anair Balla', 'Santa Felicidade', '82030-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1935, 'Colombo', 'Anair Bonato Tosin', 'Centro Industrial Mauá', '83413-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1936, 'Londrina', 'Anair Pezarini Correia', 'Avelino A Vieira', '86056-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1937, 'Almirante Tamandaré', 'Anair Tonello Natividade', 'Jardim Arco Íris', '83504-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1938, 'Londrina', 'Anália Franco', 'Brasília', '86039-560', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1939, 'Araucária', 'Anália Gomes Merhy', 'Thomaz Coelho', '83707-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1940, 'Almirante Tamandaré', 'Anália Mendes dos Santos', 'Jardim Campo Verde', '83502-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1941, 'São José dos Pinhais', 'Anália Rosário de Carvalho', 'Braga', '83020-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1942, 'Foz do Iguaçu', 'Anambé', 'Conjunto A', '85866-420', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1943, 'Arapongas', 'Anambé', 'Vila Nova', '86707-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1944, 'Arapongas', 'Anambé-açu', 'Conjunto Centauro', '86709-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1945, 'Arapongas', 'Anambé-branco', 'Jardim Aeroporto', '86702-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1946, 'Arapongas', 'Anambé-de-cauda-curta', 'Vila Triângulo', '86709-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1947, 'Arapongas', 'Anambé-mirim', 'Jardim Colúmbia IV', '86707-825', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1948, 'Curitiba', 'Anambés', 'Cajuru', '82920-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1949, 'Arapongas', 'Anambé-sol', 'Casa Família Arapongas IV', '86709-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1950, 'Arapongas', 'Anambé-una', 'Jardim São Bento', '86706-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1951, 'Arapongas', 'Anambezinho', 'Conjunto Palmares', '86706-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1952, 'Foz do Iguaçu', 'Ananaí', 'Conjunto A', '85866-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1953, 'Arapongas', 'Ananaí', 'Vila Alvorada', '86708-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1954, 'Londrina', 'Ananás', 'Maira', '86035-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1955, 'Londrina', 'Anani', 'Santa Rita 1', '86071-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1956, 'Apucarana', 'Ananias de Oliveira', 'Residencial Parque da Raposa', '86812-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1957, 'Londrina', 'Ananias Fonseca da Silva', 'Cafezal 1', '86049-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1958, 'Umuarama', 'Ananias Pio Teixeira', 'Parque Bandeirantes', '87504-689', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1959, 'Londrina', 'Ananisa Gomes do Prado', 'Conjunto Habitacional José Giordano', '86082-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1960, 'Umuarama', 'Anapólis', 'Conjunto Residencial Córrego Longe', '87504-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1961, 'Foz do Iguaçu', 'Anápolis', 'Jardim Lancaster', '85869-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1962, 'Maringá', 'Anápolis', 'Vila Morangueira', '87040-320', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1963, 'Toledo', 'Anápolis', 'Jardim Anápolis', '85905-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1964, 'Foz do Iguaçu', 'Anapu', 'Vila Militar', '85857-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1965, 'Castro', 'Anario Aquiles', 'Cantagalo', '84178-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1966, 'Curitiba', 'Anastácia Dobrezynski', 'Capão da Imbuia', '82810-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1967, 'Araucária', 'Anastácia Gawleta Dobzenski', 'Costeira', '83708-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1968, 'Francisco Beltrão', 'Anastácia Rosa Lazarotto', 'Nova Petrópolis', '85601-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1969, 'Araucária', 'Anastácio Fizikowski', 'Sabiá', '83708-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1970, 'Curitiba', 'Anastácio Homann', 'Orleans', '82310-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1971, 'Curitiba', 'Anastasia Dobzipiski', 'Barreirinha', '82210-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1972, 'Foz do Iguaçu', 'Anatália Costa Cabral', 'Jardim Califórnia', '85867-508', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1973, 'Londrina', 'Anatólio Michaelowski', 'Jardim Tókio', '86063-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1974, 'Maringá', 'Anchieta', 'Zona 01', '87010-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1975, 'Pato Branco', 'Anchieta', 'São Vicente', '85506-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1976, 'Sarandi', 'Anchieta', 'São José I', '87114-595', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1977, 'Sarandi', 'Anchieta', 'Jardim Independência II', '87113-270', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1978, 'Colombo', 'Anchieta', 'Jardim Santa Helena', '83407-770', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1979, 'Campo Mourão', 'Anchieta', 'Jardim Esperança', '87309-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1980, 'Curitiba', 'Ancião Joaquim dos Santos Neto', 'Cidade Industrial', '81250-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1981, 'Ponta Grossa', 'Andaluzita', 'Neves', '84021-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1982, 'Guarapuava', 'Andaraí', 'São Cristóvão', '85060-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1983, 'Arapongas', 'Andarilho', 'Conjunto Ulisses Guimarães', '86706-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1984, 'Curitiba', 'Anderson de França', 'Umbará', '81930-558', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1985, 'Umuarama', 'Anderson dos Santos Siqueira', 'Jardim Cruzeiro', '87504-588', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1986, 'Curitiba', 'Anderson Juliano Rosa Nascimento', 'Campo de Santana', '81490-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1987, 'Almirante Tamandaré', 'Anderson Paulo Czelusniak', 'Parque Timbu', '83514-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1988, 'Piraquara', 'Anderson Schadlich', 'Guarituba', '83311-317', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1989, 'Cascavel', 'Anderstop', 'Interlagos', '85814-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1990, 'Apucarana', 'Andídio de Souza Nascimento', 'Jardim Colonial II', '86812-547', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1991, 'Londrina', 'Andira', 'Kovalski', '86020-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1992, 'Foz do Iguaçu', 'Andira', 'Jardim Paraná', '85867-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1993, 'Guarapuava', 'Andira', 'Santa Cruz', '85015-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1994, 'Pinhais', 'Andira', 'Planta Portal da Serra', '83325-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1995, 'Ponta Grossa', 'Andira', 'Oficinas', '84036-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1996, 'Pato Branco', 'Andira', 'Santo Antônio', '85507-340', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1997, 'Telêmaco Borba', 'Andira', 'Área 02', '84267-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1998, 'Colombo', 'Andira', 'Jardim Guaraituba', '83410-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (1999, 'Curitiba', 'Andira', 'Pinheirinho', '81880-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2000, 'Sarandi', 'Ando', 'Parque São Pedro', '87112-507', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2001, 'Francisco Beltrão', 'Andorinha', 'Padre Eurico', '85604-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2002, 'Pinhais', 'Andorinha', 'Jardim Fênix', '83326-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2003, 'Araucária', 'Andorinha', 'Capela Velha', '83706-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2004, 'Cambé', 'Andorinha', 'Conjunto Habitacional Waldomiro M Gomes', '86182-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2005, 'Arapongas', 'Andorinha-colar-negro', 'Conjunto Flamingos III', '86703-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2006, 'Arapongas', 'Andorinha-do-campo', 'Jardim Petrópolis', '86709-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2007, 'Arapongas', 'Andorinha-do-rio', 'Parque Industrial III', '86706-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2008, 'Arapongas', 'Andorinha-do-sul', 'Jardim São Carlos', '86704-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2009, 'Arapongas', 'Andorinha-grande', 'Jardim São Rafael', '86703-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2010, 'Foz do Iguaçu', 'Andorinhas', 'Portal da Foz', '85859-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2011, 'Arapongas', 'Andorinhas', 'Centro', '86701-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2012, 'Pinhais', 'Andrade Muricy', 'Planta Núcleo Colonial de Pinhais', '83321-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2013, 'Guarapuava', 'Andrade Neves', 'Trianon', '85012-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2014, 'Guarapuava', 'Andrade Neves', 'Santana', '85070-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2015, 'Guarapuava', 'Andrade Neves', 'Santa Cruz', '85015-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2016, 'Ponta Grossa', 'Andrade Neves', 'Uvaranas', '84031-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2017, 'Paranavaí', 'Andrades', 'Jardim Santa Eugênia', '87705-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2018, 'Foz do Iguaçu', 'Andradina', 'Conjunto C', '85870-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2019, 'Foz do Iguaçu', 'Andradina', 'Jardim Lancaster', '85861-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2020, 'Foz do Iguaçu', 'Andradina', 'Jardim Lancaster', '85869-380', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2021, 'Ponta Grossa', 'Andradita', 'Neves', '84021-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2022, 'Curitiba', 'André Andretta', 'Abranches', '82130-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2023, 'Curitiba', 'André Barbosa Sueki', 'Campo de Santana', '81490-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2024, 'Londrina', 'André Betti', 'Jardim Marissol', '86030-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2025, 'Cambé', 'André Bigas', 'Recanto Santa Andréa', '86189-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2026, 'Curitiba', 'André Bonato', 'Umbará', '81930-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2027, 'Pato Branco', 'André Borsot', 'La Salle', '85505-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2028, 'Curitiba', 'André Cecone', 'Campina do Siqueira', '80740-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2029, 'Pato Branco', 'André de Barros', 'Santo Antônio', '85507-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2030, 'Cascavel', 'André de Barros', 'Nova Cidade', '85803-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2031, 'Curitiba', 'André de Barros', 'Centro', '80010-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2032, 'Ponta Grossa', 'André de Geus', 'Boa Vista', '84071-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2033, 'Cambé', 'André Di Pietro', 'Conjunto Residencial Roberto Conceição', '86183-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2034, 'Londrina', 'André Emílio Guergoletto', 'Ouro Verde', '86080-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2035, 'Curitiba', 'André Ferreira Barbosa', 'Capão Raso', '81130-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2036, 'Curitiba', 'André Ferreira Barbosa', 'Capão Raso', '81150-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2037, 'Curitiba', 'André Ferreira Camargo', 'Xaxim', '81710-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2038, 'Londrina', 'André Gallo', 'Vale dos Tucanos', '86046-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2039, 'Curitiba', 'André Gonçalves da Silva', 'Atuba', '82860-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2040, 'Curitiba', 'André Haag', 'Novo Mundo', '81050-615', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2041, 'Curitiba', 'André João Gasparin', 'Novo Mundo', '81020-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2042, 'Curitiba', 'André José Giraldello', 'Taboão', '82130-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2043, 'Curitiba', 'André Kaviski', 'Campina do Siqueira', '80730-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2044, 'Londrina', 'André Kemmer', 'Nova Olinda', '86073-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2045, 'Curitiba', 'André Klenk', 'Tingui', '82620-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2046, 'Curitiba', 'André Klug', 'Barreirinha', '82700-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2047, 'Ponta Grossa', 'André Koslosky', 'Chapada', '84062-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2048, 'Sarandi', 'André Kovacs', 'Jardim Independência I', '87114-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2049, 'Piraquara', 'André Luiz', 'Jardim Veneza', '83310-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2050, 'Londrina', 'André Luiz Nogari', 'Alto da Boa Vista', '86083-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2051, 'Curitiba', 'André Matte', 'Pinheirinho', '81870-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2052, 'Curitiba', 'André Moliterno', 'Uberaba', '81570-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2053, 'Araucária', 'André Moll', 'Tindiquera', '83708-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2054, 'São José dos Pinhais', 'André Moro', 'Águas Belas', '83040-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2055, 'Ponta Grossa', 'André Mularski', 'Olarias', '84035-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2056, 'Colombo', 'André Nadolny', 'Jardim Moinho Velho', '83403-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2057, 'Curitiba', 'André Oszika', 'Capão Raso', '81110-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2058, 'Foz do Iguaçu', 'André Paulino do Nascimento', 'Parque Ouro Verde', '85854-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2059, 'São José dos Pinhais', 'André Perbiche', 'São Sebastião', '83075-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2060, 'Curitiba', 'André Petrelli', 'Jardim das Américas', '81540-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2061, 'Curitiba', 'André Prado', 'Cidade Industrial', '81460-239', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2062, 'Campo Largo', 'André Sarnik', 'Vila Santa Terezinha', '83602-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2063, 'São José dos Pinhais', 'André Siccuro', 'Afonso Pena', '83045-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2064, 'Araucária', 'André Skraba', 'Costeira', '83709-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2065, 'Piraquara', 'André Struginski', 'Jardim Guarituba', '83312-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2066, 'Curitiba', 'André Szalbot', 'Capão Raso', '81110-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2067, 'Curitiba', 'André Vigo', 'Pilarzinho', '82100-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2068, 'Curitiba', 'André Visinoni', 'Cidade Industrial', '81280-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2069, 'Araucária', 'André Wojcik', 'Capela Velha', '83706-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2070, 'Curitiba', 'André Zanetti', 'Vista Alegre', '80810-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2071, 'São José dos Pinhais', 'André Zen', 'Aristocrata', '83025-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2072, 'Curitiba', 'André Zilio', 'Santo Inácio', '82010-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2073, 'Cascavel', 'Andréa Galafassi', 'Nova Cidade', '85803-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2074, 'Curitiba', 'Andréa Zilio', 'Santo Inácio', '82010-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2075, 'Londrina', 'Andrelina Patrícia de Carvalho', 'Jardim Acapulco', '86045-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2076, 'Curitiba', 'Andrelino Pereira da Silva', 'Campo de Santana', '81490-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2077, 'Curitiba', 'Andrelino Queiroz Dourado', 'Cidade Industrial', '81350-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2078, 'Sarandi', 'Andrômeda', 'Jardim Universal', '87114-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2079, 'Apucarana', 'Andry Prijma', 'Jardim Catuaí III', '86802-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2080, 'Curitiba', 'Anella Wrublewski Berbeka', 'Atuba', '82860-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2081, 'Pinhais', 'Anésia Corrêa Evangelista', 'Chácaras Atuba', '83325-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2082, 'Londrina', 'Anézia L. Comino de Oliveira', 'Ponte Seca', '86042-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2083, 'Foz do Iguaçu', 'Angatuba', 'Jardim Cedro', '85862-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2084, 'Toledo', 'Ângela A. Pasqualli', 'Jardim Pasqualli', '85905-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2085, 'Foz do Iguaçu', 'Ângela Aparecida Andrade', 'Jardim Porto Belo', '85867-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2086, 'Maringá', 'Ângela Aparecida de Melo', 'Conjunto Habitacional Requião', '87047-479', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2087, 'São José dos Pinhais', 'Ângela Bassa Foggiatto', 'Afonso Pena', '83050-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2088, 'Curitiba', 'Ângela Budel', 'Butiatuvinha', '82320-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2089, 'Curitiba', 'Ângela Costa Bazzo', 'Pilarzinho', '82110-390', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2090, 'Piraquara', 'Ângela da Costa Lima', 'Vila Fuck', '83305-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2091, 'Curitiba', 'Ângela Dall''Osto Vizoli', 'São Braz', '82315-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2092, 'Toledo', 'Ângela Fornari', 'Conjunto Cohapar', '85910-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2093, 'Londrina', 'Ângela Frigo Beltrame', 'Aquilles Sthengel', '86086-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2094, 'Curitiba', 'Ângela Gabardo Parolin', 'Campo de Santana', '81940-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2095, 'Curitiba', 'Ângela Ganz', 'Campina do Siqueira', '80740-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2096, 'Curitiba', 'Ângela Giugliano Meschino', 'Pilarzinho', '82120-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2097, 'Curitiba', 'Ângela Goulin Toaldo', 'Butiatuvinha', '82320-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2098, 'Colombo', 'Ângela Guidolim da Silva', 'Centro', '83414-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2099, 'Curitiba', 'Ângela Navarini Scotti', 'Tatuquara', '81940-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2100, 'Colombo', 'Ângela Perin d''Agostin', 'Roça Grande', '83401-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2101, 'Cambé', 'Ângela Rigone Bertan', 'Jardim Vitória', '86184-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2102, 'Londrina', 'Ângela Rosa', 'Presidente Vargas', '86083-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2103, 'Colombo', 'Ângela Tereza Ceccon Corleto', 'Jardim Monte Líbano', '83407-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2104, 'Toledo', 'Ângela Tonial', 'Jardim Paulista', '85909-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2105, 'Telêmaco Borba', 'Angélica', 'Jardim Alegre', '84268-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2106, 'Cascavel', 'Angélica', 'Periolo', '85817-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2107, 'Curitiba', 'Angélica Erthal Kucek', 'Sítio Cercado', '81925-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2108, 'São José dos Pinhais', 'Angélica Gapski', 'Afonso Pena', '83040-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2109, 'Piraquara', 'Angélica Gomes das Neves da Silva', 'Vila Mariana', '83311-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2110, 'Curitiba', 'Angélica Kenski', 'Cajuru', '82980-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2111, 'Curitiba', 'Angélica Maria Taborda Santos', 'Boqueirão', '81750-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2112, 'Ponta Grossa', 'Angélica Nadal Schoemberger', 'Orfãs', '84015-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2113, 'Curitiba', 'Angélica Negrello de Conto', 'Umbará', '81940-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2114, 'Curitiba', 'Angélica Pavelski', 'Augusta', '81260-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2115, 'Colombo', 'Angelim Walesko', 'Jardim dos Eucaliptos', '83408-496', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2116, 'Campo Largo', 'Angelin Domingos Carli', 'Vila Bancária', '83601-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2117, 'Londrina', 'Angelin Faneco', 'Jardim São Paulo', '86046-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2118, 'Foz do Iguaçu', 'Angelin Favassa', 'Loteamento Universitário das Américas', '85870-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2119, 'Guarapuava', 'Angelin Meireles Túlio', 'São Cristóvão', '85063-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2120, 'Curitiba', 'Angelina Ançai', 'Fazendinha', '81320-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2121, 'Londrina', 'Angelina Basso', 'Colúmbia', '86057-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2122, 'Curitiba', 'Angelina Braga Cortezzi', 'Santa Felicidade', '82410-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2123, 'Colombo', 'Angelina Cavalli', 'Jardim Adriana', '83408-477', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2124, 'Curitiba', 'Angelina de Lima Pires Oliveira', 'Tatuquara', '81470-430', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2125, 'Araucária', 'Angelina Huttner', 'Sabiá', '83708-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2126, 'Curitiba', 'Angelina Legat Pasini', 'Alto Boqueirão', '81770-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2127, 'São José dos Pinhais', 'Angelina M. Senegaglia', 'Planta Quississana', '83085-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2128, 'Apucarana', 'Angelina Menegazzo', 'Jardim Menegazzo', '86802-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2129, 'Curitiba', 'Angelina Princival Calopreso', 'Cidade Industrial', '81450-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2130, 'Londrina', 'Angelina Refondini', 'João Paz', '86087-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2131, 'Londrina', 'Angelina Ricci Vezozzo', 'Indústrias Leves', '86087-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2132, 'Londrina', 'Angelina Ricci Vezozzo', 'Indústrias Leves', '86030-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2133, 'Londrina', 'Angelina Tardivo Sisti', 'Jardim Graziela', '86036-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2134, 'Curitiba', 'Angelina Turesso Cavalim', 'Cidade Industrial', '81170-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2135, 'Londrina', 'Angelino Ferreira de Souza', 'Novo Amparo', '86087-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2136, 'Francisco Beltrão', 'Angelita Rech', 'Seminário', '85605-659', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2137, 'Campo Mourão', 'Ângelo Amaral', 'Jardim Joana D''Arc', '87300-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2138, 'Londrina', 'Ângelo Anelli', 'Conjunto Residencial Vale do Arvoredo', '86047-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2139, 'Londrina', 'Ângelo Antônio Tronchini', 'Jardim Itaipu', '86036-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2140, 'São José dos Pinhais', 'Ângelo Bassa', 'Afonso Pena', '83065-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2141, 'Colombo', 'Ângelo Basseti', 'Jardim Ana Terra', '83406-167', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2142, 'Apucarana', 'Ângelo Basso', 'Núcleo Habitacional Jurema', '86801-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2143, 'Curitiba', 'Ângelo Bertoncello', 'Cajuru', '82920-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2144, 'Colombo', 'Ângelo Betinardi', 'Vila Vale Verde', '83406-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2145, 'Curitiba', 'Ângelo Boff', 'Sítio Cercado', '81925-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2146, 'Curitiba', 'Ângelo Bom', 'Campo Comprido', '81210-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2147, 'Londrina', 'Ângelo Bonato', 'Jamile Dequech', '86048-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2148, 'Curitiba', 'Ângelo Bresegnello', 'Bairro Alto', '82840-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2149, 'Francisco Beltrão', 'Ângelo Candiotto', 'Guanabara', '85604-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2150, 'Apucarana', 'Ângelo Carmagnani', 'Loteamento Sanches dos Santos', '86806-597', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2151, 'Curitiba', 'Ângelo Caron', 'São Braz', '82300-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2152, 'Maringá', 'Ângelo Cavalin', 'Jardim Aclimação', '87050-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2153, 'Curitiba', 'Ângelo Cavichiolo', 'Cajuru', '82930-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2154, 'Cascavel', 'Ângelo Chiamulera', 'Pioneiros Catarinenses', '85805-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2155, 'Umuarama', 'Ângelo Colautto', 'Jardim dos Príncipes', '87502-046', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2156, 'Pato Branco', 'Ângelo Copetti', 'Novo Horizonte', '85507-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2157, 'Toledo', 'Ângelo Cornelli', 'Jardim Anápolis', '85905-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2158, 'Curitiba', 'Ângelo Cunico', 'Barreirinha', '82220-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2159, 'Telêmaco Borba', 'Ângelo dal''Col Júnior', 'Centro', '84261-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2160, 'Guarapuava', 'Ângelo Dalla Vechia', 'Primavera', '85050-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2161, 'Curitiba', 'Ângelo Dallarmi', 'Santa Felicidade', '82015-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2162, 'Colombo', 'Ângelo Dallazuana Sobrinho', 'Itajacuru', '83407-839', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2163, 'São José dos Pinhais', 'Ângelo dal''Negro', 'Bom Jesus', '83025-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2164, 'Colombo', 'Ângelo Dal''Pra', 'Vila São Gabriel', '83406-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2165, 'Londrina', 'Ângelo Depieri', 'Ernani de Moura Lima', '86037-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2166, 'Curitiba', 'Ângelo do Rosário', 'Sítio Cercado', '81900-787', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2167, 'Curitiba', 'Ângelo Domingos Durigan', 'Cascatinha', '82020-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2168, 'Toledo', 'Ângelo Donin', 'Jardim Porto Alegre', '85906-716', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2169, 'Toledo', 'Ângelo Fabris', 'Loteamento Lidia Joana Vols', '85912-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2170, 'Castro', 'Ângelo Fagundes da Fonseca', 'Centro', '84165-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2171, 'Colombo', 'Ângelo Falavinha Dal''Pra', 'Jardim Nossa Senhora das Graças', '83407-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2172, 'Cascavel', 'Ângelo Fanhame', 'Morumbi', '85817-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2173, 'Maringá', 'Ângelo Favaretto', 'Jardim Paris', '87083-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2174, 'Curitiba', 'Ângelo Favretto', 'Sítio Cercado', '81920-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2175, 'Francisco Beltrão', 'Ângelo Ferrari', 'Pinheirinho', '85603-295', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2177, 'Londrina', 'Ângelo Flumignan', 'Cambezinho', '86040-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2178, 'Colombo', 'Ângelo Francisco Borato', 'Jardim Monza', '83406-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2179, 'Colombo', 'Ângelo Frasão', 'Jardim Santa Cândida', '83404-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2180, 'Londrina', 'Ângelo Fregonese', 'Jardim Barcelona', '86073-368', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2181, 'Curitiba', 'Ângelo Gai', 'Umbará', '81940-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2182, 'Londrina', 'Ângelo Gaiotto', 'Santa Rita 1', '86072-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2183, 'Piraquara', 'Ângelo Gali', 'Centro', '83301-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2184, 'Toledo', 'Ângelo Giachini', 'Jardim La Salle', '85903-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2185, 'Cascavel', 'Ângelo Godoy', 'Santos Dumont', '85804-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2186, 'Curitiba', 'Ângelo Golin', 'Sítio Cercado', '81920-728', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2187, 'Curitiba', 'Ângelo Gulin', 'Santa Cândida', '82640-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2188, 'Curitiba', 'Ângelo João Gottardi', 'Cajuru', '82970-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2189, 'São José dos Pinhais', 'Ângelo José Moreski', 'Ipê', '83055-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2190, 'Curitiba', 'Ângelo Júlio Ianke', 'Cidade Industrial', '81450-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2191, 'Londrina', 'Ângelo Kreta', 'Assis', '86085-685', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2192, 'Colombo', 'Ângelo Lazaroto', 'Jardim São Gabriel', '83407-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2193, 'Cambé', 'Ângelo Lovato', 'Jardim Riviera', '86187-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2194, 'Toledo', 'Ângelo Luiz Parizzotto', 'Jardim Anápolis', '85905-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2195, 'Ponta Grossa', 'Ângelo Madalozzo', 'Jardim Carvalho', '84016-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2196, 'Curitiba', 'Ângelo Maestrelli', 'Bigorrilho', '80710-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2197, 'Apucarana', 'Ângelo Mantovani', 'Núcleo Habitacional das Indústrias', '86806-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2198, 'Curitiba', 'Ângelo Marqueto', 'Cidade Industrial', '81260-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2199, 'Ponta Grossa', 'Ângelo Martins', 'Boa Vista', '84072-306', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2200, 'Curitiba', 'Ângelo Maschio', 'Uberaba', '81590-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2201, 'Curitiba', 'Ângelo Massignan', 'São Braz', '82320-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2202, 'Curitiba', 'Ângelo Massignan', 'São Braz', '82315-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2203, 'Toledo', 'Ângelo Massola', 'Jardim Concórdia', '85906-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2204, 'Curitiba', 'Ângelo Massuchetto', 'Boa Vista', '82650-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2205, 'Curitiba', 'Ângelo Mazzarotto', 'Santa Felicidade', '82320-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2206, 'Londrina', 'Ângelo Meranca', 'Castelo', '86027-340', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2207, 'Pato Branco', 'Ângelo Merlin', 'Industrial', '85509-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2208, 'Campo Largo', 'Ângelo Merotto', 'Rondinha', '83607-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2209, 'Toledo', 'Ângelo Micheletto', 'Conjunto Habitacional São Francisco', '85915-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2210, 'Colombo', 'Ângelo Milani', 'Jardim Belo Rincão', '83412-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2211, 'Colombo', 'Ângelo Milani Scremin', 'Jardim Nossa Senhora de Fátima', '83405-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2212, 'Londrina', 'Ângelo Mioto', 'Heimtal', '86084-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2213, 'Colombo', 'Ângelo Mocelin', 'Vila Santo Antônio', '83413-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2214, 'Umuarama', 'Ângelo Moreira da Fonseca', 'Zona I-A', '87503-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2215, 'Umuarama', 'Ângelo Moreira da Fonseca', 'Parque Danielle', '87506-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2216, 'Umuarama', 'Ângelo Moreira da Fonseca', 'Zona I-A', '87504-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2217, 'Ponta Grossa', 'Ângelo Moro', 'Estrela', '84050-100', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2218, 'Curitiba', 'Ângelo Moro', 'Sítio Cercado', '81925-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2219, 'São José dos Pinhais', 'Ângelo Moro Redeschi', 'Cruzeiro', '83010-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2220, 'Francisco Beltrão', 'Ângelo Pelisser', 'Pinheirinho', '85603-173', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2221, 'Sarandi', 'Ângelo Perine', 'Parque São Pedro', '87112-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2222, 'Sarandi', 'Ângelo Perine', 'Parque São Pedro', '87112-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2223, 'Colombo', 'Ângelo Perine', 'Vila São Gabriel', '83406-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2224, 'Araucária', 'Ângelo Perini', 'Estação', '83705-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2225, 'Londrina', 'Ângelo Pesarini', 'Três Marcos', '86046-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2226, 'Curitiba', 'Ângelo Pianaro', 'Butiatuvinha', '82320-570', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2227, 'Curitiba', 'Ângelo Piazzetta', 'Cristo Rei', '80050-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2228, 'Curitiba', 'Ângelo Piotto', 'Cidade Industrial', '81280-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2229, 'São José dos Pinhais', 'Ângelo Porfírio Berton', 'Afonso Pena', '83045-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2230, 'Apucarana', 'Ângelo Portinari', 'Vila Santa Adélia', '86802-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2231, 'Londrina', 'Ângelo Pugglia', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2232, 'Francisco Beltrão', 'Ângelo Reinaldo Urio', 'Antônio de Paiva Cantelmo', '85603-532', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2233, 'Londrina', 'Ângelo Ricardo Galdino', 'João Paz', '86087-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2234, 'Curitiba', 'Ângelo Rigolino', 'Tatuquara', '81940-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2235, 'Castro', 'Ângelo Rolim de Moura', 'Núcleo Habitacional Padre Piva', '84178-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2236, 'Londrina', 'Ângelo Romeiro Nardo', 'Ernani de Moura Lima', '86037-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2237, 'Colombo', 'Ângelo Rosenente', 'Colônia Faria', '83412-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2238, 'Curitiba', 'Ângelo Rossa', 'Campo Comprido', '81270-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2239, 'Paranavaí', 'Ângelo S. Neto', 'Jardim América', '87705-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2240, 'Cascavel', 'Ângelo Salvati', 'Cascavel Velho', '85818-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2241, 'Cascavel', 'Ângelo Sbardela', 'Cascavel Velho', '85818-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2242, 'Curitiba', 'Ângelo Scaramuza', 'Xaxim', '81810-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2243, 'São José dos Pinhais', 'Ângelo Setim', 'Afonso Pena', '83040-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2244, 'São José dos Pinhais', 'Ângelo Sgarbe', 'São Sebastião', '83075-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2245, 'Curitiba', 'Ângelo Slompo', 'Santa Felicidade', '82020-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2246, 'Apucarana', 'Ângelo Stabile', 'Vila Vera Cruz', '86804-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2247, 'Curitiba', 'Ângelo Stival', 'Santa Felicidade', '82400-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2248, 'Colombo', 'Ângelo Strapasson Costa', 'Centro', '83414-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2249, 'Londrina', 'Ângelo Tescaro', 'Jardim Itatiaia 2', '86047-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2250, 'Colombo', 'Ângelo Tognato', 'Jardim Cristina', '83410-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2251, 'Curitiba', 'Ângelo Tozim', 'Campo de Santana', '81490-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2252, 'Curitiba', 'Ângelo Trevisan', 'Cascatinha', '82010-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2253, 'Curitiba', 'Ângelo Vendramin', 'Santa Felicidade', '82320-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2254, 'Curitiba', 'Ângelo Vercesi', 'Bacacheri', '82510-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2255, 'Londrina', 'Ângelo Vicentini', 'Santa Mônica', '86079-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2256, 'Colombo', 'Ângelo Vidolin', 'Jardim Paraná', '83412-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2257, 'Curitiba', 'Ângelo Vigo', 'Pilarzinho', '82100-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2258, 'Sarandi', 'Ângelo Vinha', 'Parque Alvamar', '87113-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2259, 'Curitiba', 'Ângelo Zamir Biasi', 'Santa Cândida', '82630-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2260, 'Campo Largo', 'Ângelo Zanetti', 'Loteamento Itaboa', '83605-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2261, 'Curitiba', 'Ângelo Zanotto', 'Butiatuvinha', '82320-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2262, 'São José dos Pinhais', 'Ângelo Zen', 'Centro', '83005-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2263, 'Curitiba', 'Ângelo Zeni', 'Bom Retiro', '80520-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2264, 'Cascavel', 'Ângelo Zonin', 'Cascavel Velho', '85818-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2265, 'Londrina', 'Angico', 'Santa Rita 1', '86071-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2266, 'Piraquara', 'Angico', 'Vila Santa Maria', '83306-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2267, 'Telêmaco Borba', 'Angico', 'Área 01', '84268-140', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2268, 'Ponta Grossa', 'Angico-branco', 'Contorno', '84061-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2269, 'Francisco Beltrão', 'Angola', 'Seminário', '85605-660', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2270, 'Pinhais', 'Angola', 'Vila Esplanada', '83320-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2271, 'Telêmaco Borba', 'Angola', 'Vila Esperança', '84272-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2272, 'Colombo', 'Angola', 'Planta Santa Úrsula', '83405-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2273, 'Maringá', 'Angra', 'Parque das Grevíleas', '87025-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2274, 'Guarapuava', 'Angra dos Reis', 'São Cristóvão', '85060-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2275, 'Francisco Beltrão', 'Angra dos Reis', 'Pinheirinho', '85603-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2276, 'Londrina', 'Anhangueira', 'São Pedro', '86036-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2277, 'Telêmaco Borba', 'Anhanguera', 'Núcleo Bandeirantes', '84269-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2278, 'Maringá', 'Anhangüera', 'Zona 03', '87050-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2279, 'Umuarama', 'Anhangüera', 'Zona V', '87504-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2280, 'Foz do Iguaçu', 'Anhembi', 'Jardim Santa Rosa', '85869-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2281, 'Foz do Iguaçu', 'Anhembi', 'Conjunto A', '85860-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2282, 'Umuarama', 'Anhumai', 'Jardim Tropical', '87503-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2283, 'Arapongas', 'Anhuma-poca', 'Jardim Bononi', '86703-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2284, 'Arapongas', 'Anhumas', 'Vila Aparecida', '86707-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2285, 'Arapongas', 'Anhumbi', 'Centro', '86705-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2286, 'Arapongas', 'Anhumbi-cemitério', 'Centro', '86701-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2287, 'Curitiba', 'Aníbal Afonso', 'Abranches', '82220-475', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2288, 'Curitiba', 'Aníbal Bartholomeu João Lazzarotto', 'Jardim das Américas', '81520-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2289, 'Cascavel', 'Aníbal Curi', 'Santa Cruz', '85806-097', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2290, 'Londrina', 'Aníbal de Siqueira Cabral', 'Conjunto Residencial Vale do Arvoredo', '86047-515', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2291, 'Paranaguá', 'Aníbal Dias Paiva', 'Vila Paranaguá', '83221-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2292, 'Paranaguá', 'Aníbal Dias Paiva', 'Estradinha', '83206-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2293, 'Londrina', 'Aníbal Domingos Pires', 'Jardim San Diego', '86073-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2294, 'Cascavel', 'Aníbal dos Santos Matias', 'Presidente', '85818-166', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2295, 'Colombo', 'Aníbal Feliciano dos Santos', 'Jardim Nossa Senhora da Penha', '83402-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2296, 'Curitiba', 'Aníbal Goulart Maia Filho', 'Bairro Alto', '82820-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2297, 'Curitiba', 'Aníbal Guimarães Carneiro', 'Seminário', '80240-360', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2298, 'Cascavel', 'Aníbal Lopes da Silva', 'Santa Felicidade', '85803-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2299, 'Curitiba', 'Aníbal Lourenço de Oliveira', 'Tatuquara', '81480-275', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2300, 'Curitiba', 'Aníbal Requião', 'Xaxim', '81810-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2301, 'Paranaguá', 'Aníbal Roque', 'Parque São João', '83212-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2302, 'São José dos Pinhais', 'Aníbal Silva', 'Afonso Pena', '83050-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2303, 'Ponta Grossa', 'Aníbal Theófilo', 'Uvaranas', '84020-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2304, 'Toledo', 'Anibaldo Hoffmann', 'Residencial Santa Clara', '85914-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2305, 'Curitiba', 'Aníbio Gonçalves de Souza', 'Cidade Industrial', '81450-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2306, 'Londrina', 'Aniceto Espiga', 'Portal de Versalhes 1', '86057-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2307, 'Curitiba', 'Anilda Moro Ploszaj', 'Portão', '81070-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2308, 'Londrina', 'Anis Maroun Lebbos', 'Indusville', '86031-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2309, 'Londrina', 'Anis Maroun Lebbos', 'Pinheiros', '86063-115', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2310, 'Castro', 'Anísio Antunes Neto', 'Jardim Samambaia', '84182-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2311, 'Ponta Grossa', 'Anísio Calazans', 'Boa Vista', '84073-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2312, 'Londrina', 'Anísio Figueiredo', 'Gavea', '86065-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2313, 'Londrina', 'Anísio Figueiredo', 'San Remo', '86062-585', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2314, 'Umuarama', 'Anísio Francisco Silva', 'Parque San Remo I', '87506-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2315, 'Londrina', 'Anísio Ribas Bueno', 'Operária', '86038-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2316, 'Londrina', 'Anísio Ribas Bueno', 'Centro', '86010-065', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2317, 'Francisco Beltrão', 'Anísio Teixeira', 'Alvorada', '85601-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2318, 'Londrina', 'Anita de Souza', 'Cambará', '86039-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2319, 'Francisco Beltrão', 'Anita Garibaldi', 'Centro', '85601-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2320, 'Foz do Iguaçu', 'Anita Garibaldi', 'Jardim Cláudia', '85852-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2321, 'Guarapuava', 'Anita Garibaldi', 'Morro Alto', '85067-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2322, 'Londrina', 'Anita Garibaldi', 'Jardim Agari', '86020-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2323, 'Ponta Grossa', 'Anita Garibaldi', 'Orfãs', '84015-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2324, 'Toledo', 'Anita Garibaldi', 'Boa Esperança', '85909-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2325, 'Cascavel', 'Anita Garibaldi', 'Nova Cidade', '85803-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2326, 'Apucarana', 'Anita Garibaldi', 'Jardim Albino Biachi', '86802-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2327, 'Cambé', 'Anita Garibaldi', 'Residencial Elizabeth', '86188-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2328, 'Curitiba', 'Anita Garibaldi', 'Juvevê', '80540-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2329, 'Curitiba', 'Anita Garibaldi', 'São Lourenço', '82210-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2330, 'Curitiba', 'Anita Garibaldi', 'Barreirinha', '82220-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2331, 'Curitiba', 'Anita Garibaldi', 'Ahú', '82200-530', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2332, 'Londrina', 'Anita Honami Nakashima', 'Jardim Strass', '86084-825', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2333, 'Curitiba', 'Anita Jonson Zuctanski', 'Sítio Cercado', '81920-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2334, 'Londrina', 'Anita Magalhães de Oliveira', 'Residencial Vila Romana', '86031-808', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2335, 'Foz do Iguaçu', 'Anita Malfatti', 'Vila Pérola', '85865-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2336, 'Cascavel', 'Anita Malfatti', 'Independência', '85811-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2337, 'Colombo', 'Anita Malgatti', 'Vila Petrópolis', '83409-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2338, 'Guarapuava', 'Anita Martins Carneiro', 'Boqueirão', '85023-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2339, 'Londrina', 'Anita Pereira Correia', 'Residencial Loris Sahyun', '86040-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2340, 'Ponta Grossa', 'Anita Philipowski', 'Contorno', '84060-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2341, 'Curitiba', 'Anita Ribas', 'Bacacheri', '82520-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2342, 'Paranaguá', 'Anita Ribeiro Fontes', 'Conjunto Residencial Prefeito Cominese', '83215-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2343, 'Piraquara', 'Anita Zeppin', 'Jardim Veneza', '83310-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2344, 'Ponta Grossa', 'Anivaldo M. Rodrigues', 'Chapada', '84062-678', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2345, 'Curitiba', 'Anizia Maria da Conceição Ferreira', 'Tatuquara', '81470-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2346, 'Cascavel', 'Anizio Batista', 'Região do Lago 3', '85819-778', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2347, 'Curitiba', 'Anjo de Luz', 'Cidade Industrial', '81230-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2348, 'Almirante Tamandaré', 'Anjo-da-Guarda', 'Vila Cachoeira', '83504-240', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2349, 'Curitiba', 'Anjolilo Buzzetti', 'Cidade Industrial', '81460-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2350, 'Curitiba', 'Anna Bendett', 'Pilarzinho', '82120-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2351, 'Curitiba', 'Anna Bora', 'Campo de Santana', '81490-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2352, 'Curitiba', 'Anna Ciupka', 'Campina do Siqueira', '80740-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2353, 'Londrina', 'Anna de Oliveira Barroso', 'Lagoa Dourada', '86041-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2354, 'Colombo', 'Anna de Souza', 'Centro Industrial Mauá', '83413-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2355, 'Curitiba', 'Anna Dinarowski Sobczyk', 'Cidade Industrial', '81280-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2356, 'Londrina', 'Anna Domingues Molina', 'Residencial Moradias Tibagi', '86080-448', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2357, 'Paranaguá', 'Anna dos Santos Bara', 'Costeira', '83203-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2358, 'São José dos Pinhais', 'Anna Ferreira de Camargo', 'Guatupê', '83060-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2359, 'Curitiba', 'Anna Friebe', 'Prado Velho', '80215-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2360, 'Curitiba', 'Anna Garcia da Silva', 'Pilarzinho', '80820-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2361, 'Curitiba', 'Anna Garcia de Moura', 'Pilarzinho', '82115-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2362, 'Curitiba', 'Anna Gbur Barcik', 'Santo Inácio', '82010-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2363, 'Londrina', 'Anna Gonçalves Korki', 'Portal de Versalhes 3', '86055-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2364, 'Curitiba', 'Anna Henriqueta Schiavon Kucek', 'Sítio Cercado', '81900-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2365, 'Curitiba', 'Anna Kinelska', 'Cidade Industrial', '81260-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2366, 'Curitiba', 'Anna Kloster Guimarães', 'Uberaba', '81590-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2367, 'Curitiba', 'Anna Maurer Rutz', 'Boa Vista', '82650-095', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2368, 'Curitiba', 'Anna Meyer Fruet', 'Cidade Industrial', '81170-025', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2369, 'Londrina', 'Anna Morena de Mello Menezes', 'Lima Azevedo', '86060-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2370, 'Foz do Iguaçu', 'Anna Nery', 'Jardim Cláudia', '85852-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2371, 'Londrina', 'Anna Peres Caparro', 'Residencial Portal de Piza', '86041-309', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2372, 'Curitiba', 'Anna Reinhandt', 'Cidade Industrial', '81460-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2373, 'Curitiba', 'Anna Schaffer Weigert', 'Vista Alegre', '80820-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2374, 'Curitiba', 'Anna Schella Schroeder', 'Pilarzinho', '82120-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2375, 'Ponta Grossa', 'Anna Scremin', 'Cará-cará', '84043-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2376, 'Curitiba', 'Anna Trentim Reque', 'Cajuru', '82980-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2377, 'Curitiba', 'Anna Z. Homann', 'São Braz', '82310-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2378, 'São José dos Pinhais', 'Anna Zen', 'Colônia Murici', '83085-215', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2379, 'Cascavel', 'Anne Frank', 'Alto Alegre', '85805-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2380, 'Curitiba', 'Anne Frank', 'Hauer', '81610-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2381, 'Curitiba', 'Anne Frank', 'Boqueirão', '81730-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2382, 'Curitiba', 'Anne Frank', 'Boqueirão', '81650-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2383, 'Toledo', 'Anne Russ', 'Residencial Santa Clara', '85903-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2384, 'Curitiba', 'Anne Sulivan', 'Pilarzinho', '82120-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2385, 'São José dos Pinhais', 'Anneliese Gellert Krigsner', 'Afonso Pena', '83065-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2386, 'Londrina', 'Annie Bessant', 'Nossa Senhora de Lourdes', '86039-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2387, 'Curitiba', 'Annita Gaertner', 'Cidade Industrial', '81350-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2388, 'Curitiba', 'Annita Nemetz Muller', 'Uberaba', '81580-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2389, 'Curitiba', 'Anor Gomes de Castro', 'Capão da Imbuia', '82810-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2390, 'Toledo', 'Anor Normelio Dei Svaldi', 'Jardim Bressan', '85913-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2391, 'Curitiba', 'Anselmo Camati', 'Guaíra', '80220-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2392, 'São José dos Pinhais', 'Anselmo Costa', 'Braga', '83020-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2393, 'Curitiba', 'Anselmo de Lima Filho', 'Cidade Industrial', '81290-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2394, 'Curitiba', 'Anselmo José Pereira', 'Alto Boqueirão', '81770-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2395, 'São José dos Pinhais', 'Anselmo Krupeizak', 'Afonso Pena', '83065-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2396, 'Curitiba', 'Anselmo Nicco', 'Mossunguê', '81200-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2397, 'Colombo', 'Anselmo Pavin', 'Sapopema', '83407-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2398, 'Curitiba', 'Anselmo Pilati', 'Pilarzinho', '82120-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2399, 'São José dos Pinhais', 'Anselmo Vaccari', 'Águas Belas', '83040-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2400, 'Londrina', 'Antares', 'Sol', '86070-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2401, 'Maringá', 'Antares', 'Residencial Regente', '87045-739', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2402, 'Ponta Grossa', 'Antares', 'Colônia Dona Luiza', '84043-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2403, 'Pinhais', 'Antártida', 'Vila Irene', '83323-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2404, 'Colombo', 'Antenor Alves de Souza', 'Jardim César Augusto', '83402-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2405, 'Apucarana', 'Antenor Consolaro', 'Vila Shangri-La', '86812-240', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2406, 'São José dos Pinhais', 'Antenor dos Santos', 'Ipê', '83055-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2407, 'Londrina', 'Antenor Duenhas', 'Jacutinga', '86087-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2408, 'Almirante Tamandaré', 'Antenor Ferreira da Silva', 'Vila Cachoeira', '83504-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2409, 'Curitiba', 'Antenor Gomes Camargo', 'Xaxim', '81830-046', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2410, 'Curitiba', 'Antenor Gonçalves Franco', 'Taboão', '82130-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2411, 'Paranavaí', 'Antenor Grigoli', 'Jardim Iguaçu', '87705-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2412, 'Curitiba', 'Antenor Guimarães', 'Pilarzinho', '82110-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2413, 'Curitiba', 'Antenor José Tedeschi', 'Cajuru', '82930-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2414, 'Curitiba', 'Antenor Kaiser', 'Campo Comprido', '81280-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2415, 'Colombo', 'Antenor Lazarini', 'Serrinha', '83415-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2416, 'Ponta Grossa', 'Antenor Lourenço de Oliveira', 'Contorno', '84060-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2417, 'Guarapuava', 'Antenor Lustosa Ribas', 'Vila Bela', '85027-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2418, 'Curitiba', 'Antenor Malin', 'Pilarzinho', '82100-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2419, 'Toledo', 'Antenor Pavan', 'Vila Pioneiro', '85909-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2420, 'Curitiba', 'Antenor Pereira', 'Pilarzinho', '82100-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2421, 'Guarapuava', 'Antenor Pereira dos Santos', 'Cascavel', '85040-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2422, 'Apucarana', 'Antenor Rosa', 'Jardim Aeroporto', '86812-506', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2423, 'Ponta Grossa', 'Antero de Mello Franco', 'Oficinas', '84036-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2424, 'Londrina', 'Antero de Quental', 'Conjunto Residencial Vale do Arvoredo', '86047-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2425, 'Curitiba', 'Antero de Quental', 'Lindóia', '81010-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2426, 'Ponta Grossa', 'Antero Machado de Mello', 'Chapada', '84062-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2427, 'Pato Branco', 'Antero Petri', 'São Vicente', '85506-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2428, 'São José dos Pinhais', 'Anthero Pereira dos Santos', 'Braga', '83020-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2429, 'Paranaguá', 'Anthero Régis Pereira da Costa', 'Estradinha', '83206-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2430, 'Pinhais', 'Antídio Batista de Souza', 'Jardim Boa Vista', '83327-067', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2431, 'Londrina', 'Antimônio', 'Jardim São Francisco de Assis', '86067-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2432, 'Arapongas', 'Anto', 'Vila Alvorada', '86708-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2433, 'Londrina', 'Antônia Abade Bonfim', 'Jardim Barcelona', '86073-356', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2434, 'Curitiba', 'Antônia Campana Koubetch', 'Cidade Industrial', '81350-638', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2435, 'Maringá', 'Antônia Capoti Fernandes', 'Parque Tarumã', '87053-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2436, 'Londrina', 'Antônia Carolina da Silva', 'Jardim Marízia I', '86079-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2437, 'Londrina', 'Antônia Cucoola Fregonese', 'Jardim Barcelona', '86073-367', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2438, 'Curitiba', 'Antônia Gabardo Nizer', 'Pilarzinho', '82115-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2439, 'Sarandi', 'Antônia Garrido Stevanelli', 'Jardim Nova Paulista', '87111-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2440, 'Londrina', 'Antônia Isepan Vieira', 'Conjunto Habitacional José Garcia Molina', '86080-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2441, 'Umuarama', 'Antônia Lupion Barros', 'Jardim Vitória', '87509-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2442, 'Londrina', 'Antônia Maria Gardemann', 'Conjunto Professora Hilda Mandarino', '86080-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2443, 'Almirante Tamandaré', 'Antônia Maria Xavier', 'Jardim Mônica', '83505-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2444, 'Londrina', 'Antônia Martins de Oliveira', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2445, 'São José dos Pinhais', 'Antônia Miravalhes Possebom', 'Afonso Pena', '83045-130', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2446, 'Curitiba', 'Antônia Molina Bella', 'Cidade Industrial', '81460-157', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2447, 'São José dos Pinhais', 'Antônia Morais Bello', 'Miringuava', '83090-428', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2448, 'Laranjeiras do Sul', 'Antônia Oliveira Xavier', 'Vila Industrial', '85303-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2449, 'Londrina', 'Antônia Pattaro Grigoletto', 'Dom Pedro I', '86089-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2450, 'Paranaguá', 'Antonieta Cominese', 'Padre Jackson', '83221-210', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2451, 'Curitiba', 'Antonieta da Costa Montanari', 'Augusta', '81260-548', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2452, 'Paranaguá', 'Antonieta de Souza Magalhães', 'Rocio', '83221-705', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2453, 'Guarapuava', 'Antonieta Lima Rocha', 'Bonsucesso', '85045-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2454, 'Apucarana', 'Antonieta S. Lautenschlager', 'Centro', '86800-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2455, 'Ponta Grossa', 'Antonil', 'Uvaranas', '84032-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2456, 'Ponta Grossa', 'Antonil', 'Oficinas', '84036-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2457, 'Foz do Iguaçu', 'Antonina', 'Jardim Paraná', '85867-270', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2458, 'Guarapuava', 'Antonina', 'Boqueirão', '85020-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2459, 'Laranjeiras do Sul', 'Antonina', 'Água Verde', '85302-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2460, 'Francisco Beltrão', 'Antonina', 'Nossa Senhora Aparecida', '85601-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2461, 'Londrina', 'Antonina', 'Indústrias', '86043-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2462, 'São José dos Pinhais', 'Antonina', 'Cidade Jardim', '83035-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2463, 'Ponta Grossa', 'Antonina', 'Oficinas', '84036-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2464, 'Pato Branco', 'Antonina', 'São Vicente', '85506-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2465, 'Toledo', 'Antonina', 'Jardim Bressan', '85913-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2466, 'Telêmaco Borba', 'Antonina', 'Jardim União', '84266-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2467, 'Cambé', 'Antonina', 'Jardim Ana Eliza', '86188-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2468, 'Cascavel', 'Antonina', 'São Cristóvão', '85813-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2469, 'Colombo', 'Antonina', 'Jardim Guaraituba', '83410-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2471, 'Curitiba', 'Antonina Baganha Lima', 'Cidade Industrial', '81240-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2472, 'Curitiba', 'Antonina Brasil dos Reis', 'Capão da Imbuia', '82810-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2473, 'Ponta Grossa', 'Antonina Szathowski', 'Chapada', '84064-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2474, 'Ponta Grossa', 'Antonina Wrodlewski dos Santos', 'Olarias', '84026-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2475, 'Almirante Tamandaré', 'Antoninho Portela', 'Jardim Parati', '83503-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2476, 'Curitiba', 'Antonino Teixeira', 'Santa Cândida', '82630-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2477, 'Paranaguá', 'Antônio A. da Fonseca', 'Divinéia', '83212-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2478, 'Apucarana', 'Antônio A. de Almeida', 'Jardim Iguatemi', '86810-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2479, 'Paranaguá', 'Antônio Abud', 'Parque São João', '83212-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2480, 'Curitiba', 'Antônio Adão Falarz', 'Orleans', '82310-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2481, 'Curitiba', 'Antônio Ader', 'Fanny', '81030-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2482, 'Curitiba', 'Antônio Adilson Neves', 'Xaxim', '81710-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2483, 'Sarandi', 'Antônio Affonso Ognibeni', 'Jardim Nova Independência I', '87114-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2484, 'Curitiba', 'Antônio Agenor do Nascimento', 'Jardim das Américas', '81540-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2485, 'Curitiba', 'Antônio Aggio', 'Cidade Industrial', '81310-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2486, 'Curitiba', 'Antônio Alberto Magrin', 'Cidade Industrial', '81170-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2487, 'Colombo', 'Antônio Alberto Strapasson', 'Sapopema', '83414-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2488, 'Piraquara', 'Antônio Alceu Zielonca', 'Planta Deodoro', '83304-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2489, 'Cambé', 'Antônio Alexandrino', 'Jardim Planalto Verde', '86192-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2490, 'Telêmaco Borba', 'Antônio Alfredo Martins', 'Jardim Bom Jesus', '84262-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2491, 'Londrina', 'Antônio Aljarilla Bejerano', 'Ernani de Moura Lima', '86037-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2492, 'Curitiba', 'Antônio Alves', 'Campo de Santana', '81490-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2493, 'Foz do Iguaçu', 'Antônio Alves do Amaral', 'Conjunto Habitacional Fernanda', '85862-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2494, 'Guarapuava', 'Antônio Alves Loures', 'Morro Alto', '85067-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2495, 'Paranaguá', 'Antônio Alves Marinho', 'Parque São João', '83212-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2496, 'Cascavel', 'Antônio Alves Massaneiro', 'Independência', '85813-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2497, 'Cascavel', 'Antônio Alves Massaneiro', 'Centro', '85812-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2498, 'Maringá', 'Antônio Alves Munhoz', 'Conjunto Habitacional Requião', '87047-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2499, 'Araucária', 'Antônio Alves Pinto', 'Thomaz Coelho', '83707-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2500, 'Maringá', 'Antônio Alves Ramalho', 'Conjunto Habitacional Requião', '87047-456', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2501, 'Londrina', 'Antônio Alves Resende', 'Colúmbia', '86057-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2502, 'Londrina', 'Antônio Alves Rezende', 'Jardim Tropical', '86087-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2503, 'Pinhais', 'Antônio Alves Santos', 'Vale da Boa Esperança', '83320-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2504, 'Londrina', 'Antônio Amadeu', 'Monte Belo', '86041-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2505, 'Londrina', 'Antônio Amado Noivo', 'Vila Ipiranga', '86010-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2506, 'Maringá', 'Antônio Amaral', 'Vila Esperança', '87030-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2507, 'Colombo', 'Antônio Amilton Baggio', 'Centro Industrial Mauá', '83413-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2508, 'Colombo', 'Antônio Amilton Trevisan', 'Centro Industrial Mauá', '83413-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2509, 'Maringá', 'Antônio Andrade', 'Jardim Andrade', '87035-425', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2510, 'Curitiba', 'Antônio André Jansson', 'São Braz', '82315-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2511, 'Colombo', 'Antônio André Johnsson', 'Centro', '83414-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2512, 'Curitiba', 'Antônio Andriguetto', 'Uberaba', '81580-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2513, 'Curitiba', 'Antônio Antoniacomi', 'Santa Cândida', '82630-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2514, 'Londrina', 'Antônio Antunes Felício', 'Conjunto Habitacional José Garcia Molina', '86080-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2515, 'Piraquara', 'Antônio Aparecido Esteves', 'Vila Ipanema', '83301-059', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2516, 'Colombo', 'Antônio Appel', 'Planta Santa Úrsula', '83405-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2517, 'Pato Branco', 'Antônio Ascari', 'Cristo Rei', '85506-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2518, 'Londrina', 'Antônio Augusto', 'Ernani de Moura Lima', '86037-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2519, 'Curitiba', 'Antônio Augusto de Brito', 'Umbará', '81930-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2520, 'Londrina', 'Antônio Augusto de Faria', 'São Lourenço', '86043-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2521, 'Londrina', 'Antônio Augusto de Oliveira', 'San Fernando', '86040-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2522, 'Curitiba', 'Antônio Augusto Fiorenzano', 'Santa Felicidade', '82410-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2523, 'Foz do Iguaçu', 'Antônio Ayres de Aguirra', 'Jardim Eliza I', '85853-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2524, 'Toledo', 'Antônio B. Soares', 'Jardim Cassandra', '85909-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2525, 'Curitiba', 'Antônio Baggio', 'Umbará', '81930-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2526, 'Londrina', 'Antônio Baldan', 'Andes', '86076-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2527, 'Londrina', 'Antônio Baldo', 'Assis', '86085-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2528, 'Ponta Grossa', 'Antônio Balzer', 'Chapada', '84063-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2529, 'Umuarama', 'Antônio Bandeira', 'Conjunto Residencial Ouro Preto', '87504-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2530, 'Piraquara', 'Antônio Baptista Salgueiro', 'Vila San Remo I', '83301-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2531, 'Campo Largo', 'Antônio Barausse', 'Vila Elizabeth', '83607-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2532, 'Guarapuava', 'Antônio Barbosa', 'Santana', '85070-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2533, 'Curitiba', 'Antônio Barbosa de Oliveira', 'Cajuru', '82950-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2534, 'Curitiba', 'Antônio Barbosa Ferraz Júnior', 'Portão', '81320-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2535, 'Curitiba', 'Antônio Bariquelo', 'Fanny', '81030-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2536, 'Curitiba', 'Antônio Bartapeli', 'Santa Felicidade', '82030-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2537, 'Colombo', 'Antônio Batista da Silva', 'Jardim dos Eucaliptos', '83408-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2538, 'São José dos Pinhais', 'Antônio Batista de Bastos', 'Afonso Pena', '83065-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2787, 'Guarapuava', 'Antônio Gaudi', 'São Cristóvão', '85063-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2539, 'Almirante Tamandaré', 'Antônio Batista de Siqueira', 'Vila Santa Terezinha', '83501-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2540, 'Curitiba', 'Antônio Batista Valle', 'São João', '82030-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2541, 'Pato Branco', 'Antônio Bazzo', 'Anchieta', '85501-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2542, 'Londrina', 'Antônio Belasco', 'Jardim Vale Verde', '86040-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2543, 'Maringá', 'Antônio Beltran', 'Conjunto Residencial Itamaraty', '87015-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2544, 'Colombo', 'Antônio Benato', 'Jardim Monza', '83406-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2545, 'Curitiba', 'Antônio Bento', 'Sítio Cercado', '81910-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2546, 'Apucarana', 'Antônio Bernardes Filho', 'Vila Swain', '86800-456', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2547, 'Londrina', 'Antônio Bernardi', 'Residencial Portal de Piza', '86041-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2548, 'Apucarana', 'Antônio Bertasso', 'Residencial Parque da Raposa', '86812-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2549, 'Curitiba', 'Antônio Bertazoni', 'Xaxim', '81710-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2550, 'Apucarana', 'Antônio Berton', 'Loteamento Residencial Tami', '86803-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2551, 'Colombo', 'Antônio Betinardi', 'Jardim N das Graças', '83407-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2552, 'Londrina', 'Antônio Bezerra de Lima', 'Jardim Olga', '86087-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2553, 'São José dos Pinhais', 'Antônio Bianchetti', 'Afonso Pena', '83065-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2554, 'Almirante Tamandaré', 'Antônio Bini', 'Jardim Bela Vista', '83513-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2555, 'Campo Mourão', 'Antônio Bitencourt Franco', 'Jardim Bandeirantes', '87308-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2556, 'Campo Largo', 'Antônio Boaron', 'Botiatuva', '83602-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2557, 'Cambé', 'Antônio Bocate', 'Jardim Boa Vista', '86191-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2558, 'Londrina', 'Antônio Bonato', 'Jardim San Diego', '86073-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2559, 'Curitiba', 'Antônio Bonfim', 'Cachoeira', '82710-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2560, 'Francisco Beltrão', 'Antônio Bordignon', 'São Cristóvão', '85601-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2561, 'Curitiba', 'Antônio Borges', 'Cidade Industrial', '81315-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2562, 'Campo Largo', 'Antônio Borges de Carvalho', 'Jardim Florestal', '83602-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2563, 'Guarapuava', 'Antônio Bortolanza', 'Morro Alto', '85065-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2564, 'Londrina', 'Antônio Bortolato', 'Residencial Portal de Piza', '86041-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2565, 'Londrina', 'Antônio Bortolotti', 'Lindóia', '86031-270', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2566, 'Curitiba', 'Antônio Boza', 'Sítio Cercado', '81925-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2567, 'Pinhais', 'Antônio Braga', 'Planta Núcleo Colonial de Pinhais', '83321-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2568, 'Maringá', 'Antônio Brambilla', 'Jardim Paris', '87083-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2569, 'Ponta Grossa', 'Antônio Branco', 'Uvaranas', '84025-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2570, 'Londrina', 'Antônio Brandalize', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2571, 'Curitiba', 'Antônio Brandalize', 'Uberaba', '81570-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2572, 'Toledo', 'Antônio Bressan', 'Conjunto Habitacional São Francisco', '85912-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2573, 'Guarapuava', 'Antônio Bridi', 'Bonsucesso', '85045-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2574, 'Araucária', 'Antônio Brunatto', 'Costeira', '83708-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2575, 'Londrina', 'Antônio Brutomesso', 'Maria Lúcia', '86072-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2576, 'Curitiba', 'Antônio Brzowski', 'Mossunguê', '81210-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2577, 'Campo Mourão', 'Antônio Bueno de Camargo', 'Jardim Gutierres', '87300-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2578, 'Cambé', 'Antônio Burgo', 'Jardim José Favaro', '86183-786', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2579, 'Cambé', 'Antônio Burgo Filho', 'Jardim José Favaro', '86183-788', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2580, 'Colombo', 'Antônio Busato', 'Vila Ana Maria', '83413-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2581, 'Curitiba', 'Antônio Buso', 'Cajuru', '82960-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2582, 'Paranavaí', 'Antônio Buzignani', 'Vila Operária', '87708-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2583, 'Cambé', 'Antônio C. Grades', 'Conjunto Residencial Roberto Conceição', '86183-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2584, 'Londrina', 'Antônio Caetano Barbosa', 'Catuai', '86086-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2585, 'Curitiba', 'Antônio Calheiro Rodrigues', 'Uberaba', '81560-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2586, 'Curitiba', 'Antônio Camilo', 'Tarumã', '82530-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2587, 'Curitiba', 'Antônio Camilo da Paz', 'Alto Boqueirão', '81770-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2588, 'Pato Branco', 'Antônio Camozzatto', 'Centro', '85501-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2589, 'Curitiba', 'Antônio Cândido Cavalim', 'Bairro Alto', '82820-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2590, 'Curitiba', 'Antônio Cândido Ferreira', 'Prado Velho', '80215-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2591, 'Araucária', 'Antônio Cândido Nascimento', 'Fazenda Velha', '83703-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2592, 'Araucária', 'Antônio Cantador', 'Iguaçu', '83701-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2593, 'Ponta Grossa', 'Antônio Caos', 'Uvaranas', '84031-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2594, 'Colombo', 'Antônio Capellari', 'Planta Santa Tereza', '83401-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2595, 'Londrina', 'Antônio Capello', 'Pantaneiro', '86072-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2596, 'Londrina', 'Antônio Caramori', 'Conjunto Residencial Marajoara', '86080-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2597, 'Umuarama', 'Antônio Cardoso', 'Parque das Jaboticabeiras', '87509-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2598, 'Apucarana', 'Antônio Cardoso', 'Núcleo Habitacional João Goulart', '86807-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2599, 'Ponta Grossa', 'Antônio Carlos', 'Nova Rússia', '84053-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2600, 'Almirante Tamandaré', 'Antônio Carlos Borges', 'Jardim Parati', '83503-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2601, 'Londrina', 'Antônio Carlos Coral', 'Maria Lúcia', '86072-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2602, 'Guarapuava', 'Antônio Carlos Cúnico', 'Boqueirão', '85020-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2603, 'Apucarana', 'Antônio Carlos da Silva', 'Jardim Santos Dumont I', '86812-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2604, 'Maringá', 'Antônio Carlos de Held', 'Jardim Alvorada', '87033-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2605, 'Curitiba', 'Antônio Carlos de Jesus Maiolino', 'Santa Cândida', '82720-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2606, 'Londrina', 'Antônio Carlos de Oliveira Leme', 'Jardim Ilha do Mel', '86081-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2607, 'Londrina', 'Antônio Carlos Fausto Sodré', 'Sabará I', '86066-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2608, 'Cascavel', 'Antônio Carlos Kraide', 'Brasília', '85815-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2609, 'Londrina', 'Antônio Carlos Ranéa', 'Jardim Paris', '86082-099', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2610, 'Francisco Beltrão', 'Antônio Carneiro Neto', 'Alvorada', '85601-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2611, 'Maringá', 'Antônio Carniel', 'Zona 05', '87015-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2612, 'Londrina', 'Antônio Carvalho', 'Jacutinga', '86087-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2613, 'São José dos Pinhais', 'Antônio Cavalli', 'Miringuava', '83090-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2614, 'Colombo', 'Antônio Cavalli', 'Jardim Marambaia', '83404-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2615, 'Colombo', 'Antônio Cavassin', 'Centro', '83414-140', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2616, 'Apucarana', 'Antônio Cazarin', 'Loteamento Residencial Cazarin', '86802-436', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2617, 'Colombo', 'Antônio Ceccon', 'Centro Industrial Mauá', '83413-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2618, 'Curitiba', 'Antônio Celli', 'Água Verde', '80250-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2619, 'Londrina', 'Antônio César Callero', 'Jardim Athenas', '86082-006', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2620, 'Curitiba', 'Antônio César Casagrande', 'Pilarzinho', '82110-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2621, 'Londrina', 'Antônio Cesário Vidal', 'Jardim San Diego', '86073-655', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2622, 'Foz do Iguaçu', 'Antônio Cezar Cabral', 'Parque Presidente II', '85863-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2623, 'São José dos Pinhais', 'Antônio Chabereck', 'Afonso Pena', '83050-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2624, 'Curitiba', 'Antônio Chalbaud Biscaia', 'Guabirotuba', '81510-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2625, 'Curitiba', 'Antônio Chella', 'Bom Retiro', '80520-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2626, 'Colombo', 'Antônio Chemin', 'Roça Grande', '83403-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2627, 'Almirante Tamandaré', 'Antônio Chevonica', 'Jardim Paraíso', '83512-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2628, 'Curitiba', 'Antônio Chueda', 'Ganchinho', '81935-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2629, 'Curitiba', 'Antônio Claudino', 'Pinheirinho', '81870-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2630, 'São José dos Pinhais', 'Antônio Claudino Barbosa', 'Costeira', '83015-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2631, 'Cascavel', 'Antônio Cláudio Gorino', 'Santa Cruz', '85806-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2632, 'Maringá', 'Antônio Clemente da Costa Neto', 'Parque das Grevíleas', '87025-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2633, 'Maringá', 'Antônio Clementino Ferreira', 'Conjunto João de Barro I', '87053-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2634, 'Curitiba', 'Antônio Coelho Santos', 'Boqueirão', '81750-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2635, 'Francisco Beltrão', 'Antônio Cogo', 'Vila Nova', '85605-056', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2636, 'Londrina', 'Antônio Colli Filho', 'Jardim Imagawa', '86080-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2637, 'Curitiba', 'Antônio Coltro', 'Alto Boqueirão', '81770-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2638, 'Toledo', 'Antônio Comarella', 'Conjunto Habitacional São Francisco', '85905-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2639, 'Campo Mourão', 'Antônio Constâncio de Souza', 'Jardim Paulista', '87310-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2640, 'São José dos Pinhais', 'Antônio Constantino Machado', 'Águas Belas', '83010-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2641, 'Ponta Grossa', 'Antônio Contim Mendes', 'Boa Vista', '84072-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2642, 'Curitiba', 'Antônio Contin', 'Cajuru', '82940-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2643, 'Pinhais', 'Antônio Cordeiro', 'Loteamento Pineville', '83325-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2644, 'São José dos Pinhais', 'Antônio Cordeiro da Rocha', 'Braga', '83020-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2645, 'Curitiba', 'Antônio Corrêa Bittencourt', 'Ahú', '82200-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2646, 'Almirante Tamandaré', 'Antônio Correia', 'Vila Palmira', '83514-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2647, 'Maringá', 'Antônio Correia Fontana', 'Vila Esperança', '87020-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2648, 'São José dos Pinhais', 'Antônio Costa', 'São Pedro', '83005-540', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2649, 'Curitiba', 'Antônio Costa', 'Vista Alegre', '80820-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2650, 'Londrina', 'Antônio Cotarelli', 'Conjunto Habitacional José Garcia Molina', '86080-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2651, 'Cambé', 'Antônio Crippa', 'Jardim Santa Adelaide', '86192-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2652, 'Londrina', 'Antônio Cursi', 'Jardim Piza', '86073-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2653, 'Paranavaí', 'Antônio Custódio dos Santos Júnior', 'Jardim Santos Dumont', '87706-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2654, 'Colombo', 'Antônio Czocher', 'Jardim Guadalajara', '83402-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2655, 'Londrina', 'Antônio da Silva', 'Novo Amparo', '86087-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2656, 'Colombo', 'Antônio da Silva', 'Vila Santo Antônio', '83413-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2657, 'Piraquara', 'Antônio da Silva Pinto', 'Vila Ipanema', '83301-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2658, 'Curitiba', 'Antônio Dalmarco', 'Fazendinha', '81320-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2659, 'Cascavel', 'Antônio Damian', 'Claudete', '85811-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2660, 'Curitiba', 'Antônio Daniel Dalcuche Filho', 'Uberaba', '81570-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2661, 'Curitiba', 'Antônio Dantas', 'Capão Raso', '81020-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2662, 'Curitiba', 'Antônio Dariva', 'Campo Comprido', '81220-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2663, 'Pinhais', 'Antônio de Andrade', 'Vila Maria Antonieta', '83331-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2664, 'Cambé', 'Antônio de Angeli', 'Jardim Itália', '86192-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2665, 'Londrina', 'Antônio de Carvalho Lage Filho', 'Cilo 3', '86073-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2666, 'Pinhais', 'Antônio de Castro Alves', 'Núcleo Colonial de Pinhais', '83321-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2667, 'Curitiba', 'Antônio de Cristo', 'Atuba', '82860-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2668, 'Curitiba', 'Antônio de Lima Castro', 'Portão', '80330-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2669, 'Cascavel', 'Antônio de Matos', 'Pioneiros Catarinenses', '85805-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2670, 'Londrina', 'Antônio de Moraes', 'Dom Pedro', '86039-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2671, 'Londrina', 'Antônio de Moraes Barros', 'Petrópolis', '86015-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2672, 'Curitiba', 'Antônio de Oliveira Furmann', 'Boa Vista', '82540-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2673, 'Curitiba', 'Antônio de Oliveira Santos', 'Cidade Industrial', '81315-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2674, 'Maringá', 'Antônio de Oliveira Sobrinho', 'Copacabana Residencial', '87023-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2675, 'Francisco Beltrão', 'Antônio de Paiva Cantelmo', 'Industrial', '85601-270', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2676, 'Colombo', 'Antônio de Paula', 'Vila São Paulo', '83411-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2677, 'Almirante Tamandaré', 'Antônio de Paula Braga', 'Vila Formosa', '83506-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2678, 'Curitiba', 'Antônio de Paula Chanosky', 'São Braz', '82310-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2679, 'Curitiba', 'Antônio de Paula Franca', 'Cascatinha', '82020-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2680, 'Curitiba', 'Antônio de Pauli', 'Campo Comprido', '81210-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2681, 'Almirante Tamandaré', 'Antônio de Siqueira', 'Vila Rachel', '83501-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2682, 'Almirante Tamandaré', 'Antônio de Souza', 'Vila Joly', '83505-126', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2683, 'Colombo', 'Antônio de Souza', 'Jardim Guadalajara', '83402-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2684, 'Ponta Grossa', 'Antônio Dechandt', 'Uvaranas', '84031-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2685, 'Apucarana', 'Antônio Delgado Maldonado', 'Jardim Aviação', '86812-518', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2686, 'Paranavaí', 'Antônio Diamante', 'Jardim América', '87705-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2687, 'Guarapuava', 'Antônio Dias Adorno', 'Primavera', '85050-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2688, 'Cambé', 'Antônio Dias Adorno', 'Jardim Riviera', '86187-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2689, 'Curitiba', 'Antônio Dias Barbosa', 'Cajuru', '82960-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2690, 'Londrina', 'Antônio Diniz do Paro Sobral', 'Conjunto Café', '86038-005', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2691, 'Curitiba', 'Antônio Dionísio Marach', 'Cachoeira', '82710-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2692, 'Curitiba', 'Antônio Dionísio Sobrinho', 'Cidade Industrial', '81450-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2693, 'Curitiba', 'Antônio do Rosário', 'Xaxim', '81710-035', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2694, 'São José dos Pinhais', 'Antônio Dombrowski', 'Miringuava', '83090-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2695, 'Curitiba', 'Antônio Domeneguetti', 'Cidade Industrial', '81305-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2696, 'Apucarana', 'Antônio Domingos Alves', 'Vila Country Club', '86808-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2697, 'Londrina', 'Antônio Domingues de Oliveira', 'Parque Industrial Alicante', '86087-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2698, 'Cambé', 'Antônio Donadio', 'Vila Mesquita', '86182-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2699, 'Guarapuava', 'Antônio Dorigon', 'Vila Carli', '85040-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2700, 'Curitiba', 'Antônio Duarte Velloso', 'Bom Retiro', '80520-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2701, 'Cascavel', 'Antônio Eduardo', '14 de Novembro', '85804-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2702, 'Umuarama', 'Antônio Eduardo Giovanini', 'Parque Bandeirantes', '87504-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2703, 'Curitiba', 'Antônio Eduardo Matuszewski', 'Cidade Industrial', '81460-159', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2704, 'Almirante Tamandaré', 'Antônio Eduardo Trevisan', 'Jardim Dona Belizaria', '83513-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2705, 'Londrina', 'Antônio Eleutério Naves', 'Conjunto Habitacional Bronzzetti', '86037-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2706, 'Curitiba', 'Antônio Emílio Cumin', 'Uberaba', '81590-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2707, 'Cascavel', 'Antônio Engremonn', 'Brasília', '85815-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2708, 'Paranavaí', 'Antônio Eredia Molina', 'Jardim Ipê', '87707-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2709, 'Curitiba', 'Antônio Ernesto Antonietto', 'Cajuru', '82950-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2710, 'Curitiba', 'Antônio Escorsin', 'São Braz', '82310-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2711, 'Curitiba', 'Antônio Escorsin', 'Santa Felicidade', '82015-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2712, 'Curitiba', 'Antônio Escorsin', 'São Braz', '82300-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2713, 'Londrina', 'Antônio Escudeiro Martins', 'Conjunto Professora Hilda Mandarino', '86080-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2714, 'Colombo', 'Antônio Euclydes da Silva', 'Jardim Eldorado', '83402-747', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2715, 'Londrina', 'Antônio Euclydes Sapia', 'Conjunto Habitacional  Alexandre Urbanas', '86037-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2716, 'Guarapuava', 'Antônio F. Rodrigues', 'São Cristóvão', '85060-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2717, 'Campo Largo', 'Antônio Fabrício da Silva', 'Vila Solene', '83607-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2718, 'Colombo', 'Antônio Falavinha', 'Vila Vale Verde', '83406-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2719, 'Curitiba', 'Antônio Falcão', 'Cascatinha', '82020-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2720, 'Guarapuava', 'Antônio Farah', 'Santana', '85070-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2721, 'Londrina', 'Antônio Faria Filho', 'Pinheiros', '86063-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2722, 'Londrina', 'Antônio Favoretto', 'Jardim Graziela', '86036-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2723, 'Paranaguá', 'Antônio Felintro de Lima', 'Vila do Caic', '83215-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2724, 'Paranavaí', 'Antônio Felipe', 'Jardim São João', '87709-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2725, 'Paranavaí', 'Antônio Felipe', 'Centro', '87702-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2726, 'Paranavaí', 'Antônio Felipe', 'Centro', '87704-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2727, 'Curitiba', 'Antônio Fernandes Apolinario', 'Santa Cândida', '82630-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2728, 'Curitiba', 'Antônio Fernandes da Silva', 'Cidade Industrial', '81170-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2729, 'Londrina', 'Antônio Fernandes Guerra', 'Tucano', '86047-155', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2730, 'Ponta Grossa', 'Antônio Fernando Oldakowski', 'Contorno', '84061-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2731, 'Colombo', 'Antônio Ferrarini', 'Colônia Faria', '83412-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2732, 'Curitiba', 'Antônio Ferreira', 'Portão', '81070-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2733, 'Londrina', 'Antônio Ferreira da Costa', 'Conjunto Café', '86038-015', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2734, 'Curitiba', 'Antônio Ferreira do Nascimento Filho', 'Cidade Industrial', '81230-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2735, 'Curitiba', 'Antônio Ferreira Lemos', 'Portão', '81320-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2736, 'Curitiba', 'Antônio Ferreira Maciel', 'Santa Cândida', '82650-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2737, 'Castro', 'Antônio Ferreira Salgado', 'Vila Santa Cruz', '84168-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2738, 'Almirante Tamandaré', 'Antônio Ferro', 'Boichininga', '83513-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2739, 'Curitiba', 'Antônio Ferro', 'Santa Felicidade', '82030-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2740, 'Araucária', 'Antônio Fila', 'Boqueirão', '83704-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2741, 'Colombo', 'Antônio Fiorese', 'Jardim Bandeirantes', '83408-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2742, 'São José dos Pinhais', 'Antônio Florêncio Guimarães', 'Silveira da Motta', '83030-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2743, 'Curitiba', 'Antônio Floriano Filho', 'Xaxim', '81710-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2744, 'São José dos Pinhais', 'Antônio Foggiatto', 'Zaniolo', '83025-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2745, 'Toledo', 'Antônio Foiato', 'Conjunto Habitacional São Francisco', '85912-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2746, 'Curitiba', 'Antônio Folly Primo', 'Santa Felicidade', '82020-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2747, 'Curitiba', 'Antônio Foltran', 'Bigorrilho', '80710-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2748, 'Cambé', 'Antônio Forastieri', 'Jardim Vila Rica', '86192-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2749, 'Colombo', 'Antônio Fracaro', 'Jardim Belo Rincão', '83412-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2750, 'Araucária', 'Antônio Franca', 'Centro', '83702-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2751, 'Curitiba', 'Antônio Francisco Bonatto', 'Ahú', '80540-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2752, 'São José dos Pinhais', 'Antônio Francisco de Andrade', 'Guatupê', '83060-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2753, 'Foz do Iguaçu', 'Antônio Francisco de Matos', 'Jardim Marisa', '85867-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2754, 'Almirante Tamandaré', 'Antônio Francisco Lisboa', 'Planta Nossa Senhora do Pilar', '83508-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2755, 'Colombo', 'Antônio Francisco Lisboa', 'Jardim Alvorada', '83409-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2756, 'São José dos Pinhais', 'Antônio Francisco Luciano', 'Braga', '83020-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2757, 'Maringá', 'Antônio Francisco Rodrigues', 'Parque Residencial Patrícia', '87040-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2758, 'Colombo', 'Antônio Francisco Scrok', 'Vila Vale Verde', '83406-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2759, 'Londrina', 'Antônio Francisco Segantin', 'Garden Park Residence', '86079-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2760, 'Londrina', 'Antônio Franco', 'Arrabal', '86086-015', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2761, 'Pato Branco', 'Antônio Franco', 'Bortot', '85504-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2762, 'Ponta Grossa', 'Antônio Franke', 'Chapada', '84063-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2763, 'Londrina', 'Antônio Franzin', 'Parque Industrial Buena Vista', '86032-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2764, 'Colombo', 'Antônio Frasão', 'Jardim Monte Líbano', '83407-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2765, 'Paranavaí', 'Antônio Frederico Ozanam', 'Vila Operária', '87708-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2766, 'Maringá', 'Antônio Frederico Ozanam', 'Jardim São Jorge', '87080-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2767, 'Campo Mourão', 'Antônio Frederico Ozanam', 'Jardim Lopes', '87302-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2768, 'Ponta Grossa', 'Antônio Frederico Ozanan', 'Estrela', '84050-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2769, 'Curitiba', 'Antônio Freitas Barbosa', 'Capão Raso', '81110-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2770, 'Maringá', 'Antônio Fuji', 'Vila Esperança', '87020-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2771, 'Curitiba', 'Antônio Furlan', 'Bacacheri', '82510-030', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2772, 'Curitiba', 'Antônio Furtado Figueiredo', 'Barreirinha', '82210-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2773, 'Piraquara', 'Antônio Gabardo', 'Guarituba', '83311-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2774, 'Curitiba', 'Antônio Gabardo', 'Umbará', '81940-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2775, 'Campo Largo', 'Antônio Gabardo Júnior', 'Conjunto Águas Claras', '83602-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2776, 'Campo Largo', 'Antônio Gabardo Júnior', 'Bom Jesus', '83604-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2777, 'Araucária', 'Antônio Gabriel Siemens', 'Barigui', '83707-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2778, 'Curitiba', 'Antônio Gagno', 'Cidade Industrial', '81450-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2779, 'Curitiba', 'Antônio Gai', 'Tatuquara', '81480-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2780, 'Maringá', 'Antônio Galera Garri', 'Jardim Novo Horizonte', '87010-147', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2781, 'Curitiba', 'Antônio Galléas', 'Capão Raso', '81130-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2782, 'Ponta Grossa', 'Antônio Garcia Valentim', 'Boa Vista', '84072-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2783, 'São José dos Pinhais', 'Antônio Gasola', 'Zaniolo', '83025-746', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2784, 'Colombo', 'Antônio Gasparin', 'Serrinha', '83415-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2785, 'Colombo', 'Antônio Gasparin', 'Centro', '83414-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2786, 'Curitiba', 'Antônio Gasparin', 'Novo Mundo', '81050-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2788, 'Londrina', 'Antônio Gaya', 'Conjunto Habitacional  Alexandre Urbanas', '86037-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2789, 'Pinhais', 'Antônio Gelinski', 'Jardim Triângulo', '83331-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2790, 'Colombo', 'Antônio Gentil', 'Vila Luiz Baron', '83412-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2791, 'Foz do Iguaçu', 'Antônio Gerassi', 'Loteamento Parque do Patriarco', '85854-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2792, 'Curitiba', 'Antônio Geronasso', 'Boa Vista', '82540-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2793, 'Curitiba', 'Antônio Geroslau Ferreira', 'Cidade Industrial', '81450-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2794, 'Almirante Tamandaré', 'Antônio Gideão Tosin', 'Vila Bela Vista', '83513-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2795, 'Londrina', 'Antônio Gil dos Santos Gameiro', 'Aníbal de Siqueira Cabral', '86089-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2796, 'Apucarana', 'Antônio Gilberto M. de Oliveira', 'Núcleo Habitacional das Indústrias', '86806-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2797, 'Campo Largo', 'Antônio Gitkoski', 'Botiatuva', '83602-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2798, 'Cambé', 'Antônio Godoy Rodrigues', 'Jardim Vô Zezinho', '86192-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2799, 'Campo Mourão', 'Antônio Gomes', 'Jardim Nossa Senhora Aparecida', '87309-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2800, 'Londrina', 'Antônio Gomes da Silva', 'Residencial Portal do Sol', '86082-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2801, 'Londrina', 'Antônio Gomes Santiago', 'Ernani de Moura Lima', '86037-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2802, 'Curitiba', 'Antônio Gomide', 'Fazendinha', '81330-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2803, 'Apucarana', 'Antônio Gonçalves da Silva', 'Vila Nova', '86812-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2804, 'Pinhais', 'Antônio Gonçalves Dias', 'Núcleo Colonial de Pinhais', '83321-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2805, 'Pinhais', 'Antônio Gonçalves dos Santos', 'Planta Cláudio Mehl', '83326-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2806, 'Londrina', 'Antônio Gonçalves Ortiz', 'Colúmbia', '86057-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2807, 'Curitiba', 'Antônio Gongola', 'Boa Vista', '82560-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2808, 'Almirante Tamandaré', 'Antônio Gouvea', 'Jardim do Norte', '83511-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2809, 'Paranavaí', 'Antônio Graaff', 'Vila Operária', '87708-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2810, 'Curitiba', 'Antônio Grade', 'Vista Alegre', '80820-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2811, 'Campo Mourão', 'Antônio Graniuk', 'Jardim Bandeirantes', '87308-520', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2812, 'Curitiba', 'Antônio Greca', 'Ahú', '82200-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2813, 'Guarapuava', 'Antônio Gregório Ferreira', 'Conradinho', '85055-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2814, 'Curitiba', 'Antônio Grochovski', 'Santa Cândida', '82720-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2815, 'Curitiba', 'Antônio Grocoske', 'Prado Velho', '80215-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2816, 'Curitiba', 'Antônio Gruba', 'Vista Alegre', '80820-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2817, 'Apucarana', 'Antônio Grubisick', 'Núcleo Habitacional Osmar G Freire', '86801-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2818, 'Almirante Tamandaré', 'Antônio Guedes', 'Jardim Água Boa', '83513-166', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2819, 'Ponta Grossa', 'Antônio Haas', 'Contorno', '84061-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2820, 'Toledo', 'Antônio Heiss', 'Jardim Concórdia', '85906-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2821, 'Curitiba', 'Antônio Hélio Ferraz de Oliveira', 'Cidade Industrial', '81460-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2822, 'Curitiba', 'Antônio Hofmann', 'Santa Quitéria', '80310-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2823, 'Toledo', 'Antônio Humberto Guimarães', 'Jardim Paulista', '85909-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2824, 'Colombo', 'Antônio Ignacio de Souza', 'Jardim Guadalajara', '83402-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2825, 'Londrina', 'Antônio Inácio Pereira', 'Coliseu', '86076-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2826, 'Paranaguá', 'Antônio Jabur', 'Vila Guarani', '83221-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2827, 'Londrina', 'Antônio Jacob Filho', 'Conjunto Vivi Xavier', '86082-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2828, 'Cambé', 'Antônio Jacomel', 'Jardim Boa Vista', '86191-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2829, 'Curitiba', 'Antônio Jerônymo', 'Cidade Industrial', '81170-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2830, 'Paranavaí', 'Antônio Jesus de Oliveira', 'Vila Prudêncio', '87702-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2831, 'Foz do Iguaçu', 'Antônio João', 'Centro', '85851-205', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2832, 'Londrina', 'Antônio João', 'Parque Residencial João Piza', '86041-135', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2833, 'Ponta Grossa', 'Antônio João', 'Orfãs', '84015-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2834, 'Paranavaí', 'Antônio João', 'Jardim São Jorge', '87710-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2835, 'Curitiba', 'Antônio João Ziliotto', 'Campina do Siqueira', '80740-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2836, 'Almirante Tamandaré', 'Antônio Johnson', 'Jardim das Oliveiras', '83503-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2837, 'Almirante Tamandaré', 'Antônio Johnson', 'Jardim Monte Santo', '83501-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2838, 'Curitiba', 'Antônio Jonque Filho', 'Uberaba', '81570-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2839, 'Campo Largo', 'Antônio Jordão Guiraud', 'Vila Bancária', '83601-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2840, 'Maringá', 'Antônio José Beraldo', 'Conjunto Habitacional Sol Nascente', '87055-455', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2841, 'Curitiba', 'Antônio José Bonato', 'Ganchinho', '81935-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2842, 'Paranavaí', 'Antônio José da Silva', 'Jardim Aeroporto', '87707-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2843, 'Paranavaí', 'Antônio José da Silva', 'Jardim Paraíso', '87708-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2844, 'Paranavaí', 'Antônio José da Silva', 'Jardim do Sol', '87711-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2845, 'Paranavaí', 'Antônio José de Meira', 'Jardim Paulista', '87709-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2846, 'Apucarana', 'Antônio José de Oliveira', 'Barra Funda', '86800-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2847, 'Apucarana', 'Antônio José de Oliveira', 'Jardim Figueira', '86801-670', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2848, 'Cascavel', 'Antônio José Elias', 'Coqueiral', '85807-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2849, 'Curitiba', 'Antônio José Francosi', 'Cidade Industrial', '81240-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2850, 'Castro', 'Antônio José Gomes', 'Morada do Sol', '84172-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2851, 'Castro', 'Antônio José Gomes', 'Jardim Social Primavera', '84174-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2852, 'Pinhais', 'Antônio José Pereira', 'Prive Bois de Boulogne', '83330-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2853, 'Maringá', 'Antônio José Pérez Corrêa', 'Jardim Botânico', '87060-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2854, 'Paranaguá', 'Antônio José Santana Lobo', 'Vila Guarani', '83221-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2855, 'Apucarana', 'Antônio Judai', 'Jardim Espanha', '86802-018', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2856, 'Campo Mourão', 'Antônio Justino Ferreira', 'Jardim Paulista', '87310-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2857, 'Guarapuava', 'Antônio Kais', 'Conradinho', '85055-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2858, 'Colombo', 'Antônio Kamaroski', 'Jardim Aurora', '83411-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2859, 'Curitiba', 'Antônio Kaminski', 'Orleans', '81200-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2860, 'Apucarana', 'Antônio Kare de Assis', 'Jardim Aviação', '86812-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2861, 'Colombo', 'Antônio Kierski', 'Vila Campo Alto', '83408-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2862, 'Curitiba', 'Antônio Kolody', 'Butiatuvinha', '82320-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2863, 'Curitiba', 'Antônio Kosovski', 'Boqueirão', '81670-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2864, 'Pinhais', 'Antônio Kowalczuck', 'Conjunto Residencial Inocoop', '83326-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2865, 'Piraquara', 'Antônio Kowalczuk', 'Centro', '83301-695', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2866, 'Curitiba', 'Antônio Krainiski', 'Abranches', '82130-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2867, 'Curitiba', 'Antônio Krasinski', 'Orleans', '81200-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2868, 'Araucária', 'Antônio Kujawa', 'Centro', '83702-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2869, 'Curitiba', 'Antônio Kusma', 'Cidade Industrial', '81260-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2870, 'Francisco Beltrão', 'Antônio L. Sabadin', 'Miniguaçu', '85605-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2871, 'Curitiba', 'Antônio Lacerda Braga', 'Cidade Industrial', '81170-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2872, 'Curitiba', 'Antônio Lago', 'Boa Vista', '82560-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2873, 'Araucária', 'Antônio Laskawski', 'Tindiquera', '83708-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2874, 'Curitiba', 'Antônio Lau', 'Campina do Siqueira', '80740-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2875, 'Cascavel', 'Antônio Leivas', 'Santa Felicidade', '85803-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2876, 'Curitiba', 'Antônio Leodenir Gabardo', 'Sítio Cercado', '81925-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2877, 'Londrina', 'Antônio Lima da Silva Filho', 'Bourbon', '86046-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2878, 'São José dos Pinhais', 'Antônio Lino de Assis', 'Ipê', '83055-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2879, 'Apucarana', 'Antônio Lolo Menegazzo Filho', 'Jardim Menegazzo', '86802-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2880, 'Londrina', 'Antônio Lopes', 'Giovani Lunardelli', '86037-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2881, 'Londrina', 'Antônio Lopes Alves', 'Catuai', '86086-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2882, 'Londrina', 'Antônio Lopes Servilha', 'Conjunto Semiramis Barros Braga', '86088-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2883, 'Guarapuava', 'Antônio Losso', 'Conradinho', '85055-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2884, 'Maringá', 'Antônio Lourenço', 'Conjunto João de Barro Porto Seguro II', '87055-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2885, 'Colombo', 'Antônio Lourenço Lazarotto', 'Serrinha', '83415-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2886, 'Campo Mourão', 'Antônio Lourival Bathke', 'Jardim Santa Cruz', '87309-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2887, 'Cascavel', 'Antônio Lucas de Castilhos', 'Vila Tolentino', '85802-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2888, 'Londrina', 'Antônio Luciano', 'Nova Conquista', '86040-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2889, 'Curitiba', 'Antônio Luiz de Oliveira', 'Pinheirinho', '81870-215', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2890, 'Curitiba', 'Antônio Luiz Rodrigues Freitas', 'Cidade Industrial', '81270-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2891, 'Curitiba', 'Antônio Luiz Vieira', 'Pilarzinho', '82120-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2892, 'Guarapuava', 'Antônio Lustosa de Siqueira', 'Primavera', '85050-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2893, 'Curitiba', 'Antônio Luza', 'Cidade Industrial', '81305-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2894, 'Araucária', 'Antônio Machnievicz', 'Campina da Barra', '83709-757', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2895, 'Curitiba', 'Antônio Macioski', 'Campo Comprido', '81270-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2896, 'Curitiba', 'Antônio Maestrelli', 'Cidade Industrial', '81460-287', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2897, 'Paranaguá', 'Antônio Maia', 'Jardim Araçá', '83221-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2898, 'Londrina', 'Antônio Mano', 'Jardim Pacaembu', '86079-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2899, 'Curitiba', 'Antônio Manoel Gomes', 'Novo Mundo', '81050-686', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2900, 'Pinhais', 'Antônio Manoel Martins', 'Prive Bois de Boulogne', '83330-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2901, 'Londrina', 'Antônio Manoel Ribeiro', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2902, 'Londrina', 'Antônio Mantovani', 'Jardim Maria Celina', '86081-535', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2903, 'Cambé', 'Antônio Mantovani', 'Parque Residencial Ana Rosa', '86183-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2904, 'Curitiba', 'Antônio Manzocki', 'Mercês', '80710-190', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2905, 'Foz do Iguaçu', 'Antônio Maran', 'Novo Mundo', '85862-429', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2906, 'Londrina', 'Antônio Marcelino de Oliveira', 'Jardim São Jorge', '86082-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2907, 'Curitiba', 'Antônio Marcelino Scalet', 'Pinheirinho', '81825-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2908, 'Francisco Beltrão', 'Antônio Marcelo', 'Luther King', '85605-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2909, 'Curitiba', 'Antônio Marchiorato', 'Cachoeira', '82710-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2910, 'Ponta Grossa', 'Antônio Marenda', 'Cará-cará', '84033-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2911, 'Ponta Grossa', 'Antônio Marenda', 'Colônia Dona Luiza', '84045-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2912, 'Maringá', 'Antônio Maria', 'Conjunto Residencial Cidade Alta', '87053-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2913, 'Londrina', 'Antônio Maria Claretti', 'Petrópolis', '86015-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2914, 'Curitiba', 'Antônio Mariano de Lima', 'Abranches', '82130-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2915, 'Maringá', 'Antônio Marin', 'Vila Santo Antônio', '87020-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2916, 'Londrina', 'Antônio Marques', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2917, 'Curitiba', 'Antônio Martin de Araújo', 'Jardim Botânico', '80210-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2918, 'Campo Mourão', 'Antônio Martins da Silva', 'Jardim Joana D''Arc', '87300-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2919, 'Londrina', 'Antônio Martins Fernandes', 'Eucaliptos', '86031-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2920, 'Londrina', 'Antônio Martins Lardin', 'Parque Universidade', '86056-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2921, 'Londrina', 'Antônio Martins Lopes', 'Gleba Ribeirão Jacutinga', '86087-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2922, 'Araucária', 'Antônio Marzalek', 'Thomaz Coelho', '83706-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2923, 'Colombo', 'Antônio Maschio', 'Parque Residencial Santa Terezinha', '83408-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2924, 'Londrina', 'Antônio Massao Miyasaki', 'Residencial Loris Sahyun', '86040-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2925, 'Cascavel', 'Antônio Massaro', 'Presidente', '85818-156', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2926, 'Curitiba', 'Antônio Matheus', 'Umbará', '81930-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2927, 'Almirante Tamandaré', 'Antônio Matilde dos Santos', 'Vila Ajambi', '83504-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2928, 'Londrina', 'Antônio Mazzer', 'Santa Joana', '86044-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2929, 'Piraquara', 'Antônio Meireles Sobrinho', 'Planta Meireles Sobrinho', '83304-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2930, 'Curitiba', 'Antônio Meirelles Sobrinho', 'Cajuru', '82900-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2931, 'Curitiba', 'Antônio Melillo', 'Parolin', '81030-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2932, 'Apucarana', 'Antônio Melnick', 'Vila Operária 2', '86802-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2933, 'Castro', 'Antônio Menarim', 'Vila Rio Branco', '84172-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2934, 'Araucária', 'Antônio Mendes', 'Costeira', '83709-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2935, 'Londrina', 'Antônio Mendes da Silva', 'Jardim Santa Fé', '86035-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2936, 'Curitiba', 'Antônio Mendes de Siqueira', 'Pinheirinho', '81870-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2937, 'Londrina', 'Antônio Mendonça da Silva', 'Franciscato', '86043-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2938, 'Londrina', 'Antônio Menegazzo', 'Cambezinho', '86040-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2939, 'Apucarana', 'Antônio Menegazzo', 'Jardim Menegazzo', '86802-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2940, 'Pinhais', 'Antônio Micheletti', 'Prive Bois de Boulogne', '83330-267', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2941, 'Apucarana', 'Antônio Miguel Pellegrina', 'Jardim Catuaí III', '86802-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2942, 'Araucária', 'Antônio Mikosz', 'Capela Velha', '83706-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2943, 'Londrina', 'Antônio Milton Mendes', 'Jardim Primavera', '86086-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2944, 'Curitiba', 'Antônio Mion', 'Alto da Rua XV', '80040-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2945, 'Almirante Tamandaré', 'Antônio Mirestzki', 'Vila Formosa', '83506-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2946, 'Curitiba', 'Antônio Moacir Ribeiro Batista', 'Cidade Industrial', '81310-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2947, 'Londrina', 'Antônio Molina Martins Filho', 'Residencial Moradias Tibagi', '86080-447', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2948, 'São José dos Pinhais', 'Antônio Molleta Filho', 'Costeira', '83015-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2949, 'São José dos Pinhais', 'Antônio Molletta Filho', 'Barro Preto', '83015-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2950, 'Francisco Beltrão', 'Antônio Montemezzo', 'Pinheirinho', '85606-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2951, 'Ponta Grossa', 'Antônio Moraes', 'Chapada', '84063-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2952, 'Paranaguá', 'Antônio Morais Pereira da Costa', 'Correia Velho', '83206-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2953, 'Cambé', 'Antônio Morandin', 'Jardim Itália', '86192-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2954, 'Maringá', 'Antônio Moreira Barbosa', 'Vila Christino', '87050-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2956, 'Ponta Grossa', 'Antônio Moro', 'Estrela', '84050-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2957, 'São José dos Pinhais', 'Antônio Moro', 'Costeira', '83010-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2958, 'Curitiba', 'Antônio Morona', 'Capão da Imbuia', '82810-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2959, 'Londrina', 'Antônio Motta Cruz', 'Limoeiro', '86037-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2960, 'Campo Largo', 'Antônio Munari', 'Bom Jesus', '83601-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2961, 'Londrina', 'Antônio Muniz Franco', 'Conjunto Habitacional José Giordano', '86082-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2962, 'Cambé', 'Antônio Muniz Franco', 'Novo Bandeirantes', '86188-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2963, 'Curitiba', 'Antônio Muzzillo', 'Tingui', '82600-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2964, 'Pinhais', 'Antônio Natal', 'Prive Bois de Boulogne', '83330-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2965, 'Ponta Grossa', 'Antônio Natel de Paula', 'Orfãs', '84015-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2966, 'Londrina', 'Antônio Negro', 'Jardim Maria Celina', '86081-546', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2967, 'Londrina', 'Antônio Niero', 'Esperança', '86046-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2968, 'Curitiba', 'Antônio Nogarolli', 'Bigorrilho', '80710-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2969, 'Paranavaí', 'Antônio Novaes Filho', 'Parque Morumbi', '87703-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2970, 'São José dos Pinhais', 'Antônio Nunes da Rocha Rios', 'Rio Pequeno', '83070-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2971, 'Foz do Iguaçu', 'Antônio Nunes Rios', 'Parque Presidente II', '85863-490', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2972, 'Campo Largo', 'Antônio Nunes Vieira', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-777', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2973, 'Maringá', 'Antônio Octávio Scramim', 'Zona 05', '87015-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2974, 'São José dos Pinhais', 'Antônio Olinto', 'São Pedro', '83020-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2975, 'Telêmaco Borba', 'Antônio Olinto', 'Alto das Oliveiras', '84266-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2976, 'Curitiba', 'Antônio Olinto', 'Capão Raso', '81130-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2977, 'Curitiba', 'Antônio Oliveira dos Santos', 'Santa Cândida', '82640-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2978, 'Curitiba', 'Antônio Olivetti', 'Cidade Industrial', '81270-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2979, 'Curitiba', 'Antônio Olívio Rodrigues', 'Capão da Imbuia', '82800-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2980, 'Curitiba', 'Antônio Onofrio Corrêa', 'Alto Boqueirão', '81850-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2981, 'Londrina', 'Antônio Ontiveros', 'Santa Mônica', '86079-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2982, 'São José dos Pinhais', 'Antônio Orilei Bastos', 'Rio Pequeno', '83070-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2983, 'Londrina', 'Antônio Orlando Abdo', 'Residencial Portal de Piza', '86041-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2984, 'Maringá', 'Antônio Ostrenky', 'Zona 08', '87050-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2985, 'Londrina', 'Antônio Ostrenski', 'Conjunto Café', '86038-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2986, 'Umuarama', 'Antônio Ostrenski', 'Zona I', '87501-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2987, 'Apucarana', 'Antônio Ostrenski', 'Centro', '86800-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2988, 'Campo Largo', 'Antônio Otacílio de Oliveira Pacheco', 'Jardim Florestal', '83602-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2989, 'Curitiba', 'Antônio Pacce', 'Jardim das Américas', '81540-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2990, 'Guarapuava', 'Antônio Pacheco', 'Morro Alto', '85065-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2991, 'Londrina', 'Antônio Pacheco Franco', 'Cafezal 1', '86049-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2992, 'São José dos Pinhais', 'Antônio Palanicki', 'Costeira', '83015-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2993, 'Araucária', 'Antônio Pannek', 'Costeira', '83708-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2994, 'Curitiba', 'Antônio Parize', 'Cascatinha', '82015-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2995, 'Curitiba', 'Antônio Parolin Júnior', 'Parolin', '80220-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2996, 'Curitiba', 'Antônio Pastre', 'Cidade Industrial', '81450-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2997, 'Curitiba', 'Antônio Pavelski', 'Augusta', '81260-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2998, 'Telêmaco Borba', 'Antônio Pedro de Souza', 'Socomim', '84266-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (2999, 'Curitiba', 'Antônio Pegoraro', 'Pilarzinho', '82120-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3000, 'Londrina', 'Antônio Pelegrinelli', 'Jardim Piza', '86073-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3001, 'Apucarana', 'Antônio Penharbel Esparza', 'Vila Amin Maia', '86800-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3002, 'Paranaguá', 'Antônio Pereira', 'Dom Pedro II', '83203-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3003, 'Paranaguá', 'Antônio Pereira', 'Vila Paranaguá', '83221-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3004, 'Londrina', 'Antônio Pereira da Silva', 'Jardim Vale Azul', '86041-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3005, 'Londrina', 'Antônio Pereira de Rezende', 'Recanto Edy', '86050-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3006, 'São José dos Pinhais', 'Antônio Pereira Vale', 'Guatupê', '83060-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3007, 'Apucarana', 'Antônio Peres Clabonde', 'Jardim Esperança', '86810-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3008, 'Colombo', 'Antônio Peres Moreno', 'Jardim dos Eucaliptos', '83408-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3009, 'Sarandi', 'Antônio Pérola', 'Parque São Pedro', '87112-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3010, 'Maringá', 'Antônio Peruzzi', 'Jardim Andrade', '87035-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3011, 'Curitiba', 'Antônio Petrini', 'Uberaba', '81580-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3012, 'Curitiba', 'Antônio Petruzziello', 'Pilarzinho', '82110-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3013, 'Londrina', 'Antônio Piacentini', 'Portal de Versalhes 3', '86055-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3014, 'Campo Largo', 'Antônio Pianaro', 'Vila Nossa Senhora do Carmo', '83601-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3015, 'Campo Largo', 'Antônio Pianaro', 'Jardim São Vicente', '83602-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3016, 'Londrina', 'Antônio Picinin', 'Monte Belo', '86041-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3017, 'Curitiba', 'Antônio Pietruza', 'Portão', '80610-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3018, 'Londrina', 'Antônio Pimentel', 'Jardim Honda II', '86076-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3019, 'Curitiba', 'Antônio Pinto de Jesus', 'Cidade Industrial', '81310-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3020, 'São José dos Pinhais', 'Antônio Piovesan', 'Bom Jesus', '83025-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3021, 'Curitiba', 'Antônio Pires da Silva', 'Lindóia', '81010-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3022, 'Londrina', 'Antônio Pisconti', 'Cafezal', '86045-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3023, 'Curitiba', 'Antônio Portela', 'Orleans', '82015-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3024, 'Ponta Grossa', 'Antônio Prado', 'Boa Vista', '84073-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3025, 'Ponta Grossa', 'Antônio Prado', 'Uvaranas', '84032-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3026, 'Colombo', 'Antônio Prado', 'Centro', '83414-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3027, 'Colombo', 'Antônio Puppi', 'Centro', '83414-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3028, 'Curitiba', 'Antônio Rafael Sartori', 'Santa Felicidade', '82015-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3029, 'Cambé', 'Antônio Raminelli', 'Parque Residencial Ana Rosa', '86183-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3030, 'Londrina', 'Antônio Ramos Valença', 'Jardim Alphaville', '86084-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3031, 'Foz do Iguaçu', 'Antônio Raposo', 'Centro', '85851-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3032, 'Telêmaco Borba', 'Antônio Raposo Tavares', 'Núcleo Bandeirantes', '84269-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3033, 'Cambé', 'Antônio Raposo Tavares', 'Jardim Ana Eliza', '86187-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3034, 'Cambé', 'Antônio Rasteiro', 'Jardim Planalto Verde', '86192-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3035, 'Curitiba', 'Antônio Razera', 'Sítio Cercado', '81910-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3036, 'Curitiba', 'Antônio Rebelatto', 'Boqueirão', '81670-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3037, 'Curitiba', 'Antônio Rebelatto', 'Xaxim', '81710-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3038, 'Francisco Beltrão', 'Antônio Rebouças', 'São Miguel', '85602-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3039, 'Curitiba', 'Antônio Rechetelo', 'Fazendinha', '81320-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3040, 'Curitiba', 'Antônio Reinaldo Zanon', 'Cidade Industrial', '81240-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3041, 'Curitiba', 'Antônio Ribeiro Macedo', 'Xaxim', '81810-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3042, 'São José dos Pinhais', 'Antônio Rocha Barbosa', 'Braga', '83020-226', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3043, 'Curitiba', 'Antônio Rodolfo Turra', 'Santa Cândida', '82640-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3044, 'Cambé', 'Antônio Rodrigues', 'Novo Bandeirantes', '86188-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3045, 'Curitiba', 'Antônio Rodrigues', 'Seminário', '80740-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3046, 'Cambé', 'Antônio Rodrigues Arzao', 'Jardim Riviera', '86187-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3047, 'Telêmaco Borba', 'Antônio Rodrigues Arzão', 'Núcleo Bandeirantes', '84269-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3048, 'Londrina', 'Antônio Rodrigues da Silva', 'Conjunto Novo Amparo', '86087-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3049, 'Foz do Iguaçu', 'Antônio Rodrigues de Almeida', 'Jardim Panorama II', '85856-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3050, 'São José dos Pinhais', 'Antônio Rodrigues Gallego', 'Braga', '83020-256', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3051, 'Londrina', 'Antônio Rodrigues Pinto', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3052, 'Ponta Grossa', 'Antônio Rodrigues Teixeira Júnior', 'Jardim Carvalho', '84016-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3053, 'Ponta Grossa', 'Antônio Rodrigues Teixeira Júnior', 'Jardim Carvalho', '84015-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3054, 'Colombo', 'Antônio Rogério da Silva Rosa', 'Jardim Itambé', '83402-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3055, 'Castro', 'Antônio Rolim de Moura', 'Centro', '84165-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3056, 'Londrina', 'Antônio Romão', 'Jardim Santa Fé', '86035-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3057, 'Londrina', 'Antônio Rosa', 'Milton Gavetti', '86078-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3058, 'Colombo', 'Antônio Rosa da Silva', 'Parque Residencial Santa Terezinha II', '83408-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3059, 'Telêmaco Borba', 'Antônio Rúbens Prestes', 'Vila São José', '84263-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3060, 'São José dos Pinhais', 'Antônio Rubens Silveira', 'São Sebastião', '83075-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3061, 'Maringá', 'Antônio Rubini', 'Conjunto Habitacional Requião', '87047-477', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3062, 'Londrina', 'Antônio Ruivo Duarte', 'Jardim Marissol', '86030-497', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3063, 'Ponta Grossa', 'Antônio Sabedotti', 'Boa Vista', '84071-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3064, 'Ponta Grossa', 'Antônio Sad', 'Jardim Carvalho', '84016-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3065, 'Ponta Grossa', 'Antônio Sad', 'Boa Vista', '84073-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3066, 'Foz do Iguaçu', 'Antônio Salazar', 'Parque Presidente II', '85863-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3067, 'Campo Largo', 'Antônio Saldanha de Paula', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-767', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3068, 'Londrina', 'Antônio Salema', 'Sabará I', '86066-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3069, 'Maringá', 'Antônio Salema', 'Zona 02', '87010-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3070, 'Curitiba', 'Antônio Salin', 'Umbará', '81930-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3071, 'Londrina', 'Antônio Sancevero', 'Colúmbia', '86057-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3072, 'Londrina', 'Antônio Santos', 'Jardim Santa Fé', '86035-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3073, 'Curitiba', 'Antônio Sanzovo', 'Butiatuvinha', '82400-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3074, 'Londrina', 'Antônio Saperas', 'Santa Rita 1', '86072-195', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3075, 'Curitiba', 'Antônio Sarote', 'Tatuquara', '81480-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3076, 'Cascavel', 'Antônio Sartori', 'Brasília', '85815-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3077, 'Campo Mourão', 'Antônio Sartori', 'Jardim Laura', '87301-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3078, 'Campo Mourão', 'Antônio Sartori', 'Jardim Laura', '87300-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3079, 'Curitiba', 'Antônio Sbalqueiro', 'Mercês', '80710-220', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3080, 'São José dos Pinhais', 'Antônio Sbrissia', 'São Pedro', '83020-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3081, 'São José dos Pinhais', 'Antônio Sbrissia', 'São Pedro', '83005-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3082, 'Toledo', 'Antônio Scain', 'Centro', '85901-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3083, 'São José dos Pinhais', 'Antônio Scalise Filho', 'Carioca', '83005-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3084, 'Curitiba', 'Antônio Scheidt', 'Santa Cândida', '82630-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3085, 'Ponta Grossa', 'Antônio Schemberger', 'Chapada', '84063-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3086, 'Castro', 'Antônio Schendroski', 'Água Suja', '84165-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3087, 'Curitiba', 'Antônio Schiebel', 'Boqueirão', '81670-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3088, 'Curitiba', 'Antônio Schiebel', 'Boqueirão', '81650-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3089, 'Piraquara', 'Antônio Schuartz', 'Planta Araçatuba', '83301-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3090, 'Curitiba', 'Antônio Schwartz', 'Sítio Cercado', '81920-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3091, 'Londrina', 'Antônio Segretti', 'Itapoã', '86043-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3092, 'Colombo', 'Antônio Serafim', 'Parque do Embu', '83414-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3093, 'Colombo', 'Antônio Serraglio', 'Jardim Osasco', '83403-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3094, 'São José dos Pinhais', 'Antônio Setim', 'Águas Belas', '83040-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3095, 'Colombo', 'Antônio Severino das Neves', 'Jardim Cristina II', '83410-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3096, 'Colombo', 'Antônio Sgoda', 'Santa Gema', '83407-207', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3097, 'São José dos Pinhais', 'Antônio Silva', 'Guatupê', '83060-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3098, 'Londrina', 'Antônio Silveira Santos', 'São Lourenço', '86043-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3099, 'Guarapuava', 'Antônio Silvério', 'Morro Alto', '85070-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3100, 'Foz do Iguaçu', 'Antônio Silvestre', 'Loteamento Universitário das Américas II', '85870-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3101, 'Paranavaí', 'Antônio Silvestre de Oliveira', 'Jardim Simoni I', '87711-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3102, 'Francisco Beltrão', 'Antônio Sílvio Barbieri', 'Pinheirinho', '85603-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3103, 'Piraquara', 'Antônio Simião', 'Vila Juliana', '83306-095', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3104, 'Curitiba', 'Antônio Simm', 'Capão da Imbuia', '82800-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3105, 'Curitiba', 'Antônio Simões Cardoso', 'Uberaba', '81580-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3106, 'Curitiba', 'Antônio Simoes de Oliveira', 'Sítio Cercado', '81920-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3107, 'Francisco Beltrão', 'Antônio Singer', 'Antônio de Paiva Cantelmo', '85603-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3108, 'Guarapuava', 'Antônio Siqueira Ribas', 'Primavera', '85050-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3109, 'Londrina', 'Antônio Sisti', 'Londres', '86081-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3110, 'São José dos Pinhais', 'Antônio Sitoni', 'Guatupê', '83060-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3111, 'Curitiba', 'Antônio Sitorski', 'Novo Mundo', '81020-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3112, 'São José dos Pinhais', 'Antônio Skakuy', 'Afonso Pena', '83040-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3113, 'Curitiba', 'Antônio Skrepec', 'Pinheirinho', '81870-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3114, 'Foz do Iguaçu', 'Antônio Soares', 'Mutirão', '85858-580', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3115, 'Curitiba', 'Antônio Sprada', 'Boqueirão', '81630-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3116, 'Foz do Iguaçu', 'Antônio Staziuk', 'Jardim Princesa Daiana', '85867-686', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3117, 'Castro', 'Antônio Stella', 'Vila Santa Cruz', '84168-045', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3118, 'Curitiba', 'Antônio Stinglin', 'Pilarzinho', '82100-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3119, 'Curitiba', 'Antônio Stival', 'Santa Felicidade', '82400-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3120, 'Almirante Tamandaré', 'Antônio Stochero', 'Jardim Planalto', '83514-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3121, 'Apucarana', 'Antônio Stoppa', 'Vila Rural Nova Ukrania', '86810-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3122, 'Curitiba', 'Antônio Strapasson', 'Butiatuvinha', '82320-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3123, 'Curitiba', 'Antônio Sviontek', 'Cidade Industrial', '81450-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3124, 'Pinhais', 'Antônio Taborda Ribas', 'Moradias Perdizes', '83326-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3125, 'Curitiba', 'Antônio Teixeira de Andrade', 'Pinheirinho', '81880-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3126, 'Londrina', 'Antônio Tesser', 'Jardim Indusville', '86031-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3213, 'Londrina', 'Aparecido Mauro Bortolato', 'Sabará III', '86066-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3127, 'Londrina', 'Antônio Theodoro de A. Camargo', 'Conjunto Residencial Doutor Alberto João Zortea', '86042-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3128, 'Almirante Tamandaré', 'Antônio Tibúrcio de Carvalho', 'Loteamento Nova Morada', '83504-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3129, 'Colombo', 'Antônio Todeschini', 'Jardim Palmares', '83412-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3130, 'Londrina', 'Antônio Toledo da Silva', 'Jardim Marízia I', '86079-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3131, 'Londrina', 'Antônio Torres', 'Conjunto Habitacional Bronzzetti', '86037-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3132, 'Curitiba', 'Antônio Tosin', 'Cidade Industrial', '81230-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3133, 'Colombo', 'Antônio Trevisan', 'Vila Rosemari Galvão', '83411-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3134, 'Curitiba', 'Antônio Turíbio Teixeira Braga', 'Butiatuvinha', '82320-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3135, 'Londrina', 'Antônio Urias', 'Jardim Imagawa', '86080-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3136, 'Maringá', 'Antônio Valdir Zanutto', 'Jardim Novo Horizonte', '87010-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3137, 'Piraquara', 'Antônio Valenga', 'Planta Deodoro', '83304-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3138, 'Curitiba', 'Antônio Valentin', 'Capão da Imbuia', '82810-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3139, 'Curitiba', 'Antônio Valle', 'Santa Felicidade', '82030-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3140, 'Campo Mourão', 'Antônio Vargas Neto', 'Jardim Modelo', '87309-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3141, 'Cascavel', 'Antônio Vaz', 'Santa Felicidade', '85803-805', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3142, 'Piraquara', 'Antônio Vaz de Siqueira', 'Vila Franca', '83305-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3143, 'Paranavaí', 'Antônio Vendramim', 'Jardim Ibirapuera', '87705-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3144, 'Paranavaí', 'Antônio Vendramim', 'Jardim Ouro Branco', '87704-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3145, 'Curitiba', 'Antônio Venski', 'São Braz', '82310-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3146, 'Londrina', 'Antônio Vicente da Silva', 'Jardim Piza', '86073-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3147, 'Curitiba', 'Antônio Vicente de Andrade', 'Campo Comprido', '81220-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3148, 'Londrina', 'Antônio Vicente de Souza', 'Jardim Pacaembu', '86079-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3149, 'Londrina', 'Antônio Vicente de Souza', 'Nova Olinda', '86073-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3150, 'Cambé', 'Antônio Vicentin', 'Vila Salomé', '86192-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3151, 'Cascavel', 'Antônio Victor', 'Santa Felicidade', '85803-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3152, 'Campo Largo', 'Antônio Vidal', 'Loteamento Mina Clara Huber', '83602-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3153, 'Laranjeiras do Sul', 'Antônio Vidal Pontes', 'Cristo Rei', '85304-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3154, 'São José dos Pinhais', 'Antônio Vidolin', 'Cruzeiro', '83010-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3155, 'Ponta Grossa', 'Antônio Vieira', 'Orfãs', '84070-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3156, 'Ponta Grossa', 'Antônio Vieira', 'Jardim Carvalho', '84015-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3157, 'Apucarana', 'Antônio Vieira', 'Jardim Esperança', '86810-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3158, 'Londrina', 'Antônio Vieira da Silva', 'Jardim Tarobá I', '86042-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3159, 'Paranavaí', 'Antônio Vieira dos Santos', 'Jardim Santos Dumont', '87706-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3160, 'Curitiba', 'Antônio Vieira dos Santos', 'Abranches', '82130-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3161, 'Ponta Grossa', 'Antônio Viezzer', 'Oficinas', '84045-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3162, 'Londrina', 'Antônio Vilela de Magalhães', 'Santa Rita 3', '86072-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3163, 'Ponta Grossa', 'Antônio Vítor Bhunemann', 'Uvaranas', '84030-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3164, 'Curitiba', 'Antônio Vivaldi', 'Fazendinha', '81330-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3165, 'Londrina', 'Antônio Vizitação Lopes Rúbio', 'Cafezal 1', '86049-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3166, 'Sarandi', 'Antônio Volpato', 'Jardim Belém', '87111-011', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3167, 'Sarandi', 'Antônio Volpato', 'Jardim Europa', '87111-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3168, 'Araucária', 'Antônio Wikrota', 'Fazenda Velha', '83703-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3169, 'Curitiba', 'Antônio Woicik', 'Pinheirinho', '81825-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3170, 'Curitiba', 'Antônio Wolpe', 'Butiatuvinha', '82315-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3171, 'Curitiba', 'Antônio Wosniak', 'Cidade Industrial', '81250-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3172, 'Curitiba', 'Antônio Zak', 'Alto Boqueirão', '81850-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3173, 'Curitiba', 'Antônio Zamarian', 'Vista Alegre', '80820-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3174, 'Toledo', 'Antônio Zanella', 'Boa Esperança', '85909-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3175, 'Curitiba', 'Antônio Zanon', 'Tatuquara', '81480-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3176, 'Piraquara', 'Antônio Zapchan', 'Vila Marumbi', '83304-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3177, 'São José dos Pinhais', 'Antônio Zaramella', 'Colônia Rio Grande', '83025-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3178, 'Curitiba', 'Antônio Zeni', 'Capão da Imbuia', '82810-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3179, 'Colombo', 'Antônio Zequinão', 'Jardim Planalto', '83409-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3180, 'Pinhais', 'Antônio Zielonka', 'Vila Tarumã', '83323-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3181, 'Ponta Grossa', 'Antúrio', 'Contorno', '84060-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3182, 'Araucária', 'Antúrio', 'Campina da Barra', '83709-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3183, 'Campo Mourão', 'Antúrio', 'Jardim Paulista', '87310-470', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3184, 'Londrina', 'Anu', 'Conjunto Habitacional Violim', '86088-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3185, 'Arapongas', 'Anu', 'Vila Iguaçu', '86708-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3186, 'Londrina', 'Anuar Caram', 'Conjunto Semiramis Barros Braga', '86088-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3187, 'Arapongas', 'Anu-branco', 'Jardim Portal das Flores', '86701-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3188, 'Arapongas', 'Anu-coroca', 'Parque Industrial IV', '86706-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3189, 'Curitiba', 'Anulina Castilho de Almeida Jorge', 'Jardim das Américas', '81520-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3190, 'Arapongas', 'Anumara', 'Conjunto Ulisses Guimarães', '86706-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3191, 'Almirante Tamandaré', 'Anúncia Viante Giannini', 'Jardim Giannini', '83511-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3192, 'Cambé', 'Anunciato Bernardy', 'Jardim Tarobá', '86191-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3193, 'Arapongas', 'Anunguaçu', 'Vila Vicentini', '86707-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3194, 'Arapongas', 'Anu-preto', 'Jardim Santo Antônio', '86705-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3195, 'Cascavel', 'Apalais', 'Santa Cruz', '85806-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3196, 'Arapongas', 'Apanacim', 'Vila Nova', '86707-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3197, 'Londrina', 'Aparecida Andrade Esteves', 'Portal de Versalhes 3', '86055-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3198, 'Londrina', 'Aparecida Bernardes Caetano', 'Jardim Olímpico', '86056-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3199, 'Campo Mourão', 'Aparecida Caldas Lapezak', 'Vila Teixeira', '87300-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3200, 'Curitiba', 'Aparecida Callegarine Barreto', 'Atuba', '82860-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3201, 'Guarapuava', 'Aparecida da Silva Pinto', 'Boqueirão', '85023-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3202, 'Cascavel', 'Aparecida do Norte', 'Pioneiros Catarinenses', '85805-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3203, 'Cascavel', 'Aparecida dos Portos', '14 de Novembro', '85804-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3204, 'Londrina', 'Aparecida Farly Piantini', 'Jardim Planalto', '86084-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3205, 'Londrina', 'Aparecida Fonseca Barbosa', 'Conjunto Semiramis Barros Braga', '86088-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3206, 'Curitiba', 'Aparecida Garavello de Almeida', 'Cidade Industrial', '81310-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3207, 'Curitiba', 'Aparecida Júlia dos Santos Ribeiro', 'Atuba', '82860-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3208, 'Londrina', 'Aparecida Mucilo Mecunhe', 'Colinas', '86056-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3209, 'Cascavel', 'Aparecido Brame Pinho', 'Nova Cidade', '85803-126', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3210, 'Londrina', 'Aparecido da Silva', 'Jardim Continental', '86081-186', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3211, 'Londrina', 'Aparecido de Morais', 'Jardim Primavera', '86086-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3212, 'Paranavaí', 'Aparecido Marques da Silva', 'Parque Morumbi', '87703-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7238, 'Londrina', 'Chile', 'Centro', '86010-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3214, 'Londrina', 'Aparecido Ramos', 'Parigot de Souza 2', '86082-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3215, 'Curitiba', 'Aparecido Rodrigues', 'Alto Boqueirão', '81850-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3216, 'Londrina', 'Aparecido Rodrigues do Prado', 'Assis', '86085-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3217, 'Londrina', 'Aparecido Vicente Garcia', 'Parque Industrial Buena Vista', '86032-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3218, 'Cascavel', 'Aparício Domingos da Silva', 'Santos Dumont', '85804-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3219, 'Curitiba', 'Aparício Lemes', 'Boqueirão', '81650-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3220, 'Piraquara', 'Aparício Torres Marins', 'Jardim Guarani', '83311-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3221, 'Foz do Iguaçu', 'Aparício Vieira', 'Jardim Porto Belo', '85867-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3222, 'Curitiba', 'Apeles de Ferrante', 'Capão da Imbuia', '82810-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3223, 'Foz do Iguaçu', 'Apepu Grande', 'Jardim Manaus', '85857-740', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3224, 'Araucária', 'Aphonso João Peretto', 'Capela Velha', '83706-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3225, 'Paranaguá', 'Apiácas', 'Jardim Guaraituba', '83209-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3226, 'Cascavel', 'Apinajés', 'Santa Cruz', '85806-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3227, 'Guarapuava', 'Apixai', 'São Cristóvão', '85063-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3228, 'Ponta Grossa', 'Apocalipse', 'Chapada', '84062-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3229, 'Cambé', 'Apocalipse', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3230, 'Guarapuava', 'Apolinário de Morais', 'Boqueirão', '85020-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3231, 'Foz do Iguaçu', 'Apolinário de Souza', 'Boa Esperança', '85854-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3232, 'Campo Mourão', 'Apolinário Gorski', 'Jardim Conrado', '87308-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3233, 'Sarandi', 'Apolo', 'Jardim Universal', '87114-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3234, 'Umuarama', 'Apolo', 'Jardim Iguaçu', '87501-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3235, 'Piraquara', 'Apolônia Bruneti Gugelmim', 'Vila Juliana', '83306-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3236, 'Pinhais', 'Apolônia Jacomel de Andrade', 'Jardim Guairacá', '83324-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3237, 'Curitiba', 'Apolônia Kozak', 'Santo Inácio', '82010-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3238, 'Campo Mourão', 'Apolônia Stanitzewski', 'Jardim Copacabana', '87302-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3239, 'Curitiba', 'Apolônio de Tiana', 'Santa Cândida', '82720-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3240, 'Colombo', 'Apolônio Koshinski', 'Sapopema', '83407-087', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3241, 'Foz do Iguaçu', 'Aporé', 'Cohapar II', '85857-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3242, 'Pinhais', 'Aporé', 'Loteamento Alphaville Graciosa', '83327-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3243, 'Curitiba', 'Apparecida Feliciano Caetano', 'Cidade Industrial', '81170-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3244, 'Londrina', 'Apterix', 'Conjunto Habitacional Violim', '86088-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3245, 'Arapongas', 'Apterix', 'Vila Edio', '86705-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3246, 'Foz do Iguaçu', 'Apucarana', 'Jardim Belvedere I', '85867-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3247, 'Laranjeiras do Sul', 'Apucarana', 'Água Verde', '85302-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3248, 'Francisco Beltrão', 'Apucarana', 'Industrial', '85601-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3249, 'Guarapuava', 'Apucarana', 'Bonsucesso', '85045-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3250, 'Londrina', 'Apucarana', 'Antares', '86036-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3251, 'Maringá', 'Apucarana', 'Zona 08', '87050-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3252, 'Paranaguá', 'Apucarana', 'Jardim Paranaguá', '83218-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3253, 'Ponta Grossa', 'Apucarana', 'Nova Rússia', '84071-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3254, 'São José dos Pinhais', 'Apucarana', 'Cruzeiro', '83010-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3255, 'Pinhais', 'Apucarana', 'Vila Emiliano Perneta', '83324-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3256, 'Sarandi', 'Apucarana', 'Novo Panorama', '87113-199', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3257, 'Umuarama', 'Apucarana', 'Zona I', '87501-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3258, 'Umuarama', 'Apucarana', 'Zona V', '87504-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3259, 'Cambé', 'Apucarana', 'Jardim Ana Eliza', '86187-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3260, 'Cascavel', 'Apucarana', 'São Cristóvão', '85816-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3261, 'Araucária', 'Apucarana', 'Iguaçu', '83701-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3262, 'Campo Mourão', 'Apucarana', 'Conjunto Residencial Antilhas', '87308-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3263, 'Colombo', 'Apucarana', 'Jardim Guaraituba', '83410-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3264, 'Curitiba', 'Apucarana', 'Sítio Cercado', '81900-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3265, 'Londrina', 'Aquário', 'Sol', '86070-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3266, 'Curitiba', 'Aquelino Orestes Baglioli', 'Prado Velho', '80215-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3267, 'Umuarama', 'Aquidaban', 'Zona I', '87503-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3268, 'Foz do Iguaçu', 'Aquidauana', 'Jardim Manaus', '85857-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3269, 'Sarandi', 'Aquidauana', 'Jardim Esplanada', '87112-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3270, 'Apucarana', 'Aquiles', 'Vila Shangri-La', '86812-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3271, 'Apucarana', 'Aquiles Miquelan', 'Jardim Marissol II', '86807-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3272, 'Colombo', 'Aquiles Stenghel Coller', 'Jardim Rio Verde', '83405-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3273, 'Cascavel', 'Aquilino Zatti', 'Nova Cidade', '85803-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3274, 'Umuarama', 'Arabela Arena Caetano', 'Jardim Tropical', '87508-146', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3275, 'Curitiba', 'Arábia', 'Cajuru', '82960-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3276, 'Londrina', 'Araçá', 'Damasco', '86035-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3277, 'Ponta Grossa', 'Araçá', 'Contorno', '84061-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3278, 'Piraquara', 'Araçá', 'Vila Santa Maria', '83306-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3279, 'Curitiba', 'Aracacu', 'Uberaba', '81560-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3280, 'Francisco Beltrão', 'Aracaju', 'Pinheirinho', '85603-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3281, 'Londrina', 'Aracaju', 'Jardim Agari', '86020-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3282, 'Foz do Iguaçu', 'Aracaju', 'Parque Residencial Três Fronteiras', '85855-600', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3283, 'Guarapuava', 'Aracaju', 'São Cristóvão', '85060-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3284, 'Foz do Iguaçu', 'Aracaju', 'Conjunto C', '85870-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3285, 'São José dos Pinhais', 'Aracaju', 'Costeira', '83015-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3286, 'Maringá', 'Aracaju', 'Vila Morangueira', '87040-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3287, 'Pato Branco', 'Aracaju', 'La Salle', '85505-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3288, 'Piraquara', 'Aracaju', 'Vila Vicente Macedo', '83303-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3289, 'Pinhais', 'Aracaju', 'Conjunto Residencial Renato Bonilauri', '83325-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3290, 'Umuarama', 'Aracaju', 'Zona VII', '87503-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3291, 'Telêmaco Borba', 'Aracaju', 'Vila Santa Rita', '84263-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3292, 'Campo Largo', 'Aracaju', 'Vila Rivabem', '83605-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3293, 'Campo Mourão', 'Aracaju', 'Jardim Constantino', '87303-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3294, 'Cambé', 'Aracaju', 'Vila Salomé', '86192-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3295, 'Curitiba', 'Aracaju', 'Cajuru', '82930-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3296, 'Curitiba', 'Aracalina', 'Bairro Alto', '82840-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3297, 'Foz do Iguaçu', 'Aracari', 'Conjunto A', '85866-160', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3298, 'Ponta Grossa', 'Aracari', 'Colônia Dona Luiza', '84046-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3299, 'Arapongas', 'Aracari', 'Vila Nova', '86707-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3300, 'Curitiba', 'Aracari', 'Pinheirinho', '81870-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3301, 'Arapongas', 'Araçari-de-crista', 'Jardim São Bento', '86706-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3302, 'Arapongas', 'Araçari-limão', 'Vila Triângulo', '86709-226', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3303, 'Arapongas', 'Araçari-mulato', 'Jardim Boa Vista', '86702-176', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3304, 'Arapongas', 'Araçari-poca', 'Jardim Cultura', '86707-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3305, 'Arapongas', 'Araçari-poca-de-bico-vermelho', 'Jardim Nova Baroneza', '86706-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3306, 'Curitiba', 'Araçás', 'Uberaba', '81540-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3307, 'Piraquara', 'Aracati', 'Jardim Tropical', '83314-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3308, 'Foz do Iguaçu', 'Araçatuba', 'Jardim Lancaster', '85869-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3309, 'Francisco Beltrão', 'Araçatuba', 'Pinheirinho', '85603-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3311, 'Guarapuava', 'Araçatuba', 'Boqueirão', '85022-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3312, 'Piraquara', 'Araçatuba', 'Planta Araçatuba', '83301-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3313, 'Cambé', 'Araçatuba', 'Jardim São Paulo', '86191-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3314, 'Londrina', 'Aracauba', 'Santa Rita 1', '86071-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3315, 'Londrina', 'Aracelles F. Gordilho', 'Jardim Acapulco', '86045-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3316, 'Curitiba', 'Araci Cequinel Kuster', 'Jardim das Américas', '81520-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3317, 'Londrina', 'Araci de Almeida', 'Conjunto Vivi Xavier', '86082-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3318, 'Ponta Grossa', 'Aracuã', 'Colônia Dona Luiza', '84046-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3319, 'Arapongas', 'Aracuã', 'Jardim Panorama', '86708-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3320, 'Ponta Grossa', 'Aracy Maciel Iurk', 'Boa Vista', '84071-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3321, 'Londrina', 'Aracy Soares Santos', 'Santiago', '86071-790', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3322, 'Ponta Grossa', 'Arade', 'Jardim Carvalho', '84016-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3323, 'Guarapuava', 'Aragão de Mattos Leão', 'São Cristóvão', '85063-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3324, 'Guarapuava', 'Aragão de Mattos Leão Filho', 'Jardim das Américas', '85030-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3325, 'Guarapuava', 'Aragão de Mattos Leão Filho', 'Alto Cascavel', '85025-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3326, 'Ponta Grossa', 'Aragonita', 'Neves', '84021-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3327, 'Foz do Iguaçu', 'Araguaia', 'Loteamento Campos do Iguaçu', '85857-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3328, 'Londrina', 'Araguaia', 'Jardim Agari', '86025-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3329, 'Maringá', 'Araguaia', 'Parque das Grevíleas', '87025-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3330, 'Paranaguá', 'Araguaia', 'Jardim Guaraituba', '83209-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3331, 'Pinhais', 'Araguaia', 'Loteamento Alphaville Graciosa', '83327-078', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3332, 'Sarandi', 'Araguaia', 'Parque Residencial Bela Vista', '87112-258', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3333, 'Sarandi', 'Araguaia', 'Parque Residencial Nova Aliança', '87111-737', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3334, 'Campo Mourão', 'Araguaia', 'Jardim Santa Nilce II', '87308-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3335, 'Curitiba', 'Araguaia', 'Capão da Imbuia', '82810-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3336, 'Maringá', 'Araguaia II', 'Parque das Grevíleas', '87025-125', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3337, 'Foz do Iguaçu', 'Araguari', 'Vila Militar', '85857-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3338, 'Londrina', 'Araguari', 'Yara', '86027-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3339, 'Paranaguá', 'Araguari', 'Jardim Guaraituba', '83209-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3340, 'Cascavel', 'Araguari', 'Brasmadeira', '85814-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3341, 'Londrina', 'Araicás', 'Vila Goes', '86026-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3342, 'Curitiba', 'Arakem Távora', 'Cidade Industrial', '81350-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3343, 'Ponta Grossa', 'Arambé', 'Colônia Dona Luiza', '84046-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3344, 'Cascavel', 'Aramis Athayde', 'São Cristóvão', '85816-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3345, 'Curitiba', 'Aramis Milarch', 'Tatuquara', '81470-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3346, 'Curitiba', 'Aramis Taborda Athayde', 'Hugo Lange', '80040-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3347, 'Curitiba', 'Arantes Ferreira', 'Sítio Cercado', '81920-778', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3348, 'Arapongas', 'Arapaçu', 'Vila Nova', '86707-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3349, 'Arapongas', 'Arapaçu-bicudo', 'Jardim Boa Vista', '86702-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3350, 'Arapongas', 'Arapaçu-de-bico-preto', 'Vila Triângulo', '86709-227', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3351, 'Arapongas', 'Arapaçu-grande', 'Conjunto Flamingos III', '86703-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3352, 'Arapongas', 'Arapaçu-listrado', 'Parque Industrial II', '86703-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3353, 'Arapongas', 'Arapaçu-vermelho', 'Conjunto Águias', '86704-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3354, 'Foz do Iguaçu', 'Arapara', 'Conjunto A', '85866-440', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3355, 'Arapongas', 'Arapara', 'Conjunto Del Condor', '86703-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3356, 'Foz do Iguaçu', 'Arapiraca', 'Parque Imperatriz', '85862-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3357, 'Almirante Tamandaré', 'Arapiraca', 'Jardim São Vicente', '83505-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3358, 'Foz do Iguaçu', 'Araponga', 'Portal da Foz', '85859-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3359, 'Francisco Beltrão', 'Araponga', 'Miniguaçu', '85605-250', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3360, 'Guarapuava', 'Arapongas', 'Boqueirão', '85022-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3361, 'Guarapuava', 'Arapongas', 'Boqueirão', '85023-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3362, 'Londrina', 'Arapongas', 'Dom Bosco', '86060-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3363, 'Ponta Grossa', 'Arapongas', 'Chapada', '84064-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3364, 'Pinhais', 'Arapongas', 'Jardim Alto Tarumã', '83325-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3365, 'São José dos Pinhais', 'Arapongas', 'São Cristóvão', '83040-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3366, 'Ponta Grossa', 'Arapongas', 'Nova Rússia', '84071-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3367, 'Paranaguá', 'Arapongas', 'Emboguaçu', '83209-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3368, 'Maringá', 'Arapongas', 'Zona 08', '87050-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3369, 'Sarandi', 'Arapongas', 'Conjunto Floresta', '87112-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3370, 'Umuarama', 'Arapongas', 'Zona II', '87502-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3371, 'Arapongas', 'Arapongas', 'Centro', '86701-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3372, 'Cascavel', 'Arapongas', 'Floresta', '85814-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3373, 'Campo Mourão', 'Arapongas', 'Conjunto Habitacional Milton Luiz Pereira', '87306-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3374, 'Araucária', 'Arapongas', 'Capela Velha', '83706-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3375, 'Apucarana', 'Arapongas', 'Vila Martins', '86800-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3376, 'Colombo', 'Arapongas', 'Jardim Guaraituba', '83410-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3377, 'Cambé', 'Arapongas', 'Jardim Ana Eliza', '86187-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3378, 'Campo Largo', 'Arapongas', 'Vila Gilcy', '83609-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3379, 'Curitiba', 'Arapongas', 'Sítio Cercado', '81900-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3380, 'Arapongas', 'Araponguinha', 'Jardim São Bento', '86706-716', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3381, 'Francisco Beltrão', 'Arapoti', 'Miniguaçu', '85605-457', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3382, 'Foz do Iguaçu', 'Arapoti', 'Jardim do Norte', '85854-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3383, 'Guarapuava', 'Arapoti', 'Bonsucesso', '85045-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3384, 'Pinhais', 'Arapoti', 'Jardim Pedro Demeterco', '83324-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3385, 'Ponta Grossa', 'Arapoti', 'Oficinas', '84036-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3386, 'São José dos Pinhais', 'Arapoti', 'Cruzeiro', '83010-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3387, 'Telêmaco Borba', 'Arapoti', 'Área 07', '84267-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3388, 'Colombo', 'Arapoti', 'Jardim Guaraituba', '83410-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3389, 'Curitiba', 'Arapoti', 'Sítio Cercado', '81900-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3390, 'Foz do Iguaçu', 'Arapuã', 'Vila Carima', '85855-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3391, 'Maringá', 'Arara', 'Jardim Olímpico', '87070-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3392, 'Maringá', 'Arara', 'Conjunto Residencial Ney Braga', '87075-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3393, 'Ponta Grossa', 'Arara', 'Chapada', '84064-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3394, 'Araucária', 'Arara', 'Capela Velha', '83706-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3395, 'Londrina', 'Arara-azul', 'Jacomo Violin', '86088-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3396, 'Arapongas', 'Arara-azul', 'Jardim Baroneza', '86706-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3397, 'Londrina', 'Araracanga', 'Santa Rita 1', '86071-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3398, 'Arapongas', 'Araracanga', 'Vila Natal', '86707-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3399, 'Arapongas', 'Arara-canindé', 'Jardim Europa', '86707-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3400, 'Cascavel', 'Ararajuba', 'Floresta', '85814-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3401, 'Arapongas', 'Ararajuba', 'Casa Família Arapongas I', '86706-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3402, 'Curitiba', 'Araranguá', 'Cidade Industrial', '81230-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3403, 'Arapongas', 'Arara-pitanga', 'Jardim Bandeirantes', '86703-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3404, 'Guarapuava', 'Araraquara', 'Boqueirão', '85022-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3405, 'Londrina', 'Araraquara', 'Veraliz', '86062-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3406, 'Telêmaco Borba', 'Araraquara', 'Vila Ana Mari', '84263-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3407, 'Cascavel', 'Araraquara', 'Morumbi', '85817-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3408, 'Arapongas', 'Araras', 'Centro', '86701-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3409, 'Campo Mourão', 'Araras', 'Jardim Gutierres', '87300-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3410, 'Arapongas', 'Araraúna', 'Jardim Europa', '86707-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3411, 'Arapongas', 'Arara-vermelha', 'Conjunto Centauro', '86709-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3412, 'Arapongas', 'Arari', 'Vila Passos', '86705-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3413, 'Londrina', 'Araribóia', 'Portuguesa', '86026-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3414, 'Pato Branco', 'Araribóia', 'Centro', '85505-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3415, 'Pato Branco', 'Araribóia', 'Centro', '85501-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3416, 'Colombo', 'Araribóia', 'Jardim Alvorada', '83409-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3417, 'Arapongas', 'Ararinha', 'Jardim Europa', '86707-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3418, 'Arapongas', 'Ararinha-azul', 'Jardim Colúmbia IV', '86707-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3419, 'Curitiba', 'Araripe Júnior', 'Fazendinha', '81330-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3420, 'Londrina', 'Araruana', 'Paraná', '86026-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3421, 'Ponta Grossa', 'Araruana', 'Oficinas', '84036-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3422, 'Guarapuava', 'Araruna', 'Morro Alto', '85067-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3423, 'Campo Mourão', 'Araruna', 'Centro', '87301-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3424, 'Campo Mourão', 'Araruna', 'Centro', '87302-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3425, 'Curitiba', 'Araruna', 'Pinheirinho', '81880-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3426, 'Ponta Grossa', 'Araruva', 'Jardim Carvalho', '84015-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3427, 'Telêmaco Borba', 'Araruva', 'Bela Vista do Paraíso', '84262-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3428, 'Londrina', 'Arary Madeira', 'Conjunto Habitacional João Turquino', '86056-855', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3429, 'Ponta Grossa', 'Arary Souto', 'Contorno', '84052-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3430, 'Curitiba', 'Arary Souto', 'Bacacheri', '82620-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3431, 'Pato Branco', 'Arassuai', 'Menino Deus', '85502-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3432, 'Arapongas', 'Arataiacu', 'Vila São Vicente', '86707-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3433, 'Curitiba', 'Araticum', 'Uberaba', '81560-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3434, 'Londrina', 'Aratinga', 'Yara', '86027-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3435, 'Arapongas', 'Aratinga-estrela', 'Jardim Boa Vista', '86702-177', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3436, 'Foz do Iguaçu', 'Araucária', 'Conjunto A', '85860-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3437, 'Foz do Iguaçu', 'Araucária', 'Conjunto A', '85861-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3438, 'Guarapuava', 'Araucária', 'Alto Cascavel', '85031-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3439, 'Foz do Iguaçu', 'Araucária', 'Conjunto A', '85866-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3440, 'Foz do Iguaçu', 'Araucária', 'Novo Mundo', '85862-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3441, 'Ponta Grossa', 'Araucária', 'Estrela', '84050-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3442, 'Pato Branco', 'Araucária', 'Santa Terezinha', '85506-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3443, 'Pato Branco', 'Araucária', 'Santa Terezinha', '85501-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3444, 'Maringá', 'Araucária', 'Jardim Pinheiros', '87043-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3445, 'Piraquara', 'Araucária', 'Planta Araçatuba', '83301-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3446, 'São José dos Pinhais', 'Araucária', 'Cruzeiro', '83010-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3447, 'Sarandi', 'Araucária', 'Jardim Monterey', '87112-295', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3448, 'Telêmaco Borba', 'Araucária', 'Socomim', '84265-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3449, 'Telêmaco Borba', 'Araucária', 'Área 01', '84268-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3450, 'Almirante Tamandaré', 'Araucária', 'Jardim Roma', '83504-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3451, 'Colombo', 'Araucária', 'Jardim Guaraituba', '83410-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3452, 'Cascavel', 'Araucária', 'Parque Verde', '85807-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3453, 'Curitiba', 'Araucária', 'Atuba', '82860-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3454, 'Ponta Grossa', 'Araújo de Porto Alegre', 'Nova Rússia', '84070-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3455, 'Curitiba', 'Araújo Porto Alegre', 'Guabirotuba', '81510-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3456, 'Londrina', 'Araúna', 'Yara', '86027-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3457, 'Curitiba', 'Araúna', 'São Braz', '82015-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3458, 'Foz do Iguaçu', 'Araxa', 'Centro', '85851-016', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3459, 'Maringá', 'Araxá', 'Jardim Alvorada', '87033-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3460, 'Curitiba', 'Arcanjo São Miguel', 'Barreirinha', '82700-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3461, 'Curitiba', 'Arcanjo São Rafael', 'Sítio Cercado', '81910-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3462, 'Londrina', 'Arcebispo Dom Geraldo Fernandes', 'Centro', '86026-720', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3463, 'Londrina', 'Arcebispo Dom Geraldo Fernandes', 'Centro', '86020-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3464, 'Londrina', 'Arcebispo Dom Geraldo Fernandes', 'Centro', '86010-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3465, 'Londrina', 'Arcebispo Dom Geraldo Fernandes', 'Centro', '86025-800', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3466, 'Pinhais', 'Arcelino Ferreira', 'Moradias Palmital', '83325-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3467, 'Curitiba', 'Arcendino Rosa Neves', 'Xaxim', '81710-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3468, 'Curitiba', 'Arcésio Correia Lima', 'Atuba', '82630-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3469, 'Curitiba', 'Arcésio de Barros Lima', 'Tatuquara', '81470-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3470, 'Curitiba', 'Arcésio de Barros Lima', 'Tatuquara', '81480-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3471, 'Paranaguá', 'Arcesio Guimarães', 'Vila Guarani', '83221-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3472, 'Curitiba', 'Arcesio Guimarães', 'Jardim Social', '82530-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3473, 'Londrina', 'Archângelo Delallibera', 'Cafezal 1', '86049-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3474, 'Londrina', 'ArchÂngelo Massaro', 'Alto da Boa Vista', '86083-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3475, 'Curitiba', 'Archangelo Smaniotto', 'Jardim das Américas', '81540-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3476, 'Araucária', 'Archelau de Almeida Torres', 'Iguaçu', '83701-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3477, 'Araucária', 'Archelau de Almeida Torres', 'Campina da Barra', '83709-767', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3478, 'Araucária', 'Archelau de Almeida Torres', 'Centro', '83702-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3479, 'Londrina', 'Archiminio Fernandes de Morais', 'São Lourenço', '86043-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3480, 'Curitiba', 'Arcília Becher dos Santos', 'Pinheirinho', '81825-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3481, 'Londrina', 'Arcílio Diassi', 'Eucaliptos', '86031-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3482, 'Londrina', 'Arcindo Sardo', 'Jardim das Américas', '86076-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3483, 'Araucária', 'Arcione Cantador Grabowski', 'Fazenda Velha', '83704-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3484, 'São José dos Pinhais', 'Arcipar', 'Afonso Pena', '83065-210', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3485, 'Curitiba', 'Arcisio da Cunha Niclewicz', 'Alto Boqueirão', '81860-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3486, 'Sarandi', 'Arco-iris', 'Parque Residencial Santana', '87112-577', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3487, 'Cascavel', 'Arco-Íris', 'Nova Cidade', '85803-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3488, 'Curitiba', 'Arcy Neves', 'Campo Comprido', '81220-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3489, 'São José dos Pinhais', 'Arcy Possebon', 'Afonso Pena', '83045-200', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3490, 'Francisco Beltrão', 'Ardelino Martini', 'Sadia', '85603-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3491, 'Francisco Beltrão', 'Ardoino Prolo', 'Pinheirinho', '85603-174', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3492, 'Paranavaí', 'Arduíno Mário Morini', 'Jardim América', '87705-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3493, 'Curitiba', 'Aref Kudri', 'Pinheirinho', '81150-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3494, 'Telêmaco Borba', 'Areia Preta', 'Área 02', '84267-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3495, 'Londrina', 'Arenito', 'Waldemar Hauer', '86030-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3496, 'Foz do Iguaçu', 'Arenque', 'Profilurb II', '85855-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3497, 'Francisco Beltrão', 'Arestelino Scalabrim', 'Seminário', '85605-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3498, 'Colombo', 'Argel', 'Vila Alto da Cruz III', '83405-490', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3499, 'Guarapuava', 'Argélia', 'São Cristóvão', '85063-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3500, 'Londrina', 'Argélia', 'Ouro Verde', '86080-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3501, 'Francisco Beltrão', 'Argélia', 'Seminário', '85605-666', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3502, 'Pinhais', 'Argélia', 'Vl Dona Guiomar', '83320-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3503, 'Curitiba', 'Argélia', 'Cajuru', '82960-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3504, 'Cascavel', 'Argelim', 'Parque Verde', '85807-678', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3505, 'Londrina', 'Argemiro Donadio', 'Giovani Lunardelli', '86037-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3506, 'Cascavel', 'Argemiro Hirt', '14 de Novembro', '85804-106', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3507, 'Foz do Iguaçu', 'Argemiro José do Prado', 'Loteamento Universitário das Américas', '85870-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3508, 'Guarapuava', 'Argemiro Pacheco', 'São Cristóvão', '85060-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3509, 'Piraquara', 'Argemiro Rodrigues de Paula', 'Jardim dos Eucaliptos', '83311-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3510, 'Francisco Beltrão', 'Argentina', 'Luther King', '85605-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3511, 'Guarapuava', 'Argentina', 'Morro Alto', '85067-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3512, 'Londrina', 'Argentina', 'Larsen', '86010-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3513, 'Pato Branco', 'Argentina', 'Jardim América', '85502-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3514, 'Maringá', 'Argentina', 'Jardim Alvorada', '87033-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3515, 'Maringá', 'Argentina', 'Ebenezer', '87035-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3516, 'São José dos Pinhais', 'Argentina', 'Cidade Jardim', '83035-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3517, 'Toledo', 'Argentina', 'Jardim Porto Alegre', '85906-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3518, 'Telêmaco Borba', 'Argentina', 'Socomim', '84266-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3519, 'Cambé', 'Argentina', 'Jardim Morada do Sol', '86181-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3520, 'Apucarana', 'Argentina', 'Jardim Diamantina', '86804-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3521, 'Colombo', 'Argentina', 'Jardim Rio Verde', '83405-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3522, 'Almirante Tamandaré', 'Argentina', 'Jardim São Francisco', '83501-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3523, 'Francisco Beltrão', 'Argentino Salvatti', 'Antônio de Paiva Cantelmo', '85603-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3524, 'Foz do Iguaçu', 'Argílio Brol', 'Parque Morumbi', '85858-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3525, 'Londrina', 'Argolo Ferrão', 'Nova', '86015-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3526, 'Londrina', 'Argus', 'Sol', '86070-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3527, 'São José dos Pinhais', 'Ari Alberti', 'São Cristóvão', '83005-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3528, 'Almirante Tamandaré', 'Ari Antônio Buzato', 'Jardim São José', '83501-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3529, 'Foz do Iguaçu', 'Ari Barroso', 'Jardim Naipi', '85853-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3530, 'Londrina', 'Ari Barroso', 'Conjunto Vivi Xavier', '86082-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3531, 'Pato Branco', 'Ari Barroso', 'Menino Deus', '85502-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3532, 'Maringá', 'Ari Barroso', 'Zona 05', '87015-620', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3533, 'Toledo', 'Ari Barroso', 'Jardim Europa', '85908-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3534, 'Apucarana', 'Ari Barroso', 'Vila Nova', '86812-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3535, 'Colombo', 'Ari Barroso', 'Jardim Milena', '83409-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3536, 'Cascavel', 'Ari Barroso', 'Brasília', '85815-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3537, 'Almirante Tamandaré', 'Ari de Lara Vaz', 'Planta Mosacal', '83513-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3538, 'Curitiba', 'Ari dos Santos Marinho', 'Tingui', '82600-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3539, 'Curitiba', 'Ari dos Santos Sobrinho', 'Uberaba', '81590-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3540, 'Curitiba', 'Ari José Valle', 'São João', '82030-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3541, 'Curitiba', 'Ari José''Sperotto', 'Cidade Industrial', '81460-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3542, 'Cambé', 'Ari Manduca', 'Jardim Tarobá', '86191-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3543, 'Curitiba', 'Ari Manfron', 'Cidade Industrial', '81460-208', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3544, 'Foz do Iguaçu', 'Ari Siegel', 'Jardim Princesa Daiana', '85867-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3545, 'Curitiba', 'Ari Taborda', 'Cidade Industrial', '81170-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3546, 'Paranaguá', 'Ari Trancoso Matoso', 'Parque São João', '83212-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3547, 'Foz do Iguaçu', 'Ariano Suassuna', 'Jardim Central', '85864-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3548, 'Umuarama', 'Aricanduva', 'Zona II', '87502-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3549, 'Ponta Grossa', 'Arichernes Carlos Gobbo', 'Uvaranas', '84030-759', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3550, 'Curitiba', 'Arino Buchmann', 'Xaxim', '81720-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3551, 'Foz do Iguaçu', 'Arinos', 'Centro', '85851-015', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3552, 'Curitiba', 'Arion José Loureiro de Andrade', 'Atuba', '82860-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3553, 'Curitiba', 'Arion Niepce da Silva', 'Portão', '80610-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3554, 'Curitiba', 'Ariosvaldo Moreira', 'Cajuru', '82920-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3555, 'Curitiba', 'Ariosvaldo Moreira', 'Cajuru', '82930-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3556, 'Curitiba', 'Ariovaldo Kato', 'Cajuru', '82920-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3557, 'Umuarama', 'Ariovaldo Rodrigues de Moraes', 'Jardim Petrópolis', '87506-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3558, 'Pinhais', 'Aripuanã', 'Loteamento Alphaville Graciosa', '83327-087', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3559, 'Paranaguá', 'Aripuanã', 'Jardim Guaraituba', '83209-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3560, 'Foz do Iguaçu', 'Ariquemes', 'Jardim Lancaster I', '85869-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3561, 'Cascavel', 'Ariquemes', 'São Cristóvão', '85816-215', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3562, 'Arapongas', 'Ariramba', 'Vila Nova', '86707-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3563, 'Arapongas', 'Ariramba-azul', 'Jardim Monte Carlo', '86704-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3564, 'Arapongas', 'Ariramba-da-mata', 'Conjunto Águias', '86704-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3565, 'Arapongas', 'Ariramba-vermelho', 'Jardim Aeroporto', '86702-216', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3566, 'Foz do Iguaçu', 'Ariranha', 'Conjunto A', '85861-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3567, 'Pinhais', 'Aristeu de Castro Fernandes', 'Vila Maria Antonieta', '83331-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3568, 'Colombo', 'Aristeu de Castro Fernandes', 'Jardim Viviane', '83407-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3569, 'Curitiba', 'Aristeu Girardello', 'Novo Mundo', '81050-630', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3570, 'Curitiba', 'Aristeu Martins', 'Uberaba', '81570-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3571, 'Campo Mourão', 'Aristhoteles Xavier do Rego', 'Jardim Bandeirantes', '87308-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3572, 'Foz do Iguaçu', 'Aristides Atayde', 'Vila São Sebastião', '85870-430', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3573, 'Curitiba', 'Aristides Athayde', 'Jardim Social', '82520-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3574, 'São José dos Pinhais', 'Aristides Borges de Macedo', 'São Pedro', '83005-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3575, 'Curitiba', 'Aristides Borsato', 'Fazendinha', '81320-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3576, 'Curitiba', 'Aristides César de Oliveira Filho', 'Uberaba', '81590-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3577, 'Curitiba', 'Aristides Cooper', 'São Lourenço', '82210-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3578, 'Campo Largo', 'Aristides de Brito Portela', 'Jardim Bela Vista', '83605-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3579, 'Pinhais', 'Aristides de Oliveira', 'Jardim Atuba I', '83326-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3580, 'Paranaguá', 'Aristides de Oliveira', 'Industrial', '83203-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3581, 'Curitiba', 'Aristides de Oliveira Furmann', 'Pinheirinho', '81880-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3582, 'Londrina', 'Aristides de Souza Mello', 'São Lourenço', '86043-430', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3583, 'Pinhais', 'Aristides Evangelista', 'Prive Bois de Boulogne', '83330-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3584, 'Araucária', 'Aristides Ferreira', 'Boqueirão', '83704-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3585, 'Curitiba', 'Aristides Ferreira de Andrade', 'Vista Alegre', '80820-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3586, 'Curitiba', 'Aristides Fioravante', 'Fazendinha', '81330-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3587, 'São José dos Pinhais', 'Aristides Franca', 'Cidade Jardim', '83035-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3588, 'Araucária', 'Aristides Hitner', 'Costeira', '83709-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3589, 'Colombo', 'Aristides Jordão', 'Sapopema', '83415-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3590, 'Londrina', 'Aristides Leonardo da Fonseca', 'Nova Conquista', '86040-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3591, 'Paranavaí', 'Aristides Lobo', 'Jardim São Jorge', '87710-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3592, 'Ponta Grossa', 'Aristides Lobo', 'Olarias', '84035-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3593, 'Maringá', 'Aristides Lobo', 'Vila Santo Antônio', '87030-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3594, 'Londrina', 'Aristides Maluf', 'Cristo Rei', '86046-605', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3595, 'Curitiba', 'Aristides Manoel Cheratzki', 'Cidade Industrial', '81305-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3596, 'Curitiba', 'Aristides Marquezini', 'Sítio Cercado', '81920-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3597, 'Piraquara', 'Aristides Merhi', 'Jardim dos Estados 2', '83308-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3598, 'Curitiba', 'Aristides Pereira da Cruz', 'Portão', '80330-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3599, 'São José dos Pinhais', 'Aristides Ramos de Abreu', 'Guatupê', '83060-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3600, 'Cambé', 'Aristides Sabadini', 'Jardim Tarobá', '86191-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3601, 'Londrina', 'Aristides Simões', 'Santa Joana', '86044-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3602, 'Curitiba', 'Aristides Teixeira', 'Centro Cívico', '80530-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3603, 'Piraquara', 'Aristides Tiller', 'Planta Granjas Eldorado', '83309-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3604, 'Curitiba', 'Aristides Tissot', 'Cidade Industrial', '81240-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3605, 'Guarapuava', 'Aristides Vieira Thives', 'Boqueirão', '85023-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3606, 'Curitiba', 'Aristocleto Taborda Portella', 'Ganchinho', '81935-378', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3607, 'Londrina', 'Aristóteles', 'Maringá', '86060-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3608, 'São José dos Pinhais', 'Aristóteles', 'Aristocrata', '83030-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3609, 'Cascavel', 'Aristóteles', 'Interlagos', '85814-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3610, 'Colombo', 'Aristóteles', 'Vila Guarani', '83408-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3611, 'Apucarana', 'Aristóteles', 'Vila Nova', '86812-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3612, 'Curitiba', 'Aristóteles', 'Barreirinha', '82700-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3613, 'Curitiba', 'Aristóteles da Silva Santos', 'Boqueirão', '81650-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3614, 'Londrina', 'Aristóteles de Oliveira Chueire', 'Aragarça', '86038-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3615, 'Londrina', 'Aristóteles Pereira da Silva', 'Aníbal de Siqueira Cabral', '86089-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3616, 'São José dos Pinhais', 'Arival Anselmo Matzenbacher', 'Miringuava', '83090-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3617, 'Guarapuava', 'Arival Ribas Cramer', 'Dos Estados', '85035-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3618, 'Paranaguá', 'Arivaldo Correia Ribeiro', 'Vila do Caic', '83215-689', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3619, 'Guarapuava', 'Arizona', 'Morro Alto', '85067-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3620, 'Toledo', 'Arlei Leonardi', 'Pacaembu', '85910-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3621, 'Curitiba', 'Arlene Maria Hansel', 'Guabirotuba', '81520-585', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3622, 'Almirante Tamandaré', 'Arlete Antônia da Silva', 'Planta Almirante', '83508-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3623, 'Curitiba', 'Arlete Martins', 'Taboão', '82130-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3624, 'Colombo', 'Arlindo Andreta', 'Vila São Gabriel', '83406-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3625, 'Almirante Tamandaré', 'Arlindo Antônio Barbosa', 'Vila Grécia', '83502-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3626, 'Londrina', 'Arlindo Antônio Vieira', 'Operária', '86038-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3627, 'Guarapuava', 'Arlindo Antunes de Almeida', 'Boqueirão', '85022-470', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3628, 'Curitiba', 'Arlindo Araújo Sobrinho', 'Guabirotuba', '81510-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3629, 'Foz do Iguaçu', 'Arlindo Barcelos dos Santos', 'Jardim Califórnia', '85855-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3630, 'São José dos Pinhais', 'Arlindo Bordignon', 'Braga', '83020-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3631, 'Apucarana', 'Arlindo Bresolin', 'Chácara Mate Amargo', '86803-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3632, 'Curitiba', 'Arlindo Chiminacio', 'Tatuquara', '81940-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3633, 'Curitiba', 'Arlindo Cooper', 'Cidade Industrial', '81170-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3634, 'Curitiba', 'Arlindo de Lara', 'Tingui', '82620-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3635, 'Londrina', 'Arlindo Dias Santana', 'Parque Residencial Campos Elísios', '86044-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3636, 'Toledo', 'Arlindo Dreer', 'Loteamento Lidia Joana Vols', '85912-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3637, 'São José dos Pinhais', 'Arlindo Fernandes', 'Braga', '83020-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3638, 'São José dos Pinhais', 'Arlindo Francez', 'Afonso Pena', '83050-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3639, 'Apucarana', 'Arlindo Godoy Vianna', 'Loteamento Sanches dos Santos', '86806-577', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3640, 'Colombo', 'Arlindo H. de Carvalho', 'Jardim Santa Cândida', '83402-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3641, 'São José dos Pinhais', 'Arlindo João da Costa', 'São Cristóvão', '83040-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3642, 'Umuarama', 'Arlindo Líbero da Silva', 'Parque Bandeirantes', '87504-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3643, 'Maringá', 'Arlindo Marquezini', 'Conjunto Habitacional Hermann Moraes Barros', '87023-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3644, 'Foz do Iguaçu', 'Arlindo Milate', 'Jardim Porto Belo', '85867-517', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3645, 'Curitiba', 'Arlindo Natal', 'Uberaba', '81580-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3646, 'Londrina', 'Arlindo Nogueira de Carvalho', 'Roseira', '86041-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3647, 'Maringá', 'Arlindo Pedralli', 'Parque das Laranjeiras', '87083-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3648, 'Paranaguá', 'Arlindo Piovesan Vidal', 'Parque São João', '83212-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3649, 'São José dos Pinhais', 'Arlindo Pissaia', 'Colônia Rio Grande', '83025-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3650, 'Guarapuava', 'Arlindo Ribeiro', 'Centro', '85010-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3651, 'Guarapuava', 'Arlindo Ribeiro', 'Batel', '85015-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3652, 'Londrina', 'Arlindo Ribeiro do Prado', 'Conjunto Habitacional José Giordano', '86082-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3653, 'Curitiba', 'Arlindo Rocha', 'Cajuru', '82920-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3654, 'Curitiba', 'Arlindo Scaramuzza', 'Uberaba', '81560-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3655, 'Ponta Grossa', 'Arlindo Teodoro Costa', 'Boa Vista', '84071-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3656, 'Maringá', 'Arlindo Urgnani', 'Conjunto Habitacional Requião', '87047-436', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3657, 'Londrina', 'Arlindo Ziliotto', 'Alto da Boa Vista', '86083-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3658, 'Foz do Iguaçu', 'Armando', 'Conjunto A', '85860-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3659, 'Londrina', 'Armando Balarotti', 'Portal de Versalhes 1', '86057-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3660, 'Curitiba', 'Armando Bogo', 'Cajuru', '82900-315', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3661, 'Cascavel', 'Armando Busato', 'Santa Felicidade', '85803-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3662, 'Paranavaí', 'Armando C. Araújo', 'Centro', '87702-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3663, 'Curitiba', 'Armando Carvalho Chaves', 'Sítio Cercado', '81920-748', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3664, 'Maringá', 'Armando Crippa', 'Jardim Liberdade', '87047-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3665, 'Cascavel', 'Armando de Souza Mello', 'Santa Felicidade', '85803-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3666, 'Curitiba', 'Armando Della Bianca', 'Cajuru', '82930-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3667, 'Londrina', 'Armando Forim', 'Milton Gavetti', '86078-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3668, 'Curitiba', 'Armando Lobo Alvim', 'Butiatuvinha', '82400-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3669, 'Cambé', 'Armando Lucas Pinheiro', 'Planta São Francisco', '86182-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3670, 'Toledo', 'Armando Luiz Arrosi', 'Centro', '85901-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3671, 'Umuarama', 'Armando Luiz Bretas', 'Jardim San Fernando', '87508-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3672, 'Londrina', 'Armando Ortenzi', 'Jardim Santa Cruz', '86084-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3673, 'Londrina', 'Armando Piantini', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3674, 'Curitiba', 'Armando Prince', 'Tarumã', '82810-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3675, 'Maringá', 'Armando Raul Espejo Aquije', 'Vila Esperança', '87020-530', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3676, 'Piraquara', 'Armando Romani', 'Centro', '83301-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3677, 'Curitiba', 'Armando Sales de Oliveira', 'Guabirotuba', '81510-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3678, 'Londrina', 'Armando Sanguinetti', 'Assis', '86086-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3679, 'Umuarama', 'Armando Viana', 'Conjunto Residencial Ouro Preto', '87504-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3680, 'Foz do Iguaçu', 'Armelindo Daros Copetti', 'Vila Adriana', '85854-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3681, 'Curitiba', 'Armelindo Peruzzo', 'Sítio Cercado', '81925-598', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3682, 'Campo Mourão', 'Armelindo Trombini', 'Conjunto Residencial Ilha Bela', '87309-097', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3683, 'Campo Mourão', 'Armil Rodrigues Prado', 'Jardim Lar Paraná', '87305-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3684, 'Curitiba', 'Armildo Berwig', 'Atuba', '82860-085', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3685, 'Curitiba', 'Armin Prusse', 'Cidade Industrial', '81280-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3686, 'Curitiba', 'Arminda Alves Assumpção', 'Tingui', '82600-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3687, 'Curitiba', 'Arminda Carneiro Neto', 'Sítio Cercado', '81935-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3688, 'Curitiba', 'Arminda Volpi Morganti', 'Uberaba', '81550-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3689, 'Ponta Grossa', 'Armindo Krapp', 'Uvaranas', '84026-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3690, 'Foz do Iguaçu', 'Armindo Roberto Matte', 'Cohapar III', '85858-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3691, 'Almirante Tamandaré', 'Arnaldina Danguy de Freitas', 'Vila Pacheco', '83511-546', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3692, 'Araucária', 'Arnaldo Antônio Senegaglia', 'Tindiquera', '83708-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3693, 'Curitiba', 'Arnaldo Baptista de Castro', 'Atuba', '82860-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3694, 'Araucária', 'Arnaldo Borba', 'Capela Velha', '83706-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3695, 'Pinhais', 'Arnaldo de Andrade', 'Vila Maria Antonieta', '83331-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3696, 'Curitiba', 'Arnaldo de Barros', 'Seminário', '80240-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3697, 'Londrina', 'Arnaldo de Oliveira dos Santos', 'Jardim Maria Celina', '86081-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3698, 'Cascavel', 'Arnaldo Estrela', 'Brasília', '85815-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3699, 'Cambé', 'Arnaldo Fazan', 'Jardim Vitória', '86184-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3700, 'Curitiba', 'Arnaldo Fecci', 'Pilarzinho', '82110-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3701, 'Curitiba', 'Arnaldo Ferreira de Abreu', 'Sítio Cercado', '81920-725', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3702, 'Curitiba', 'Arnaldo Fontana', 'Bigorrilho', '80710-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3703, 'Curitiba', 'Arnaldo Gabardo', 'Xaxim', '81710-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3704, 'Curitiba', 'Arnaldo Granatto', 'Abranches', '82210-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3705, 'Curitiba', 'Arnaldo Gusi', 'Xaxim', '81830-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3706, 'Paranaguá', 'Arnaldo M. de Carvalho', 'Parque São João', '83212-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3707, 'Toledo', 'Arnaldo Manica', 'Conjunto Residencial Tocantins', '85903-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3708, 'Sarandi', 'Arnaldo Martins', 'Parque Alvamar', '87113-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3709, 'Curitiba', 'Arnaldo Monti Bertolini', 'Cajuru', '82920-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3710, 'Curitiba', 'Arnaldo Pisseti', 'Bairro Alto', '82820-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3711, 'Ponta Grossa', 'Arnaldo Szesz', 'Chapada', '84063-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3712, 'Curitiba', 'Arnaldo Thá', 'Fazendinha', '81330-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3713, 'Curitiba', 'Arnan Chemin Branco', 'Cidade Industrial', '81460-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3714, 'Curitiba', 'Arnaud Ferreira Velloso', 'Cidade Industrial', '81260-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3715, 'Campo Largo', 'Arnestor Antônio Welter', 'Jardim Rondinha', '83607-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3716, 'Piraquara', 'Arnhem', 'Holandez', '83312-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3717, 'Piraquara', 'Arnica', 'Vila Santa Maria', '83306-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3718, 'Pinhais', 'Arnildo Fabro', 'Conjunto Residencial Áquila', '83326-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3719, 'Curitiba', 'Arno Emílio Gerstenberger', 'Pilarzinho', '82100-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3720, 'Curitiba', 'Arno Feliciano de Castilho', 'Bairro Alto', '82820-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3721, 'Colombo', 'Arno Henneng', 'Jardim Palmares', '83412-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3722, 'Foz do Iguaçu', 'Arno Mertig', 'Loteamento Universitário das Américas', '85870-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3723, 'Foz do Iguaçu', 'Arno Welter', 'Parque Ouro Verde', '85853-126', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3724, 'Ponta Grossa', 'Arno Wolf', 'Colônia Dona Luiza', '84046-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3725, 'Curitiba', 'Arnold Schmidt', 'Xaxim', '81830-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3726, 'Maringá', 'Arnoldo Armstrong de Oliveira', 'Conjunto Residencial Ney Braga', '87075-190', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3727, 'Laranjeiras do Sul', 'Arnoldo Gomes Sales', 'Getúlio Vargas', '85304-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3728, 'Curitiba', 'Arnoldo Kuhl', 'Portão', '81070-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3729, 'Apucarana', 'Arnoldo Langbein', 'Centro', '86800-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3730, 'Curitiba', 'Arnoldo Ravanelo', 'Prado Velho', '80215-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3731, 'Ponta Grossa', 'Arnoldo Szesz', 'Contorno', '84060-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3732, 'Curitiba', 'Arnoldo Wolff Gaensly', 'Atuba', '82630-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3733, 'Ponta Grossa', 'Arnon', 'Jardim Carvalho', '84016-687', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3734, 'Paranaguá', 'Arnon Corrêa', 'Jardim Araçá', '83221-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3735, 'Londrina', 'Aroeira', 'Leonor', '86071-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3736, 'Ponta Grossa', 'Aroeira', 'Contorno', '84061-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3737, 'Telêmaco Borba', 'Aroeira', 'Área 01', '84268-160', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3738, 'Cascavel', 'Aroeira', 'Brasmadeira', '85814-148', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3739, 'Cascavel', 'Aroeira', 'Parque Verde', '85807-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3740, 'Curitiba', 'Arold Loid Rauth', 'Pilarzinho', '82110-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3741, 'Foz do Iguaçu', 'Aroldino Ferreira Cordeiro', 'Jardim Florença', '85867-366', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3742, 'Ponta Grossa', 'Aroldo Caillot', 'Colônia Dona Luiza', '84043-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3743, 'Pinhais', 'Aroldo Camargo de Araújo', 'Jardim Dona Carmem', '83326-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3744, 'Curitiba', 'Aroldo Coture', 'Cidade Industrial', '81315-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3745, 'Foz do Iguaçu', 'Aroldo Esteves de Souza', 'Jardim Copacabana II', '85856-510', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3746, 'Ponta Grossa', 'Aroldo Schemberger', 'Jardim Carvalho', '84016-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3747, 'Almirante Tamandaré', 'Aroldo Teixeira Alves', 'Jardim Casa Blanca', '83513-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3748, 'São José dos Pinhais', 'Arpo', 'Ouro Fino', '83010-290', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3749, 'Colombo', 'Arquimedes', 'Planta Maracanã', '83408-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3750, 'Curitiba', 'Arquimedes Cruz', 'Jardim Social', '82520-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3751, 'Pato Branco', 'Arquimedes Gobatto', 'Bela Vista', '85509-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3752, 'Colombo', 'Arquimedes Pavin', 'Jardim Florença', '83414-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3753, 'Piraquara', 'Arquisse Jacob Testa', 'Guarituba', '83311-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3754, 'Curitiba', 'Arquiteto Alexandre Krasinski Filho', 'Cidade Industrial', '81460-188', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3755, 'Foz do Iguaçu', 'Arquiteto Décio Luiz Cardoso', 'Centro', '85851-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3756, 'Campo Mourão', 'Arquiteto Hamilton Tavella Borges', 'Conjunto Residencial Ilha Bela', '87309-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3757, 'Ponta Grossa', 'Arquiteto Nicolau Ferigotti', 'Uvaranas', '84031-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3758, 'Maringá', 'Arquiteto Nildo Ribeiro da Rocha', 'Jardim Higienópolis', '87060-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3759, 'Maringá', 'Arquiteto Nildo Ribeiro da Rocha', 'Vila Marumby', '87005-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3760, 'Maringá', 'Arquiteto Nildo Ribeiro da Rocha', 'Jardim Ipanema', '87053-330', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3761, 'Maringá', 'Arquiteto Nildo Ribeiro da Rocha', 'Parque Industrial', '87065-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3762, 'Maringá', 'Arquiteto Nildo Ribeiro da Rocha', 'Vila Emília', '87010-480', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3763, 'Cascavel', 'Arquitetura', 'Universitário', '85819-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3764, 'Telêmaco Borba', 'Arroio Cachoeira', 'Área 08', '84270-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3765, 'Telêmaco Borba', 'Arroio Chuí', 'Vila Rosa', '84272-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3766, 'Toledo', 'Arroio Toledo', 'Jardim Paulista', '85909-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3767, 'Curitiba', 'Arroio Trinta', 'Cidade Industrial', '81270-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3768, 'Londrina', 'Arruda', 'Sabará I', '86066-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3769, 'Ponta Grossa', 'Arruda Câmara', 'Boa Vista', '84073-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3770, 'Ponta Grossa', 'Arruda Câmara', 'Uvaranas', '84032-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3771, 'Paranaguá', 'Arsênio B. dos Santos', 'Parque São João', '83212-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3772, 'Curitiba', 'Arsênio de Azevedo', 'Cajuru', '82940-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3773, 'Curitiba', 'Arsezio Antônio Scandelari', 'Pilarzinho', '82120-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3774, 'Pato Branco', 'Artêmio Felini', 'Cristo Rei', '85507-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3775, 'São José dos Pinhais', 'Artex', 'Miringuava', '83090-050', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3776, 'São José dos Pinhais', 'Arthur Alves de Bastos', 'Colônia Murici', '83085-516', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3777, 'Curitiba', 'Arthur Belache', 'Santa Felicidade', '82410-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3778, 'Francisco Beltrão', 'Arthur Bernardes', 'São Miguel', '85602-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3779, 'Guarapuava', 'Arthur Bernardes', 'Morro Alto', '85065-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3780, 'Foz do Iguaçu', 'Arthur Bernardes', 'Parque Presidente', '85863-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3781, 'Paranaguá', 'Arthur Bernardes', 'Alvorada', '83206-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3782, 'Paranaguá', 'Arthur Bernardes', 'Serraria do Rocha', '83221-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3783, 'Pato Branco', 'Arthur Bernardes', 'Brasília', '85504-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3784, 'Pinhais', 'Arthur Bernardes', 'Vila Amélia', '83330-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3785, 'Toledo', 'Arthur Bernardes', 'Jardim Filadélpia', '85902-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3786, 'Apucarana', 'Arthur Bernardes', 'Vila Orizze', '86808-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3787, 'Curitiba', 'Arthur Bindo', 'Santa Felicidade', '82030-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3788, 'Cambé', 'Arthur Bocatto', 'Jardim Vô Zezinho', '86192-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3789, 'Ponta Grossa', 'Arthur Cezar Pina', 'Uvaranas', '84031-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3790, 'Paranaguá', 'Arthur de Abreu', 'Centro Histórico', '83203-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3791, 'Ponta Grossa', 'Arthur de Azevedo', 'Oficinas', '84040-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3792, 'Curitiba', 'Arthur Delattre', 'Tingui', '82600-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3793, 'Ponta Grossa', 'Arthur Denck', 'Contorno', '84060-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3794, 'Castro', 'Arthur Ehalt', 'Cantagalo', '84178-285', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3795, 'Curitiba', 'Arthur Erzinger', 'Cajuru', '82970-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3796, 'Curitiba', 'Arthur Euclides de Moura', 'Xaxim', '81810-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3797, 'Curitiba', 'Arthur Francisco Fronza', 'Pilarzinho', '82115-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3798, 'Curitiba', 'Arthur Geronasso', 'Boa Vista', '82560-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3799, 'Ponta Grossa', 'Arthur Gomes', 'Neves', '84021-570', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3800, 'Ponta Grossa', 'Arthur Gomes de Paula', 'Oficinas', '84036-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3801, 'Castro', 'Arthur Gomes Machado', 'Vila Rio Branco', '84172-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3802, 'Araucária', 'Arthur Hasselmann', 'Boqueirão', '83704-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3803, 'Curitiba', 'Arthur Hipólito Bisse', 'Cidade Industrial', '81240-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3804, 'Londrina', 'Arthur Jaceguai', 'Itamarati', '86061-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3805, 'Curitiba', 'Arthur José Nísio', 'Uberaba', '81550-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3806, 'Araucária', 'Arthur Kicote', 'Boqueirão', '83704-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3807, 'Curitiba', 'Arthur Leal', 'Alto Boqueirão', '81860-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3808, 'Curitiba', 'Arthur Leinig', 'Vista Alegre', '80810-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3809, 'Londrina', 'Arthur Lopes', 'Jatobá', '86043-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3810, 'Londrina', 'Arthur Magro', 'Tarobá', '86042-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3811, 'Curitiba', 'Arthur Manoel Iwersen', 'Boqueirão', '81750-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3812, 'Curitiba', 'Arthur Manoel Iwersen', 'Boqueirão', '81770-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3813, 'Piraquara', 'Arthur Martins', 'Vila Ipanema', '83301-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3814, 'Curitiba', 'Arthur Martins Franco', 'Fazendinha', '81330-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3815, 'Curitiba', 'Arthur Martins Franco', 'Cidade Industrial', '81350-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3816, 'Apucarana', 'Arthur Miller Thomas', 'Jardim Aclimação', '86808-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3817, 'Foz do Iguaçu', 'Arthur Milton Farinon', 'Parque Ouro Verde', '85854-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3818, 'Curitiba', 'Arthur Mohr', 'Portão', '81070-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3819, 'Curitiba', 'Arthur Morgenstern Júnior', 'Novo Mundo', '81020-515', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3820, 'Curitiba', 'Arthur Müller', 'Xaxim', '81830-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3821, 'Curitiba', 'Arthur Nepomuceno', 'Uberaba', '81580-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3822, 'Curitiba', 'Arthur Otto Suckow', 'Prado Velho', '80215-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3823, 'Francisco Beltrão', 'Arthur Petrassin', 'São Miguel', '85602-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3824, 'Curitiba', 'Arthur Pina', 'Boqueirão', '81670-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3825, 'Francisco Beltrão', 'Arthur Pinto Salgado', 'Presidente Kennedy', '85605-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3826, 'São José dos Pinhais', 'Arthur Poland', 'Costeira', '83015-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3827, 'Curitiba', 'Arthur Polzin', 'Novo Mundo', '81020-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3828, 'Piraquara', 'Arthur Portela de Oliveira', 'Planta Laranjeiras', '83307-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3829, 'Curitiba', 'Arthur Praxedes de Miranda', 'Bairro Alto', '82840-530', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3830, 'Curitiba', 'Arthur Ramos', 'Atuba', '82840-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3831, 'Curitiba', 'Arthur Rodrigues Tramujas Neto', 'Alto Boqueirão', '81750-460', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3832, 'Araucária', 'Arthur Sander Ferreira', 'Boqueirão', '83704-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3833, 'São José dos Pinhais', 'Arthur Schopenhauer', 'Aristocrata', '83030-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3834, 'Curitiba', 'Arthur Staude', 'Uberaba', '81550-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3835, 'Curitiba', 'Arthur Suplicy de Lacerda', 'Seminário', '80740-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3836, 'Curitiba', 'Arthur Tambosi', 'Cidade Industrial', '81460-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3837, 'Foz do Iguaçu', 'Arthur Texdorf', 'Jardim São Paulo II', '85856-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3838, 'Londrina', 'Arthur Thomas', 'Rodocentro', '86065-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3839, 'Maringá', 'Arthur Thomas', 'Zona 01', '87013-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3840, 'Umuarama', 'Arthur Thomas', 'Zona III', '87502-190', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3841, 'Londrina', 'Arthur Thomaz', 'Jardim Novo Sabará', '86066-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3842, 'São José dos Pinhais', 'Arthur Urban', 'Miringuava', '83090-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3843, 'Londrina', 'Ártico', 'Jardim Indianápolis', '86010-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3844, 'Cascavel', 'Artilharia', 'Região do Lago', '85812-360', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3845, 'Curitiba', 'Artina Bellino Coutinho', 'Barreirinha', '82700-640', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3846, 'Curitiba', 'Artur Alberto Schmeiske', 'Alto Boqueirão', '81770-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3847, 'Curitiba', 'Artur Ângelo Pelanda', 'Alto Boqueirão', '81850-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3848, 'Curitiba', 'Artur Bailo', 'Mossunguê', '81200-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3849, 'Paranavaí', 'Artur Bernades', 'Jardim Paulista', '87709-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3850, 'Paranavaí', 'Artur Bernardes', 'Jardim Progresso', '87701-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3851, 'Telêmaco Borba', 'Artur Bernardes', 'Alto das Oliveiras', '84265-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3852, 'Pato Branco', 'Artur Bertol', 'Santa Terezinha', '85501-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3853, 'Colombo', 'Artur de Azevedo', 'Jardim Quitandinha', '83409-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3855, 'Ponta Grossa', 'Artur Hilgemberg', 'Neves', '84020-767', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3856, 'Curitiba', 'Artur Julião da Silva', 'Bacacheri', '82600-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3857, 'Francisco Beltrão', 'Artur Júlio Nacke', 'Sadia', '85606-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3858, 'Almirante Tamandaré', 'Artur Kamaroski da Silva', 'Planta São Venâncio', '83504-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3859, 'Araucária', 'Artur Klas', 'Costeira', '83709-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3860, 'Toledo', 'Artur Mazaferro', 'Residencial Santa Clara', '85907-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3861, 'Guarapuava', 'Artur Menarim', 'Morro Alto', '85065-746', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3862, 'Pinhais', 'Artur Nehring', 'Vila Carolina', '83326-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3863, 'Cascavel', 'Artur Nísio', 'Country', '85813-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3864, 'Guarapuava', 'Artur Scheidt', 'Santana', '85070-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3865, 'Campo Mourão', 'Artur Tramujas Filho', 'Parque Industrial I', '87306-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3866, 'Foz do Iguaçu', 'Artur Valdomiro Sparremberg', 'Jardim Veraneio', '85855-638', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3867, 'Pinhais', 'Aruana', 'Loteamento Alphaville Graciosa', '83327-097', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3868, 'Apucarana', 'Aruaques', 'Núcleo Habitacional Colonial', '86812-428', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3869, 'Londrina', 'Arvid Augusto Ericsson', 'Cilo 3', '86072-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3870, 'Curitiba', 'Ary Barroso', 'Boa Vista', '82560-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3871, 'Curitiba', 'Ary Barroso', 'Boa Vista', '82540-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3872, 'Curitiba', 'Ary Camargo Queiroz', 'Centro Cívico', '80030-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3873, 'Curitiba', 'Ary Caramão Arruda', 'Cidade Industrial', '81450-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3874, 'Colombo', 'Ary Cardoso da Silva', 'Vila São Gabriel', '83406-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3875, 'Curitiba', 'Ary Claudino Ziemer', 'Pinheirinho', '81870-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3876, 'Curitiba', 'Ary de Souza', 'Cidade Industrial', '81305-200', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3877, 'Curitiba', 'Ary Florêncio Guimarães', 'Vila Izabel', '80240-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3878, 'Pinhais', 'Ary Lopes', 'Loteamento Pineville', '83325-587', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3879, 'Ponta Grossa', 'Ary Munhoz', 'Uvaranas', '84030-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3880, 'Curitiba', 'Ary Rolim Costa', 'Fazendinha', '81330-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3881, 'Curitiba', 'Ary Taborda', 'Ganchinho', '81935-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3882, 'Foz do Iguaçu', 'Asa branca', 'Conjunto A', '85866-150', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3883, 'Cambé', 'Asa Norte', 'Jardim Alvorada', '86191-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3884, 'Cambé', 'Asa Sul', 'Jardim Alvorada', '86191-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3885, 'Londrina', 'Asa-branca', 'Waldemar Hauer', '86030-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3886, 'Paranaguá', 'Asa-branca', 'Santos Dumont', '83209-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3887, 'Umuarama', 'Asa-branca', 'Conjunto Patrimônio Umuarama', '87505-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3888, 'Arapongas', 'Asa-de-telha', 'Conjunto Padre Bernardo Merckel', '86706-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3889, 'Paranaguá', 'Ascendino Pessoa Maciel', 'Vila Garcia', '83218-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3890, 'Pinhais', 'Ásia', 'Jardim Boa Esperança', '83323-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3891, 'Cascavel', 'Ásia', 'Brasília', '85815-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3892, 'Cascavel', 'Ásia', 'Periolo', '85817-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3893, 'Londrina', 'Assad Abu-Jamra', 'Vale das Araucárias', '86047-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3894, 'Campo Mourão', 'Assad Nasser', 'Jardim Lar Paraná', '87305-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3895, 'Londrina', 'Assad Sahão', 'Roseira', '86041-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3896, 'Curitiba', 'Assad Zacarias', 'Uberaba', '81560-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3897, 'Londrina', 'Assaí', 'Judith', '86061-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3898, 'Foz do Iguaçu', 'Assaí', 'Jardim Lancaster II', '85869-370', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3899, 'Ponta Grossa', 'Assaí', 'Uvaranas', '84025-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3900, 'Maringá', 'Assaí', 'Chácara Assaí', '87005-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3901, 'Pinhais', 'Assaí', 'Jardim Dona Joaquina II', '83325-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3902, 'São José dos Pinhais', 'Assaí', 'Cruzeiro', '83010-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3903, 'Telêmaco Borba', 'Assaí', 'Área 02', '84267-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3904, 'Cascavel', 'Assaí', 'Santa Cruz', '85806-738', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3905, 'Curitiba', 'Assaí', 'Sítio Cercado', '81900-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3906, 'Curitiba', 'Assírio Gomes Martins', 'Taboão', '82130-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3907, 'Londrina', 'Assis', 'Champagnat', '86062-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3908, 'Maringá', 'Assis', 'Zona 06', '87015-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3909, 'Foz do Iguaçu', 'Assis Basílio', 'Vila Pérola', '85865-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3910, 'Foz do Iguaçu', 'Assis Brasil', 'Vila Portes', '85865-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3911, 'Francisco Beltrão', 'Assis Brasil', 'Cango', '85604-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3912, 'Pato Branco', 'Assis Brasil', 'Brasília', '85504-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3913, 'Ponta Grossa', 'Assis Brasil', 'Orfãs', '84015-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3914, 'Toledo', 'Assis Brasil', 'Vila Industrial', '85905-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3915, 'Cascavel', 'Assis Brasil', 'São Cristóvão', '85816-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3916, 'Curitiba', 'Assis Brasil', 'Barreirinha', '82220-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3917, 'Londrina', 'Assis Chateaubriand', 'Marumbi', '86071-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3918, 'Foz do Iguaçu', 'Assis Chateaubriand', 'Jardim Cristina', '85864-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3919, 'Guarapuava', 'Assis Chateaubriand', 'Jardim das Américas', '85030-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3920, 'Paranavaí', 'Assis Chateaubriand', 'Jardim Santa Cecília', '87702-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3921, 'Maringá', 'Assis Chateaubriand', 'Vila Santo Antônio', '87030-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3922, 'Telêmaco Borba', 'Assis Chateaubriand', 'Alto das Oliveiras', '84266-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3923, 'Curitiba', 'Assis Figueiredo', 'Parolin', '80630-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3924, 'Curitiba', 'Assma Karam Geara', 'Cajuru', '82900-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3925, 'Arapongas', 'Assobiador', 'Jardim Morumbi', '86708-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3926, 'Foz do Iguaçu', 'Assum Preto', 'Portal da Foz', '85859-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3927, 'Londrina', 'Assumpta Romeu Pelegrinelli', 'Conjunto Novo Amparo 2', '86056-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3928, 'Foz do Iguaçu', 'Assunção', 'Conjunto C', '85870-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3929, 'Guarapuava', 'Assunção', 'Santana', '85070-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3930, 'Francisco Beltrão', 'Assunção', 'Miniguaçu', '85605-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3931, 'Foz do Iguaçu', 'Assunção', 'Jardim Liberdade', '85858-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3932, 'Londrina', 'Assunção', 'Guanabara', '86050-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3933, 'Maringá', 'Assunção', 'Vila Marumby', '87005-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3934, 'Telêmaco Borba', 'Assunção', 'Nossa Senhora de Fátima', '84264-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3935, 'Cascavel', 'Assunção', 'Alto Alegre', '85805-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3936, 'Colombo', 'Assunção', 'Planta Cristóvão Colombo', '83404-520', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3937, 'Curitiba', 'Assunta Biagini', 'Bigorrilho', '80710-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3938, 'Cascavel', 'Assunta Bonatto', 'Centro', '85805-005', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3939, 'Londrina', 'Astolfo Nogueira', 'Assis', '86085-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3940, 'Curitiba', 'Astolpho Macedo Souza', 'Butiatuvinha', '82320-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3941, 'Curitiba', 'Astolpho Nogueira', 'Campo Comprido', '81220-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3942, 'Curitiba', 'Astor Toniolo', 'Santa Felicidade', '82410-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3943, 'Londrina', 'Astorga', 'Hedy', '86061-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3944, 'Guarapuava', 'Astorga', 'Jardim das Américas', '85030-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3945, 'Foz do Iguaçu', 'Astorga', 'Mata Verde', '85853-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3946, 'São José dos Pinhais', 'Astorga', 'Silveira da Motta', '83030-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3947, 'Maringá', 'Astorga', 'Zona 08', '87050-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3948, 'Ponta Grossa', 'Astorga', 'Nova Rússia', '84053-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3949, 'Toledo', 'Astorga', 'Vila Industrial', '85904-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3950, 'Umuarama', 'Astorga', 'Zona I', '87501-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3951, 'Sarandi', 'Astorga', 'Parque Residencial Nova Aliança', '87111-738', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3952, 'Colombo', 'Astorga', 'Jardim Guaraituba', '83410-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3953, 'Campo Mourão', 'Astorga', 'Conjunto Residencial Athilhas', '87308-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3954, 'Curitiba', 'Astorga', 'Sítio Cercado', '81900-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3955, 'Curitiba', 'Astrônomo Omar Khayyam', 'Sítio Cercado', '81920-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3956, 'Curitiba', 'Ata', 'Uberaba', '81550-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3957, 'Curitiba', 'Atahualpa', 'Cajuru', '82940-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3958, 'Piraquara', 'Ataide Alves da Costa', 'Vila Ipanema', '83301-056', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3959, 'Foz do Iguaçu', 'Ataide Ferreira de Souza', 'Porto Belo', '85867-630', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3960, 'São José dos Pinhais', 'Ataíde Mariotto', 'Planta Quississana', '83085-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3961, 'Foz do Iguaçu', 'Atalaia', 'Vila Carima', '85855-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3962, 'Guarapuava', 'Atalaia', 'Boqueirão', '85023-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3963, 'Maringá', 'Atalaia', 'Zona 08', '87050-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3964, 'Pinhais', 'Atalaia', 'Núcleo Colonial de Pinhais', '83321-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3965, 'Telêmaco Borba', 'Atalaia', 'Jardim União', '84266-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3966, 'Campo Mourão', 'Atalaia', 'Conjunto Habitacional Parigot de Souza', '87310-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3967, 'Colombo', 'Atalaia', 'Jardim Guaraituba', '83410-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3968, 'Pinhais', 'Ataliba Coelho dos Santos', 'Prive Bois de Boulogne', '83330-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3969, 'Guarapuava', 'Atanagildo Martins Pinto', 'Vila Bela', '85025-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3970, 'Londrina', 'Atanásio Bello', 'Portal de Versalhes 3', '86055-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3971, 'Pinhais', 'Ataulfo Alves', 'Vila Maria Antonieta', '83331-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3972, 'Maringá', 'Ataulfo Alves', 'Conjunto Residencial Cidade Alta', '87053-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3973, 'Colombo', 'Ataulfo Alves', 'Jardim Quitandinha', '83409-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3974, 'Cascavel', 'Ataulfo Alves', 'Brasília', '85815-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3975, 'Londrina', 'Ataúlfo Alves', 'Conjunto Vivi Xavier', '86082-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3976, 'Ponta Grossa', 'Ataúlfo Alves', 'Estrela', '84050-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3977, 'Pato Branco', 'Ataúlfo Alves', 'Chaparral', '85507-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3978, 'Apucarana', 'Ataúlfo Alves', 'Núcleo Habitacional Castelo Branco', '86812-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3979, 'Curitiba', 'Ataúlfo Alves', 'Xaxim', '81820-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3980, 'Londrina', 'Ataulpho de Paiva', 'Monções', '86015-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3981, 'Foz do Iguaçu', 'Atayde Ayres de Aguirra', 'Beverly Falls Park', '85858-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3982, 'Foz do Iguaçu', 'Atenas', 'Beverly Falls Park', '85858-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3983, 'Francisco Beltrão', 'Atenas', 'Aeroporto', '85603-847', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3984, 'Guarapuava', 'Atenas', 'Santana', '85070-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3985, 'Telêmaco Borba', 'Atenas', 'Nossa Senhora do Perpétuo Socorro', '84265-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3986, 'Colombo', 'Atenas', 'Vila Santa Clara', '83405-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3987, 'São José dos Pinhais', 'Atevide Miranda', 'Guatupê', '83060-217', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3988, 'São José dos Pinhais', 'Athaide Bonin', 'Braga', '83020-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3989, 'Curitiba', 'Athaide Cardon', 'Novo Mundo', '81020-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3990, 'Almirante Tamandaré', 'Athaide de Siqueira', 'Vila Rachel', '83501-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3991, 'Ponta Grossa', 'Athaide Ferreira de Menezes', 'Boa Vista', '84071-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3992, 'Ponta Grossa', 'Athaides Grein Taques', 'Boa Vista', '84072-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3993, 'Londrina', 'Athail Cunha Leoni', 'Jardim Maria Celina', '86081-547', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3994, 'Ponta Grossa', 'Athanagildo Martins de Almeida', 'Contorno', '84052-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3995, 'Paranaguá', 'Athenas', 'Parque Agari', '83215-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3996, 'Londrina', 'Athos Anzola', 'Santiago', '86071-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3997, 'Curitiba', 'Athos Moraes Castro Vellozo', 'Cidade Industrial', '81350-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3998, 'Foz do Iguaçu', 'Atibaia', 'Jardim Terra e Lar', '85858-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (3999, 'Foz do Iguaçu', 'Ático José Rorato', 'Jardim Petropólis', '85868-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4000, 'Araucária', 'Atílio Benevenuto Furlan', 'Vila Nova', '83703-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4001, 'Curitiba', 'Atílio Borio', 'Cristo Rei', '80050-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4002, 'Curitiba', 'Atílio Borio', 'Alto da Rua XV', '80040-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4003, 'Araucária', 'Atílio Bosquete', 'Tindiquera', '83708-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4004, 'Curitiba', 'Atílio Brunetti', 'Capão Raso', '81130-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4005, 'Curitiba', 'Atílio Brunetti', 'Capão Raso', '81150-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4006, 'Apucarana', 'Atílio Carleto', 'Parque Bela Vista', '86803-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4007, 'Campo Largo', 'Atílio Castagnoli', 'Loteamento Santa Rita', '83602-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4008, 'Cambé', 'Atílio Codato', 'Jardim Riviera', '86187-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4009, 'Curitiba', 'Atílio Dal Negro', 'Uberaba', '81580-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4010, 'Toledo', 'Atílio de Bona', 'Residencial Santa Clara', '85908-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4011, 'Londrina', 'Atílio Favoretto', 'Jardim Alphaville', '86084-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4012, 'Toledo', 'Atílio Formighieri', 'Centro', '85901-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4013, 'Ponta Grossa', 'Atílio Gardinal', 'Orfãs', '84015-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4014, 'Curitiba', 'Atílio Gasparini', 'Jardim Social', '82520-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4015, 'Curitiba', 'Atílio Leal', 'Ahú', '82200-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4016, 'Curitiba', 'Atílio Pilatti', 'Xaxim', '81810-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4017, 'Curitiba', 'Atílio Pioto', 'Uberaba', '81590-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4018, 'Campo Largo', 'Atílio Rivabem', 'Vila Bancária', '83601-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4019, 'Curitiba', 'Atílio Rodrigues Cardoso', 'Cidade Industrial', '81170-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4020, 'Sarandi', 'Atílio Salvalagio', 'Centro', '87111-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4021, 'Londrina', 'Atílio Scudeler', 'Portuguesa', '86025-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4022, 'Londrina', 'Atílio Vidotti', 'Eucaliptos', '86031-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4023, 'Curitiba', 'Atílio Vieira de Moura', 'São Lourenço', '82210-205', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4024, 'Curitiba', 'Atílio Vieira de Moura', 'Cidade Industrial', '81350-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4025, 'Curitiba', 'Atílio Zaramella', 'Boa Vista', '82540-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4026, 'Arapongas', 'Atingau', 'Jardim Caravelle', '86702-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4027, 'Maringá', 'Atlanta', 'Jardim Atlânta', '87045-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4028, 'Cambé', 'Atlanta', 'Jardim Califórnia', '86182-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4029, 'Paranaguá', 'Atlântica', 'Jardim Paranaguá', '83218-410', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4030, 'Sarandi', 'Atlântica', 'Jardim Escala', '87114-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4031, 'Umuarama', 'Atlântica', 'Jardim Paraíso', '87505-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4032, 'Londrina', 'Atlântico', 'Jardim Indianápolis', '86010-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4033, 'Guarapuava', 'Atlântida', 'Santa Cruz', '85015-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4034, 'Maringá', 'Atleta Sidney Areas', 'Jardim Seminário', '87080-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4035, 'Ponta Grossa', 'Atoba', 'Colônia Dona Luiza', '84046-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4036, 'Arapongas', 'Atoba', 'Vila Nova', '86707-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4037, 'Arapongas', 'Atobá-australiano', 'Conjunto Novo Centauro', '86709-537', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4038, 'Arapongas', 'Atobá-pardo', 'Jardim Boa Vista', '86702-178', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4039, 'Cascavel', 'Atrinio', 'Esmeralda', '85806-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4040, 'Cascavel', 'Atrinio', 'Esmeralda', '85806-765', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4041, 'Curitiba', 'Attilio Alice', 'Tingui', '82600-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4042, 'Campo Largo', 'Attilio de Almeida Barbosa', 'Centro', '83601-330', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4043, 'Araucária', 'Attilio Druszcz', 'Campina da Barra', '83709-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4044, 'Francisco Beltrão', 'Attilio Fontana', 'Pinheirinho', '85603-025', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4045, 'São José dos Pinhais', 'Attilio João Bortolotti', 'Rio Pequeno', '83070-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4046, 'Londrina', 'Attilio Niero', 'Jardim Império do Sol', '86073-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4047, 'Londrina', 'Attilio Octávio Bizato', 'Centro', '86010-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4048, 'Piraquara', 'Attilio Pedão', 'Guarituba', '83310-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4049, 'Curitiba', 'Attilio Ramon', 'Bairro Alto', '82840-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4050, 'Curitiba', 'Attilio Silva Fonseca', 'Sítio Cercado', '81925-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4051, 'São José dos Pinhais', 'Attilio Talamini', 'Costeira', '83015-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4052, 'Curitiba', 'Attilio Vicelli', 'Cidade Industrial', '81260-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4053, 'Almirante Tamandaré', 'Atuba', 'Vila Alto Pinheiros', '83503-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4054, 'Foz do Iguaçu', 'Atum', 'Profilurb I', '85855-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4055, 'Foz do Iguaçu', 'Atuma', 'Loteamento Campos do Iguaçu', '85857-360', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4056, 'Arapongas', 'Aturiá', 'Vila São Vicente', '86707-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4057, 'Cambé', 'Augostinho Ferrarini', 'Jardim Riviera', '86187-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4058, 'Maringá', 'Augostinho Franco da Rocha', 'Conjunto João de Barro Porto Seguro II', '87055-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4059, 'Cambé', 'Augostinho Spagnolo', 'Jardim Silvino', '86188-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4060, 'Colombo', 'Augusta', 'Vila Augusta', '83407-405', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4061, 'Londrina', 'Augusta Consolin Vidotti', 'Jardim Alphaville', '86084-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4062, 'Pinhais', 'Augusta Santos Andrade', 'Vila Maria Antonieta', '83331-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4063, 'Curitiba', 'Auguste Comte', 'Santa Felicidade', '82030-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4064, 'Curitiba', 'Augustina Drulla', 'Campo Comprido', '81200-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4065, 'Toledo', 'Augustinho Donin', 'Conjunto Habitacional São Francisco', '85912-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4066, 'Apucarana', 'Augustinho Fabene', 'Mutirão Projeto Bóia Fria', '86803-540', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4067, 'Curitiba', 'Augustinho Lucca', 'Santa Felicidade', '82320-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4068, 'Ponta Grossa', 'Augustinho Mathias Pinheiro', 'Chapada', '84063-380', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4069, 'Londrina', 'Augustinho Matiniano Perandrea', 'Roseira', '86041-505', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4070, 'São José dos Pinhais', 'Augustinho Zen', 'Silveira da Motta', '83030-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4071, 'São José dos Pinhais', 'Augusto Adão', 'Ipê', '83055-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4072, 'Apucarana', 'Augusto Alberti', 'Núcleo Habitacional Castelo Branco', '86812-385', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4073, 'Londrina', 'Augusto Ballalai', 'Milton Gavetti', '86078-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4074, 'Curitiba', 'Augusto Basiewicz', 'Tatuquara', '81480-336', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4075, 'Curitiba', 'Augusto Basso', 'Pilarzinho', '82110-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4076, 'Curitiba', 'Augusto Beck', 'Augusta', '81260-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4077, 'Sarandi', 'Augusto Birches Terrão', 'Jardim Nova Paulista', '87111-161', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4078, 'Sarandi', 'Augusto Birches Terrão', 'Boa Vista', '87111-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4079, 'Londrina', 'Augusto Borges', 'Conjunto Residencial Cafezal', '86045-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4080, 'Londrina', 'Augusto Bortolato', 'Sabará III', '86066-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4081, 'Campo Largo', 'Augusto Bulow', 'Vila Kuster', '83604-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4082, 'Londrina', 'Augusto Canezin', 'San Fernando', '86040-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4083, 'Ponta Grossa', 'Augusto Canto', 'Jardim Carvalho', '84015-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4084, 'Piraquara', 'Augusto Carlos Raposo', 'Guarituba', '83311-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4085, 'Foz do Iguaçu', 'Augusto Colombeli', 'Loteameto Jardim Colombelli', '85862-476', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4086, 'Londrina', 'Augusto Conte', 'Universitário', '86050-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4087, 'São José dos Pinhais', 'Augusto Conte', 'Aristocrata', '83030-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4088, 'Curitiba', 'Augusto Conte', 'Abranches', '82220-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4089, 'Ponta Grossa', 'Augusto Cunha', 'Uvaranas', '84031-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4090, 'São José dos Pinhais', 'Augusto da Cruz', 'Colônia Murici', '83085-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4091, 'Pinhais', 'Augusto da Silva', 'Chácara Esperança', '83328-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4092, 'Curitiba', 'Augusto Dallegrave Figueiredo', 'Xaxim', '81820-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4093, 'Curitiba', 'Augusto David de Moraes', 'Uberaba', '81550-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4094, 'Curitiba', 'Augusto de Mari', 'Portão', '80610-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4095, 'Curitiba', 'Augusto de Mari', 'Guaíra', '80630-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4096, 'Francisco Beltrão', 'Augusto de Ross', 'Cango', '85604-266', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4097, 'Francisco Beltrão', 'Augusto de Ross', 'Cango', '85604-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4098, 'Londrina', 'Augusto de Souza Brandão', 'Nova Londres', '86015-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4099, 'São José dos Pinhais', 'Augusto Debarba', 'Miringuava', '83090-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4100, 'Campo Largo', 'Augusto Dering Sobrinho', 'Vila Ferrari', '83606-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4101, 'Curitiba', 'Augusto Dias Paredes', 'Boqueirão', '81730-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4102, 'Almirante Tamandaré', 'Augusto Domacoski', 'Jardim Paraíso', '83512-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4103, 'Foz do Iguaçu', 'Augusto dos Anjos', 'Loteamento Paraguaçu', '85865-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4104, 'Ponta Grossa', 'Augusto dos Anjos', 'Cará-cará', '84043-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4105, 'Curitiba', 'Augusto dos Anjos', 'Abranches', '82220-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4106, 'Paranavaí', 'Augusto Fabretti', 'Jardim Alvorada do Sul', '87707-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4107, 'Campo Largo', 'Augusto Fabris', 'Loteamento Ouro Verde I', '83606-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4108, 'Ponta Grossa', 'Augusto Farias Rocha', 'Jardim Carvalho', '84015-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4109, 'Curitiba', 'Augusto Faustino Stalchmidt', 'Cajuru', '82920-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4110, 'Laranjeiras do Sul', 'Augusto Fernandes de Lima', 'Vila Industrial', '85303-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4111, 'Ponta Grossa', 'Augusto Ferreira', 'Jardim Carvalho', '84016-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4112, 'Curitiba', 'Augusto Fleischfresser', 'São Braz', '82315-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4113, 'Toledo', 'Augusto Formighieri', 'Jardim Santa Maria', '85903-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4114, 'Foz do Iguaçu', 'Augusto Fragoso', 'Parque Presidente', '85863-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4115, 'Curitiba', 'Augusto Frogguer', 'Mossunguê', '81200-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4116, 'Londrina', 'Augusto Gallo', 'Jatobá', '86043-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4117, 'Araucária', 'Augusto Gawleta', 'Estação', '83705-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4118, 'Londrina', 'Augusto Gomes', 'Jardim das Palmeiras', '86083-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4119, 'Guarapuava', 'Augusto Gomes de Oliveira', 'Alto da XV', '85065-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4120, 'Cascavel', 'Augusto Gomes de Oliveira', '14 de Novembro', '85804-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4121, 'Londrina', 'Augusto Guerino', 'Portal de Versalhes 1', '86057-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4122, 'Curitiba', 'Augusto Hauer', 'Pilarzinho', '82110-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4123, 'Curitiba', 'Augusto Heyn', 'Tatuquara', '81470-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4124, 'Curitiba', 'Augusto Ickert', 'Vila Izabel', '80240-500', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4125, 'Apucarana', 'Augusto Joaquim Vieira', 'Vila Apucaraninha', '86813-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4126, 'Londrina', 'Augusto Jondral', 'Cilo 2', '86067-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4127, 'Curitiba', 'Augusto Justi', 'Butiatuvinha', '82320-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4128, 'Curitiba', 'Augusto Klingenfuss', 'Pinheirinho', '81870-216', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4129, 'Guarapuava', 'Augusto Kremer', 'Cascavel', '85040-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4130, 'Guarapuava', 'Augusto Kruger', 'Boqueirão', '85020-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4131, 'Toledo', 'Augusto Kurschner', 'Conjunto Habitacional São Francisco', '85915-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4132, 'Curitiba', 'Augusto Litz', 'Santa Felicidade', '82410-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4133, 'Curitiba', 'Augusto Marach', 'Novo Mundo', '81020-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4134, 'Guarapuava', 'Augusto Marcon', 'Primavera', '85053-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4135, 'Londrina', 'Augusto Massaretto', 'Jardim Continental', '86081-177', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4136, 'Ponta Grossa', 'Augusto Meyer Júnior', 'Cará-cará', '84043-618', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4137, 'São José dos Pinhais', 'Augusto Micrute', 'Colônia Acioli', '83075-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4138, 'Curitiba', 'Augusto Mocelin', 'Santa Felicidade', '82020-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4139, 'Apucarana', 'Augusto Moreira Duarte', 'Parque Bela Vista', '86803-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4140, 'Curitiba', 'Augusto Mueller', 'Xaxim', '81810-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4141, 'Toledo', 'Augusto Negri', 'Residencial Santa Clara', '85908-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4142, 'Toledo', 'Augusto Passarini', 'Jardim Alta Floresta', '85905-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4143, 'Campo Largo', 'Augusto Perussollo', 'Loteamento Itaboa', '83605-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4144, 'Curitiba', 'Augusto Pinto Borba', 'Cajuru', '82980-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4145, 'Curitiba', 'Augusto Renoir', 'Guabirotuba', '81510-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4146, 'Ponta Grossa', 'Augusto Ribas', 'Uvaranas', '84030-005', 'Parque', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4147, 'Ponta Grossa', 'Augusto Ribas', 'Centro', '84010-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4148, 'Araucária', 'Augusto Ribeiro dos Santos', 'Costeira', '83709-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4149, 'Curitiba', 'Augusto Ricciardella Correia', 'Santo Inácio', '82010-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4150, 'Londrina', 'Augusto Rossi', 'Monterey', '86038-385', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4151, 'Maringá', 'Augusto Ruschi', 'Jardim Tabaete', '87005-170', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4152, 'Curitiba', 'Augusto Schechtel', 'Xaxim', '81830-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4153, 'Londrina', 'Augusto Severo', 'Santos Dumont', '86039-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4154, 'Ponta Grossa', 'Augusto Severo', 'Nova Rússia', '84071-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4155, 'Ponta Grossa', 'Augusto Severo', 'Nova Rússia', '84070-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4156, 'Ponta Grossa', 'Augusto Severo', 'Nova Rússia', '84053-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4157, 'Curitiba', 'Augusto Severo', 'Alto da Glória', '80030-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4158, 'Curitiba', 'Augusto Soares da Costa', 'Sítio Cercado', '81920-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4159, 'Curitiba', 'Augusto Steembock', 'Uberaba', '81550-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4160, 'Curitiba', 'Augusto Steenbock Neto', 'Sítio Cercado', '81910-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4161, 'Curitiba', 'Augusto Stellfeld', 'Centro', '80410-140', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4162, 'Curitiba', 'Augusto Stellfeld', 'Centro', '80430-140', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4163, 'Curitiba', 'Augusto Stellfeld', 'Bigorrilho', '80730-150', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4164, 'São José dos Pinhais', 'Augusto Stresser', 'Afonso Pena', '83050-129', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4165, 'Curitiba', 'Augusto Stresser', 'Alto da Glória', '80030-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4166, 'Curitiba', 'Augusto Stresser', 'Juvevê', '80040-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4167, 'Telêmaco Borba', 'Augusto Tobich', 'Centro', '84261-630', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4168, 'Pinhais', 'Augusto Trevisan', 'Vila Maria Antonieta', '83331-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4169, 'Toledo', 'Augusto Voss', 'Loteamento Lidia Joana Vols', '85912-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4170, 'Apucarana', 'Augusto Weiand', 'Vila Nova', '86812-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4171, 'Foz do Iguaçu', 'Augusto Werner', 'Boa Esperança', '85854-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4172, 'Curitiba', 'Augusto Zibarth', 'Uberaba', '81560-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4173, 'Toledo', 'Augusto Zorzo', 'Conjunto Residencial Rossani', '85901-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4174, 'Arapongas', 'Aura', 'Vila Nova', '86707-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4175, 'Toledo', 'Áurea', 'Centro', '85900-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4176, 'Campo Mourão', 'Áurea', 'Centro', '87302-095', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4177, 'Curitiba', 'Áurea Brittes de Oliveira', 'Pilarzinho', '82115-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4178, 'Curitiba', 'Áurea da Conceição F. Kulcheski', 'Cidade Industrial', '81315-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4179, 'Londrina', 'Áurea Erthal Sorage', 'Monte Belo', '86041-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4180, 'Paranaguá', 'Áurea Pereira da Martins', 'Jardim Iguaçu', '83210-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4181, 'Piraquara', 'Aurélia da Silveira', 'Jardim Avaí', '83312-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4182, 'Curitiba', 'Aureliano Azevedo da Silveira', 'São João', '82030-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4183, 'Curitiba', 'Aureliano Rocha Loures', 'Tarumã', '82530-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4184, 'Londrina', 'Aurélio Buarque de Holanda', 'Conjunto Parigot de Souza 1', '86081-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4185, 'Francisco Beltrão', 'Aurélio Buarque de Hollanda', 'São Miguel', '85602-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4186, 'Francisco Beltrão', 'Aurélio Franciscon', 'Marrecas', '85601-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4187, 'Londrina', 'Aurélio Luiz Bergamin', 'Jardim Maria Celina', '86081-557', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4188, 'Londrina', 'Aurélio Paglia', 'Jardim Planalto', '86084-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4189, 'Paranaguá', 'Aurélio Ribeiro Moro', 'Vila Garcia', '83218-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4190, 'Almirante Tamandaré', 'Aurélio Todeschi', 'Planta São Venâncio', '83504-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4191, 'Londrina', 'Áureo Ribeiro Leite', 'Conjunto Semiramis Barros Braga', '86088-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4192, 'Apucarana', 'Áureo Sampaio Morais', 'Jardim Morada do Sol', '86811-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4193, 'Foz do Iguaçu', 'Áureo Syng', 'Jardim Panorama', '85856-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4194, 'Piraquara', 'Auristela Bilro Tinoco', 'Planta Bosque Centenário', '83311-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4195, 'São José dos Pinhais', 'Aurora', 'Guatupê', '83060-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4196, 'Cascavel', 'Aurora', 'Nova Cidade', '85803-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4197, 'Francisco Beltrão', 'Aurora Bordignon', 'Antônio de Paiva Cantelmo', '85603-533', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4198, 'Cascavel', 'Aurora de Maris Silvério', 'Santa Cruz', '85806-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4199, 'Pinhais', 'Aurora do Carmo dos Santos', 'Prive Bois de Boulogne', '83330-266', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4200, 'Guarapuava', 'Aurora Graeff Losso', 'São Cristóvão', '85020-716', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4201, 'Francisco Beltrão', 'Aurora Marcon', 'Aeroporto', '85603-848', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4202, 'São José dos Pinhais', 'Aurora Pasqualin Zen', 'Afonso Pena', '83045-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4203, 'Ponta Grossa', 'Aurora Ribas Droppa', 'Boa Vista', '84072-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4204, 'Curitiba', 'Aurora Tedesco dos Santos', 'Cidade Industrial', '81460-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4205, 'Francisco Beltrão', 'Austrália', 'Pinheirinho', '85606-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4206, 'Pinhais', 'Austrália', 'Planta Bernardo Luz', '83323-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4207, 'Londrina', 'Áustria', 'Igapó', '86046-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4208, 'Guarapuava', 'Áustria', 'Industrial', '85053-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4209, 'Foz do Iguaçu', 'Áustria', 'Jardim Europa', '85859-316', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4210, 'Almirante Tamandaré', 'Áustria', 'Vila Graziela', '83505-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4211, 'Cascavel', 'Áustria', 'Cascavel Velho', '85818-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4212, 'Cambé', 'Áustria', 'Jardim Morada do Sol', '86181-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4213, 'Londrina', 'Autamar de Souza Inácio Mostaco', 'Antônio M Nogueira Cafezal 4', '86089-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4214, 'Curitiba', 'Auton Tchekow', 'Capão Raso', '81020-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4215, 'Cascavel', 'Avaetés', 'Santo Onofre', '85806-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4216, 'Foz do Iguaçu', 'Avaí', 'Jardim Itamaraty', '85863-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4217, 'Guarapuava', 'Avalacir Justos Kaminski', 'São Cristóvão', '85063-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4218, 'Foz do Iguaçu', 'Avaré', 'Jardim Karla', '85868-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4219, 'Apucarana', 'Avaré', 'Jardim Eldorado', '86802-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4220, 'Londrina', 'Ave-do-paraíso', 'Paraíso', '86078-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4221, 'São José dos Pinhais', 'Ave-do-paraíso', 'Afonso Pena', '83045-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4222, 'Arapongas', 'Ave-do-paraíso', 'Vila Nova', '86707-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4223, 'Curitiba', 'Avelina da Luz da Silva', 'Sítio Cercado', '81910-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4224, 'Francisco Beltrão', 'Avelina Pereira Bedenarski', 'Seminário', '85605-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4225, 'Curitiba', 'Avelina Sanson Cooper', 'Barreirinha', '82210-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4226, 'Curitiba', 'Avelino A. Vieira', 'Cidade Industrial', '81250-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4227, 'Curitiba', 'Avelino Almeida Cardoso', 'Santa Cândida', '82720-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4228, 'Ponta Grossa', 'Avelino Antônio Vieira', 'Boa Vista', '84070-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4229, 'Campo Mourão', 'Avelino Antônio Vieira', 'Jardim Aeroporto', '87310-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4230, 'Toledo', 'Avelino Bretto', 'Panorama', '85911-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4231, 'Campo Mourão', 'Avelino Bueno', 'Jardim Santa Cruz', '87309-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4232, 'Toledo', 'Avelino Dalla Costa', 'Jardim Concórdia', '85906-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4233, 'Toledo', 'Avelino Hofstaetter', 'Coopagro', '85903-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4234, 'Curitiba', 'Avelino Lucchesi', 'Pilarzinho', '82100-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4235, 'Curitiba', 'Avelino Mantovani', 'Uberaba', '81590-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4236, 'Colombo', 'Avelino Mottin', 'Cercadinho', '83415-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4237, 'Ponta Grossa', 'Avelino Pereira Campos', 'Chapada', '84062-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4238, 'Francisco Beltrão', 'Avelino Rossi', 'Seminário', '85605-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4239, 'Londrina', 'Avelino Vieira', 'Gleba Fazenda Palhano', '86062-035', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4240, 'Piraquara', 'Avelino Vieira', 'Chácara Águas Claras', '83308-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4241, 'Toledo', 'Avelino Vieira', 'Jardim Porto Alegre', '85906-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4242, 'Arapongas', 'Ave-lira', 'Vila Nova', '86707-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4243, 'Maringá', 'Avenca', 'Jardim Industrial', '87065-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4244, 'Araucária', 'Avenca', 'Campina da Barra', '83709-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4245, 'Umuarama', 'Aventureiros', 'Jardim San Martim', '87508-127', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4246, 'Ponta Grossa', 'Aventurina', 'Neves', '84021-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4247, 'Cascavel', 'Aventurina', 'Esmeralda', '85806-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4248, 'Curitiba', 'Averrões', 'Barreirinha', '82700-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4249, 'Francisco Beltrão', 'Avestruz', 'Padre Eurico', '85604-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4250, 'Londrina', 'Avestruz', 'Paraíso', '86078-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4251, 'Guarapuava', 'Avestruz', 'Boqueirão', '85020-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4252, 'Umuarama', 'Avestruz', 'Jardim Sol Nascente', '87505-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4253, 'Araucária', 'Avestruz', 'Capela Velha', '83706-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4254, 'Apucarana', 'Avestruz', 'Núcleo Habitacional Michel Soni', '86813-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4255, 'Arapongas', 'Avestruz', 'Centro', '86701-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4256, 'Apucarana', 'Aviação', 'Vila Nova', '86812-500', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4257, 'Apucarana', 'Aviação', 'Jardim Trabalhista', '86807-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4258, 'Apucarana', 'Aviador Adilson Sérgio Prijma', 'Loteamento Residencial Cazarin', '86802-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4259, 'Curitiba', 'Aviador Armin Buhrer', 'Uberaba', '81560-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4260, 'Curitiba', 'Aviador Armin Buhrer', 'Uberaba', '81550-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4261, 'Curitiba', 'Aviador Cícero Marques', 'Bacacheri', '82515-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4262, 'Ponta Grossa', 'Aviador Frare Batista', 'Olarias', '84035-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4263, 'Ponta Grossa', 'Aviador Gastão Soares', 'Jardim Carvalho', '84016-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4264, 'Castro', 'Aviador Iereni Malherbi Sinhori', 'Vila Santa Cruz', '84168-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4265, 'Curitiba', 'Aviador Luiz Bergmann', 'Bacacheri', '82515-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4266, 'Colombo', 'Aviador Max Fontoura', 'Centro Industrial Mauá', '83413-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4267, 'Ponta Grossa', 'Aviador Paula Xavier', 'Nova Rússia', '84010-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4268, 'Curitiba', 'Aviador Vicente Wolski', 'Bacacheri', '82510-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4269, 'Curitiba', 'Avicena', 'Santa Cândida', '82630-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4270, 'Maringá', 'Ávila', 'Loteamento Madrid', '87053-537', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4271, 'Londrina', 'Avinhado', 'Conjunto Habitacional Violim', '86084-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4272, 'Arapongas', 'Avinhado', 'Vila Nova', '86707-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4273, 'Guarapuava', 'Avio Bitencourt Ribas', 'Bonsucesso', '85035-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4274, 'Arapongas', 'Avoante', 'Vila Aparecida', '86707-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4275, 'Guarapuava', 'Aymoré', 'Vila Carli', '85040-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4276, 'Paranaguá', 'Ayro Carvalho Cruz', 'Vila Garcia', '83218-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4277, 'Ponta Grossa', 'Ayrton Berger', 'Contorno', '84060-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4278, 'São José dos Pinhais', 'Ayrton Cubas', 'Braga', '83020-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4279, 'Curitiba', 'Ayrton Greiffo', 'Campo Comprido', '81230-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4280, 'Curitiba', 'Ayrton Leal da Silva', 'Alto Boqueirão', '81850-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4281, 'Curitiba', 'Ayrton Luciano Franco', 'Santa Cândida', '82630-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4282, 'Curitiba', 'Ayrton Pizzatto Gusi', 'Xaxim', '81830-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4283, 'São José dos Pinhais', 'Ayrton Précoma', 'Zaniolo', '83025-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4284, 'Foz do Iguaçu', 'Ayrton Senna', 'Jardim Dona Leila', '85853-695', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4285, 'Foz do Iguaçu', 'Ayrton Senna', 'Jardim Dona Leila', '85856-450', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4286, 'Umuarama', 'Ayrton Senna', 'Parque Tarumã', '87508-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4287, 'Apucarana', 'Ayrton Senna', 'Jardim Recanto dos Palmares', '86803-570', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4288, 'Almirante Tamandaré', 'Ayrton Senna', 'Jardim Anita Garibaldi', '83504-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4289, 'Londrina', 'Ayrton Senna da Silva', 'Gleba Fazenda Palhano', '86050-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4290, 'Pinhais', 'Ayrton Senna da Silva', 'Vl Dona Guiomar', '83320-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4291, 'Pinhais', 'Ayrton Senna da Silva', 'Vila Maria Antonieta', '83331-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4292, 'Paranaguá', 'Ayrton Senna da Silva', 'Jardim Samambaia', '83215-670', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4293, 'Paranaguá', 'Ayrton Senna da Silva', 'Parque São João', '83212-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4294, 'Paranaguá', 'Ayrton Senna da Silva', 'Emboguaçu', '83209-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4295, 'Paranaguá', 'Ayrton Senna da Silva', 'Industrial', '83206-410', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4296, 'Pinhais', 'Ayrton Senna da Silva', 'Jardim Pinhais', '83323-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4297, 'Campo Largo', 'Ayrton Senna da Silva', 'Jardim Busmayer', '83606-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4298, 'Francisco Beltrão', 'Azaléia', 'Nossa Senhora Aparecida', '85601-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4299, 'Guarapuava', 'Azaléia', 'Jardim das Américas', '85030-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4300, 'Ponta Grossa', 'Azaléia', 'Contorno', '84061-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4301, 'Apucarana', 'Azaléia', 'Jardim das Flores II', '86810-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4302, 'Araucária', 'Azaléia', 'Campina da Barra', '83709-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4303, 'Piraquara', 'Azaleia Schulmann', 'Jardim Veneza', '83310-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4304, 'Pinhais', 'Azaléias', 'Planta Walde Rosi Galvão', '83328-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4305, 'Sarandi', 'Azaléias', 'Jardim Monterey', '87112-789', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4306, 'Colombo', 'Azemiro Ferreira da Silva', 'Jardim das Flores', '83402-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4307, 'Apucarana', 'Azen Said Mohd', 'Jardim Catuaí', '86802-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4308, 'Ponta Grossa', 'Azevedo Marques', 'Uvaranas', '84030-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4309, 'Guarapuava', 'Azevedo Portugal', 'Bonsucesso', '85035-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4310, 'Guarapuava', 'Azevedo Portugal', 'Centro', '85010-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4311, 'Curitiba', 'Azis Surugi', 'Boqueirão', '81750-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4312, 'Cascavel', 'Azul', 'Brasília', '85815-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4313, 'Francisco Beltrão', 'Azulão', 'Padre Ulrico', '85604-476', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4314, 'Foz do Iguaçu', 'Azulão', 'Portal da Foz', '85859-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4315, 'Maringá', 'Azulão', 'Jardim Olímpico', '87070-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4316, 'Pinhais', 'Azulão', 'Jardim Cláudia', '83326-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4317, 'Londrina', 'Azulão', 'Conjunto Habitacional Violim', '86084-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4318, 'Arapongas', 'Azulão', 'Jardim Lorena', '86707-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4319, 'Campo Mourão', 'Azulão', 'Jardim Nossa Senhora Aparecida', '87309-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4320, 'Araucária', 'Azulão', 'Estação', '83705-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4321, 'Apucarana', 'Azulão', 'Recanto das Araras', '86812-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4322, 'Cambé', 'Azulão', 'Conjunto Habitacional Waldomiro M Gomes', '86182-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4323, 'Arapongas', 'Azulão-da-mata', 'Jardim São Carlos', '86704-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4324, 'Arapongas', 'Azulão-da-serra', 'Conjunto Del Condor', '86703-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4325, 'Arapongas', 'Azulinho', 'Vila Aymoré', '86708-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4326, 'Arapongas', 'Azulinho', 'Vila Vicentini', '86707-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4327, 'Arapongas', 'Azulona', 'Casa Família Arapongas I', '86706-707', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4328, 'Ponta Grossa', 'Azurita', 'Neves', '84021-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4329, 'Foz do Iguaçu', 'B', 'Conjunto Residencial Yang Ming', '85854-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4330, 'Foz do Iguaçu', 'B', 'Conjunto C', '85870-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4331, 'Ponta Grossa', 'B', 'Jardim Carvalho', '84016-710', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4332, 'Ponta Grossa', 'B', 'Contorno', '84060-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4333, 'Piraquara', 'B', 'Chácara Águas Claras', '83309-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4334, 'Paranavaí', 'B', 'Vila Alta', '87708-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4335, 'Maringá', 'B', 'Vila Vardelina', '87080-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4336, 'Ponta Grossa', 'B', 'Cará-cará', '84043-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4337, 'Paranavaí', 'B', 'Jardim São Cristóvão', '87702-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4338, 'Maringá', 'B', 'Jardim Guararapes', '87045-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4339, 'Ponta Grossa', 'B', 'Chapada', '84063-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4340, 'Ponta Grossa', 'B', 'Olarias', '84035-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4341, 'Paranavaí', 'B', 'Vila Operária', '87708-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4342, 'Paranaguá', 'B', 'Vila Guarani', '83221-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4343, 'Maringá', 'B', 'Jardim San Remo', '87060-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4344, 'Ponta Grossa', 'B', 'Uvaranas', '84032-476', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4345, 'Ponta Grossa', 'B', 'Uvaranas', '84031-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4346, 'Umuarama', 'B', 'Parque Industrial II', '87507-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4347, 'Umuarama', 'B', 'Núcleo Cruzeiro', '87509-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4348, 'Umuarama', 'B', 'Parque Dom Pedro I', '87508-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4349, 'Umuarama', 'B', 'Jardim Carolina', '87501-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4350, 'Campo Largo', 'B', 'Jardim Santa Nely', '83608-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4351, 'Campo Largo', 'B', 'Popular Nova', '83602-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4352, 'Almirante Tamandaré', 'B', 'Loteamento Recanto dos Papagaios', '83512-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4353, 'Almirante Tamandaré', 'B', 'Jardim Marrocos', '83511-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4354, 'Campo Largo', 'B', 'Vila Alzira', '83608-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4355, 'Campo Largo', 'B', 'Vila Santo Onofre', '83608-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4356, 'Campo Largo', 'B', 'Jardim Emília', '83607-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4357, 'Campo Largo', 'B', 'Jardim Tropical', '83602-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4358, 'Campo Largo', 'B', 'Vila Mariano Torres', '83608-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4359, 'Campo Largo', 'B', 'Jardim Três Rios', '83603-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4360, 'Campo Mourão', 'B', 'Distrito Industrial I', '87306-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4361, 'Almirante Tamandaré', 'B', 'Jardim São Caetano', '83507-151', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4362, 'Castro', 'B', 'Vila do Rosário', '84168-068', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4363, 'Castro', 'B', 'Vila do Rosário', '84168-067', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4364, 'Castro', 'B', 'Jardim Bela Vista', '84165-416', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4365, 'Campo Largo', 'B', 'Vila Antônio Seguro', '83602-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4366, 'Foz do Iguaçu', 'Babaçu', 'Jardim Tropical', '85855-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4367, 'Ponta Grossa', 'Babaçu', 'Neves', '84020-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4368, 'Ponta Grossa', 'Babilônia', 'Jardim Carvalho', '84016-688', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4369, 'Curitiba', 'Bacaba', 'Uberaba', '81550-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4370, 'Foz do Iguaçu', 'Bacalhau', 'Profilurb I', '85855-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4371, 'Cambé', 'Bacaris', 'Jardim Tupi', '86183-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4372, 'Curitiba', 'Bacupari', 'Uberaba', '81550-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4373, 'Arapongas', 'Bacurau', 'Jardim Cultura', '86707-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4374, 'Arapongas', 'Bacurau-claro', 'Jardim Portal das Flores', '86701-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4375, 'Arapongas', 'Bacurau-de-cauda-branca', 'Conjunto Flamingos III', '86703-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4376, 'Arapongas', 'Bacurau-migrador', 'Conjunto Águias', '86704-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4377, 'Arapongas', 'Bacurau-negro', 'Jardim Petrópolis', '86709-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4378, 'Arapongas', 'Bacurauzinho', 'Jardim Aeroporto', '86702-217', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4379, 'Curitiba', 'Baden Powell', 'Rebouças', '80060-080', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4380, 'Araucária', 'Badia Nacif Merhy', 'Fazenda Velha', '83703-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4381, 'Londrina', 'Badri Dagher', 'Jardim Acapulco', '86045-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4382, 'Ponta Grossa', 'Bady Miguel Esperidião', 'Boa Vista', '84072-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4383, 'Foz do Iguaçu', 'Baeté', 'Loteamento Campos do Iguaçu', '85857-310', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4384, 'Arapongas', 'Bagageiro', 'Conjunto Padre Bernardo Merckel', '86708-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4385, 'Londrina', 'Bagatelli', 'Parque Industrial José Belinati', '86039-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4386, 'Foz do Iguaçu', 'Bagé', 'Jardim Paraná', '85867-200', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4387, 'Guarapuava', 'Bagé', 'Boqueirão', '85020-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4388, 'Cascavel', 'Bagé', 'Canadá', '85813-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4389, 'Curitiba', 'Bagé', 'Campo Comprido', '81270-570', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4390, 'Foz do Iguaçu', 'Bagre', 'Profilurb I', '85855-290', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4391, 'Telêmaco Borba', 'Bahamas', 'Vila Esperança', '84272-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4392, 'Apucarana', 'Bahamas', 'Núcleo Habitacional Vale Verde', '86805-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4393, 'Laranjeiras do Sul', 'Bahia', 'Água Verde', '85302-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4394, 'Guarapuava', 'Bahia', 'Dos Estados', '85035-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4395, 'Foz do Iguaçu', 'Bahia', 'Vila Matilde', '85852-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4396, 'Londrina', 'Bahia', 'Centro', '86026-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4397, 'Francisco Beltrão', 'Bahia', 'Vila Maria Delani', '85605-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4398, 'Londrina', 'Bahia', 'Jardim Palmares', '86025-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4399, 'Ponta Grossa', 'Bahia', 'Nova Rússia', '84070-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4400, 'Piraquara', 'Bahia', 'Jardim dos Estados 3', '83307-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4401, 'Paranaguá', 'Bahia', 'Vila do Povo', '83209-638', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4402, 'Paranavaí', 'Bahia', 'Centro', '87704-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4403, 'São José dos Pinhais', 'Bahia', 'Silveira da Motta', '83030-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4404, 'Maringá', 'Bahia', 'Vila Emília', '87010-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4405, 'Toledo', 'Bahia', 'Jardim Porto Alegre', '85906-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4406, 'Telêmaco Borba', 'Bahia', 'Nossa Senhora de Fátima', '84264-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4407, 'Umuarama', 'Bahia', 'Zona II', '87501-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4408, 'Almirante Tamandaré', 'Bahia', 'Vila Dolores', '83514-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4409, 'Cascavel', 'Bahia', 'São Cristóvão', '85813-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4410, 'Colombo', 'Bahia', 'Vila Guaraci', '83404-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4411, 'Almirante Tamandaré', 'Bahia', 'Jardim Formosa', '83511-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4412, 'Apucarana', 'Bahia', 'Vila Pirilli', '86808-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4413, 'Campo Largo', 'Bahia', 'Jardim Esmeralda', '83604-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4414, 'Araucária', 'Bahia', 'Iguaçu', '83701-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4415, 'Curitiba', 'Bahia', 'Guaíra', '80630-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4416, 'Londrina', 'Bahia de Hudson', 'Quebec', '86060-225', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4417, 'Maringá', 'Baía Blanca', 'Conjunto Habitacional Del Prata', '87055-187', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4418, 'Curitiba', 'Bairro Alto', 'Bairro Alto', '82820-295', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4419, 'Foz do Iguaçu', 'Baitaca', 'Conjunto A', '85866-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4420, 'Ponta Grossa', 'Baitaca', 'Colônia Dona Luiza', '84046-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4421, 'Foz do Iguaçu', 'Balbina de Souza', 'Parque Morumbi I', '85858-646', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4422, 'Francisco Beltrão', 'Baldoino Helmann', 'Pinheirinho', '85606-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4423, 'Paranaguá', 'Balduina de Andrade Lobo ''Baduca''', 'Correia Velho', '83206-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4424, 'Paranaguá', 'Balduina de Andrade Lobo ''Baduca''', 'Emboguaçu', '83209-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4425, 'Apucarana', 'Balduíno Cordeiro Neira', 'Jardim Kiri', '86802-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4426, 'Toledo', 'Balduíno Felicetti', 'Jardim Canaã', '85914-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4427, 'Cascavel', 'Balduíno João Bellé', 'Nova Cidade', '85803-127', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4428, 'Ponta Grossa', 'Balduíno Taques', 'Orfãs', '84015-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4429, 'Ponta Grossa', 'Balduíno Taques', 'Centro', '84010-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4430, 'Ponta Grossa', 'Balduíno Taques', 'Estrela', '84040-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4431, 'Campo Largo', 'Balduíno Vidal', 'Jardim Busmayer', '83606-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4432, 'Foz do Iguaçu', 'Balduíno Wandscheer', 'Jardim Panorama', '85856-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4433, 'Foz do Iguaçu', 'Balduíno Weirich', 'Boa Esperança', '85854-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4434, 'Curitiba', 'Baldur Magnus Grubba', 'Cidade Industrial', '81310-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4435, 'Curitiba', 'Baldur Magnus Grubba', 'Novo Mundo', '81050-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4436, 'Foz do Iguaçu', 'Baleia', 'Conjunto A', '85860-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4437, 'Cascavel', 'Baleia Azul', 'Cataratas', '85818-747', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4438, 'Campo Mourão', 'Balmenha Wurzius Trombini', 'Parque Industrial I', '87306-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4439, 'Telêmaco Borba', 'Balsa Nova', 'Vila Arcina', '84268-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4440, 'Almirante Tamandaré', 'Balsa Nova', 'Jardim Roma', '83504-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4441, 'Campo Largo', 'Balsa Nova', 'Jardim Itaqui', '83604-140', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4442, 'Colombo', 'Balsa Nova', 'Jardim Guaraituba', '83410-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4443, 'Curitiba', 'Balsa Nova', 'Sítio Cercado', '81900-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4444, 'Londrina', 'Bálsamo', 'Leonor', '86071-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4445, 'Foz do Iguaçu', 'Balsas', 'Loteameto Dona Amanda', '85853-738', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4446, 'Piraquara', 'Balsas', 'Jardim Tropical', '83314-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4447, 'Almirante Tamandaré', 'Baltazar Bunik', 'Jardim Primavera', '83506-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4448, 'São José dos Pinhais', 'Baltazar Carrasco dos Reis', 'Ipê', '83055-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4449, 'Curitiba', 'Baltazar Carrasco dos Reis', 'Rebouças', '80215-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4450, 'Curitiba', 'Baltazar Carrasco dos Reis', 'Rebouças', '80230-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4451, 'Curitiba', 'Baltazar Carrasco dos Reis', 'Rebouças', '80250-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4452, 'Ponta Grossa', 'Baltazar Lisboa', 'Ronda', '84051-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4453, 'Almirante Tamandaré', 'Balzac', 'Jardim Campos Elísios', '83508-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4454, 'Cascavel', 'Balzak', 'Interlagos', '85814-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4455, 'Ponta Grossa', 'Bambu', 'Uvaranas', '84033-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4456, 'Telêmaco Borba', 'Bambu', 'Área 01', '84268-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4457, 'Foz do Iguaçu', 'Bambui', 'Loteamento Campos do Iguaçu', '85857-510', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4458, 'Curitiba', 'Bananas', 'Uberaba', '81550-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4459, 'Londrina', 'Bandeirantes', 'Vila Ipiranga', '86010-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4460, 'Guarapuava', 'Bandeirantes', 'Primavera', '85050-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4461, 'Foz do Iguaçu', 'Bandeirantes', 'Loteamento Witt', '85862-537', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4462, 'Paranavaí', 'Bandeirantes', 'Jardim São Jorge', '87710-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4463, 'Paranaguá', 'Bandeirantes', 'Jardim Paranaguá', '83218-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4464, 'São José dos Pinhais', 'Bandeirantes', 'São Cristóvão', '83040-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4465, 'Maringá', 'Bandeirantes', 'Zona 07', '87030-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4466, 'Pinhais', 'Bandeirantes', 'Loteamento Alphaville Graciosa', '83327-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4467, 'Ponta Grossa', 'Bandeirantes', 'Nova Rússia', '84070-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4468, 'Umuarama', 'Bandeirantes', 'Zona III', '87504-535', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4469, 'Telêmaco Borba', 'Bandeirantes', 'Vila São Francisco de Assis', '84264-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4470, 'Apucarana', 'Bandeirantes', 'Centro', '86800-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4471, 'Colombo', 'Bandeirantes', 'Jardim Guaraituba', '83410-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4472, 'Curitiba', 'Bandeirantes', 'Pinheirinho', '81880-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4473, 'Curitiba', 'Bandeirantes', 'Sítio Cercado', '81900-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4474, 'Curitiba', 'Bandeirantes Dias Cortes', 'Jardim Social', '82530-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4475, 'Telêmaco Borba', 'Bandeiras', 'Núcleo Bandeirantes', '84269-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4476, 'Foz do Iguaçu', 'Bangu', 'Parque Morumbi II', '85859-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4477, 'Foz do Iguaçu', 'Bangu', 'Parque Morumbi II', '85858-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4478, 'Maringá', 'Baobá', 'Parque Palmeiras', '87023-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4479, 'Sarandi', 'Baptista Bossato', 'Conjunto Floresta', '87112-780', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4480, 'São José dos Pinhais', 'Baptistin Pauletto', 'Miringuava', '83090-240', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4481, 'Ponta Grossa', 'Barão Brasílio Machado', 'Oficinas', '84036-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4482, 'Foz do Iguaçu', 'Barão da Serra Negra', 'Parque Morumbi I', '85858-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4483, 'Foz do Iguaçu', 'Barão da Serra Negra', 'Parque Morumbi II', '85859-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4484, 'Curitiba', 'Barão de Antonina', 'São Francisco', '80530-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4485, 'Ponta Grossa', 'Barão de Bojuru', 'Ronda', '84051-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4486, 'Ponta Grossa', 'Barão de Camaguã', 'Uvaranas', '84025-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4487, 'Guarapuava', 'Barão de Capanema', 'Santa Cruz', '85015-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4488, 'Ponta Grossa', 'Barão de Capanema', 'Nova Rússia', '84070-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4489, 'Ponta Grossa', 'Barão de Cerro Largo', 'Uvaranas', '84030-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4490, 'Paranavaí', 'Barão de Guarapuava', 'Jardim São Jorge', '87710-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4491, 'Ponta Grossa', 'Barão de Guaraúna', 'Centro', '84010-670', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4492, 'Curitiba', 'Barão de Guaraúna', 'Alto da Glória', '80030-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4493, 'Maringá', 'Barão de Iguatemi', 'Jardim Tupinambá', '87040-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4494, 'Ponta Grossa', 'Barão de Itamaracá', 'Uvaranas', '84025-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4495, 'Curitiba', 'Barão de Itamaracá', 'Fazendinha', '81330-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4496, 'Maringá', 'Barão de Jaceguai', 'Jardim Tupinambá', '87040-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4497, 'Ponta Grossa', 'Barão de Jacutinga', 'Uvaranas', '84032-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4498, 'Londrina', 'Barão de Jaraguá', 'Paulista', '86079-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4499, 'Londrina', 'Barão de Loreto', 'Nova Londres', '86015-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4500, 'Ponta Grossa', 'Barão de Macaé', 'Uvaranas', '84032-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4501, 'Ponta Grossa', 'Barão de Macaúbas', 'Uvaranas', '84032-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4502, 'Sarandi', 'Barão de Mauá', 'Santa Tereza', '87112-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4503, 'Londrina', 'Barão de Mesquita', 'Itamarati', '86061-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4504, 'Ponta Grossa', 'Barão de Monte Alegre', 'Nova Rússia', '84053-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4505, 'Curitiba', 'Barão de Monte Alegre', 'Jardim das Américas', '81540-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4506, 'Maringá', 'Barão de Paranapiacaba', 'Jardim Tupinambá', '87040-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4507, 'Maringá', 'Barão de Parnaíba', 'Jardim Tupinambá', '87040-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4508, 'Ponta Grossa', 'Barão de Penedo', 'Uvaranas', '84032-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4509, 'Ponta Grossa', 'Barão de Penedo', 'Boa Vista', '84073-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4510, 'Maringá', 'Barão de Piracicaba', 'Jardim Tupinambá', '87040-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4511, 'Maringá', 'Barão de Piratininga', 'Jardim Tupinambá', '87040-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4512, 'Ponta Grossa', 'Barão de Ramalho', 'Uvaranas', '84030-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4513, 'Curitiba', 'Barão de Santo Ângelo', 'Xaxim', '81820-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4514, 'Curitiba', 'Barão de Santo Ângelo', 'Xaxim', '81810-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4515, 'Maringá', 'Barão de Sergipe', 'Jardim Tupinambá', '87040-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4516, 'Curitiba', 'Barão de Studart', 'Vista Alegre', '80820-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4517, 'Ponta Grossa', 'Barão de Teffe', 'Centro', '84010-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4518, 'Ponta Grossa', 'Barão do Amazonas', 'Ronda', '84051-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4519, 'Paranaguá', 'Barão do Amazonas', 'Alboitt', '83221-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4520, 'Londrina', 'Barão do Cerro Azul', 'Recreio', '86025-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4521, 'Maringá', 'Barão do Cerro Azul', 'Jardim Tupinambá', '87040-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4522, 'Ponta Grossa', 'Barão do Cerro Azul', 'Centro', '84010-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4523, 'São José dos Pinhais', 'Barão do Cerro Azul', 'Bom Jesus', '83025-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4524, 'São José dos Pinhais', 'Barão do Cerro Azul', 'Carioca', '83005-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4525, 'Paranavaí', 'Barão do Cerro Azul', 'Jardim Santos Dumont', '87706-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4526, 'Piraquara', 'Barão do Cerro Azul', 'Centro', '83301-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4527, 'Cascavel', 'Barão do Cerro Azul', 'Ciro Nardi', '85802-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4528, 'Cambé', 'Barão do Cerro Azul', 'Jardim Silvino', '86188-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4529, 'Cascavel', 'Barão do Cerro Azul', 'Centro', '85801-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4530, 'Guarapuava', 'Barão do Rio Branco', 'Boqueirão', '85020-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4531, 'Laranjeiras do Sul', 'Barão do Rio Branco', 'Água Verde', '85302-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4532, 'Laranjeiras do Sul', 'Barão do Rio Branco', 'Centro', '85301-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4533, 'Laranjeiras do Sul', 'Barão do Rio Branco', 'São Francisco', '85303-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4534, 'Guarapuava', 'Barão do Rio Branco', 'Centro', '85010-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4535, 'Guarapuava', 'Barão do Rio Branco', 'Batel', '85015-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4536, 'Foz do Iguaçu', 'Barão do Rio Branco', 'Centro', '85851-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4537, 'Maringá', 'Barão do Rio Branco', 'Vila Ipiranga', '87045-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4538, 'Paranavaí', 'Barão do Rio Branco', 'Jardim São Jorge', '87711-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4539, 'Pato Branco', 'Barão do Rio Branco', 'Baixada', '85506-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4540, 'Pato Branco', 'Barão do Rio Branco', 'Centro', '85501-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4541, 'Paranaguá', 'Barão do Rio Branco', 'Jardim Paranaguá', '83218-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4542, 'Piraquara', 'Barão do Rio Branco', 'Jardim Bela Vista', '83301-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4543, 'Ponta Grossa', 'Barão do Rio Branco', 'Centro', '84010-710', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4544, 'Paranaguá', 'Barão do Rio Branco', 'Costeira', '83203-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4545, 'Toledo', 'Barão do Rio Branco', 'Centro', '85901-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4546, 'Toledo', 'Barão do Rio Branco', 'Centro', '85905-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4547, 'Sarandi', 'Barão do Rio Branco', 'Santa Tereza', '87112-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4548, 'Toledo', 'Barão do Rio Branco', 'Centro', '85900-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4549, 'Cambé', 'Barão do Rio Branco', 'Centro', '86181-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4550, 'Cascavel', 'Barão do Rio Branco', 'Brasmadeira', '85813-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4551, 'Almirante Tamandaré', 'Barão do Rio Branco', 'Jardim Iracema', '83508-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4552, 'Almirante Tamandaré', 'Barão do Rio Branco', 'Jardim Buenos Aires', '83507-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4553, 'Cascavel', 'Barão do Rio Branco', 'São Cristóvão', '85812-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4554, 'Cascavel', 'Barão do Rio Branco', 'São Cristóvão', '85813-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4555, 'Campo Largo', 'Barão do Rio Branco', 'Centro', '83601-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4556, 'Curitiba', 'Barão do Rio Branco', 'Centro', '80010-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4557, 'Maringá', 'Barão do Rio Pardo', 'Jardim Tupinambá', '87040-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4558, 'Maringá', 'Barão do Rio Prata', 'Jardim Tupinambá', '87040-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4559, 'Curitiba', 'Barão do Serro Azul', 'Centro', '80020-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4560, 'Maringá', 'Barão do Tibagi', 'Jardim Tupinambá', '87040-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4561, 'Maringá', 'Barão do Tietê', 'Jardim Tupinambá', '87040-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4562, 'Curitiba', 'Barão dos Campos Gerais', 'Juvevê', '80030-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4563, 'Ponta Grossa', 'Barão Vila de Barra', 'Uvaranas', '84025-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4564, 'Ponta Grossa', 'Barão Von Holleben', 'Contorno', '84060-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4565, 'Umuarama', 'Bararuba', 'Jardim Tropical', '87503-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4566, 'Ponta Grossa', 'Barata de Almeida', 'Uvaranas', '84025-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4567, 'Telêmaco Borba', 'Baraúna', 'Área 06', '84271-440', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4568, 'Cascavel', 'Barawanas', 'Santa Cruz', '85806-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4569, 'Telêmaco Borba', 'Barbacena', 'Área 06', '84271-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4570, 'Curitiba', 'Barbacena', 'Campo Comprido', '81220-330', 'Conjunto', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4571, 'Foz do Iguaçu', 'Barbado', 'Conjunto A', '85860-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4572, 'Ponta Grossa', 'Barbalho Bezerra', 'Uvaranas', '84025-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4573, 'Curitiba', 'Bárbara Cvintal', 'Mossunguê', '81210-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4574, 'Colombo', 'Bárbara Socher', 'Jardim Santa Fé', '83403-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4575, 'Ponta Grossa', 'Bárbara Stein', 'Olarias', '84026-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4576, 'Foz do Iguaçu', 'Barbosa Ferraz', 'Jardim Belvedere II', '85867-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4577, 'Curitiba', 'Barbosa Ferraz', 'Alto Boqueirão', '81830-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4578, 'Ponta Grossa', 'Barbosa Lima', 'Uvaranas', '84020-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4579, 'Ponta Grossa', 'Barbosa Ribeiro', 'Uvaranas', '84031-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4580, 'Ponta Grossa', 'Barbosa Rodrigues', 'Uvaranas', '84031-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4581, 'Arapongas', 'Barbudo-de-coroa', 'Conjunto Padre Bernardo Merckel', '86706-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4582, 'Guarapuava', 'Barcelona', 'Santana', '85070-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4583, 'Londrina', 'Barcelona', 'Parque Residencial João Piza', '86041-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4584, 'Foz do Iguaçu', 'Barcelona', 'Jardim Alice II', '85858-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4585, 'Maringá', 'Barcelona', 'Jardim Atlânta', '87045-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4586, 'Umuarama', 'Barcelona', 'Jardim Los Angeles', '87509-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4587, 'Sarandi', 'Barcelona', 'Jardim Panorama', '87113-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4588, 'Maringá', 'Barcelona II', 'Loteamento Madrid', '87053-516', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4589, 'Foz do Iguaçu', 'Barigui', 'Vila Militar', '85857-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4590, 'Paranaguá', 'Barigui', 'Santos Dumont', '83209-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4591, 'Almirante Tamandaré', 'Barigui', 'Vila Alto Pinheiros', '83503-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4592, 'Araucária', 'Barigui', 'Iguaçu', '83701-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4593, 'Curitiba', 'Barigui', 'Santo Inácio', '82010-700', 'Parque', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4594, 'Curitiba', 'Barigui II', 'Cidade Industrial', '81350-180', 'Conjunto', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4595, 'Maringá', 'Bariloche', 'Conjunto Habitacional Del Prata', '87055-186', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4596, 'Foz do Iguaçu', 'Bariri', 'Loteameto Jardim Colombelli', '85862-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4597, 'Colombo', 'Bariri', 'Jardim Santa Helena', '83407-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4598, 'São José dos Pinhais', 'Barnabel dos Santos', 'Ipê', '83055-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4599, 'Paranaguá', 'Baronesa do Cerro Azul', 'Costeira', '83203-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4600, 'Paranaguá', 'Baronesa do Cerro Azul', 'Campo Grande', '83206-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4601, 'Guarapuava', 'Barra Bonita', 'Industrial', '85045-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4602, 'Cascavel', 'Barra Bonita', 'Brasmadeira', '85814-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4603, 'Almirante Tamandaré', 'Barra dos Coqueiros', 'Jardim São Vicente', '83505-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4604, 'Foz do Iguaçu', 'Barra Grande', 'Jardim Alvorada', '85859-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4605, 'Foz do Iguaçu', 'Barra Mansa', 'Jardim Ipê', '85869-686', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4606, 'Francisco Beltrão', 'Barra Mansa', 'Pinheirinho', '85603-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4607, 'Guarapuava', 'Barra Mansa', 'Boqueirão', '85020-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4608, 'Foz do Iguaçu', 'Barra Velha', 'Jardim Lancaster V', '85869-716', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4609, 'Guarapuava', 'Barra Velha', 'Jardim das Américas', '85030-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4610, 'Foz do Iguaçu', 'Barra Verde', 'Jardim Ipanema', '85862-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4611, 'Foz do Iguaçu', 'Barracao', 'Parque Imperatriz', '85863-620', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4612, 'Francisco Beltrão', 'Barracão', 'Pinheirinho', '85601-176', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4613, 'Ponta Grossa', 'Barracão', 'Oficinas', '84036-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4614, 'Curitiba', 'Barreirinha', 'Barreirinha', '82210-420', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4615, 'Ponta Grossa', 'Barreto de Menezes', 'Boa Vista', '84073-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4616, 'Londrina', 'Barretos', 'Veraliz', '86062-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4617, 'Foz do Iguaçu', 'Barretos', 'Jardim Lancaster II', '85869-330', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4618, 'Telêmaco Borba', 'Barro Preto', 'Área 02', '84267-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4619, 'Foz do Iguaçu', 'Barro Velho', 'Jardim Lancaster V', '85869-717', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4620, 'Guarapuava', 'Barroco', 'Morro Alto', '85065-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4621, 'Maringá', 'Barroso', 'Zona 08', '87050-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4622, 'Maringá', 'Barroso', 'Zona 03', '87050-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4623, 'Colombo', 'Barroso', 'Vila Petrópolis', '83409-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4624, 'Londrina', 'Bartira', 'Novo Antares', '86036-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4625, 'Umuarama', 'Bartira', 'Jardim São Marcos', '87501-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4626, 'Curitiba', 'Bartolomeu André Rudek', 'Bairro Alto', '82840-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4627, 'Londrina', 'Bartolomeu Bueno', 'Vila Ipiranga', '86010-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4628, 'Pato Branco', 'Bartolomeu Bueno', 'Pinheirinho', '85506-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4629, 'Ponta Grossa', 'Bartolomeu Bueno', 'Uvaranas', '84025-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4630, 'Umuarama', 'Bartolomeu Bueno', 'Zona III', '87502-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4631, 'Guarapuava', 'Bartolomeu Bueno da Silva', 'Primavera', '85050-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4632, 'Telêmaco Borba', 'Bartolomeu Bueno da Silva', 'Núcleo Bandeirantes', '84269-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4633, 'Cambé', 'Bartolomeu Bueno da Silva', 'Jardim Riviera', '86187-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4634, 'Cambé', 'Bartolomeu da Costa Soeiro', 'Parque Residencial Ana Rosa', '86183-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4635, 'Foz do Iguaçu', 'Bartolomeu de Gusmão', 'Jardim Panorama', '85856-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4636, 'Foz do Iguaçu', 'Bartolomeu de Gusmão', 'Centro', '85852-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4637, 'Foz do Iguaçu', 'Bartolomeu de Gusmão', 'Centro', '85851-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4638, 'Ponta Grossa', 'Bartolomeu de Gusmão', 'Uvaranas', '84020-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4639, 'Cascavel', 'Bartolomeu de Gusmão', 'Pacaembu', '85816-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4640, 'Curitiba', 'Bartolomeu Lourenço de Gusmão', 'Boqueirão', '81650-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4641, 'Curitiba', 'Bartolomeu Lourenço de Gusmão', 'Boqueirão', '81730-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4642, 'Curitiba', 'Bartolomeu Lourenço de Gusmão', 'Hauer', '81610-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4643, 'Paranavaí', 'Bartolomeu Peres', 'Jardim Ipê', '87707-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4644, 'Ponta Grossa', 'Baru', 'Contorno', '84061-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4645, 'São José dos Pinhais', 'Baruch Spinoza', 'Aristocrata', '83030-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4646, 'Guarapuava', 'Barueri', 'Jardim das Américas', '85030-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4647, 'Foz do Iguaçu', 'Barueri', 'Jardim Ipê', '85869-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4648, 'Londrina', 'Basiléia', 'Bela Suiça', '86050-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4649, 'Colombo', 'Basílio Antunes dos Santos', 'Parque Residencial Santa Terezinha II', '83408-796', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4650, 'Castro', 'Basílio Chirum', 'Centro', '84165-625', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4651, 'Ponta Grossa', 'Basílio da Gama', 'Chapada', '84063-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4652, 'Curitiba', 'Basílio Fuck', 'Xaxim', '81830-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4653, 'Foz do Iguaçu', 'Basílio Jacik', 'Parque Residencial Itália', '85858-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4654, 'Maringá', 'Basílio Jequim', 'Jardim Veredas', '87060-106', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4655, 'Curitiba', 'Basílio Kowalczuk', 'São Braz', '82300-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4656, 'Londrina', 'Basílio Murgi', 'Jamile Dequech', '86048-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4657, 'Ponta Grossa', 'Basílio Parabocz', 'Oficinas', '84035-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4658, 'Campo Mourão', 'Basílio Pellizzer', 'Jardim Modelo', '87309-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4659, 'Colombo', 'Basílio Pereira', 'Planta Gregório Nadolni', '83404-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4660, 'Castro', 'Basílio Polistchuk Sobrinho', 'Cantagalo', '84178-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4661, 'Guarapuava', 'Basílio Ribas', 'Industrial', '85053-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4662, 'Castro', 'Basílio Tavares', 'Vila Rio Branco', '84172-335', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4663, 'Francisco Beltrão', 'Basílio Tiecher', 'Alvorada', '85601-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4664, 'Londrina', 'Basílio Zani', 'Conjunto Habitacional José Giordano', '86082-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4665, 'Curitiba', 'Bassamo de Grappa', 'Santa Felicidade', '82030-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4666, 'Londrina', 'Bassiano Spoladore', 'Jardim das Palmeiras', '86083-480', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4667, 'Foz do Iguaçu', 'Bastos', 'Loteameto Jardim Colombelli', '85862-485', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4668, 'Ponta Grossa', 'Batalhão de Suez', 'Uvaranas', '84025-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4669, 'Curitiba', 'Batalhão de Suez', 'Centro', '80410-130', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4670, 'Arapongas', 'Batará', 'Vila Bernardes', '86705-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4671, 'Foz do Iguaçu', 'Batatais', 'Parque Morumbi', '85858-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4672, 'Telêmaco Borba', 'Bateias', 'Vila São Francisco de Assis', '84264-650', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4673, 'Curitiba', 'Batista da Costa', 'Xaxim', '81820-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4674, 'Curitiba', 'Batista da Costa', 'Xaxim', '81810-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4675, 'Curitiba', 'Batista Ganz', 'Santo Inácio', '82010-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4676, 'Toledo', 'Batista Luzardo', 'Panorama', '85911-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4677, 'Curitiba', 'Batista Pessine', 'Vista Alegre', '80820-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4678, 'Pinhais', 'Batista Ramos', 'Planta Cláudio Mehl', '83326-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4679, 'Campo Largo', 'Batista Sabim', 'Itaqui de Cima', '83605-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4680, 'Foz do Iguaçu', 'Batuiba', 'Conjunto A', '85866-170', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4681, 'Ponta Grossa', 'Batuíra', 'Colônia Dona Luiza', '84043-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4682, 'Arapongas', 'Batuíra-do-campo', 'Vila Iguaçu', '86708-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4683, 'Arapongas', 'Batuíra-grande', 'Jardim São Bento', '86706-717', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4684, 'Arapongas', 'Batuíra-solitária', 'Parque Industrial II', '86703-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4685, 'Arapongas', 'Batuqueiro', 'Jardim Morumbi', '86708-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4686, 'Arapongas', 'Batuquira', 'Vila Bernardes', '86705-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4687, 'Foz do Iguaçu', 'Baturité', 'Vila Guarani', '85862-346', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4688, 'Francisco Beltrão', 'Bauru', 'Pinheirinho', '85603-620', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4689, 'Guarapuava', 'Bauru', 'Boqueirão', '85022-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4690, 'Londrina', 'Bauru', 'Amaro', '86062-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4691, 'Foz do Iguaçu', 'Bauru', 'Jardim Petropólis', '85868-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4692, 'Maringá', 'Bauru', 'Jardim Internorte', '87045-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4693, 'Cascavel', 'Bavinia', 'Recanto Tropical', '85807-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4694, 'Toledo', 'Beata Angelina', 'Jardim Porto Alegre', '85906-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4695, 'Curitiba', 'Beato Gaspar Stanggassinger', 'Cidade Industrial', '81460-186', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4696, 'Curitiba', 'Beato Pedro Donders', 'Cidade Industrial', '81460-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4697, 'Londrina', 'Beatriz Prado Ribas', 'Jardim Pioneiros', '86036-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4698, 'Londrina', 'Beatriz Vasconcellos de Assumpção', 'Ilha Bela', '86036-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4699, 'Foz do Iguaçu', 'Bebedouro', 'Loteameto Jardim Colombelli', '85862-467', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4700, 'Foz do Iguaçu', 'Beberibe', 'Loteamento Campos do Iguaçu', '85857-350', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4701, 'Maringá', 'Becervilho dos Santos', 'Conjunto Residencial Cidade Alta', '87053-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4702, 'Ponta Grossa', 'Beckmann', 'Contorno', '84052-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4703, 'Guarapuava', 'Beco', 'Dos Estados', '85035-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4704, 'Campo Largo', 'Beco do Ari', 'Vila Santa Terezinha', '83602-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4705, 'Arapongas', 'Becua', 'Conjunto Ulisses Guimarães', '86706-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4706, 'Curitiba', 'Beethoven', 'Vista Alegre', '80820-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4707, 'Araucária', 'Begônia', 'Campina da Barra', '83709-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4708, 'Campo Mourão', 'Begônia', 'Jardim Lar Paraná', '87305-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4709, 'Londrina', 'Beija-flor', 'Paraíso', '86078-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4710, 'Foz do Iguaçu', 'Beija-flor', 'Portal da Foz', '85859-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4711, 'Guarapuava', 'Beija-Flor', 'São Cristóvão', '85063-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4712, 'Laranjeiras do Sul', 'Beija-flor', 'Vila Industrial', '85303-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4713, 'Francisco Beltrão', 'Beija-flor', 'Padre Eurico', '85604-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4714, 'Maringá', 'Beija-flor', 'Conjunto Habitacional João de Barro Thaís', '87075-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4715, 'Pato Branco', 'Beija-flor', 'Planalto', '85509-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4716, 'São José dos Pinhais', 'Beija-flor', 'Afonso Pena', '83045-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4717, 'Ponta Grossa', 'Beija-flor', 'Chapada', '84064-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4718, 'Umuarama', 'Beija-flor', 'Jardim São Marcos', '87501-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4719, 'Telêmaco Borba', 'Beija-flor', 'Vila Cristina', '84272-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4720, 'Sarandi', 'Beija-flor', 'Conjunto Floresta', '87112-680', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4721, 'Toledo', 'Beija-flor', 'Jardim Santa Maria', '85903-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4722, 'Cambé', 'Beija-flor', 'Conjunto Habitacional Waldomiro M Gomes', '86182-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4723, 'Campo Mourão', 'Beija-flor', 'Conjunto Habitacional Milton Luiz Pereira', '87306-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4724, 'Apucarana', 'Beija-flor', 'Núcleo Habitacional Michel Soni', '86813-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4725, 'Campo Largo', 'Beija-flor', 'Jardim Lise', '83605-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4726, 'Cascavel', 'Beija-flor', 'Floresta', '85814-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4727, 'Araucária', 'Beija-flor', 'Capela Velha', '83706-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4728, 'Almirante Tamandaré', 'Beija-flor', 'Loteamento Montparnasse', '83508-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4729, 'Arapongas', 'Beija-flor', 'Centro', '86701-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4730, 'Arapongas', 'Beija-flor-branco', 'Jardim São Carlos', '86704-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4731, 'Arapongas', 'Beija-flor-de-coleira', 'Jardim Coroados', '86707-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4732, 'Arapongas', 'Beija-flor-de-penacho', 'Jardim Caravelle', '86702-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4733, 'Arapongas', 'Beija-flor-rubi', 'Casa Família Arapongas IV', '86709-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4734, 'Colombo', 'Beira Alta', 'Parque Residencial Santa Terezinha', '83408-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4735, 'Foz do Iguaçu', 'Beira Rio', 'Jardim Itaipu', '85867-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4736, 'Foz do Iguaçu', 'Beira Rio', 'Jardim América', '85864-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4737, 'Foz do Iguaçu', 'Beira Rio', 'Vila Portes', '85865-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4738, 'Umuarama', 'Beira Rio', 'Parque Industrial I', '87507-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4739, 'Araucária', 'Beira Rio', 'Iguaçu', '83701-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4740, 'Cascavel', 'Beira Rio', 'Coqueiral', '85807-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4741, 'Curitiba', 'Beit Chabad', 'Cidade Industrial', '81305-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4742, 'Cascavel', 'Bela', 'Universitário', '85819-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4743, 'Guarapuava', 'Bela Floresta', 'Industrial', '85045-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4744, 'Francisco Beltrão', 'Bela Vista', 'Cango', '85604-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4745, 'Foz do Iguaçu', 'Bela Vista', 'Jardim Duarte', '85861-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4746, 'Paranavaí', 'Bela Vista', 'Jardim Novo Horizonte', '87711-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4747, 'São José dos Pinhais', 'Bela Vista', 'São Sebastião', '83075-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4748, 'Umuarama', 'Bela Vista', 'Conjunto Residencial Córrego Longe', '87504-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4749, 'Sarandi', 'Bela Vista', 'Parque Residencial Nova Aliança', '87111-739', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4750, 'Sarandi', 'Bela Vista', 'Parque Residencial Bela Vista', '87112-265', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4751, 'Apucarana', 'Bela Vista', 'Vila Santa Terezinha', '86802-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4752, 'Campo Mourão', 'Bela Vista', 'Jardim Pio XII', '87306-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4753, 'Colombo', 'Bela Vista', 'Santa Gema', '83407-206', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4754, 'Campo Mourão', 'Bela Vista', 'Jardim Lar Paraná', '87305-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4755, 'Cascavel', 'Bela Vista', 'Cataratas', '85818-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4756, 'Curitiba', 'Bela Vista', 'Guabirotuba', '81520-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4757, 'Almirante Tamandaré', 'Bela Vista do Ipê', 'Vila Feliz', '83505-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4758, 'Ponta Grossa', 'Bela Vista do Paraíso', 'Chapada', '84062-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4759, 'Curitiba', 'Bela Vista do Paraíso', 'Campo Comprido', '81240-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4760, 'Foz do Iguaçu', 'Belarmino de Mendonça', 'Centro', '85851-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4761, 'Cascavel', 'Belas Artes', 'Universitário', '85819-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4762, 'Guarapuava', 'Belchior Dias Moreira', 'Primavera', '85050-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4763, 'Telêmaco Borba', 'Belchior Dias Moreira', 'Núcleo Bandeirantes', '84269-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4764, 'Guarapuava', 'Belém', 'Conradinho', '85055-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4765, 'Londrina', 'Belém', 'Centro', '86026-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4766, 'Foz do Iguaçu', 'Belém', 'Conjunto C', '85870-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4767, 'Londrina', 'Belém', 'Centro', '86026-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4768, 'São José dos Pinhais', 'Belém', 'Costeira', '83015-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4769, 'Maringá', 'Belém', 'Parque Residencial Cidade Nova', '87023-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4770, 'Pinhais', 'Belém', 'Conjunto Residencial Renato Bonilauri', '83325-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4771, 'Piraquara', 'Belém', 'Vila Vicente Macedo', '83303-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4772, 'Umuarama', 'Belém', 'Zona III', '87502-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4773, 'Telêmaco Borba', 'Belém', 'Nossa Senhora de Fátima', '84264-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4774, 'Colombo', 'Belém', 'Jardim Curitiba', '83406-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4775, 'Campo Mourão', 'Belém', 'Jardim Vitória', '87303-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4776, 'Cascavel', 'Belém', 'Cancelli', '85811-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4777, 'Cambé', 'Belém', 'Vila Salomé', '86192-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4778, 'Curitiba', 'Belém', 'Cabral', '80035-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4779, 'Foz do Iguaçu', 'Belford Duarte', 'Jardim São Miguel', '85858-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4780, 'Francisco Beltrão', 'Bélgica', 'Alvorada', '85601-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4781, 'Guarapuava', 'Bélgica', 'Morro Alto', '85067-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4782, 'Londrina', 'Bélgica', 'Igapó', '86046-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4783, 'Sarandi', 'Bélgica', 'Jardim Europa', '87111-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4784, 'Cambé', 'Bélgica', 'Centro', '86181-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4785, 'Colombo', 'Belgrado', 'Vila Santa Clara', '83405-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4786, 'Campo Mourão', 'Belin Carolo', 'Jardim Aeroporto', '87310-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4787, 'Londrina', 'Belize', 'Bela Suiça', '86050-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4788, 'Telêmaco Borba', 'Belize', 'Vila São Vicente de Paula', '84262-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4789, 'Apucarana', 'Belize', 'Núcleo Habitacional Vale Verde', '86805-257', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4790, 'Londrina', 'Belmira da Conceição', 'Avelino A Vieira', '86056-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4791, 'Curitiba', 'Belmira Vieira das Chagas', 'Cidade Industrial', '81350-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4792, 'Foz do Iguaçu', 'Belmiro', 'Parque Morumbi II', '85859-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4793, 'Guarapuava', 'Belmiro Bertoncelo', 'Primavera', '85053-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4794, 'Ponta Grossa', 'Belmiro Braga', 'Contorno', '84032-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4795, 'Ponta Grossa', 'Belmiro Braga', 'Boa Vista', '84073-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4796, 'Londrina', 'Belmiro Catori', 'Jardim Imagawa', '86080-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4797, 'Guarapuava', 'Belmiro de Miranda', 'Trianon', '85012-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4798, 'Londrina', 'Belmiro de Oliveira', 'Santiago', '86071-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4799, 'São José dos Pinhais', 'Belmiro Marquez', 'Guatupê', '83060-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4800, 'Pinhais', 'Belmiro Pereira Alves', 'Chácara Esperança', '83328-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4801, 'Curitiba', 'Belmiro Pereira de Lara', 'Tatuquara', '81480-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4802, 'Ponta Grossa', 'Belmiro Sassi', 'Neves', '84020-768', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4803, 'Paranaguá', 'Belmiro Sebastião Marques', 'Parque São João', '83212-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4804, 'Paranaguá', 'Belmiro Sebastião Marques', 'Vila dos Comerciários', '83215-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4805, 'Foz do Iguaçu', 'Belmonte', 'Jardim Canadá', '85869-186', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4806, 'Londrina', 'Belo Horizonte', 'Centro', '86020-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4807, 'Francisco Beltrão', 'Belo Horizonte', 'Alvorada', '85601-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4808, 'Guarapuava', 'Belo Horizonte', 'Bonsucesso', '85060-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4809, 'Londrina', 'Belo Horizonte', 'Centro', '86020-270', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4810, 'Laranjeiras do Sul', 'Belo Horizonte', 'Água Verde', '85302-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4811, 'Foz do Iguaçu', 'Belo Horizonte', 'Conjunto C', '85870-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4812, 'Maringá', 'Belo Horizonte', 'Jardim Ipiranga', '87020-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4813, 'Piraquara', 'Belo Horizonte', 'Vila Vicente Macedo', '83303-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4814, 'São José dos Pinhais', 'Belo Horizonte', 'Centro', '83005-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4815, 'Pato Branco', 'Belo Horizonte', 'Pinheiros', '85504-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4816, 'Paranavaí', 'Belo Horizonte', 'Centro', '87703-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4817, 'Pinhais', 'Belo Horizonte', 'Conjunto Residencial Renato Bonilauri', '83325-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4818, 'Toledo', 'Belo Horizonte', 'Jardim Porto Alegre', '85906-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4819, 'Umuarama', 'Belo Horizonte', 'Jardim Tamoio', '87505-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4820, 'Umuarama', 'Belo Horizonte', 'Jardim Cidade Alta', '87502-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4821, 'Sarandi', 'Belo Horizonte', 'Jardim Tropical', '87113-810', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4822, 'Sarandi', 'Belo Horizonte', 'Jardim Independência II', '87113-240', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4823, 'Telêmaco Borba', 'Belo Horizonte', 'Vila Santa Rita', '84263-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4824, 'Colombo', 'Belo Horizonte', 'Vila Santa Helena', '83406-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4825, 'Almirante Tamandaré', 'Belo Horizonte', 'Jardim Gramados', '83504-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4826, 'Cascavel', 'Belo Horizonte', 'Ciro Nardi', '85802-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4827, 'Cambé', 'Belo Horizonte', 'Centro', '86181-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4828, 'Castro', 'Belo Horizonte', 'Jardim Bela Vista', '84165-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4829, 'Apucarana', 'Belo Horizonte', 'Jardim Ponta Grossa', '86804-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4830, 'Cascavel', 'Belo Horizonte', 'Alto Alegre', '85805-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4831, 'Curitiba', 'Belo Horizonte', 'Batel', '80240-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4832, 'Francisco Beltrão', 'Beltrão', 'Marrecas', '85601-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4833, 'Maringá', 'Belvedere', 'Vila Nova', '87045-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4834, 'Londrina', 'Bem-aventurado José Marello', 'Jardim Alemanha', '86031-057', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4835, 'Foz do Iguaçu', 'Bem-te-vI', 'Portal da Foz', '85859-385', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4836, 'Laranjeiras do Sul', 'Bem-te-vi', 'Vila Industrial', '85303-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4837, 'Londrina', 'Bem-te-vi', 'Waldemar Hauer', '86030-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4838, 'Guarapuava', 'Bem-te-vi', 'Boqueirão', '85022-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4839, 'Francisco Beltrão', 'Bem-te-vI', 'Padre Eurico', '85604-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4840, 'Maringá', 'Bem-te-vi', 'Conjunto Residencial Ney Braga', '87075-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4841, 'Maringá', 'Bem-te-vi', 'Jardim Olímpico', '87070-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4842, 'Ponta Grossa', 'Bem-te-vi', 'Chapada', '84064-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4843, 'São José dos Pinhais', 'Bem-te-vi', 'Afonso Pena', '83045-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4844, 'Umuarama', 'Bem-te-vi', 'Jardim Sol Nascente', '87505-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4845, 'Telêmaco Borba', 'Bem-te-vi', 'Vila São Vicente de Paula', '84262-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4846, 'Sarandi', 'Bem-te-vi', 'Conjunto Floresta', '87112-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4847, 'Campo Largo', 'Bem-te-vi', 'Vila Gilcy', '83609-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4848, 'Cascavel', 'Bem-te-vI', 'Floresta', '85814-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4849, 'Arapongas', 'Bem-te-vi', 'Centro', '86701-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4850, 'Cambé', 'Bem-Te-vI', 'Conjunto Habitacional Waldomiro M Gomes', '86182-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4851, 'Campo Mourão', 'Bem-te-vi', 'Vila Teixeira', '87300-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4852, 'Araucária', 'Bem-te-vi', 'Capela Velha', '83706-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4853, 'Arapongas', 'Bem-te-vi-assobiador', 'Conjunto Novo Centauro', '86709-538', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4854, 'Arapongas', 'Bem-te-vi-carijó', 'Conjunto Padre Bernardo Merckel', '86706-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4855, 'Arapongas', 'Bem-te-vi-do-brejo', 'Jardim Colúmbia III', '86707-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4856, 'Arapongas', 'Bem-te-vi-rajado', 'Casa Família Arapongas I', '86706-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4857, 'Curitiba', 'Benedicto Berillo Fangueiro', 'Uberaba', '81540-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4858, 'Curitiba', 'Benedicto Campos', 'Jardim das Américas', '81530-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4859, 'Londrina', 'Benedicto de Carvalho', 'Residencial Abussafe', '86037-788', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4860, 'Curitiba', 'Benedita Cândida da Silva', 'Cidade Industrial', '81310-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4861, 'Curitiba', 'Benedita de Franca Ramos', 'Atuba', '82620-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4862, 'Londrina', 'Benedita Eugênia Eduardo', 'Estados', '86083-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4863, 'Curitiba', 'Benedita Leão Silveira Pereira', 'Cidade Industrial', '81350-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4864, 'Londrina', 'Benedita Moreira Rodrigues', 'Colúmbia', '86057-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4865, 'Londrina', 'Benedita Pires da Silveira', 'Aragarça', '86038-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4866, 'São José dos Pinhais', 'Benedito Afonso Camargo', 'Afonso Pena', '83065-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4867, 'Londrina', 'Benedito Alves Moreira', 'Conjunto Habitacional Champagnat', '86086-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4868, 'Curitiba', 'Benedito Antunes de Oliveira', 'Uberaba', '81570-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4869, 'Londrina', 'Benedito Aparecido Nóbrega', 'Conjunto Habitacional José Giordano', '86082-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4870, 'Almirante Tamandaré', 'Benedito B. da Silva', 'Colônia Vila Prado', '83504-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4871, 'Curitiba', 'Benedito Bley', 'Cajuru', '82930-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4872, 'Curitiba', 'Benedito Calixto', 'Uberaba', '81530-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4873, 'Londrina', 'Benedito Cardoso de Oliveira', 'Jardim Paris', '86082-089', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4874, 'Guarapuava', 'Benedito Carias de Oliveira', 'Primavera', '85050-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4875, 'Curitiba', 'Benedito Carollo', 'Cidade Industrial', '81290-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4876, 'Curitiba', 'Benedito Cordeiro', 'Umbará', '81930-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4877, 'Campo Largo', 'Benedito Cordeiro da Silva', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-787', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4878, 'Curitiba', 'Benedito Correia de Freitas', 'Abranches', '82130-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4879, 'Curitiba', 'Benedito da Costa Coelho', 'Pinheirinho', '81820-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4880, 'Londrina', 'Benedito de Oliveira Júnior', 'Monte Carlo', '86040-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4881, 'Londrina', 'Benedito Del Rosário Gavilan Silva', 'Espírito Santo', '86073-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4882, 'Londrina', 'Benedito Dias', 'Jardim Império do Sol', '86073-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4883, 'Curitiba', 'Benedito Dubiela', 'Tatuquara', '81470-196', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4884, 'Maringá', 'Benedito Eduardo Meneguetti', 'Jardim São Silvestre', '87055-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4885, 'Curitiba', 'Benedito Elias Kubrusly', 'Sítio Cercado', '81920-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4886, 'Londrina', 'Benedito Fernandes de Lima', 'Jardim São Jorge', '86082-809', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4887, 'Curitiba', 'Benedito Ferreira de Souza', 'Sítio Cercado', '81920-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4888, 'Colombo', 'Benedito Fonseca de Souza', 'Jardim das Flores', '83402-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4889, 'Curitiba', 'Benedito Franca', 'Capão da Imbuia', '82810-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4890, 'Almirante Tamandaré', 'Benedito G. de Oliveira', 'Jardim Ipanema', '83507-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4891, 'Toledo', 'Benedito G. do Nascimento', 'Conjunto Habitacional São Francisco', '85915-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4892, 'São José dos Pinhais', 'Benedito Galdino de Freitas', 'Colônia Rio Grande', '83025-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4893, 'Almirante Tamandaré', 'Benedito Gomes do Nascimento', 'Loteamento Nova Morada', '83504-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4894, 'Londrina', 'Benedito Gonçalves da Silva', 'Dom Pedro II', '86073-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4895, 'Londrina', 'Benedito Gonçalves de Siqueira', 'Parque Universidade', '86056-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4896, 'Curitiba', 'Benedito Guil', 'Capão da Imbuia', '82800-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4897, 'Apucarana', 'Benedito J. dos Reis', 'Núcleo Habitacional Osmar G Freire', '86801-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4898, 'Curitiba', 'Benedito J. F. da Silva', 'Cidade Industrial', '81170-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4899, 'Apucarana', 'Benedito José dos Santos', 'Jardim Paulista', '86808-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4900, 'Londrina', 'Benedito José Theodoro', 'Itapoã', '86043-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4901, 'Londrina', 'Benedito Leite de Souza', 'Conjunto Parigot de Souza 1', '86081-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4902, 'Curitiba', 'Benedito Lemes Machado', 'Capão Raso', '81130-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4903, 'Maringá', 'Benedito Lima Siqueira', 'Jardim das Nações', '87060-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4904, 'Campo Mourão', 'Benedito Lisboa de Souza', 'Jardim Alvorada', '87308-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4905, 'Cascavel', 'Benedito Lopes Bragança', 'Santa Felicidade', '85803-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4906, 'Londrina', 'Benedito Machado', 'Conjunto Habitacional Saltinho', '86042-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4907, 'Londrina', 'Benedito Marcelino Duarte', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4908, 'Colombo', 'Benedito Mendes de Moraes', 'Jardim Maria Matutina', '83401-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4909, 'Maringá', 'Benedito Montenegro', 'Jardim Alvorada', '87035-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4910, 'Curitiba', 'Benedito Novo', 'Cidade Industrial', '81270-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4911, 'Londrina', 'Benedito Pedro de Araújo', 'Jardim Perobal', '86043-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4912, 'Paranavaí', 'Benedito Pereira Tangerino', 'Jardim Estrela', '87708-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4913, 'Apucarana', 'Benedito Ribeiro Valim', 'Núcleo Habitacional Marcos Freire', '86805-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4914, 'Londrina', 'Benedito Rodrigues da Cunha', 'Jardim Santa Cruz', '86084-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4915, 'Umuarama', 'Benedito Rodrigues de Oliveira', 'Parque Dom Pedro II', '87508-068', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4916, 'Londrina', 'Benedito Rodrigues Negrão', 'Avelino A Vieira', '86056-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4917, 'Londrina', 'Benedito Sales', 'Igarite', '86081-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4918, 'Campo Largo', 'Benedito Soares Pinto', 'Centro', '83601-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4919, 'Piraquara', 'Benedito Teixeira da Luz', 'Planta Wagner', '83314-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4920, 'Ponta Grossa', 'Benedito Vicente', 'Contorno', '84061-618', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4921, 'Colombo', 'Benedito Zerico Ribas Paes', 'Jardim Modelo', '83405-189', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4922, 'Pinhais', 'Benevenuto Rattmann', 'Jardim Pedro Demeterco', '83324-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4923, 'Curitiba', 'Benevenuto Tosin', 'Cajuru', '82930-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4924, 'Apucarana', 'Benevides Mesquita', 'Jardim Iguatemi', '86810-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4925, 'Londrina', 'Benfeitor Jovem Fábio Antunes', 'Jardim Alemanha', '86031-056', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4926, 'Apucarana', 'Benfica', 'Jardim Eldorado', '86802-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4927, 'Curitiba', 'Bengali', 'São Braz', '82015-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4928, 'Londrina', 'Benício Camilo', 'Maria Lúcia', '86072-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4929, 'Colombo', 'Benigna Costa Fortes', 'Jardim Modelo', '83405-188', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4930, 'Londrina', 'Benigno Borlot', 'Recanto Pitanguá', '86055-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4931, 'Telêmaco Borba', 'Benin', 'Vila São Vicente de Paula', '84262-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4932, 'Colombo', 'Benito Juarez Lazzarotto', 'Jardim Uirapuru', '83406-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4933, 'Curitiba', 'Benito Juarez Lazzarotto', 'Boa Vista', '82650-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4934, 'Piraquara', 'Benjamim Andersen', 'Jardim Santa Helena', '83308-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4935, 'Apucarana', 'Benjamim Braga Filho', 'Centro', '86800-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4936, 'Curitiba', 'Benjamim Valente', 'Santa Felicidade', '82400-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4937, 'Curitiba', 'Benjamim Zampieri Parizi', 'Butiatuvinha', '82400-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4938, 'Curitiba', 'Benjamin Antônio Ansai', 'Novo Mundo', '81030-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4939, 'Pato Branco', 'Benjamin Borges dos Santos', 'Fraron', '85503-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4940, 'Apucarana', 'Benjamin Bossa', 'Chácara Mate Amargo', '86803-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4941, 'Almirante Tamandaré', 'Benjamin Carlesso', 'Jardim Monte Santo', '83501-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4942, 'Curitiba', 'Benjamin Cavet', 'São Braz', '82300-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4943, 'São José dos Pinhais', 'Benjamin Claudino Barbosa', 'Miringuava', '83090-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4944, 'Londrina', 'Benjamin Constant', 'Centro', '86020-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4945, 'Londrina', 'Benjamin Constant', 'Centro', '86010-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4946, 'Laranjeiras do Sul', 'Benjamin Constant', 'Getúlio Vargas', '85304-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4947, 'Foz do Iguaçu', 'Benjamin Constant', 'Centro', '85851-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4948, 'Guarapuava', 'Benjamin Constant', 'Centro', '85010-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4949, 'Maringá', 'Benjamin Constant', 'Zona 07', '87020-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4950, 'Ponta Grossa', 'Benjamin Constant', 'Centro', '84010-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4951, 'Paranaguá', 'Benjamin Constant', 'Centro Histórico', '83203-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4952, 'Pato Branco', 'Benjamin Constant', 'Menino Deus', '85502-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4953, 'Toledo', 'Benjamin Constant', 'Vila Pioneiro', '85909-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4954, 'Toledo', 'Benjamin Constant', 'Jardim Europa', '85908-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4955, 'Araucária', 'Benjamin Constant', 'Centro', '83702-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4956, 'Castro', 'Benjamin Constant', 'Centro', '84165-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4957, 'Cambé', 'Benjamin Constant', 'Parque Residencial Manela', '86185-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4958, 'Cascavel', 'Benjamin Constant', 'Parque São Paulo', '85803-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4959, 'Curitiba', 'Benjamin Constant', 'Centro', '80060-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4960, 'Colombo', 'Benjamin Costacurta', 'Vila Vale Verde', '83406-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4961, 'Londrina', 'Benjamin Franklin', 'Jamaica', '86063-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4962, 'Ponta Grossa', 'Benjamin Franklin', 'Uvaranas', '84026-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4963, 'Campo Largo', 'Benjamin Gedião Ferreira', 'Jardim Bela Vista', '83605-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4964, 'Curitiba', 'Benjamin Gelinski', 'Uberaba', '81590-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4965, 'Curitiba', 'Benjamin Granatto', 'Lamenha Pequena', '82410-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4966, 'Londrina', 'Benjamin Jorge', 'Bourbon', '86046-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4967, 'Curitiba', 'Benjamin Juglair', 'Ganchinho', '81935-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4968, 'São José dos Pinhais', 'Benjamin Juliatto', 'Águas Belas', '83010-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4969, 'São José dos Pinhais', 'Benjamin L. Assis', 'Afonso Pena', '83045-230', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4970, 'Londrina', 'Benjamin Lins', 'Dom Pedro', '86039-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4972, 'Curitiba', 'Benjamin Mion', 'Santa Felicidade', '82410-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4973, 'Londrina', 'Benjamin Nalin', 'Jardim Maria Celina', '86081-556', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4974, 'São José dos Pinhais', 'Benjamin Palu', 'Bom Jesus', '83025-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4975, 'São José dos Pinhais', 'Benjamin Possebom', 'Planta Quississana', '83085-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4976, 'Colombo', 'Benjamin Ricardo dos Santos', 'Sapopema', '83407-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4977, 'Londrina', 'Benjamin Siebeneich', 'Heimtal', '86084-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4978, 'Guarapuava', 'Benjamin Teixeira', 'Vila Bela', '85025-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4979, 'Curitiba', 'Benjamin Zilli', 'Ahú', '80540-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4980, 'Curitiba', 'Benno Henrique Doetzer', 'Tatuquara', '81480-228', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4981, 'São José dos Pinhais', 'Beno Ernesto Buhrer', 'Cidade Jardim', '83035-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4982, 'Arapongas', 'Bentererê', 'Jardim Panorama', '86708-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4983, 'Arapongas', 'Bentererê-de-peito-cinza', 'Parque Industrial II', '86703-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4984, 'Londrina', 'Bento Amaral Monteiro', 'Jardim Strass', '86084-830', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4985, 'Curitiba', 'Bento Azambuja', 'Jardim Botânico', '80210-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4986, 'Guarapuava', 'Bento Camargo Ribas', 'Morro Alto', '85065-520', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4987, 'Guarapuava', 'Bento Camargo Ribas', 'São Cristóvão', '85063-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4988, 'Ponta Grossa', 'Bento do Amaral', 'Uvaranas', '84025-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4989, 'Cascavel', 'Bento dos Santos Boreto', '14 de Novembro', '85804-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4990, 'Laranjeiras do Sul', 'Bento Gonçalves', 'Getúlio Vargas', '85304-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4991, 'Londrina', 'Bento Gonçalves', 'Shangri-La', '86070-650', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4992, 'Francisco Beltrão', 'Bento Gonçalves', 'Pinheirinho', '85603-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4993, 'Foz do Iguaçu', 'Bento Gonçalves', 'Jardim Karla', '85868-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4994, 'Pato Branco', 'Bento Gonçalves', 'Cristo Rei', '85507-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4995, 'Paranavaí', 'Bento Gonçalves', 'Jardim São Jorge', '87710-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4996, 'Toledo', 'Bento Gonçalves', 'Jardim Europa', '85908-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4997, 'Cascavel', 'Bento Gonçalves', 'Nova Cidade', '85803-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4998, 'Curitiba', 'Bento Gonçalves', 'Cajuru', '82940-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (4999, 'Colombo', 'Bento Gonçalves dos Santos', 'Jardim Paraná', '83412-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5000, 'Guarapuava', 'Bento José da Silva', 'Boqueirão', '85023-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5001, 'Araucária', 'Bento Luiz de Franca', 'Tindiquera', '83708-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5002, 'Foz do Iguaçu', 'Bento Munhoz da Rocha', 'Vila Yolanda', '85853-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5003, 'Campo Mourão', 'Bento Munhoz da Rocha', 'Centro', '87300-520', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5004, 'Londrina', 'Bento Munhoz da Rocha Neto', 'Guanabara', '86050-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5005, 'Guarapuava', 'Bento Munhoz da Rocha Neto', 'Primavera', '85050-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5006, 'Londrina', 'Bento Munhoz da Rocha Neto', 'Jardim do Lago', '86050-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5007, 'Paranaguá', 'Bento Munhoz da Rocha Neto', 'Jardim América', '83212-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5008, 'Paranaguá', 'Bento Munhoz da Rocha Neto', 'Jardim Samambaia', '83215-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5009, 'Paranaguá', 'Bento Munhoz da Rocha Neto', 'Aeroporto', '83209-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5010, 'Toledo', 'Bento Munhoz da Rocha Neto', 'Jardim La Salle', '85902-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5011, 'São José dos Pinhais', 'Bento Munhoz da Rocha Neto', 'São Sebastião', '83075-356', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5012, 'Castro', 'Bento Munhoz da Rocha Neto', 'Centro', '84165-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5013, 'Cambé', 'Bento Munhoz da Rocha Neto', 'Chácara Manela', '86186-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5014, 'Curitiba', 'Bento Munhoz da Rocha Neto', 'Guaíra', '80630-190', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5015, 'Maringá', 'Bento Munhoz da Rocha Netto', 'Zona 07', '87030-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5016, 'Cascavel', 'Bento Mussurunga', 'Brasília', '85815-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5017, 'Paranaguá', 'Bento Oliveira Rocha', 'Vila São Vicente', '83209-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5018, 'Guarapuava', 'Bento Prado Martins', 'Bonsucesso', '85060-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5019, 'Ponta Grossa', 'Bento Ribeiro', 'Nova Rússia', '84071-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5020, 'Ponta Grossa', 'Bento Ribeiro', 'Nova Rússia', '84070-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5021, 'Ponta Grossa', 'Bento Ribeiro', 'Nova Rússia', '84053-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5022, 'Curitiba', 'Bento Ribeiro', 'Bairro Alto', '82840-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5023, 'Paranaguá', 'Bento Rocha', 'Dom Pedro II', '83221-565', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5024, 'Cambé', 'Bento Saloio', 'Jardim José Favaro', '86183-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5025, 'Ponta Grossa', 'Bento Viana', 'Nova Rússia', '84053-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5026, 'Curitiba', 'Bento Viana', 'Água Verde', '80240-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5027, 'Guarapuava', 'Bento XV', 'Morro Alto', '85065-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5028, 'Londrina', 'Benventura C. Boratin', 'Eucaliptos', '86031-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5029, 'Umuarama', 'Benvenuto Gazzi', 'Parque Bandeirantes', '87504-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5030, 'Umuarama', 'Benvenuto Gazzi', 'Jardim Alphavile', '87504-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5032, 'Londrina', 'Benvenutro Petrin', 'Pérola', '86038-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5033, 'Curitiba', 'Benvinda Camilo Antunes', 'Sítio Cercado', '81920-747', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5034, 'São José dos Pinhais', 'Benvindo Bastos', 'Ipê', '83055-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5035, 'Apucarana', 'Benvindo Domingos', 'Mutirão Projeto Bóia Fria', '86803-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5036, 'Almirante Tamandaré', 'Benvindo Ribeiro', 'Jardim Parati', '83503-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5037, 'Curitiba', 'Beppe Gusso', 'Santa Cândida', '82720-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5038, 'Curitiba', 'Bercellos de Freitas', 'Cidade Industrial', '81460-307', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5039, 'Curitiba', 'Berel Brik', 'Hugo Lange', '80040-360', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5040, 'Curitiba', 'Bergamo', 'Santa Felicidade', '82030-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5041, 'Londrina', 'Berilo', 'Waldemar Hauer', '86030-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5042, 'Ponta Grossa', 'Berilo', 'Neves', '84021-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5043, 'Maringá', 'Berilo', 'Jardim Santa Helena', '87083-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5044, 'Telêmaco Borba', 'Berilo', 'Vila São Francisco de Assis', '84265-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5045, 'Ponta Grossa', 'Berilonita', 'Neves', '84021-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5046, 'Guarapuava', 'Berlim', 'Santana', '85070-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5047, 'Foz do Iguaçu', 'Berlim', 'Jardim Europa', '85859-317', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5048, 'Paranaguá', 'Berlim', 'Parque Agari', '83215-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5049, 'São José dos Pinhais', 'Berlim', 'São Sebastião', '83075-260', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5050, 'Telêmaco Borba', 'Berlim', 'Nossa Senhora do Perpétuo Socorro', '84265-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5051, 'Cascavel', 'Berlim', 'Nova Cidade', '85818-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5052, 'Curitiba', 'Bermival Antônio Bozza', 'Umbará', '81930-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5053, 'Araucária', 'Bernado Martini', 'Costeira', '83709-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5054, 'Campo Largo', 'Bernardino Basani', 'Moradias Bom Jesus', '83602-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5055, 'Piraquara', 'Bernardino Campos Filho', 'Guarituba', '83311-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5056, 'Ponta Grossa', 'Bernardino de Campos', 'Boa Vista', '84073-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5057, 'Maringá', 'Bernardino de Campos', 'Zona 07', '87030-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5058, 'Cambé', 'Bernardino de Campos', 'Jardim São Paulo', '86191-550', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5059, 'Londrina', 'Bernardino Fortunato', 'Cafezal 1', '86049-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5060, 'Curitiba', 'Bernardino Iatauro', 'Orleans', '82310-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5061, 'Araucária', 'Bernardino Lemos', 'Costeira', '83709-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5062, 'Curitiba', 'Bernardino Monteiro', 'Tingui', '82620-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5063, 'Maringá', 'Bernardino Rosário da Cruz', 'Jardim Pinheiros II', '87043-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5064, 'Guarapuava', 'Bernardino Roseira de Lacerda', 'Morro Alto', '85065-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5065, 'Londrina', 'Bernardino Vasconcelos de Azevedo', 'Conjunto Habitacional  Alexandre Urbanas', '86037-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5066, 'Colombo', 'Bernardo Alberti', 'Jardim Santa Cândida', '83404-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5067, 'Campo Largo', 'Bernardo Antônio Guerchewski', 'Bom Jesus', '83604-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5068, 'Campo Largo', 'Bernardo Antônio Guerchewski', 'Vila Santa Terezinha', '83602-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5069, 'Curitiba', 'Bernardo Berman', 'Pilarzinho', '82115-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5070, 'Guarapuava', 'Bernardo Bochnnia', 'Conradinho', '85055-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5071, 'Curitiba', 'Bernardo Bubniak', 'Atuba', '82630-306', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5072, 'Curitiba', 'Bernardo Carlberg', 'São João', '82030-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5073, 'Colombo', 'Bernardo Colere', 'Jardim dos Eucaliptos', '83408-497', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5074, 'Ponta Grossa', 'Bernardo de Vasconcelos', 'Jardim Carvalho', '84015-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5075, 'Ponta Grossa', 'Bernardo de Vasconcelos', 'Jardim Carvalho', '84016-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5076, 'Curitiba', 'Bernardo do Amaral Wolff', 'São Braz', '82300-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5077, 'Almirante Tamandaré', 'Bernardo Domakoski', 'Jardim Dona Belizaria', '83513-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5078, 'São José dos Pinhais', 'Bernardo Dombrowski', 'Afonso Pena', '83050-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5079, 'Guarapuava', 'Bernardo Dominico', 'Boqueirão', '85023-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5080, 'Campo Largo', 'Bernardo Fedalto', 'Loteamento São José', '83606-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5081, 'Ponta Grossa', 'Bernardo Ferreira dos Santos', 'Olarias', '84026-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5082, 'Araucária', 'Bernardo Frederico Michel', 'Boqueirão', '83704-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5083, 'Curitiba', 'Bernardo Glodzinski', 'Tingui', '82600-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5084, 'Guarapuava', 'Bernardo Guimarães', 'Dos Estados', '85035-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5085, 'Ponta Grossa', 'Bernardo Guimarães', 'Colônia Dona Luiza', '84046-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5086, 'Paranaguá', 'Bernardo Hartog', 'Eldorado', '83206-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5087, 'São José dos Pinhais', 'Bernardo Itener', 'Miringuava', '83090-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5088, 'Curitiba', 'Bernardo Jacintho da Veiga', 'Novo Mundo', '81050-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5089, 'Guarapuava', 'Bernardo Joaquim da Silva', 'Morro Alto', '85065-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5090, 'Guarapuava', 'Bernardo José de Lacerda', 'Santa Cruz', '85015-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5091, 'Curitiba', 'Bernardo Krasinski', 'Orleans', '81200-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5092, 'Curitiba', 'Bernardo Leinig', 'Vila Izabel', '80240-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5093, 'Araucária', 'Bernardo Lemos', 'Costeira', '83708-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5094, 'Colombo', 'Bernardo Lunardon', 'Vila São Paulo', '83411-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5095, 'Curitiba', 'Bernardo Mann', 'Xaxim', '81820-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5096, 'Curitiba', 'Bernardo Manoel Hostin', 'Bairro Alto', '82820-560', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5097, 'Piraquara', 'Bernardo Melmann', 'Jardim Veneza', '83310-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5098, 'Curitiba', 'Bernardo Meyer', 'Cidade Industrial', '81350-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5099, 'Piraquara', 'Bernardo Michel', 'Vila Rosa', '83304-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5100, 'Curitiba', 'Bernardo Milano', 'Capão da Imbuia', '82810-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5101, 'Almirante Tamandaré', 'Bernardo Milek', 'Vila São Bernardo', '83506-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5102, 'Curitiba', 'Bernardo Morosin', 'Mossunguê', '81200-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5103, 'Castro', 'Bernardo Musialowski', 'Jardim Colonial', '84178-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5104, 'Curitiba', 'Bernardo Nuernberg', 'Pinheirinho', '81870-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5105, 'Pinhais', 'Bernardo Osinski', 'Vale da Boa Esperança', '83320-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5106, 'Londrina', 'Bernardo Pereira Trindade', 'Jardim São Jorge', '86082-816', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5107, 'Curitiba', 'Bernardo Pericas', 'Jardim Social', '82520-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5108, 'Castro', 'Bernardo Pusch', 'Centro', '84165-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5109, 'Curitiba', 'Bernardo Ribeiro', 'Jardim das Américas', '81540-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5110, 'Curitiba', 'Bernardo Rosenmann', 'Tingui', '82600-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5111, 'Ponta Grossa', 'Bernardo Savio', 'Jardim Carvalho', '84015-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5112, 'Londrina', 'Bernardo Sayão', 'Petrópolis', '86015-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5113, 'Curitiba', 'Bernardo Schlichta', 'Cachoeira', '82710-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5114, 'Curitiba', 'Bernardo Sobieck', 'Campo Comprido', '81270-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5115, 'Campo Largo', 'Bernardo Spack', 'Loteamento São José', '83606-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5116, 'Almirante Tamandaré', 'Bernardo Stamm', 'Planta Vila Rica', '83507-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5117, 'Curitiba', 'Bernardo Staviski', 'Campina do Siqueira', '80730-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5118, 'Curitiba', 'Bernardo Vacheski', 'Tatuquara', '81940-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5119, 'Curitiba', 'Berta Klemtz', 'Fazendinha', '81330-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5120, 'Foz do Iguaçu', 'Berta Nascimento', 'Jardim Esmeralda', '85856-120', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5121, 'Cascavel', 'Bertha F. Bartinik', 'Independência', '85813-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5122, 'Curitiba', 'Bertha Lutz', 'Cajuru', '82920-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5123, 'Curitiba', 'Bertholdo Adam', 'Pilarzinho', '82100-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5124, 'Curitiba', 'Bertholdo Francisco Buchholtz', 'Lamenha Pequena', '82410-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5125, 'Castro', 'Bertholdo Martins de Oliveira', 'Jardim dos Bancários', '84172-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5126, 'Maringá', 'Bertioga', 'Jardim Alvorada', '87033-240', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5127, 'Sarandi', 'Bertioga', 'Parque Residencial Nova Aliança', '87111-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5128, 'Londrina', 'Bertoldo Durães', 'Conjunto Café', '86038-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5129, 'Almirante Tamandaré', 'Bertolina C. de Oliveira', 'Vila Santa Terezinha', '83501-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5130, 'Ponta Grossa', 'Beta', 'Oficinas', '84035-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5131, 'Ponta Grossa', 'Beta', 'Cará-cará', '84043-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5132, 'Ponta Grossa', 'Betel', 'Jardim Carvalho', '84016-677', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5133, 'Foz do Iguaçu', 'Betim', 'Jardim Nacional', '85862-180', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5134, 'Telêmaco Borba', 'Betim', 'Área 06', '84271-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5135, 'Piraquara', 'Betonex', 'Jardim Tropical', '83314-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5136, 'Maringá', 'Betty', 'Jardim Cidade Monções', '87060-405', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5137, 'Curitiba', 'Betty de Souza Paula Halila', 'Cajuru', '82970-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5138, 'Cascavel', 'Betula', 'Recanto Tropical', '85807-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5139, 'Curitiba', 'Bety Moreira Pacheco', 'Cidade Industrial', '81460-237', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5140, 'Toledo', 'Bezerra de Menezes', 'Parque Residencial Pancera', '85902-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5141, 'Apucarana', 'Biagen Riveline', 'Jardim Santos Dumont I', '86812-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5142, 'Maringá', 'Bice Deplano Côcco', 'Parque da Gávea', '87053-267', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5143, 'Apucarana', 'Bichara José Bichara', 'Vila Vitória Régia', '86801-310', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5144, 'Arapongas', 'Bico-agudo', 'Jardim São Rafael', '86703-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5145, 'Arapongas', 'Bico-chato-de-crista-branca', 'Jardim Nova Baroneza', '86706-688', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5146, 'Arapongas', 'Bico-de-agulha', 'Jardim do Carmo', '86703-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5147, 'Arapongas', 'Bico-de-brasa', 'Jardim Universitário', '86702-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5148, 'Foz do Iguaçu', 'Bico-de-lacre', 'Portal da Foz', '85859-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5149, 'Araucária', 'Bico-de-lacre', 'Capela Velha', '83706-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5150, 'Arapongas', 'Bico-de-lacre', 'Vila Aparecida', '86707-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5151, 'Arapongas', 'Bico-de-veludo', 'Conjunto Centauro', '86709-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5152, 'Foz do Iguaçu', 'Bicudo', 'Conjunto A', '85866-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5153, 'Londrina', 'Bicudo', 'Conjunto Habitacional Violim', '86084-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5154, 'Arapongas', 'Bicudo', 'Jardim Primavera', '86702-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5155, 'Arapongas', 'Bigodinho', 'Conjunto Del Condor', '86703-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5156, 'Foz do Iguaçu', 'Biguá', 'Conjunto A', '85866-040', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5157, 'Ponta Grossa', 'Biguá', 'Colônia Dona Luiza', '84046-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5158, 'Arapongas', 'Biguá', 'Jardim Universitário', '86702-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5159, 'Foz do Iguaçu', 'Biguaçu', 'Jardim Lancaster', '85869-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5160, 'Arapongas', 'Biguatinga', 'Jardim Primavera', '86702-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5161, 'Arapongas', 'Biguá-una', 'Jardim Monte Carlo II', '86704-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5162, 'Curitiba', 'Billy Garmatter', 'Sítio Cercado', '81900-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5163, 'Curitiba', 'Bine Gersten Reiss', 'Cajuru', '82900-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5164, 'Curitiba', 'Binem Schechter', 'Santa Felicidade', '82020-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5165, 'Almirante Tamandaré', 'Bini', 'Jardim Bela Vista', '83513-470', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5166, 'Curitiba', 'Biraci Teixeira de Noronha', 'Bacacheri', '82600-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5167, 'Cambé', 'Birigui', 'Jardim São Paulo', '86191-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5168, 'Curitiba', 'Birigui', 'Cidade Industrial', '81305-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5169, 'Curitiba', 'Birmânia', 'Cajuru', '82960-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5170, 'Pato Branco', 'Bispo Dom Carlos Eduardo', 'La Salle', '85505-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5171, 'Ponta Grossa', 'Bispo Dom Geraldo Pellanda', 'Centro', '84025-007', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5172, 'Curitiba', 'Bispo Dom Inácio Krause', 'Tingui', '82620-075', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5173, 'Curitiba', 'Bispo Dom José', 'Batel', '80440-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5174, 'Curitiba', 'Bispo São Félix', 'Tatuquara', '81480-237', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5175, 'Curitiba', 'Bittencourt', 'Centro', '80060-210', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5176, 'Ponta Grossa', 'Bittencourt Sampaio', 'Nova Rússia', '84053-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5177, 'Guarapuava', 'Bituruna', 'Boqueirão', '85023-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5178, 'Ponta Grossa', 'Bituruna', 'Uvaranas', '84025-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5179, 'Curitiba', 'Bituruna', 'Alto Boqueirão', '81830-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5180, 'Londrina', 'Blaise Pascal', 'Industrial', '86063-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5181, 'Curitiba', 'Blaise Pascal', 'Abranches', '82220-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5182, 'Curitiba', 'Blasco Ibánez', 'Jardim das Américas', '81530-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5183, 'Foz do Iguaçu', 'Blasko Ibánes Santos', 'Jardim Nacional', '85862-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5184, 'Curitiba', 'Bley Zorning', 'Boqueirão', '81730-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5185, 'Curitiba', 'Bley Zorning', 'Boqueirão', '81750-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5186, 'Guarapuava', 'Blumenau', 'Boqueirão', '85022-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5187, 'Foz do Iguaçu', 'Blumenau', 'Jardim Karla', '85868-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5188, 'Piraquara', 'Blumenau', 'Planta São Tiago', '83306-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5189, 'São José dos Pinhais', 'Blumenau', 'São Sebastião', '83075-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5190, 'Telêmaco Borba', 'Blumenau', 'Área 01', '84268-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5191, 'Sarandi', 'Blumenau', 'Jardim Cometa', '87112-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5192, 'Cascavel', 'Blumenau', 'Universitário', '85819-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5193, 'Curitiba', 'Blumenau', 'Cidade Industrial', '81240-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5194, 'Guarapuava', 'Boa Esperança', 'Boqueirão', '85020-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5195, 'São José dos Pinhais', 'Boa Esperança', 'Cruzeiro', '83010-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5196, 'Toledo', 'Boa Esperança', 'Boa Esperança', '85909-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5197, 'Curitiba', 'Boa Esperança', 'Alto Boqueirão', '81830-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5198, 'Piraquara', 'Boa Terra', 'Planta Bosque Centenário', '83311-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5199, 'Guarapuava', 'Boa Vista', 'Conradinho', '85055-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5200, 'Foz do Iguaçu', 'Boa Vista', 'Jardim Amazonas', '85857-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5201, 'Pinhais', 'Boa Vista', 'Conjunto Residencial Renato Bonilauri', '83325-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5202, 'Maringá', 'Boa Vista', 'Jardim Social', '87010-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5203, 'São José dos Pinhais', 'Boa Vista', 'Costeira', '83015-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5204, 'Sarandi', 'Boa Vista', 'Jardim Cruzeiro', '87112-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5205, 'Telêmaco Borba', 'Boa Vista', 'Área 02', '84267-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5206, 'Cascavel', 'Boa Vista', '14 de Novembro', '85804-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5207, 'Curitiba', 'Boa Vista', 'Boa Vista', '82510-500', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5208, 'Curitiba', 'Boa Vista da Aparecida', 'Lamenha Pequena', '82410-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5209, 'Cascavel', 'Boa Vistinha', 'Morumbi', '85817-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5210, 'Cascavel', 'Boa Vontade', 'Brasmadeira', '85814-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5211, 'Curitiba', 'Boanerges de Menezes Caldas', 'Boa Vista', '82540-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5212, 'Colombo', 'Boanerges Mendes do Valle', 'Jardim Esplanada', '83402-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5213, 'Foz do Iguaçu', 'Boanerjes Borba Sottomaior', 'Jardim Bandeirantes', '85862-446', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5214, 'Francisco Beltrão', 'Boaventura Faust', 'São Miguel', '85602-166', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5215, 'Cascavel', 'Boaventura Tozzo', 'Presidente', '85818-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5216, 'Apucarana', 'Boca-de-leão', 'Jardim das Flores III', '86810-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5217, 'Araucária', 'Boca-de-leão', 'Campina da Barra', '83709-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5218, 'Cascavel', 'Bocaina', 'Morumbi', '85817-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5219, 'Curitiba', 'Bocaiúva', 'Santa Quitéria', '80310-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5220, 'Ponta Grossa', 'Bocaiúva do Sul', 'Oficinas', '84036-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5221, 'Cascavel', 'Bocaiúva do Sul', 'Brasmadeira', '85814-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5222, 'Almirante Tamandaré', 'Bocaiúva do Sul', 'Jardim Roma', '83504-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5223, 'Colombo', 'Boccacio', 'Jardim Campo Alto', '83408-160', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5224, 'Ponta Grossa', 'Boeing', 'Cará-cará', '84043-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5225, 'Castro', 'Bogdam Holowchak', 'Vila Santa Cruz', '84168-026', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5226, 'Maringá', 'Bogota', 'Vila Morangueira', '87040-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5227, 'Maringá', 'Bogota', 'Vila Morangueira', '87040-121', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5228, 'Foz do Iguaçu', 'Bogotá', 'Jardim Alice I', '85858-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5229, 'Francisco Beltrão', 'Bogotá', 'Seminário', '85605-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5230, 'Londrina', 'Bogotá', 'Santa Rosa', '86050-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5231, 'Pato Branco', 'Bogotá', 'Menino Deus', '85502-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5232, 'Sarandi', 'Bogotá', 'Parque São Pedro', '87112-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5233, 'Telêmaco Borba', 'Bogotá', 'Nossa Senhora de Fátima', '84264-330', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5234, 'Curitiba', 'Bogumil Radomski', 'Vista Alegre', '82100-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5235, 'Castro', 'Bogussuaw Kremer', 'Vila Santa Cruz', '84168-036', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5236, 'Arapongas', 'Boininha', 'Conjunto Ulisses Guimarães', '86706-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5237, 'Londrina', 'Boldo', 'Jardim Novo Sabará', '86066-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5238, 'Piraquara', 'Boldo', 'Vila Santa Maria', '83306-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5239, 'Araucária', 'Boles Tonchak', 'Boqueirão', '83704-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5240, 'Foz do Iguaçu', 'Boleslau Boiarski', 'Jardim do Horto', '85854-565', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5241, 'Londrina', 'Boleslau Ilnick', 'Lima Azevedo', '86060-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5242, 'Guarapuava', 'Boleslau João Sekula', 'Industrial', '85053-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5243, 'Curitiba', 'Boleslau Kuroski', 'Mossunguê', '81200-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5244, 'São José dos Pinhais', 'Boleslau Sochaczewski', 'Afonso Pena', '83050-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5245, 'Araucária', 'Boleslau Wzorek', 'Estação', '83705-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5246, 'Maringá', 'Bolívar', 'Vila Morangueira', '87030-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5247, 'Toledo', 'Bolívar José Ruaro', 'Conjunto Habitacional São Francisco', '85912-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5248, 'Guarapuava', 'Bolívia', 'Morro Alto', '85063-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5249, 'Francisco Beltrão', 'Bolívia', 'Luther King', '85605-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5250, 'Laranjeiras do Sul', 'Bolívia', 'Cristo Rei', '85304-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5251, 'Foz do Iguaçu', 'Bolívia', 'Jardim América', '85864-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5252, 'Londrina', 'Bolívia', 'Vila Brasil', '86010-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5253, 'Ponta Grossa', 'Bolívia', 'Ronda', '84051-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5254, 'Pato Branco', 'Bolívia', 'Jardim América', '85502-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5255, 'Paranaguá', 'Bolívia', 'Jardim América', '83209-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5256, 'Maringá', 'Bolívia', 'Vila Morangueira', '87040-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5257, 'Telêmaco Borba', 'Bolívia', 'Vila São Vicente de Paula', '84262-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5258, 'Sarandi', 'Bolívia', 'Jardim Castelo', '87112-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5259, 'Toledo', 'Bolívia', 'Parque Residencial Gisela', '85905-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5260, 'Colombo', 'Bolívia', 'Jardim Rio Verde', '83405-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5261, 'Castro', 'Bolívia', 'Vila do Rosário', '84168-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5262, 'Apucarana', 'Bolívia', 'Jardim Diamantina', '86804-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5263, 'Cascavel', 'Bolívia', 'Pacaembu', '85816-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5264, 'Almirante Tamandaré', 'Bolívia', 'Jardim São Francisco', '83501-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5265, 'Curitiba', 'Bolívia', 'Bacacheri', '82510-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5266, 'Francisco Beltrão', 'Bologna', 'Jardim Floresta', '85603-797', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5267, 'Curitiba', 'Bologna', 'Cascatinha', '82020-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5268, 'Londrina', 'Bolonha', 'Parque Residencial João Piza', '86041-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5269, 'Cambé', 'Bolonha', 'Residencial Monte Castelo', '86186-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5270, 'Colombo', 'Bolonha', 'Planta Boros', '83413-350', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5271, 'Pinhais', 'Bolsão das Arapongas', 'Chácara Paulivinas', '83320-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5272, 'Pinhais', 'Bolsão das Araras', 'Chácara Paulivinas', '83320-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5273, 'Pinhais', 'Bolsão das Gralhas-azuis', 'Chácara Paulivinas', '83320-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5274, 'Pinhais', 'Bolsão das Patativas', 'Chácara Paulivinas', '83320-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5275, 'Pinhais', 'Bolsão do Melros', 'Chácara Paulivinas', '83320-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5276, 'Pinhais', 'Bolsão dos Bem-te-vis', 'Chácara Paulivinas', '83320-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5277, 'Pinhais', 'Bolsão dos Canários', 'Chácara Paulivinas', '83320-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5278, 'Pinhais', 'Bolsão dos Cardeais', 'Chácara Paulivinas', '83320-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5279, 'Pinhais', 'Bolsão dos Curiós', 'Chácara Paulivinas', '83320-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5280, 'Pinhais', 'Bolsão dos Papagaios', 'Jardim Luzitano', '83320-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5281, 'Pinhais', 'Bolsão dos Sabiás', 'Chácara Paulivinas', '83320-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5282, 'Pinhais', 'Bolsão dos Tucanos', 'Chácara Paulivinas', '83320-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5283, 'Londrina', 'Bom  Pastor', 'Alto da Boa Vista', '86083-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5284, 'São José dos Pinhais', 'Bom  Pastor', 'Campina', '83015-140', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5285, 'Toledo', 'Bom  Pastor', 'Parque Residencial Pancera', '85902-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5286, 'Toledo', 'Bom  Pastor', 'Jardim Canaã', '85914-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5287, 'Foz do Iguaçu', 'Bom Jardim', 'Jardim Ipanema', '85862-318', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5288, 'Ponta Grossa', 'Bom Jardim', 'Chapada', '84062-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5289, 'Toledo', 'Bom Jardim', 'Boa Esperança', '85909-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5290, 'Pinhais', 'Bom Jesus', 'Planta Guilherme Weiss', '83322-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5291, 'Ponta Grossa', 'Bom Jesus', 'Uvaranas', '84031-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5292, 'Ponta Grossa', 'Bom Jesus', 'Uvaranas', '84031-035', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5293, 'Pato Branco', 'Bom Jesus', 'Anchieta', '85501-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5294, 'Cascavel', 'Bom Jesus', 'Região do Lago 1', '85812-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5295, 'Campo Largo', 'Bom Jesus', 'Bom Jesus', '83604-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5296, 'Curitiba', 'Bom Jesus', 'Juvevê', '80035-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5297, 'Apucarana', 'Bom Jesus da Lapa', 'Jardim Nossa Senhora de Lourdes', '86811-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5298, 'Curitiba', 'Bom Jesus de Iguapé', 'Boqueirão', '81730-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5299, 'Curitiba', 'Bom Jesus de Iguapé', 'Hauer', '81610-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5300, 'Curitiba', 'Bom Jesus de Iguapé', 'Boqueirão', '81650-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5301, 'Umuarama', 'Bom Jesus Libertador', 'Jardim Cruzeiro', '87504-577', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5302, 'Sarandi', 'Bom Pastor', 'Parque Residencial Bom Pastor', '87114-552', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5303, 'Curitiba', 'Bom Pastor', 'Alto Boqueirão', '81720-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5304, 'Cascavel', 'Bom Princípio', 'Brasmadeira', '85814-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5305, 'Guarapuava', 'Bom Retiro', 'Santana', '85070-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5306, 'Telêmaco Borba', 'Bom Retiro', 'Vila São Francisco de Assis', '84264-530', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5307, 'Telêmaco Borba', 'Bom Retiro', 'Área 02', '84267-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5308, 'Cambé', 'Bom Retiro', 'Jardim Morumbi', '86191-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5309, 'Curitiba', 'Bom Retiro', 'Bom Retiro', '80520-390', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5310, 'Sarandi', 'Bom Samaritano', 'Parque Residencial Bom Pastor', '87114-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5311, 'Umuarama', 'Bom Senhor', 'Parque das Jaboticabeiras', '87509-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5312, 'Pato Branco', 'Bom Sucesso', 'Bonatto', '85506-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5313, 'São José dos Pinhais', 'Bom Sucesso', 'Bom Jesus', '83025-070', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5314, 'Piraquara', 'Bom Sucesso', 'Jardim Santa Mônica', '83302-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5315, 'Umuarama', 'Bom Sucesso', 'Zona I', '87501-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5316, 'Colombo', 'Bom Sucesso', 'Jardim Guaraituba', '83410-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5317, 'Apucarana', 'Bom Sucesso', 'Vila São Carlos', '86800-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5318, 'Cambé', 'Bom Sucesso', 'Vila Mesquita', '86182-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5319, 'Curitiba', 'Bom Sucesso', 'Alto Boqueirão', '81830-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5320, 'Londrina', 'Bombaim', 'Cláudia', '86050-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5321, 'Curitiba', 'Bona Busnello', 'Jardim das Américas', '81540-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5322, 'Ponta Grossa', 'Bonanza', 'Cará-cará', '84043-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5323, 'Guarapuava', 'Bonfim', 'Industrial', '85045-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5324, 'Toledo', 'Bonfim', 'Jardim La Salle', '85902-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5325, 'Toledo', 'Bonfim', 'Centro', '85901-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5326, 'Curitiba', 'Bonifácio Batista Ribas', 'Barreirinha', '82710-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5327, 'Almirante Tamandaré', 'Bonifácio Bento Cordeiro', 'Vila Grécia', '83502-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5328, 'Toledo', 'Bonifácio Dewes', 'Jardim Parizzotto', '85914-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5329, 'Araucária', 'Bonifácio Kaiute', 'Estação', '83705-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5330, 'Campo Mourão', 'Bonifácio Paes Carneiro', 'Jardim Capricórnio', '87301-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5331, 'Foz do Iguaçu', 'Bonifácio Palma', 'Parque Presidente II', '85863-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5332, 'Ponta Grossa', 'Bonifácio Ribas', 'Olarias', '84025-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5333, 'Londrina', 'Bonifácio Rodrigues', 'Cafezal 1', '86049-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5334, 'Ponta Grossa', 'Bonifácio Vilela', 'Centro', '84010-330', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5335, 'Ponta Grossa', 'Bonifácio Vilela', 'Jardim Carvalho', '84015-460', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5336, 'Arapongas', 'Bonito-do-campo', 'Jardim Baroneza', '86706-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5337, 'Foz do Iguaçu', 'Bonito-lindo', 'Portal da Foz', '85859-386', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5338, 'Foz do Iguaçu', 'Bonn', 'Beverly Falls Park', '85858-240', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5339, 'Maringá', 'Bonsai', 'Jardim Imperial II', '87023-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5340, 'Ponta Grossa', 'Bonsucesso', 'Chapada', '84062-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5341, 'Campo Largo', 'Bonsucesso', 'Vila Rivabem', '83605-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5342, 'Apucarana', 'Boqueirão', 'Jardim Guarujá', '86807-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5343, 'Pato Branco', 'Borba', 'Bortot', '85504-210', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5344, 'Londrina', 'Borba Gato', 'Jardim das Américas', '86010-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5345, 'Guarapuava', 'Borba Gato', 'Alto Cascavel', '85031-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5346, 'Ponta Grossa', 'Borba Gato', 'Orfãs', '84010-780', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5347, 'Maringá', 'Borba Gato', 'Zona 06', '87015-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5348, 'Cascavel', 'Borba Gato', 'Cancelli', '85811-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5349, 'Londrina', 'Boré', 'Castelo', '86027-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5350, 'Pato Branco', 'Borges', 'São Vicente', '85506-390', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5351, 'Guarapuava', 'Borges de Medeiros', 'Vila Bela', '85027-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5352, 'Toledo', 'Borges de Medeiros', 'Vila Industrial', '85904-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5353, 'Toledo', 'Borges de Medeiros', 'Parque Residencial Gisela', '85905-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5354, 'Cascavel', 'Borin', 'Nova Cidade', '85803-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5355, 'Foz do Iguaçu', 'Bororós', 'Jardim Tarobá', '85856-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5356, 'Telêmaco Borba', 'Bororós', 'Nossa Senhora do Perpétuo Socorro', '84265-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5357, 'Cascavel', 'Bororós', 'Santa Cruz', '85806-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5358, 'Apucarana', 'Bororós', 'Núcleo Habitacional Colonial', '86812-429', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5359, 'Curitiba', 'Bororós', 'Vila Izabel', '80320-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5360, 'Arapongas', 'Borralha', 'Conjunto Tropical', '86702-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5361, 'Foz do Iguaçu', 'Borrazópolis', 'Loteamento Witt', '85862-538', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5362, 'Ponta Grossa', 'Borrazópolis', 'Nova Rússia', '84053-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5363, 'Apucarana', 'Borrazópolis', 'Núcleo Habitacional Nossa Senhora Aparecida', '86801-407', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5364, 'Curitiba', 'Borrazópolis', 'Alto Boqueirão', '81830-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5365, 'Londrina', 'Bortolo Borsato', 'Aquilles Sthengel', '86086-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5366, 'Colombo', 'Bôrtolo Cavassin', 'Uvarana', '83415-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5367, 'Umuarama', 'Bortolo Ceranto', 'Parque Cidade Jardim', '87506-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5368, 'Curitiba', 'Bortolo Cuman', 'Butiatuvinha', '82400-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5369, 'Curitiba', 'Bortolo Gava', 'Pilarzinho', '82120-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5370, 'Curitiba', 'Bortolo Gusso', 'Capão Raso', '81110-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5371, 'Cambé', 'Bortolo Loni', 'Jardim Vitória', '86184-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5372, 'Ponta Grossa', 'Bôrtolo Moro', 'Estrela', '84050-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5373, 'Almirante Tamandaré', 'Bortolo Muraro', 'Jardim Areias', '83514-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5374, 'Ponta Grossa', 'Bôrtolo Nadal', 'Uvaranas', '84020-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5375, 'Curitiba', 'Bortolo Parise', 'São Braz', '82015-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5376, 'Curitiba', 'Bortolo Paulin', 'Santa Felicidade', '82320-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5377, 'Curitiba', 'Bortolo Pelanda', 'Umbará', '81940-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5378, 'Curitiba', 'Bortolo Romani Durigan', 'Santa Felicidade', '82030-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5379, 'Pato Branco', 'Bortot', 'Santa Terezinha', '85506-050', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5380, 'Piraquara', 'Bosque Centenário', 'Planta Bosque Centenário', '83311-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5381, 'Piraquara', 'Bosque Tarumã', 'Planta Bosque Centenário', '83311-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5382, 'Maringá', 'Botafogo', 'Zona 08', '87050-370', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5383, 'Maringá', 'Botafogo', 'Vila Marumby', '87005-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5384, 'Sarandi', 'Botafogo', 'Parque Residencial Nova Aliança', '87111-746', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5385, 'Cambé', 'Botafogo Futebol e Regatas', 'Conjunto Habitacional Collor de Melo', '86188-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5386, 'Foz do Iguaçu', 'Boto', 'Profilurb II', '85855-520', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5387, 'São José dos Pinhais', 'Botteger', 'Roseira', '83070-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5388, 'Francisco Beltrão', 'Botucatu', 'Pinheirinho', '85603-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5389, 'Foz do Iguaçu', 'Botucatu', 'Jardim Paraná', '85867-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5390, 'Londrina', 'Botucatu', 'Champagnat', '86062-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5391, 'Guarapuava', 'Botucudos', 'Vila Carli', '85040-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5392, 'Apucarana', 'Bourbon', 'Jardim América', '86807-056', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5393, 'Cambé', 'Bourbon', 'Jardim do Café', '86186-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5394, 'Cascavel', 'BR 467', 'Periolo', '85817-010', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5395, 'Curitiba', 'BR-116', 'Tarumã', '82590-400', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5396, 'Curitiba', 'BR-116', 'Pinheirinho', '81690-400', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5397, 'Curitiba', 'BR-116', 'Tatuquara', '81690-500', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5398, 'Curitiba', 'BR-116', 'Jardim Botânico', '81690-100', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5399, 'Curitiba', 'BR-116', 'Atuba', '82590-100', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5400, 'Curitiba', 'BR-116', 'Xaxim', '81690-300', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5401, 'Curitiba', 'BR-116', 'Tarumã', '82590-300', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5402, 'Curitiba', 'BR-116', 'Fanny', '81690-200', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5403, 'Curitiba', 'BR-116', 'Bairro Alto', '82590-200', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5404, 'Colombo', 'BR-116', 'Jardim Palmares', '83412-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5405, 'Colombo', 'BR-116', 'Planta Boros', '83413-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5406, 'Pato Branco', 'BR-158', 'Pagnoncelli', '85509-380', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5407, 'Pato Branco', 'BR-158', 'Industrial', '85504-670', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5408, 'Pato Branco', 'BR-158', 'Trevo Patinhos', '85503-300', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5409, 'Pato Branco', 'BR-158', 'Jardim Primavera', '85502-510', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5410, 'Pato Branco', 'BR-158', 'Vila Esperança', '85503-310', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5411, 'Pato Branco', 'BR-158', 'Trevo da Guarany', '85501-570', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5412, 'Campo Mourão', 'BR-158 Saída para Peabiru', 'Jardim Bandeirantes', '87309-650', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5413, 'Campo Mourão', 'BR-272 Saída para Barbosa Ferraz', 'Vila Teixeira', '87300-490', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5414, 'Campo Mourão', 'BR-272 Saída para Goioerê', 'Distrito Industrial I', '87306-010', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5415, 'Guarapuava', 'BR-277', 'Jardim das Américas', '85045-810', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5416, 'Guarapuava', 'BR-277', 'Jardim das Américas', '85030-230', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5417, 'Guarapuava', 'BR-277', 'Jardim das Américas', '85040-480', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5418, 'Guarapuava', 'BR-277', 'Industrial', '85050-420', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5419, 'Foz do Iguaçu', 'BR-277', 'Vila Pérola', '85865-230', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5420, 'Foz do Iguaçu', 'BR-277', 'Novo Mundo', '85862-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5421, 'Foz do Iguaçu', 'BR-277', 'Parque Presidente', '85863-640', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5422, 'Guarapuava', 'BR-277', 'Jardim das Américas', '85031-350', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5423, 'São José dos Pinhais', 'BR-277', 'São Sebastião', '83075-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5424, 'São José dos Pinhais', 'BR-277', 'Roseira', '83070-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5425, 'São José dos Pinhais', 'BR-277', 'Afonso Pena', '83065-160', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5426, 'São José dos Pinhais', 'BR-277', 'Ipê', '83055-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5427, 'Cascavel', 'BR-277', 'Cascavel Velho', '85818-560', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5428, 'Campo Largo', 'BR-277', 'Bom Jesus', '83605-420', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5429, 'Campo Largo', 'BR-277', 'Jardim Emília', '83606-040', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5430, 'Campo Largo', 'BR-277', 'Vila Nova', '83607-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5431, 'Campo Largo', 'BR-277', 'Rondinha', '83608-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5432, 'Cascavel', 'BR-277', 'Universitário', '85819-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5433, 'Cascavel', 'BR-277', 'Santa Felicidade', '85803-490', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5434, 'Cascavel', 'BR-277', '14 de Novembro', '85804-200', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5435, 'Cascavel', 'BR-277', 'Santos Dumont', '85804-600', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5436, 'Curitiba', 'BR-277 Curitiba Paranaguá', 'Jardim das Américas', '81535-300', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5437, 'Curitiba', 'BR-277 Curitiba Paranaguá', 'Jardim das Américas', '81535-100', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5438, 'Curitiba', 'BR-277 Curitiba Paranaguá', 'Jardim das Américas', '81535-200', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5439, 'Curitiba', 'BR-277 Curitiba Ponta Grossa', 'Mossunguê', '82305-100', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5440, 'Curitiba', 'BR-277 Curitiba Ponta Grossa', 'Cidade Industrial', '82305-200', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5441, 'Cascavel', 'BR-369', 'Cataratas', '85818-640', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5442, 'Apucarana', 'BR-369', 'Parque Industrial Zona Norte', '86806-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5443, 'Arapongas', 'BR-369 Saída para Apucarana', 'Parque Industrial IV', '86706-430', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5444, 'Arapongas', 'BR-369 Saída para Rolândia', 'Conjunto Águias', '86703-735', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5445, 'Campo Mourão', 'BR-369 Saída para Roncador', 'Jardim Capricórnio', '87301-006', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5446, 'Ponta Grossa', 'BR-376', 'Chapada', '84064-290', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5447, 'Ponta Grossa', 'BR-376', 'Colônia Dona Luiza', '84043-450', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5448, 'Ponta Grossa', 'BR-376', 'Colônia Dona Luiza', '84046-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5449, 'São José dos Pinhais', 'BR-376', 'Cruzeiro', '83010-500', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5450, 'São José dos Pinhais', 'BR-376', 'Campina', '83015-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5451, 'São José dos Pinhais', 'BR-376', 'Miringuava', '83090-360', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5452, 'Apucarana', 'BR-376', 'Vila São Francisco', '86813-240', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5453, 'Maringá', 'BR-376 Saída para Sarandi', 'Zona 06', '87045-005', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5454, 'Toledo', 'BR-467', 'Jardim Europa', '85907-060', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5455, 'Cascavel', 'BR-467', 'Brasmadeira', '85814-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5456, 'Cascavel', 'BR-467', 'Brasília', '85815-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5457, 'Cascavel', 'BR-467', 'Cataratas', '85818-650', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5458, 'Cascavel', 'BR-467', 'Canadá', '85813-450', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5459, 'Araucária', 'BR-476', 'Thomaz Coelho', '83707-440', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5460, 'Araucária', 'BR-476', 'Estação', '83705-740', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5461, 'Araucária', 'BR-476', 'Fazenda Velha', '83703-470', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5462, 'Curitiba', 'BR-476', 'Cidade Industrial', '81450-110', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5463, 'Campo Mourão', 'BR-487 Saída para Cruzeiro do Oeste', 'Vila Cândida', '87305-380', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5464, 'Campo Mourão', 'BR-487 Saída para Pitanga', 'Jardim Araucária', '87301-450', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5465, 'Ponta Grossa', 'Bracatinga', 'Contorno', '84061-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5466, 'Piraquara', 'Bracatinga', 'Vila Santa Maria', '83306-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5467, 'Almirante Tamandaré', 'Bracatinga', 'Loteamento Chico Mendes', '83505-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5468, 'Londrina', 'Braga', 'Parque Residencial João Piza', '86041-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5469, 'Colombo', 'Braga', 'Parque Residencial Santa Terezinha', '83408-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5470, 'Foz do Iguaçu', 'Bragança', 'Jardim Ana Cristina', '85861-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5471, 'Maringá', 'Bragança', 'Jardim Universitário', '87020-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5472, 'Guarapuava', 'Bragantina', 'Morro Alto', '85067-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5473, 'Ponta Grossa', 'Brandão Ponce', 'Uvaranas', '84030-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5474, 'Curitiba', 'Brandilina Rosa Vilella Pereira', 'Campina do Siqueira', '80740-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5475, 'Ponta Grossa', 'Brandina Maria Ioungblond', 'Contorno', '84052-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5476, 'Almirante Tamandaré', 'Brás Alves', 'Jardim Areias', '83514-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5477, 'Londrina', 'Brás Cubas', 'Sabará I', '86066-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5478, 'Apucarana', 'Brás Custódio de Carvalho', 'Núcleo Habitacional Heitor S Pinheiro', '86806-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5479, 'Pinhais', 'Brasholanda', 'Planta Guilherme Weiss', '83322-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5480, 'Londrina', 'Brasil', 'Centro', '86010-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5481, 'Guarapuava', 'Brasil', 'Morro Alto', '85067-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5482, 'Foz do Iguaçu', 'Brasil', 'Centro', '85851-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5483, 'Paranavaí', 'Brasil', 'Centro', '87702-320', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5484, 'Pato Branco', 'Brasil', 'Centro', '85501-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5485, 'São José dos Pinhais', 'Brasil', 'Centro', '83005-330', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5486, 'Maringá', 'Brasil', 'Zona 04', '87015-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5487, 'Ponta Grossa', 'Brasil', 'Oficinas', '84036-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5488, 'Maringá', 'Brasil', 'Vila Operária', '87050-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5489, 'Maringá', 'Brasil', 'Zona 04', '87014-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5490, 'Piraquara', 'Brasil', 'Planta York', '83307-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5491, 'Maringá', 'Brasil', 'Zona 01', '87013-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5492, 'Telêmaco Borba', 'Brasil', 'Vila Ana Mari', '84263-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5493, 'Umuarama', 'Brasil', 'Zona VII', '87503-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5494, 'Umuarama', 'Brasil', 'Zona I', '87501-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5495, 'Sarandi', 'Brasil', 'Jardim Independência II', '87113-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5496, 'Apucarana', 'Brasil', 'Jardim Diamantina', '86804-410', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5497, 'Cascavel', 'Brasil', 'Centro', '85801-002', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5498, 'Araucária', 'Brasil', 'Centro', '83702-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5499, 'Campo Largo', 'Brasil', 'Jardim Boa Vista', '83609-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5500, 'Campo Largo', 'Brasil', 'Jardim Rivabem', '83605-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5501, 'Campo Mourão', 'Brasil', 'Jardim Laura', '87300-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5502, 'Campo Mourão', 'Brasil', 'Jardim Laura', '87301-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5503, 'Campo Mourão', 'Brasil', 'Centro', '87302-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5504, 'Cascavel', 'Brasil', 'Coqueiral', '85807-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5505, 'Cascavel', 'Brasil', 'Centro', '85812-002', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5506, 'Araucária', 'Brasil', 'Iguaçu', '83701-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5507, 'Cascavel', 'Brasil', 'Santa Cruz', '85806-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5508, 'Colombo', 'Brasil', 'Jardim Rio Verde', '83405-430', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5509, 'Cascavel', 'Brasil', 'Centro', '85810-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5510, 'Cascavel', 'Brasil', 'Centro', '85801-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5511, 'Cascavel', 'Brasil', 'Gramado', '85816-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5512, 'Cascavel', 'Brasil', 'Centro', '85810-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5513, 'Cascavel', 'Brasil', 'Centro', '85801-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5514, 'Cascavel', 'Brasil', 'Centro', '85812-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5515, 'Cascavel', 'Brasil', 'Centro', '85812-003', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5516, 'Cambé', 'Brasil', 'Centro', '86181-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5517, 'Cambé', 'Brasil', 'Vila Salomé', '86192-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5518, 'Cascavel', 'Brasil', 'Centro', '85812-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5519, 'Londrina', 'Brasil Filho', 'Cambezinho', '86040-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5520, 'Telêmaco Borba', 'Brasil para Cristo', 'Centro', '84261-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5521, 'Ponta Grossa', 'Brasil Pinheiro', 'Orfãs', '84015-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5522, 'Curitiba', 'Brasil Ribas Pinheiro Machado', 'Bacacheri', '82515-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5523, 'Sarandi', 'Brasilândia', 'Jardim Dom Bosco', '87111-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5524, 'Foz do Iguaçu', 'Brasiléia', 'Jardim Ana Cristina', '85861-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5525, 'Campo Largo', 'Brasiléia', 'Vila Dom Pedro', '83608-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5526, 'Guarapuava', 'Brasília', 'Conradinho', '85055-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5527, 'Foz do Iguaçu', 'Brasília', 'Parque Presidente', '85863-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5528, 'Laranjeiras do Sul', 'Brasília', 'Vila Industrial', '85303-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5529, 'Foz do Iguaçu', 'Brasília', 'Conjunto C', '85870-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5530, 'Londrina', 'Brasília', 'Paulista', '86079-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5531, 'Londrina', 'Brasília', 'Nossa Senhora do Desterro', '86025-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5532, 'Londrina', 'Brasília', 'Rodocentro', '86070-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5533, 'Londrina', 'Brasília', 'Lindóia', '86031-770', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5534, 'Londrina', 'Brasília', 'Yara', '86027-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5535, 'Londrina', 'Brasília', 'Indústrias Leves', '86030-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5536, 'Laranjeiras do Sul', 'Brasília', 'Água Verde', '85302-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5537, 'Francisco Beltrão', 'Brasília', 'Presidente Kennedy', '85605-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5538, 'Piraquara', 'Brasília', 'Vila Vicente Macedo', '83303-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5539, 'Piraquara', 'Brasília', 'Jardim Esmeralda', '83301-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5540, 'Pato Branco', 'Brasília', 'Brasília', '85504-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5541, 'Maringá', 'Brasília', 'Parque Residencial Cidade Nova', '87023-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5542, 'Ponta Grossa', 'Brasília', 'Uvaranas', '84025-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5543, 'São José dos Pinhais', 'Brasília', 'Ouro Fino', '83015-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5544, 'Sarandi', 'Brasília', 'Jardim Castelo', '87112-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5545, 'Umuarama', 'Brasília', 'Zona VII', '87503-460', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5546, 'Umuarama', 'Brasília', 'Zona V', '87504-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5547, 'Telêmaco Borba', 'Brasília', 'Macopa', '84263-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5548, 'Cascavel', 'Brasília', 'Cataratas', '85818-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5549, 'Apucarana', 'Brasília', 'Vila Vera Cruz', '86804-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5550, 'Colombo', 'Brasília', 'Parque São Domingos', '83404-670', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5551, 'Campo Mourão', 'Brasília', 'Jardim Conrado', '87308-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5552, 'Cambé', 'Brasília', 'Parque Residencial Cambé', '86191-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5553, 'Curitiba', 'Brasília', 'Novo Mundo', '81020-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5554, 'Curitiba', 'Brasília Alves de Faria de Lara', 'Cidade Industrial', '81250-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5555, 'Almirante Tamandaré', 'Brasília Mussulin de Siqueira', 'Jardim Bela Vista', '83513-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5556, 'Ponta Grossa', 'Brasílianita', 'Neves', '84021-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5557, 'Colombo', 'Brasilina de Oliveira Mariano', 'Jardim Nova Esperança', '83413-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5558, 'Curitiba', 'Brasilino Moura', 'Ahú', '80540-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5559, 'São José dos Pinhais', 'Brasilino Moura Pedroso', 'Ipê', '83055-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5560, 'Curitiba', 'Brasílio Ansay', 'Cidade Industrial', '81170-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5561, 'Curitiba', 'Brasílio Bacellar Filho', 'Tingui', '82620-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5562, 'Colombo', 'Brasílio Bontorin', 'Jardim Esplanada', '83402-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5563, 'São José dos Pinhais', 'Brasílio Cavalim Carvalho', 'Miringuava', '83090-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5564, 'Curitiba', 'Brasílio Cuman', 'São Braz', '82315-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5565, 'São José dos Pinhais', 'Brasílio Dal''Negro', 'Bom Jesus', '83025-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5566, 'Curitiba', 'Brasílio de Lara', 'Bairro Alto', '82820-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5567, 'Curitiba', 'Brasílio Franca', 'Cajuru', '82950-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5568, 'Paranaguá', 'Brasílio Itiberê', 'Vila Guadalupe', '83221-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5569, 'Ponta Grossa', 'Brasílio Itiberê', 'Chapada', '84064-006', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5570, 'Curitiba', 'Brasílio Itiberê', 'Rebouças', '80230-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5571, 'Curitiba', 'Brasílio Itiberê', 'Rebouças', '80250-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5572, 'Curitiba', 'Brasílio Itiberê', 'Rebouças', '80215-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5573, 'Curitiba', 'Brasílio Itiberê', 'Jardim Botânico', '80210-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5574, 'Curitiba', 'Brasílio Itiberê', 'Água Verde', '80240-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5575, 'São José dos Pinhais', 'Brasílio Itiberê da Cunha', 'São Sebastião', '83075-298', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5576, 'Curitiba', 'Brasílio José Betezek', 'São Braz', '82015-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5577, 'Piraquara', 'Brasílio Lecheta', 'Chácara Águas Claras', '83308-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5578, 'Londrina', 'Brasílio Machado', 'Marizia', '86079-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5579, 'Curitiba', 'Brasílio Pery Moreira', 'Pinheirinho', '81880-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5580, 'Curitiba', 'Brasílio Ribas', 'Novo Mundo', '81030-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5581, 'Ponta Grossa', 'Braulina Carneiro de Quadros', 'Ronda', '84051-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5582, 'Telêmaco Borba', 'Braúlio Batista Leal', 'Nossa Senhora de Fátima', '84264-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5583, 'Londrina', 'Bráulio Correa Oliveira', 'Jardim Nova Esperança', '86044-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5584, 'Curitiba', 'Bráulio Faria Prado', 'Abranches', '82130-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5585, 'Londrina', 'Brauxita', 'São Gabriel', '86027-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5586, 'Maringá', 'Braz', 'Zona 08', '87050-430', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5587, 'Curitiba', 'Braz Ribeiro', 'Cidade Industrial', '81310-407', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5588, 'Piraquara', 'Braz Serapião da Silva', 'Jardim Itiberê', '83314-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5589, 'Londrina', 'Brazilino Pereira do Nascimento', 'Assis', '86085-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5590, 'Foz do Iguaçu', 'Brazópolis', 'Parque Imperatriz', '85863-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5591, 'Francisco Beltrão', 'Brejinho', 'Pinheirinho', '85603-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5592, 'Curitiba', 'Breno Arruda', 'Jardim das Américas', '81530-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5593, 'Foz do Iguaçu', 'Breno Azambuja', 'Cohapar III', '85858-520', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5594, 'Colombo', 'Brescia', 'Centro Industrial Mauá', '83413-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5595, 'Curitiba', 'Bréscia', 'Santa Felicidade', '82320-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5596, 'Curitiba', 'Brigadeiro Antônio de Sampaio', 'Jardim Botânico', '80210-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5597, 'São José dos Pinhais', 'Brigadeiro Arthur Carlos Peralta', 'Bom Jesus', '83025-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5598, 'Curitiba', 'Brigadeiro Arthur Carlos Peralta', 'Boa Vista', '82560-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5599, 'Curitiba', 'Brigadeiro Eduardo Gomes', 'Pinheirinho', '81820-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5600, 'Londrina', 'Brigadeiro Franco', 'Fortaleza', '86079-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5601, 'Curitiba', 'Brigadeiro Franco', 'Mercês', '80430-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5602, 'Curitiba', 'Brigadeiro Franco', 'Centro', '80420-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5603, 'Curitiba', 'Brigadeiro Franco', 'Centro', '80250-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5604, 'Curitiba', 'Brigadeiro Franco', 'Rebouças', '80220-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5605, 'Ponta Grossa', 'Brigadeiro Machado de Oliveira', 'Boa Vista', '84073-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5606, 'Guarapuava', 'Brigadeiro Rocha', 'Trianon', '85012-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5607, 'Guarapuava', 'Brigadeiro Rocha', 'Centro', '85010-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5608, 'Guarapuava', 'Brigadeiro Rocha', 'Bonsucesso', '85035-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5609, 'Ponta Grossa', 'Brigadeiro Rocha Loures', 'Jardim Carvalho', '84016-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5610, 'Telêmaco Borba', 'Brigadeiro Rocha Loures', 'Fazenda Limeira', '84270-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5611, 'Curitiba', 'Brigadeiro Rocha Loures', 'Cristo Rei', '80050-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5612, 'Curitiba', 'Brigadeiro-do-Ar Mário Calmon Eppinghaus', 'Juvevê', '80040-090', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5613, 'Londrina', 'Brigham Young', 'Residencial Santa Clara', '86036-595', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5614, 'Londrina', 'Brígida Betoni Lot', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5615, 'Londrina', 'Brilhante', 'Waldemar Hauer', '86030-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5616, 'Maringá', 'Brilhante', 'Jardim Santa Helena', '87083-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5617, 'Telêmaco Borba', 'Brilhante', 'Vila São Francisco de Assis', '84264-630', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5618, 'Umuarama', 'Brilhante', 'Conjunto Residencial Ouro Branco', '87508-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5619, 'Cascavel', 'Brilhante', 'Esmeralda', '85806-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5620, 'Cambé', 'Brilhante', 'Conjunto Habitacional Cristal', '86182-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5621, 'Campo Mourão', 'Brilhante', 'Jardim Tropical I', '87310-247', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5622, 'Arapongas', 'Brilhante-veludo', 'Casa Família Arapongas IV', '86709-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5623, 'Araucária', 'Brinco de Cigana', 'Campina da Barra', '83709-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5624, 'Foz do Iguaçu', 'Brinco de Ouro', 'Parque Morumbi III', '85859-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5625, 'Toledo', 'Britânia', 'Jardim Paulista', '85910-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5626, 'Toledo', 'Britânia', 'Vila Becker', '85902-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5627, 'Londrina', 'Brochado da Rocha', 'Jardim Tatiani', '86070-640', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5628, 'Foz do Iguaçu', 'Brodoski', 'Jardim Santa Rosa', '85869-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5629, 'Foz do Iguaçu', 'Brodoski', 'Conjunto A', '85860-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5630, 'Ponta Grossa', 'Bronislau Delezuk', 'Ronda', '84051-200', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5631, 'Curitiba', 'Bronislau Lupinski', 'Santa Cândida', '82640-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5632, 'Piraquara', 'Bronislau Schved', 'Vila Franca', '83305-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5633, 'Curitiba', 'Bronislau Sitorski', 'Cidade Industrial', '81350-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5634, 'Campo Mourão', 'Bronislav Wronski', 'Jardim Aeroporto', '87310-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5635, 'Apucarana', 'Bronze', 'Parque Industrial Zona Norte', '86806-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5636, 'Foz do Iguaçu', 'Brotas', 'Chácara Dom Emílio', '85853-726', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5637, 'Cascavel', 'Brotoejas', 'Guarujá', '85804-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5638, 'Telêmaco Borba', 'Brumado', 'Área 06', '84271-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5639, 'Cascavel', 'Bruna Costa', 'Floresta', '85814-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5640, 'Curitiba', 'Bruno Alfredo Schindler', 'Fazendinha', '81320-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5641, 'Curitiba', 'Bruno Arthur Hanke', 'Sítio Cercado', '81920-738', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5642, 'Araucária', 'Bruno da Rocha', 'Boqueirão', '83704-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5643, 'Toledo', 'Bruno Dante Palma', 'Residencial Santa Clara', '85907-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5644, 'Curitiba', 'Bruno Dressler', 'Tatuquara', '81470-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5645, 'Curitiba', 'Bruno Filgueira', 'Batel', '80440-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5646, 'Curitiba', 'Bruno Filgueira', 'Bigorrilho', '80710-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5647, 'Curitiba', 'Bruno Filgueira', 'Bigorrilho', '80730-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5648, 'Curitiba', 'Bruno Filgueira', 'Água Verde', '80240-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5649, 'Curitiba', 'Bruno João da Silva', 'Pilarzinho', '82110-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5650, 'Curitiba', 'Bruno Kotelak', 'Tatuquara', '81470-205', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5651, 'Foz do Iguaçu', 'Bruno Krummenauer', 'Jardim Panorama', '85856-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5652, 'Curitiba', 'Bruno Lobo', 'Bairro Alto', '82820-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5653, 'Curitiba', 'Bruno Mertens', 'Barreirinha', '82210-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5654, 'Araucária', 'Bruno Pilato dos Santos', 'Boqueirão', '83704-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5655, 'Curitiba', 'Bruno Pomim', 'Santa Cândida', '82640-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5656, 'Londrina', 'Bruno Próspero Parolari', 'Jardim dos Alpes I', '86075-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5657, 'Curitiba', 'Bruno Schaffer', 'Vista Alegre', '80820-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5658, 'Ponta Grossa', 'Bruno Scheibel', 'Cará-cará', '84033-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5659, 'Foz do Iguaçu', 'Bruno Sther', 'Vila São Sebastião', '85870-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5660, 'Toledo', 'Bruno Velter', 'Conjunto Habitacional São Francisco', '85915-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5661, 'Foz do Iguaçu', 'Brusque', 'Jardim Lancaster V', '85869-727', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5662, 'São José dos Pinhais', 'Brusque', 'São Sebastião', '83075-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5663, 'Cascavel', 'Brusque', 'Santa Cruz', '85806-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5664, 'Foz do Iguaçu', 'Bruxelas', 'Jardim Alice I', '85858-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5665, 'Telêmaco Borba', 'Bruxelas', 'Nossa Senhora do Perpétuo Socorro', '84265-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5666, 'Almirante Tamandaré', 'Bucanvil', 'Loteamento Nova Morada', '83504-706', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5667, 'Colombo', 'Bucareste', 'Vila Alto da Cruz', '83405-540', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5668, 'Curitiba', 'Buda', 'Santa Cândida', '82630-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5669, 'Colombo', 'Budapeste', 'Vila Santa Clara', '83405-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5670, 'Foz do Iguaçu', 'Buenos Aires', 'Jardim Alice II', '85858-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5671, 'Guarapuava', 'Buenos Aires', 'Santana', '85070-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5672, 'Francisco Beltrão', 'Buenos Aires', 'Miniguaçu', '85605-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5673, 'Paranaguá', 'Buenos Aires', 'Parque Agari', '83215-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5674, 'Maringá', 'Buenos Aires', 'Vila Morangueira', '87030-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5675, 'Telêmaco Borba', 'Buenos Aires', 'Nossa Senhora de Fátima', '84264-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5676, 'Cascavel', 'Buenos Aires', 'Periolo', '85817-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5677, 'Colombo', 'Buenos Aires', 'Jardim Monza', '83406-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5678, 'Curitiba', 'Buenos Aires', 'Batel', '80250-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5679, 'Ponta Grossa', 'Bugreiro', 'Contorno', '84061-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5680, 'Guarapuava', 'Bulgária', 'Morro Alto', '85063-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5681, 'Umuarama', 'Bulgária', 'Jardim Campo Belo', '87507-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5682, 'Cambé', 'Bulgária', 'Jardim Morada do Sol', '86181-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5683, 'Foz do Iguaçu', 'Buritama', 'Jardim Santa Rosa', '85869-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5684, 'Francisco Beltrão', 'Buriti', 'Pinheirinho', '85603-290', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5685, 'Pinhais', 'Buriti', 'Jardim Pio XII', '83328-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5686, 'Ponta Grossa', 'Buriti', 'Contorno', '84061-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5687, 'Maringá', 'Buriti', 'Conjunto Residencial Parigot de Souza', '87047-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5688, 'Sarandi', 'Buriti', 'Parque Residencial Nova Aliança', '87111-747', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5689, 'Cascavel', 'Buriti', 'Brasmadeira', '85814-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5690, 'Cambé', 'Buriti', 'Jardim Alvorada', '86191-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5691, 'Curitiba', 'Buriti', 'Uberaba', '81540-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5692, 'Curitiba', 'Burle Marx', 'Bigorrilho', '82010-715', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5693, 'Curitiba', 'Buruti', 'Uberaba', '81560-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5694, 'São José dos Pinhais', 'Butantã', 'Zaniolo', '83025-745', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5695, 'Londrina', 'Butiá', 'Marabá', '86035-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5696, 'Telêmaco Borba', 'Butiá', 'Área 01', '84268-030', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5697, 'Curitiba', 'Butiá', 'Uberaba', '81560-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5698, 'Toledo', 'Butiás', 'Boa Esperança', '85909-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5699, 'Ponta Grossa', 'Butieiro', 'Contorno', '84061-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5700, 'Apucarana', 'Byngton', 'Vila Nova', '86812-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5701, 'Apucarana', 'Byngton', 'Jardim Trabalhista', '86807-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5702, 'Foz do Iguaçu', 'C', 'Conjunto C', '85870-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5703, 'Foz do Iguaçu', 'C', 'Conjunto Residencial Yang Ming', '85854-266', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5704, 'Paranavaí', 'C', 'Jardim São Cristóvão', '87702-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5705, 'Ponta Grossa', 'C', 'Uvaranas', '84031-287', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5706, 'Ponta Grossa', 'C', 'Olarias', '84035-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5707, 'Ponta Grossa', 'C', 'Chapada', '84064-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5708, 'Ponta Grossa', 'C', 'Jardim Carvalho', '84016-715', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5709, 'Piraquara', 'C', 'Chácara Águas Claras', '83309-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5710, 'Ponta Grossa', 'C', 'Contorno', '84060-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5711, 'Maringá', 'C', 'Vila Vardelina', '87080-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5712, 'Ponta Grossa', 'C', 'Cará-cará', '84043-436', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5713, 'Ponta Grossa', 'C', 'Uvaranas', '84032-477', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5714, 'Paranavaí', 'C', 'Vila Operária', '87708-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5715, 'Paranavaí', 'C', 'Vila Alta', '87708-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5716, 'Ponta Grossa', 'C', 'Contorno', '84060-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5717, 'Ponta Grossa', 'C', 'Chapada', '84063-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5718, 'Umuarama', 'C', 'Parque Industrial II', '87507-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5719, 'Umuarama', 'C', 'Parque Dom Pedro I', '87508-016', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5720, 'Umuarama', 'C', 'Jardim Carolina', '87501-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5721, 'Umuarama', 'C', 'Núcleo Cruzeiro', '87509-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5722, 'Castro', 'C', 'Jardim Social Arapongas', '84174-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5723, 'Campo Mourão', 'C', 'Distrito Industrial I', '87306-470', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5724, 'Castro', 'C', 'Vila do Rosário', '84168-069', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5725, 'Campo Largo', 'C', 'Vila Santo Onofre', '83608-126', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5726, 'Castro', 'C', 'Invernada do Matadouro', '84174-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5727, 'Campo Largo', 'C', 'Jardim Três Rios', '83603-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5728, 'Campo Largo', 'C', 'Vila Torres I', '83609-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5729, 'Campo Largo', 'C', 'Jardim Tropical', '83602-056', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5730, 'Campo Largo', 'C', 'Popular Nova', '83602-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5731, 'Campo Largo', 'C', 'Vila Antônio Seguro', '83602-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5732, 'Campo Largo', 'C', 'Jardim Emília', '83607-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5733, 'Almirante Tamandaré', 'C', 'Jardim São Caetano', '83507-152', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5734, 'Castro', 'C', 'Jardim Bela Vista', '84165-417', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5735, 'Campo Largo', 'C', 'Vila Alzira', '83608-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5736, 'Almirante Tamandaré', 'C', 'Jardim Marrocos', '83511-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5737, 'Arapongas', 'C', 'Jardim Caravelle', '86702-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5738, 'Foz do Iguaçu', 'Caaguaçu', 'Vila Paraguaia', '85864-250', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5739, 'Foz do Iguaçu', 'Cabaliana', 'Três Lagoas', '85862-436', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5740, 'Foz do Iguaçu', 'Cabeçudas', 'Parque Residencial Três Fronteiras', '85855-607', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5741, 'Foz do Iguaçu', 'Cabedelo', 'Jardim Curitibano IV', '85869-697', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5742, 'Ponta Grossa', 'Cabiúna', 'Contorno', '84061-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5743, 'Paranaguá', 'Cabo Alceu Lobo', 'Serraria do Rocha', '83221-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5744, 'Araucária', 'Cabo Antônio Machado', 'Sabiá', '83708-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5745, 'Curitiba', 'Cabo Cornélio de Souza Martins', 'Uberaba', '81590-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5746, 'Foz do Iguaçu', 'Cabo Efigênio Aparecido Viana', 'Jardim Iguaçu', '85853-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5747, 'Ponta Grossa', 'Cabo Elias dos Santos', 'Uvaranas', '84015-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5748, 'Francisco Beltrão', 'Cabo Frio', 'Pinheirinho', '85603-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5749, 'Guarapuava', 'Cabo Frio', 'Boqueirão', '85020-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5750, 'Foz do Iguaçu', 'Cabo Frio', 'Jardim Lancaster II', '85869-360', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5751, 'Londrina', 'Cabo Frio', 'Jardim Alvorada', '86062-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5752, 'Curitiba', 'Cabo Frio', 'Campo Comprido', '81240-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5753, 'Francisco Beltrão', 'Cabo Hercílio Guedes', 'Pinheirinho', '85606-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5754, 'Paranaguá', 'Cabo João dos Santos', 'Vila Rute', '83221-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5755, 'São José dos Pinhais', 'Cabo João Fagundes Machado', 'Cruzeiro', '83010-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5756, 'Guarapuava', 'Cabo Kennedy', 'Alto da XV', '85065-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5757, 'Sarandi', 'Cabo Kennedy', 'Jardim Universal', '87114-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5758, 'Londrina', 'Cabo Luiz Budziak', 'Roseira', '86041-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5759, 'Cascavel', 'Cabo Manoel Bire Aguella', 'Santa Felicidade', '85803-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5760, 'Foz do Iguaçu', 'Cabo Nicanor Francisco de Mattos', 'Jardim Marisa', '85867-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5761, 'Londrina', 'Cabo Valdomiro Volovicz', 'Residencial Abussafe', '86037-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5762, 'Guarapuava', 'Cabo Verde', 'Industrial', '85053-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5763, 'Londrina', 'Cabo Verde', 'São Cristóvão', '86025-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5764, 'Londrina', 'Caboclinho', 'Conjunto Habitacional Violim', '86084-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5765, 'Arapongas', 'Caboclinho', 'Jardim Baroneza', '86706-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5766, 'Arapongas', 'Caboclinho-de-peito-castanho', 'Parque Industrial II', '86703-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5767, 'Campo Largo', 'Cabral', 'Jardim São Vicente', '83602-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5768, 'Curitiba', 'Cabral', 'Centro', '80410-210', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5769, 'Curitiba', 'Cabral', 'Cabral', '80035-280', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5770, 'Foz do Iguaçu', 'Cabrália', 'Loteamento Menger', '85862-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5771, 'Londrina', 'Cabriúva', 'Marumbi', '86071-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5772, 'Telêmaco Borba', 'Cabriúva', 'Área 01', '84268-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5773, 'Foz do Iguaçu', 'Caburé', 'Conjunto A', '85866-090', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5774, 'Ponta Grossa', 'Caburé', 'Colônia Dona Luiza', '84046-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5775, 'Arapongas', 'Caburé', 'Jardim Lorena', '86707-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5776, 'Arapongas', 'Caburé-canela', 'Jardim São Rafael', '86703-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5777, 'Arapongas', 'Caburézinho', 'Jardim Monte Carlo II', '86704-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5778, 'Foz do Iguaçu', 'Caçador', 'Jardim das Palmeiras', '85869-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5779, 'Francisco Beltrão', 'Caçador', 'Pinheirinho', '85603-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5780, 'São José dos Pinhais', 'Caçador', 'São Sebastião', '83075-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5781, 'Almirante Tamandaré', 'Caçador', 'Jardim Apucarana', '83505-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5782, 'Almirante Tamandaré', 'Caçador', 'Planta Bela Vista', '83514-320', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5783, 'Arapongas', 'Caçador-de-árvore', 'Jardim Colúmbia I', '86707-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5784, 'Campo Mourão', 'Cacanjure', 'Jardim Pio XII', '87306-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5785, 'Foz do Iguaçu', 'Cação', 'Profilurb I', '85855-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5786, 'Foz do Iguaçu', 'Caçapava', 'Jardim Duarte', '85861-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5787, 'Arapongas', 'Cacatua', 'Vila Aparecida', '86707-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5789, 'Cascavel', 'Cacequi', 'Canadá', '85813-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5790, 'Foz do Iguaçu', 'Cáceres', 'Jardim das Palmeiras', '85869-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5791, 'Arapongas', 'Cachimbó', 'Conjunto Flamingos III', '86703-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5792, 'Foz do Iguaçu', 'Cachoeira', 'Jardim Belvedere II', '85867-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5793, 'Telêmaco Borba', 'Cachoeira', 'Área 02', '84267-260', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5794, 'Almirante Tamandaré', 'Cachoeira', 'Parque Uracap', '83505-138', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5795, 'Almirante Tamandaré', 'Cachoeira', 'Vila Alto Pinheiros', '83503-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5796, 'Foz do Iguaçu', 'Cacilda Becker', 'Jardim Cláudia', '85852-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5797, 'Londrina', 'Cacilda Becker', 'Lilian', '86015-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5798, 'Cascavel', 'Cacilda Becker', 'Brasília', '85815-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5799, 'Arapongas', 'Cacilda Becker', 'Centro', '86701-740', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5800, 'Curitiba', 'Cacilda Becker', 'Batel', '80420-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5801, 'Londrina', 'Cacilda Nasralla Neme', 'Conjunto Habitacional José Garcia Molina', '86080-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5802, 'Foz do Iguaçu', 'Cacique', 'Jardim Lancaster', '85869-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5803, 'Araucária', 'Cactus', 'Campina da Barra', '83709-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5804, 'Ponta Grossa', 'Cades', 'Jardim Carvalho', '84016-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5805, 'Curitiba', 'Cadete Reno Guido Longo Júnior', 'Boqueirão', '81650-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5806, 'Maringá', 'Cadis', 'Loteamento Madrid', '87053-528', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5807, 'Cambé', 'Caetani Campi', 'Jardim Santa Mônica', '86184-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5808, 'Curitiba', 'Caetano Alessi', 'Butiatuvinha', '82400-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5809, 'Curitiba', 'Caetano Braga Cortes', 'Santa Cândida', '82720-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5810, 'Paranaguá', 'Caetano Gomes Corrêa', 'Oceania', '83203-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5811, 'Curitiba', 'Caetano Granato', 'Pilarzinho', '82120-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5812, 'Apucarana', 'Caetano Lopes Pineda', 'Vila São Luiz', '86804-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5813, 'Curitiba', 'Caetano Marchesini', 'Portão', '81070-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5814, 'Guarapuava', 'Caetano Munhoz da Rocha', 'Vila Bela', '85027-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5815, 'Londrina', 'Caetano Munhoz da Rocha', 'Bom Retiro', '86025-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5816, 'Paranaguá', 'Caetano Munhoz da Rocha', 'Padre Jackson', '83221-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5817, 'Pato Branco', 'Caetano Munhoz da Rocha', 'Menino Deus', '85502-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5818, 'Campo Largo', 'Caetano Munhoz da Rocha', 'Loteamento Ouro Verde I', '83606-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5819, 'Curitiba', 'Caetano Munhoz da Rocha Filho', 'Pilarzinho', '80820-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5820, 'Londrina', 'Caetano Otranto', 'Shangri-La', '86070-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5821, 'Apucarana', 'Caetano Peres Clabonde', 'Parque Industrial Zona Oeste II', '86800-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5822, 'Castro', 'Caetano Ribeiro de Moraes', 'Jardim das Araucárias', '84174-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5823, 'Sarandi', 'Caetano Senhorini', 'Vera Cruz', '87111-766', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5824, 'Toledo', 'Caetano Severino Perin', 'Conjunto Barão do Rio Branco II', '85905-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5825, 'Toledo', 'Caetano Severino Perin', 'Centro', '85900-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5826, 'Cambé', 'Caetano Sitta', 'Parque Residencial Ana Rosa', '86183-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5827, 'Ponta Grossa', 'Caetano Vendrami', 'Cará-cará', '84043-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5828, 'Londrina', 'Caetano Vicentini', 'Conjunto Guilherme Braga de Abreu Pires', '86079-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5829, 'Francisco Beltrão', 'Caetê', 'São Miguel', '85602-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5830, 'Curitiba', 'Caetê', 'Prado Velho', '80220-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5831, 'Londrina', 'Caetés', 'Matarazzo', '86026-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5832, 'Umuarama', 'Caetés', 'Zona VI', '87503-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5833, 'Telêmaco Borba', 'Caetés', 'Socomim', '84266-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5834, 'Cambé', 'Caetés', 'Jardim Tupi', '86183-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5835, 'Londrina', 'Café Arabica', 'Conjunto Café', '86081-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5836, 'Londrina', 'Café Bourbon', 'Conjunto Café', '86081-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5837, 'Londrina', 'Café Catuaí', 'Conjunto Café', '86081-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5838, 'Londrina', 'Café Caturra', 'Conjunto Café', '86081-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5839, 'Londrina', 'Café Cereja', 'Conjunto Café', '86081-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5840, 'Londrina', 'Café com Leite', 'Conjunto Café', '86081-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5841, 'Londrina', 'Café Excelso', 'Conjunto Café', '86081-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5842, 'Guarapuava', 'Café Filho', 'Boqueirão', '85020-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5843, 'Foz do Iguaçu', 'Café Filho', 'Parque Presidente', '85863-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5844, 'Pinhais', 'Café Filho', 'Vila Amélia', '83330-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5845, 'Apucarana', 'Café Filho', 'Vila Formosa', '86802-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5846, 'Cascavel', 'Café Filho', 'Presidente', '85818-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5847, 'Londrina', 'Café Libérica', 'Conjunto Café', '86081-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5848, 'Londrina', 'Café Moca', 'Conjunto Café', '86081-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5849, 'Londrina', 'Café Mundo Novo', 'Conjunto Café', '86081-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5850, 'Londrina', 'Café Ouro Verde', 'Conjunto Café', '86081-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5851, 'Londrina', 'Café Robusta', 'Conjunto Café', '86081-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5852, 'Londrina', 'Café Rubiácea', 'Conjunto Café', '86081-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5853, 'Londrina', 'Café Solúvel', 'Conjunto Café', '86081-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5854, 'Londrina', 'Café Sumatra', 'Conjunto Café', '86081-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5855, 'Londrina', 'Café Supremo', 'Conjunto Café', '86081-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5856, 'Guarapuava', 'Cafeara', 'Boqueirão', '85023-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5857, 'Ponta Grossa', 'Cafeara', 'Nova Rússia', '84053-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5858, 'Curitiba', 'Cafeara', 'Sítio Cercado', '81910-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5859, 'Guarapuava', 'Cafelândia', 'Boqueirão', '85023-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5860, 'Foz do Iguaçu', 'Cafezal', 'Loteameto Dona Amanda', '85853-739', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5861, 'Sarandi', 'Cafezal', 'Parque Residencial Nova Aliança', '87111-749', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5862, 'Curitiba', 'Cagliari', 'São João', '82030-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5863, 'Laranjeiras do Sul', 'Caiapó', 'São Francisco', '85303-225', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5864, 'Arapongas', 'Caiapó', 'Aricanduva', '86706-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5865, 'Londrina', 'Caiapós', 'Jardim São Paulo', '86026-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5866, 'Apucarana', 'Caiapós', 'Núcleo Habitacional Colonial', '86812-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5867, 'Francisco Beltrão', 'Caiçara', 'Pinheirinho', '85603-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5868, 'Cascavel', 'Caiçaras', 'Santa Cruz', '85806-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5869, 'Francisco Beltrão', 'Caicó', 'São Miguel', '85602-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5870, 'Colombo', 'Caicós', 'Vila Marcelina', '83404-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5871, 'Foz do Iguaçu', 'Caieiras', 'Jardim Copacabana', '85856-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5872, 'Foz do Iguaçu', 'Caigangues', 'Jardim Tarobá', '85856-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5873, 'Cascavel', 'Caigangues', 'Santo Onofre', '85806-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5874, 'Cambé', 'Caingangues', 'Jardim Tupi', '86183-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5875, 'Londrina', 'Caingas', 'Vila Ziober', '86026-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5876, 'Curitiba', 'Caio Graccho Krueger', 'Alto Boqueirão', '81720-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5877, 'Curitiba', 'Caio Gracco', 'Barreirinha', '82700-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5878, 'Londrina', 'Caio Vioto', 'Tomy', '86036-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5879, 'Foz do Iguaçu', 'Caiobá', 'Jardim Copacabana', '85856-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5880, 'Londrina', 'Caiobá', 'Nóbrega', '86025-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5881, 'Umuarama', 'Caiobá', 'Jardim Tamoio', '87505-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5882, 'Telêmaco Borba', 'Caiobá', 'Vila Arcina', '84268-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5883, 'Cascavel', 'Caiobá', 'Periolo', '85817-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5884, 'Cambé', 'Caiobá', 'Chácara Santa Maria', '86189-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5885, 'Curitiba', 'Caiobá', 'Cajuru', '82960-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5886, 'Foz do Iguaçu', 'Cairara', 'Conjunto A', '85861-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5887, 'Pinhais', 'Cairo', 'Vl Dona Guiomar', '83320-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5888, 'Cascavel', 'Caiua', 'Brasmadeira', '85814-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5889, 'Londrina', 'Cajá', 'Panorama', '86035-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5890, 'Paranaguá', 'Cajá', 'Vila São Vicente', '83209-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5891, 'Curitiba', 'Cajá-manga', 'Uberaba', '81560-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5892, 'Curitiba', 'Cajá-manga', 'Uberaba', '81550-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5893, 'Londrina', 'Cajarana', 'Leonor', '86071-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5894, 'Ponta Grossa', 'Cajarana', 'Contorno', '84061-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5895, 'Foz do Iguaçu', 'Cajati', 'Jardim Curitibano', '85869-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5896, 'Paranaguá', 'Caju', 'Vila São Vicente', '83209-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5897, 'Maringá', 'Caju', 'Conjunto Residencial Planville', '87080-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5898, 'Maringá', 'Cajubi', 'Jardim Pássaros', '87075-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5899, 'Arapongas', 'Cajubi', 'Jardim Cultura', '86707-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5900, 'Curitiba', 'Cajubi', 'Santa Felicidade', '82015-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5901, 'Campo Mourão', 'Cajueira', 'Jardim Lar Paraná', '87305-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5902, 'Foz do Iguaçu', 'Cajueiro', 'Jardim Dona Fátima Osman', '85856-687', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5903, 'Foz do Iguaçu', 'Cajueiro', 'Chácara Dom Emílio', '85853-728', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5904, 'Guarapuava', 'Cajueiro', 'São Cristóvão', '85060-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5905, 'Maringá', 'Cajueiro', 'Conjunto João de Barro Cidade Canção', '87053-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5906, 'Londrina', 'Cajueiros', 'Casarin', '86035-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5907, 'Guarapuava', 'Cajuru', 'Boqueirão', '85022-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5908, 'Arapongas', 'Calafate', 'Vila Industrial', '86706-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5909, 'Arapongas', 'Calamão', 'Jardim Primavera', '86702-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5910, 'Londrina', 'Calandra', 'Conjunto Habitacional Violim', '86088-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5911, 'Arapongas', 'Calandra', 'Vila Cascata', '86703-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5912, 'Arapongas', 'Calau', 'Jardim do Café', '86706-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5913, 'Ponta Grossa', 'Calçadão', 'Contorno', '84061-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5914, 'Toledo', 'Caldas Júnior', 'Walter Fontana', '85909-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5915, 'Pinhais', 'Calhandra', 'Conjunto Residencial Renato Bonilauri', '83325-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5916, 'Pinhais', 'Calhandra', 'Jardim Fênix', '83326-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5917, 'Pinhais', 'Caliandra', 'Jardim Pio XII', '83328-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5918, 'Francisco Beltrão', 'Califórnia', 'Antônio de Paiva Cantelmo', '85603-126', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5919, 'Foz do Iguaçu', 'Califórnia', 'Jardim Belvedere II', '85867-625', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5920, 'Ponta Grossa', 'Califórnia', 'Olarias', '84026-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5921, 'Maringá', 'Califórnia', 'Jardim Los Angeles', '87080-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5922, 'Maringá', 'Califórnia', 'Jardim Indaiá', '87070-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5923, 'Sarandi', 'Califórnia', 'Jardim Califórnia', '87112-515', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5924, 'Toledo', 'Califórnia', 'Vila Industrial', '85904-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5925, 'Telêmaco Borba', 'Califórnia', 'Nossa Senhora de Fátima', '84264-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5926, 'Umuarama', 'Califórnia', 'Jardim San Martim', '87508-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5927, 'Campo Largo', 'Califórnia', 'Vila Rivabem', '83605-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5928, 'Cambé', 'Califórnia', 'Jardim Golden Park', '86186-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5929, 'Colombo', 'Califórnia', 'Jardim Guaraituba', '83410-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5930, 'Curitiba', 'Califórnia', 'Sítio Cercado', '81900-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5931, 'Paranaguá', 'Calim Paulo', 'Parque São João', '83212-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5932, 'Araucária', 'Calistemon', 'Campina da Barra', '83709-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5933, 'Curitiba', 'Calisto Cumin', 'Santa Felicidade', '82320-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5934, 'Curitiba', 'Calistrat Coluciuc', 'Santa Cândida', '82650-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5935, 'Curitiba', 'Calixto de Jesus', 'Tingui', '82620-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5936, 'Curitiba', 'Calixto Razolini', 'Portão', '81070-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5937, 'Piraquara', 'Calondela', 'Vila Santa Maria', '83306-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5938, 'Londrina', 'Calu', 'Jacomo Violin', '86088-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5939, 'Arapongas', 'Calu', 'Centro', '86701-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5940, 'Londrina', 'Camacam', 'João Paz', '86026-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5941, 'Cascavel', 'Camaiurás', 'Santa Cruz', '85806-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5942, 'Sarandi', 'Camapua', 'Jardim Esplanada', '87112-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5943, 'Umuarama', 'Camaqua', 'Zona VII', '87503-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5944, 'Cascavel', 'Câmara Júnior', 'Recanto Tropical', '85807-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5945, 'Curitiba', 'Câmara Júnior', 'Jardim das Américas', '81540-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5946, 'Foz do Iguaçu', 'Camarão', 'Profilurb I', '85855-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5947, 'Colombo', 'Camargo', 'Jardim Santa Cândida', '83404-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5948, 'Pinhais', 'Camarões', 'Jardim Hipódromo', '83320-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5949, 'Arapongas', 'Cambacica', 'Jardim Bandeirantes', '86703-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5950, 'Foz do Iguaçu', 'Cambará', 'Jardim Paraná', '85867-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5951, 'Guarapuava', 'Cambará', 'Jardim das Américas', '85030-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5952, 'Londrina', 'Cambará', 'Centro', '86010-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5953, 'Pinhais', 'Cambará', 'Jardim Alto Tarumã', '83325-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5954, 'São José dos Pinhais', 'Cambará', 'Cidade Jardim', '83035-230', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5955, 'Ponta Grossa', 'Cambará', 'Nova Rússia', '84053-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5956, 'Telêmaco Borba', 'Cambará', 'Bela Vista do Paraíso', '84262-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5957, 'Campo Largo', 'Cambará', 'Jardim Guairacá', '83608-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5958, 'Cascavel', 'Cambará', 'Parque Verde', '85807-677', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5959, 'Colombo', 'Cambará', 'Jardim Guaraituba', '83410-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5960, 'Araucária', 'Cambará', 'Estação', '83705-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5961, 'Almirante Tamandaré', 'Cambará', 'Loteamento Chico Mendes', '83505-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5962, 'Curitiba', 'Cambará', 'Juvevê', '80030-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5963, 'Londrina', 'Cambaxirra', 'Jacomo Violin', '86088-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5964, 'Arapongas', 'Cambaxirra', 'Vila Araponguinha', '86705-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5965, 'Londrina', 'Cambé', 'Judith', '86061-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5966, 'São José dos Pinhais', 'Cambé', 'Afonso Pena', '83045-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5967, 'Maringá', 'Cambé', 'Zona 08', '87050-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5968, 'Pinhais', 'Cambé', 'Jardim Dona Joaquina II', '83325-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5969, 'Paranaguá', 'Cambé', 'Emboguaçu', '83209-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5970, 'Umuarama', 'Cambé', 'Zona II', '87502-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5971, 'Apucarana', 'Cambé', 'Centro', '86800-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5972, 'Colombo', 'Cambé', 'Jardim Cristina II', '83410-685', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5973, 'Curitiba', 'Cambé', 'Sítio Cercado', '81900-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5974, 'Londrina', 'Cambira', 'Indústrias', '86043-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5975, 'Guarapuava', 'Cambira', 'Boqueirão', '85020-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5976, 'Maringá', 'Cambira', 'Zona 08', '87050-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5977, 'Apucarana', 'Cambira', 'Núcleo Habitacional Nossa Senhora Aparecida', '86801-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5978, 'Curitiba', 'Cambira', 'Alto Boqueirão', '81830-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5979, 'Telêmaco Borba', 'Camboja', 'Vila Esperança', '84272-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5980, 'Foz do Iguaçu', 'Camboriú', 'Loteamento Witt', '85862-536', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5981, 'Piraquara', 'Camboriú', 'Planta São Tiago', '83306-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5982, 'Umuarama', 'Camboriú', 'Jardim Birigüi', '87505-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5983, 'Cambé', 'Camboriú', 'Chácara Santa Maria', '86189-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5984, 'Curitiba', 'Cambuca', 'Uberaba', '81550-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5985, 'Londrina', 'Cambui', 'Damasco', '86035-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5986, 'Ponta Grossa', 'Cambui', 'Neves', '84020-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5987, 'Toledo', 'Cambui', 'Pacaembu', '85910-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5988, 'Telêmaco Borba', 'Cambui', 'Área 01', '84268-130', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5989, 'Umuarama', 'Cambui', 'Zona I', '87503-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5990, 'Apucarana', 'Cambui', 'Jardim Menegazzo', '86802-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5991, 'Foz do Iguaçu', 'Cambuquira', 'Jardim Santa Rosa', '85869-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5992, 'Londrina', 'Cambuquira', 'Amaro', '86062-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5993, 'Ponta Grossa', 'Camélia', 'Contorno', '84061-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5994, 'Colombo', 'Camerum', 'Planta Santa Úrsula', '83405-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5995, 'Cambé', 'Cames', 'Jardim Tupi', '86183-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5996, 'Londrina', 'Camila Kauam', 'Jardim Alemanha', '86031-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5997, 'Curitiba', 'Camile Flammarion', 'Barreirinha', '82700-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5998, 'Londrina', 'Camille Flammarion', 'Ok', '86040-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (5999, 'Curitiba', 'Camillo Marina', 'Santa Felicidade', '82320-015', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6000, 'Ponta Grossa', 'Camilo Augusto Pires', 'Uvaranas', '84030-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6001, 'Curitiba', 'Camilo Bueno', 'Tatuquara', '81480-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6002, 'Ponta Grossa', 'Camilo Castelo Branco', 'Colônia Dona Luiza', '84045-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6003, 'Curitiba', 'Camilo Castelo Branco', 'Guaíra', '81010-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6004, 'Pinhais', 'Camilo de Lellis', 'Jardim Pinhais', '83323-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6005, 'Curitiba', 'Camilo Haj Mussi', 'Santa Cândida', '82640-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6006, 'São José dos Pinhais', 'Camilo Pereira de Lima', 'Roseira', '83070-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6007, 'Foz do Iguaçu', 'Camilo Royers', 'Jardim Porto Belo', '85867-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6008, 'Londrina', 'Camilo Simões', 'Colinas', '86056-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6009, 'Arapongas', 'Caminheiro', 'Jardim Coroados', '86707-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6010, 'Sarandi', 'Caminho de Damasco', 'Parque Residencial Bom Pastor', '87114-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6011, 'Arapongas', 'Camiranga', 'Jardim Cultura', '86707-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6012, 'Telêmaco Borba', 'Camões', 'Jardim Bonavila', '84264-140', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6013, 'Curitiba', 'Camões', 'Alto da Rua XV', '80040-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6014, 'Curitiba', 'Camões', 'Cristo Rei', '80050-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6015, 'Londrina', 'Camomila', 'Jardim Novo Sabará', '86066-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6016, 'Maringá', 'Camomila', 'Conjunto João de Barro Cidade Canção', '87053-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6017, 'Foz do Iguaçu', 'Camorim', 'Três Lagoas', '85862-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6018, 'Telêmaco Borba', 'Campina Alta', 'Área 02', '84267-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6019, 'Curitiba', 'Campina da Lagoa', 'Alto Boqueirão', '81830-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6020, 'Curitiba', 'Campina do Siqueira', 'Campina do Siqueira', '80730-470', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6021, 'Maringá', 'Campina Grande', 'Vila Morangueira', '87030-480', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6022, 'Ponta Grossa', 'Campina Grande do Sul', 'Oficinas', '84036-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6023, 'Almirante Tamandaré', 'Campina Grande do Sul', 'Loteamento Chico Mendes', '83505-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6024, 'Almirante Tamandaré', 'Campina Grande do Sul', 'Jardim Roma', '83504-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6025, 'Curitiba', 'Campina Grande do Sul', 'Sítio Cercado', '81910-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6026, 'Londrina', 'Campinas', 'Amaro', '86062-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6027, 'Foz do Iguaçu', 'Campinas', 'Jardim Petropólis', '85868-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6028, 'Guarapuava', 'Campinas', 'Boqueirão', '85022-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6029, 'Francisco Beltrão', 'Campinas', 'Pinheirinho', '85603-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6030, 'Paranavaí', 'Campinas', 'Jardim América', '87705-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6031, 'Pato Branco', 'Campinas', 'São Roque', '85507-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6032, 'Telêmaco Borba', 'Campinas', 'Vila Esperança', '84272-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6033, 'Curitiba', 'Campinas', 'Cabral', '80035-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6034, 'Telêmaco Borba', 'Campo Belo', 'Área 06', '84271-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6035, 'Almirante Tamandaré', 'Campo Belo', 'Vila Feliz', '83505-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6036, 'Curitiba', 'Campo Belo', 'Campo Comprido', '81240-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6037, 'Apucarana', 'Campo Bonito', 'Vila São Jerônimo', '86801-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6038, 'Curitiba', 'Campo Comprido', 'Cidade Industrial', '81280-420', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6039, 'Curitiba', 'Campo Comprido', 'Cidade Industrial', '81280-410', 'Conjunto', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6040, 'Colombo', 'Campo do Tenente', 'Jardim Guaraituba', '83410-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6041, 'Telêmaco Borba', 'Campo Formoso', 'Área 06', '84271-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6042, 'Guarapuava', 'Campo Grande', 'Conradinho', '85055-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6043, 'Londrina', 'Campo Grande', 'Colina Verde', '86050-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6044, 'Foz do Iguaçu', 'Campo Grande', 'Conjunto C', '85870-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6045, 'Maringá', 'Campo Grande', 'Vila Morangueira', '87040-390', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6046, 'Umuarama', 'Campo Grande', 'Jardim Indaiá', '87501-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6047, 'Sarandi', 'Campo Grande', 'Jardim Itamaraty', '87112-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6048, 'Telêmaco Borba', 'Campo Grande', 'Vila São José', '84263-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6049, 'Castro', 'Campo Grande', 'Invernada do Matadouro', '84174-396', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6050, 'Cascavel', 'Campo Grande', 'Santa Cruz', '85806-777', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6051, 'Curitiba', 'Campo Grande', 'Cajuru', '82930-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6052, 'Londrina', 'Campo Largo', 'Jardim Santo Antônio', '86060-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6053, 'Francisco Beltrão', 'Campo Largo', 'Industrial', '85601-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6054, 'Guarapuava', 'Campo Largo', 'Boqueirão', '85022-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6055, 'Ponta Grossa', 'Campo Largo', 'Oficinas', '84036-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6056, 'São José dos Pinhais', 'Campo Largo', 'São Pedro', '83020-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6057, 'Paranavaí', 'Campo Largo', 'Jardim Ouro Branco', '87704-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6058, 'Colombo', 'Campo Largo', 'Jardim Guaraituba', '83410-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6059, 'Almirante Tamandaré', 'Campo Largo', 'Loteamento Chico Mendes', '83505-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6060, 'Almirante Tamandaré', 'Campo Largo', 'Jardim Roma', '83504-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6061, 'Campo Largo', 'Campo Largo', 'Loteamento São Gerônimo', '83606-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6062, 'Apucarana', 'Campo Largo', 'Vila Cinco Irmãos', '86808-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6063, 'Curitiba', 'Campo Largo da Piedade', 'Pilarzinho', '82110-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6064, 'Foz do Iguaçu', 'Campo Mourão', 'Loteamento Witt', '85862-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6065, 'Guarapuava', 'Campo Mourão', 'Jardim das Américas', '85030-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6066, 'Londrina', 'Campo Mourão', 'Jardim Alvorada', '86060-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6067, 'Piraquara', 'Campo Mourão', 'Planta Araçatuba', '83301-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6068, 'São José dos Pinhais', 'Campo Mourão', 'Afonso Pena', '83045-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6069, 'Ponta Grossa', 'Campo Mourão', 'Chapada', '84062-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6070, 'Cambé', 'Campo Mourão', 'Jardim Ana Eliza', '86188-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6071, 'Colombo', 'Campo Mourão', 'Jardim Guaraituba', '83410-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6072, 'Curitiba', 'Campo Mourão', 'Alto Boqueirão', '81860-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6073, 'Curitiba', 'Campolim Gonçalves', 'Tatuquara', '81480-316', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6074, 'Almirante Tamandaré', 'Campos de Minas', 'Vila Feliz', '83505-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6075, 'Guarapuava', 'Campos de Palma', 'Vila Bela', '85025-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6076, 'Foz do Iguaçu', 'Campos do Jordão', 'Jardim Ipê', '85869-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6077, 'Sarandi', 'Campos Gerais', 'Jardim Monterey', '87112-788', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6078, 'Guarapuava', 'Campos Sales', 'Boqueirão', '85020-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6079, 'Francisco Beltrão', 'Campos Sales', 'São Miguel', '85602-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6080, 'Foz do Iguaçu', 'Campos Sales', 'Parque Presidente', '85863-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6081, 'Pinhais', 'Campos Sales', 'Vila Amélia', '83330-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6082, 'Maringá', 'Campos Sales', 'Zona 06', '87080-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6083, 'Maringá', 'Campos Sales', 'Zona 06', '87020-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6084, 'Ponta Grossa', 'Campos Sales', 'Uvaranas', '84020-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6085, 'Telêmaco Borba', 'Campos Sales', 'Alto das Oliveiras', '84265-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6086, 'Umuarama', 'Campos Sales', 'Jardim Vitória', '87509-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6087, 'Cascavel', 'Campos Sales', 'Parque São Paulo', '85803-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6088, 'Apucarana', 'Campos Sales', 'Loteamento Central', '86807-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6089, 'Colombo', 'Campos Sales', 'Jardim Central', '83409-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6090, 'Curitiba', 'Campos Sales', 'Alto da Glória', '80030-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6091, 'Cambé', 'Campos Salles', 'Vila Atalaia', '86181-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6092, 'Ponta Grossa', 'Campos Vergueiro', 'Uvaranas', '84030-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6093, 'Ponta Grossa', 'Canaã', 'Jardim Carvalho', '84016-667', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6094, 'Telêmaco Borba', 'Canaã', 'Área 06', '84271-230', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6095, 'Foz do Iguaçu', 'Canaçari', 'Jardim Bandeirantes', '85862-437', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6096, 'Guarapuava', 'Canadá', 'Morro Alto', '85067-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6097, 'Francisco Beltrão', 'Canadá', 'Antônio de Paiva Cantelmo', '85603-127', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6098, 'Londrina', 'Canadá', 'Jerumenha', '86046-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6099, 'Maringá', 'Canadá', 'Jardim Alvorada', '87033-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6100, 'Sarandi', 'Canadá', 'Jardim Castelo', '87112-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6101, 'Telêmaco Borba', 'Canadá', 'Alto das Oliveiras', '84266-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6102, 'Toledo', 'Canadá', 'Jardim Bandeirantes', '85906-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6103, 'Cambé', 'Canadá', 'Centro', '86181-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6104, 'Cascavel', 'Canadá', '14 de Novembro', '85804-108', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6105, 'Apucarana', 'Canadá', 'Jardim Diamantina', '86804-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6106, 'Almirante Tamandaré', 'Canadá', 'Jardim Monte Santo', '83501-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6107, 'Colombo', 'Canadá', 'Jardim Bela Vista', '83404-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6108, 'Curitiba', 'Canadá', 'Bacacheri', '82510-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6109, 'Cascavel', 'Canafistula', 'Recanto Tropical', '85807-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6110, 'Foz do Iguaçu', 'Canafístula', 'Conjunto B', '85867-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6111, 'Ponta Grossa', 'Canafístula', 'Neves', '84020-778', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6112, 'Campo Mourão', 'Canafístula', 'Jardim Santa Nilce I', '87308-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6113, 'Campo Largo', 'Canal', 'Vila Solene', '83607-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6114, 'Curitiba', 'Canal Belém', 'Guabirotuba', '81510-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6115, 'Curitiba', 'Canal Belém', 'Hauer', '81610-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6116, 'Curitiba', 'Canal Belém', 'Uberaba', '81570-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6117, 'Curitiba', 'Canal Belém', 'Boqueirão', '81650-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6118, 'Curitiba', 'Canal Belém', 'Uberaba', '81580-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6119, 'Curitiba', 'Canal Belém', 'Boqueirão', '81730-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6120, 'Maringá', 'Cananéia', 'Jardim Novo Horizonte', '87005-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6121, 'Umuarama', 'Cananéia', 'Jardim Paraíso', '87507-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6122, 'Umuarama', 'Cananéia', 'Zona VI', '87503-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6123, 'Francisco Beltrão', 'Canário', 'Luther King', '85605-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6124, 'Maringá', 'Canário', 'Jardim Olímpico', '87070-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6125, 'Ponta Grossa', 'Canário', 'Chapada', '84064-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6126, 'Umuarama', 'Canário', 'Jardim Alphavile', '87504-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6127, 'Cambé', 'Canário', 'Conjunto Habitacional Waldomiro M Gomes', '86182-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6128, 'Apucarana', 'Canário', 'Núcleo Habitacional Michel Soni', '86813-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6129, 'Arapongas', 'Canário', 'Centro', '86701-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6130, 'Francisco Beltrão', 'Canário-belga', 'Padre Ulrico', '85604-477', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6131, 'Arapongas', 'Canário-da-terra', 'Conjunto Centauro', '86709-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6132, 'Arapongas', 'Canário-do-campo', 'Jardim Colúmbia I', '86707-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6133, 'Arapongas', 'Canário-pardo', 'Conjunto Padre Bernardo Merckel', '86706-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6134, 'Foz do Iguaçu', 'Canários', 'Portal da Foz', '85859-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6135, 'Araucária', 'Canários', 'Capela Velha', '83706-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6136, 'Arapongas', 'Canastreiro', 'Jardim Baroneza', '86706-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6137, 'Foz do Iguaçu', 'Canavieiras', 'Jardim Petropólis', '85869-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6138, 'Arapongas', 'Canca', 'Jardim Baroneza', '86707-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6139, 'Sarandi', 'Canção', 'Parque Residencial Santana', '87112-595', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6140, 'Arapongas', 'Cancroma', 'Vila Passos', '86705-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6141, 'Cascavel', 'Candangos', 'Presidente', '85818-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6142, 'Guarapuava', 'Candeias', 'São Cristóvão', '85060-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6143, 'Foz do Iguaçu', 'Candeias', 'Jardim Curitibano', '85869-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6144, 'Foz do Iguaçu', 'Cândida A. Peters', 'Cohapar III', '85858-530', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6145, 'Londrina', 'Cândida Gonçalves Rosa', 'Jardim Pacaembu', '86079-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6146, 'Campo Mourão', 'Cândida Laim', 'Jardim Paulino', '87306-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6147, 'Londrina', 'Cândida Quintana Zemuner', 'Conjunto Novo Amparo', '86087-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6148, 'São José dos Pinhais', 'Cândido Alves da Rocha', 'Cruzeiro', '83010-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6149, 'Paranavaí', 'Cândido Bertier Fortes', 'Jardim Campo Grande', '87701-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6150, 'Paranavaí', 'Cândido Bertier Fortes', 'Jardim Vera Cruz', '87709-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6151, 'Londrina', 'Cândido Betoni', 'Palermo', '86060-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6152, 'Curitiba', 'Cândido Bonora', 'Cidade Industrial', '81305-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6153, 'Ponta Grossa', 'Cândido Borsato', 'Uvaranas', '84030-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6154, 'Apucarana', 'Cândido das Neves', 'Núcleo Habitacional Castelo Branco', '86812-397', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6155, 'Guarapuava', 'Cândido de Abreu', 'Boqueirão', '85023-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6156, 'Londrina', 'Cândido de Abreu', 'Lindóia', '86031-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6157, 'Pato Branco', 'Cândido de Abreu', 'Jardim Primavera', '85502-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6158, 'São José dos Pinhais', 'Cândido de Abreu', 'Silveira da Motta', '83030-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6159, 'Ponta Grossa', 'Cândido de Abreu', 'Contorno', '84052-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6160, 'Umuarama', 'Cândido de Abreu', 'Jardim Primavera', '87505-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6161, 'Colombo', 'Cândido de Abreu', 'Jardim Cristina II', '83410-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6162, 'Curitiba', 'Cândido de Abreu', 'Centro Cívico', '80530-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6163, 'Curitiba', 'Cândido de Leão', 'Centro', '80020-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6164, 'Foz do Iguaçu', 'Cândido Ferreira', 'Vila Yolanda', '85853-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6165, 'Foz do Iguaçu', 'Cândido Ferreira Filho', 'Jardim Dom Pedro I', '85856-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6166, 'Curitiba', 'Cândido Hartmann', 'Santo Inácio', '82015-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6167, 'Curitiba', 'Cândido Hartmann', 'Santo Inácio', '82010-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6168, 'Curitiba', 'Cândido Hartmann', 'Mercês', '80730-440', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6169, 'Curitiba', 'Cândido Hartmann', 'Mercês', '80710-570', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6170, 'Campo Mourão', 'Cândido Holtz Vieira', 'Jardim Nossa Senhora Aparecida', '87309-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6171, 'Curitiba', 'Cândido Lopes', 'Centro', '80020-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6172, 'Curitiba', 'Cândido Machado Filho', 'São Lourenço', '82210-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6173, 'Curitiba', 'Cândido Mader', 'Juvevê', '80030-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6174, 'Umuarama', 'Cândido Mota', 'Parque Tarumã', '87508-217', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6175, 'Londrina', 'Cândido Portinari', 'Conjunto Residencial Vale do Arvoredo', '86047-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6176, 'Foz do Iguaçu', 'Cândido Portinari', 'Jardim das Nações', '85865-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6177, 'Paranaguá', 'Cândido Portinari', 'Cruzeiro', '83221-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6178, 'Piraquara', 'Cândido Portinari', 'Vila Juliana', '83306-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6179, 'Umuarama', 'Cândido Portinari', 'Conjunto Residencial Ouro Preto', '87504-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6180, 'Cascavel', 'Cândido Portinari', 'Independência', '85813-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6181, 'Colombo', 'Cândido Portinari', 'Jardim Alvorada', '83409-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6182, 'Curitiba', 'Cândido Portinari', 'Guabirotuba', '81510-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6183, 'Guarapuava', 'Cândido Ribas', 'Santana', '85070-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6184, 'Almirante Tamandaré', 'Cândido Rondon', 'Planta Nossa Senhora do Pilar', '83508-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6185, 'Guarapuava', 'Cândido Xavier', 'Boqueirão', '85020-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6186, 'Curitiba', 'Cândido Xavier', 'Água Verde', '80240-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6187, 'Curitiba', 'Cândido Xavier', 'Vila Izabel', '80320-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6188, 'Ponta Grossa', 'Cândido Xavier de A. E. Souza', 'Jardim Carvalho', '84016-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6189, 'Guarapuava', 'Cândido Xavier Ribas', 'Santana', '85070-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6190, 'Foz do Iguaçu', 'Candiru', 'Conjunto A', '85860-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6191, 'Guarapuava', 'Candói', 'Conradinho', '85055-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6192, 'Foz do Iguaçu', 'Candói', 'Loteameto Dona Amanda', '85853-737', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6193, 'Colombo', 'Candói', 'Jardim Guaraituba', '83410-015', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6194, 'Londrina', 'Canela', 'Leonor', '86071-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6195, 'Foz do Iguaçu', 'Canela', 'Jardim Colônia', '85855-156', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6196, 'Francisco Beltrão', 'Canela', 'Pinheirinho', '85603-176', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6197, 'Ponta Grossa', 'Canela', 'Neves', '84020-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6198, 'Piraquara', 'Canela', 'Vila Santa Maria', '83306-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6199, 'Maringá', 'Canela', 'Parque Palmeiras', '87023-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6200, 'Telêmaco Borba', 'Canela', 'Área 01', '84268-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6201, 'Apucarana', 'Canela', 'Jardim Recanto dos Palmares', '86803-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6202, 'Araucária', 'Canela', 'Estação', '83705-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6203, 'Cascavel', 'Canela', 'Recanto Tropical', '85807-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6204, 'Ponta Grossa', 'Caneleira', 'Contorno', '84061-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6205, 'Arapongas', 'Caneleirinho', 'Vila Araponguinha', '86705-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6206, 'Arapongas', 'Caneleiro', 'Jardim Lorena', '86706-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6207, 'Umuarama', 'Canelinha', 'Jardim Paraíso', '87507-190', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6208, 'Londrina', 'Canindé', 'Yara', '86027-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6209, 'Foz do Iguaçu', 'Canindé', 'Parque Morumbi', '85858-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6210, 'Guarapuava', 'Canindé', 'Conradinho', '85055-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6211, 'Ponta Grossa', 'Canindé', 'Colônia Dona Luiza', '84046-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6212, 'Arapongas', 'Canindé', 'Vila Aparecida', '86707-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6213, 'Cambé', 'Canindé', 'Jardim Morumbi', '86191-777', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6214, 'Curitiba', 'Canindé', 'São Braz', '82315-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6215, 'Campo Mourão', 'Canjarana', 'Jardim Bandeirantes', '87308-460', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6216, 'Apucarana', 'Canjarana', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6217, 'Laranjeiras do Sul', 'Canjeranas', 'Cristo Rei', '85304-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6218, 'Foz do Iguaçu', 'Canoas', 'Loteamento Campos do Iguaçu', '85857-440', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6219, 'Cascavel', 'Canoas', 'Canadá', '85813-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6220, 'Foz do Iguaçu', 'Canoinhas', 'Jardim Lancaster', '85869-440', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6221, 'São José dos Pinhais', 'Canoinhas', 'São Sebastião', '83075-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6222, 'Campo Largo', 'Canoinhas', 'Jardim Carmela', '83607-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6223, 'Curitiba', 'Canoinhas', 'Barreirinha', '82560-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6224, 'Londrina', 'Canopus', 'Sol', '86070-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6225, 'Maringá', 'Cantabria', 'Loteamento Madrid', '87053-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6226, 'Arapongas', 'Cantador-amarelo', 'Jardim Colúmbia IV', '86707-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6227, 'Francisco Beltrão', 'Cantagalo', 'Pinheirinho', '85603-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6228, 'Foz do Iguaçu', 'Cantagalo', 'Jardim das Palmeiras', '85869-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6229, 'Laranjeiras do Sul', 'Cantagalo', 'Água Verde', '85302-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6230, 'Guarapuava', 'Cantagalo', 'Conradinho', '85055-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6231, 'Campo Mourão', 'Cantagalo', 'Jardim Lar Paraná', '87305-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6232, 'Cambé', 'Cantares', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6233, 'Almirante Tamandaré', 'Cantídio Furquim Neto', 'Jardim Novo Horizonte da Cachoeira', '83502-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6234, 'Telêmaco Borba', 'Cantilho Gonçalves', 'Jardim Bonavila', '84264-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6235, 'Toledo', 'Cantíudio Sampaio', 'Jardim Piccinin', '85904-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6236, 'Foz do Iguaçu', 'Canto do Buriti', 'Loteamento Mata Verde', '85853-688', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6237, 'São José dos Pinhais', 'Canto dos Pássaros', 'Guatupê', '83060-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6238, 'Maringá', 'Cantor Raul Seixas', 'Jardim Ipanema', '87053-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6239, 'Londrina', 'Canudos', 'Jardim Higienópolis', '86015-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6240, 'Guarapuava', 'Capanema', 'Jardim das Américas', '85030-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6241, 'Foz do Iguaçu', 'Capanema', 'Jardim Itaipu', '85867-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6242, 'Francisco Beltrão', 'Capanema', 'Marrecas', '85601-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6243, 'Ponta Grossa', 'Capanema', 'Oficinas', '84036-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6244, 'São José dos Pinhais', 'Capanema', 'Bom Jesus', '83025-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6245, 'Cascavel', 'Capanema', 'São Cristóvão', '85816-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6246, 'Apucarana', 'Capanema', 'Vila Vitória Régia', '86801-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6247, 'Curitiba', 'Capão da Imbuia', 'Capão da Imbuia', '82810-660', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6248, 'Curitiba', 'Capão Raso', 'Novo Mundo', '81050-520', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6249, 'Londrina', 'Capella', 'Sol', '86070-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6250, 'Foz do Iguaçu', 'Capibaribe', 'Jardim Acaray', '85857-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6251, 'Paranaguá', 'Capibaribe', 'Jardim Guaraituba', '83209-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6252, 'Londrina', 'Capiberibe', 'Jacomo Violin', '86025-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6253, 'Curitiba', 'Capiberibe', 'Portão', '80330-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6254, 'Curitiba', 'Capiberibe', 'Santa Quitéria', '80310-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6255, 'Londrina', 'Capichingui', 'Leonor', '86071-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6256, 'Francisco Beltrão', 'Capinzal', 'Pinheirinho', '85603-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6257, 'Telêmaco Borba', 'Capinzal', 'Nossa Senhora do Perpétuo Socorro', '84265-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6258, 'Ponta Grossa', 'Capistrano de Abreu', 'Uvaranas', '84031-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6259, 'Colombo', 'Capistrano de Abreu', 'Vila São Lucas', '83404-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6260, 'Apucarana', 'Capistrano de Abreu', 'Vila Shangri-La', '86812-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6261, 'Curitiba', 'Capistrano de Abreu', 'Boa Vista', '82540-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6262, 'Curitiba', 'Capistrano de Abreu', 'Boa Vista', '82560-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6263, 'Umuarama', 'Capital da Amizade', 'Jardim Colibri', '87506-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6264, 'Foz do Iguaçu', 'Capitão Acácio Pedroso', 'Jardim Iguaçu', '85853-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6265, 'Foz do Iguaçu', 'Capitão Acácio Pereira', 'Jardim Iguaçu', '85853-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6266, 'Almirante Tamandaré', 'Capitão Almeida', 'Planta São Venâncio', '83504-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6267, 'Curitiba', 'Capitão Amin Mosse', 'Alto Boqueirão', '81850-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6268, 'Campo Largo', 'Capitão Ângelo José Ferreira Chaves', 'Bom Jesus', '83604-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6269, 'São José dos Pinhais', 'Capitão Antônio Joaquim Barbosa', 'Cruzeiro', '83010-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6270, 'Laranjeiras do Sul', 'Capitão Antônio Joaquim de Camargo', 'Centro', '85301-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6271, 'Curitiba', 'Capitão Antônio José', 'Xaxim', '81810-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6272, 'Curitiba', 'Capitão Antônio Naufal', 'Uberaba', '81580-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6273, 'Curitiba', 'Capitão Antônio Pedri', 'Santa Felicidade', '82020-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6274, 'Castro', 'Capitão Antônio Prestes Filho', 'Jardim das Araucárias', '84174-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6275, 'Curitiba', 'Capitão Argemiro Monteiro Wanderley', 'Capão Raso', '81130-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6276, 'Guarapuava', 'Capitão Argílio Ferreira', 'Trianon', '85012-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6277, 'Araucária', 'Capitão Aristóteles Moreira', 'Tindiquera', '83708-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6278, 'Laranjeiras do Sul', 'Capitão Ártico Antônio Fae', 'São Francisco', '85303-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6279, 'Curitiba', 'Capitão Audálio Moreira', 'Boqueirão', '81670-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6280, 'Curitiba', 'Capitão Augusto do Rego Barros', 'Tatuquara', '81480-256', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6281, 'Curitiba', 'Capitão Barcimio Sicupira', 'Cidade Industrial', '81230-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6282, 'Ponta Grossa', 'Capitão Benedito Lopes de Bragança', 'Estrela', '84050-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6283, 'São José dos Pinhais', 'Capitão Benjamin Claudino Ferreira', 'Centro', '83005-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6284, 'Curitiba', 'Capitão Borges do Canto', 'Cajuru', '82940-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6285, 'Curitiba', 'Capitão Caetano Munhoz', 'Parolin', '80220-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6286, 'Curitiba', 'Capitão Carlos Henrique Castor', 'Pilarzinho', '82120-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6287, 'Piraquara', 'Capitão Carlos Henrique de Castro', 'Vila Militar I', '83303-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6288, 'Curitiba', 'Capitão Clementino Paraná', 'Água Verde', '80620-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6289, 'Curitiba', 'Capitão Domingos Castellano', 'Santo Inácio', '82300-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6290, 'Curitiba', 'Capitão Eduardo A.torres Pereira', 'Centro', '80410-270', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6291, 'Curitiba', 'Capitão Ercílio Miro', 'Alto Boqueirão', '81860-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6292, 'Curitiba', 'Capitão Ernesto dos Anjos Barbosa', 'Novo Mundo', '81020-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6293, 'Laranjeiras do Sul', 'Capitão Félix Fleury', 'Centro', '85301-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6294, 'Laranjeiras do Sul', 'Capitão Félix Fleury', 'Getúlio Vargas', '85304-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6295, 'Londrina', 'Capitão Ferreira Gomes', 'Shangri-La', '86070-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6296, 'Guarapuava', 'Capitão Frederico Virmond', 'Alto da XV', '85065-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6297, 'Guarapuava', 'Capitão Frederico Virmond', 'Santa Cruz', '85015-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6298, 'Guarapuava', 'Capitão Frederico Virmond', 'Centro', '85010-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6299, 'Paranavaí', 'Capitão Geraldo Persilva', 'Parque Morumbi', '87703-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6300, 'Ponta Grossa', 'Capitão Goes de Moraes', 'Oficinas', '84035-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6301, 'Curitiba', 'Capitão Guilherme Bianchi', 'Cajuru', '82930-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6302, 'Toledo', 'Capitão Índio Bandeira', 'Boa Esperança', '85910-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6303, 'Campo Mourão', 'Capitão Índio Bandeira', 'Centro', '87300-005', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6304, 'Campo Mourão', 'Capitão Índio Bandeira', 'Centro', '87301-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6305, 'Curitiba', 'Capitão Ismael Roxo', 'Abranches', '82220-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6306, 'Foz do Iguaçu', 'Capitão Jacob Becker', 'Vila Yolanda', '85853-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6307, 'Londrina', 'Capitão Jacy da Silva Pinheiros', 'Cilo 3', '86073-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6308, 'Londrina', 'Capitão João Busse', 'Califórnia', '86040-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6309, 'Curitiba', 'Capitão João Busse', 'Cajuru', '82900-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6310, 'Curitiba', 'Capitão João Ribas de Oliveira', 'Guabirotuba', '81510-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6311, 'Curitiba', 'Capitão João Zaleski', 'Lindóia', '81010-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6312, 'Londrina', 'Capitão Joaquim Paiva', 'Mazzei', '86015-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6313, 'Colombo', 'Capitão Jonas Materu Almeida', 'Jardim Nova Esperança', '83413-137', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6314, 'São José dos Pinhais', 'Capitão Jonas Mateus de Almeida', 'São Sebastião', '83075-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6315, 'Curitiba', 'Capitão José da Silva Sobrinho', 'Bacacheri', '82515-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6316, 'Curitiba', 'Capitão José Maria Sobrinho', 'Fanny', '81030-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6317, 'Curitiba', 'Capitão Joséph Pereira Quevedo', 'Mercês', '80710-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6318, 'Curitiba', 'Capitão Joviano Pereira de Camargo', 'Cabral', '82200-350', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6319, 'Curitiba', 'Capitão Lauro Correia Regnier', 'Tatuquara', '81470-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6320, 'Araucária', 'Capitão Leonardo Graziano', 'Porto das Laranjeiras', '83703-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6321, 'Guarapuava', 'Capitão Leônidas Marques', 'Jardim das Américas', '85030-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6322, 'Toledo', 'Capitão Leônidas Marques', 'Boa Esperança', '85909-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6323, 'Toledo', 'Capitão Leônidas Marques', 'Pacaembu', '85910-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6324, 'Cascavel', 'Capitão Leônidas Marques', 'Região do Lago 2', '85816-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6325, 'Curitiba', 'Capitão Leônidas Marques', 'Uberaba', '81540-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6326, 'Curitiba', 'Capitão Leônidas Marques', 'Uberaba', '81550-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6327, 'Curitiba', 'Capitão Manoel Pacheco da Costa', 'Ahú', '82200-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6328, 'Castro', 'Capitão Miguel Sidor', 'Cantagalo', '84178-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6329, 'Curitiba', 'Capitão Orlando Favorito', 'Cajuru', '82920-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6330, 'Ponta Grossa', 'Capitão Pedro Afonso', 'Ronda', '84051-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6331, 'Londrina', 'Capitão Pedro Rufino', 'Nova', '86015-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6332, 'Ponta Grossa', 'Capitão Rivadávia Maciel', 'Uvaranas', '84030-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6333, 'Curitiba', 'Capitão Roberto Lopes Quintas', 'Alto Boqueirão', '81860-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6334, 'Guarapuava', 'Capitão Rocha', 'Trianon', '85017-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6335, 'Guarapuava', 'Capitão Rocha', 'Bonsucesso', '85035-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6336, 'Guarapuava', 'Capitão Rocha', 'Centro', '85010-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6337, 'Curitiba', 'Capitão Sílvio Caetano Marques', 'Barreirinha', '82710-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6338, 'Curitiba', 'Capitão Souza Franco', 'Batel', '80730-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6339, 'Paranavaí', 'Capitão Telmo Ribeiro', 'Jardim Novo Horizonte', '87711-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6340, 'Paranavaí', 'Capitão Telmo Ribeiro', 'Jardim São Jorge', '87710-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6341, 'Paranavaí', 'Capitão Telmo Ribeiro', 'Vila São Vicente', '87709-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6342, 'Curitiba', 'Capitão Tenente Eduardo Alberto de Mesquita', 'Campina do Siqueira', '80740-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6343, 'Piraquara', 'Capitão Tenente Maris de Barros', 'Vila Militar I', '83303-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6344, 'Curitiba', 'Capitão Tenente Maris de Barros', 'Portão', '80330-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6345, 'São José dos Pinhais', 'Capitão Thomaz Carvalho de Camargo', 'Cidade Jardim', '83035-440', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6346, 'Toledo', 'Capitão Tisiano', 'Jardim Paulista', '85910-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6347, 'São José dos Pinhais', 'Capitão Tobias Pereira da Cruz', 'Carioca', '83005-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6348, 'Curitiba', 'Capitão Varassin', 'Capão da Imbuia', '82810-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6349, 'Londrina', 'Capitão Vicente Januzzi Filho', 'Araxá', '86061-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6350, 'Curitiba', 'Capitão Virgínio de Oliveira Mello', 'Mercês', '80510-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6351, 'Apucarana', 'Capitão Waldemar Langank', 'Núcleo Habitacional Osmar G Freire', '86801-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6352, 'Curitiba', 'Capitão Zeppin', 'Uberaba', '81530-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6353, 'Arapongas', 'Capitão-de-coroa', 'Parque Industrial II', '86703-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6354, 'Londrina', 'Capitão-do-mato', 'Conjunto Habitacional Violim', '86088-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6355, 'Arapongas', 'Capitão-do-mato', 'Jardim Aeroporto', '86702-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6356, 'Curitiba', 'Capitãozinho Scheraib', 'Tatuquara', '81470-145', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6357, 'Foz do Iguaçu', 'Capivari', 'Conjunto Libra', '85857-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6358, 'Londrina', 'Capivari', 'Veraliz', '86062-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6359, 'Paranaguá', 'Capivari', 'Jardim Guaraituba', '83209-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6360, 'Araucária', 'Capivari', 'Iguaçu', '83701-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6361, 'Apucarana', 'Capivari', 'Centro', '86800-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6362, 'Londrina', 'Capri', 'Parque Residencial João Piza', '86041-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6363, 'Londrina', 'Capri', 'Parque Residencial João Piza', '86041-155', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6364, 'Cambé', 'Capri', 'Jardim Montecatini', '86186-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6365, 'Sarandi', 'Capricornio', 'Jardim Universal', '87114-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6366, 'Londrina', 'Capricórnio', 'Sol', '86070-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6367, 'Maringá', 'Cáqui', 'Vila Vardelina', '87080-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6368, 'Ponta Grossa', 'Caquizeiro', 'Contorno', '84061-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6369, 'Foz do Iguaçu', 'Cará', 'Profilurb I', '85855-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6370, 'Cambé', 'Caracará', 'Conjunto Habitacional Waldomiro M Gomes', '86182-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6371, 'Arapongas', 'Caracará', 'Vila Gaúcha', '86705-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6372, 'Londrina', 'Cara-cará', 'Jacomo Violin', '86088-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6373, 'Ponta Grossa', 'Cará-cará', 'Cará-cará', '84033-250', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6374, 'Arapongas', 'Caracará-canca', 'Jardim Monte Carlo', '86704-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6375, 'Arapongas', 'Caracaratinga', 'Conjunto Padre Chico', '86707-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6376, 'Francisco Beltrão', 'Caracas', 'Miniguaçu', '85605-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6377, 'Foz do Iguaçu', 'Caracas', 'Beverly Falls Park', '85858-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6378, 'Londrina', 'Caracas', 'Santa Rosa', '86050-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6379, 'Maringá', 'Caracas', 'Vila Morangueira', '87040-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6380, 'Maringá', 'Caracas', 'Vila Morangueira', '87040-011', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6381, 'Sarandi', 'Caracas', 'Jardim Castelo', '87112-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6382, 'Telêmaco Borba', 'Caracas', 'Nossa Senhora de Fátima', '84264-350', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6383, 'Colombo', 'Caracas', 'Jardim Bela Vista', '83404-610', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6384, 'Londrina', 'Caraguata', 'Casarin', '86035-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6385, 'Telêmaco Borba', 'Caraguata', 'Área 02', '84267-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6386, 'Londrina', 'Caraíbas', 'Vila Goes', '86026-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6387, 'Apucarana', 'Caraíbas', 'Núcleo Habitacional Colonial', '86812-446', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6388, 'Cascavel', 'Caraíbas', 'Santa Cruz', '85806-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6389, 'Londrina', 'Carajás', 'Jardim São Paulo', '86026-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6390, 'Foz do Iguaçu', 'Carajás', 'Jardim Tarobá', '85856-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6391, 'Guarapuava', 'Carajás', 'Vila Carli', '85040-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6392, 'Ponta Grossa', 'Carajás', 'Cará-cará', '84043-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6393, 'Cascavel', 'Carajás', 'Santa Cruz', '85806-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6394, 'Cambé', 'Carajás', 'Jardim Tupi', '86183-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6395, 'Guarapuava', 'Carambei', 'Santana', '85070-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6396, 'Curitiba', 'Carambolas', 'Uberaba', '81560-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6397, 'Londrina', 'Caramuru', 'Portuguesa', '86026-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6398, 'Maringá', 'Caramuru', 'Zona 04', '87014-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6399, 'Pato Branco', 'Caramuru', 'Centro', '85501-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6400, 'Paranavaí', 'Caramuru', 'Jardim Santos Dumont', '87706-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6401, 'Ponta Grossa', 'Caramuru', 'Contorno', '84052-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6402, 'Maringá', 'Caramuru', 'Zona 06', '87015-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6403, 'Sarandi', 'Caramuru', 'Parque Residencial Nova Aliança', '87111-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6404, 'Telêmaco Borba', 'Caramuru', 'Centro', '84261-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6405, 'Curitiba', 'Caramuru', 'Cidade Industrial', '81305-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6406, 'Foz do Iguaçu', 'Caranguejo', 'Profilurb I', '85855-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6407, 'Arapongas', 'Carão', 'Jardim Primavera', '86702-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6408, 'Arapongas', 'Carapé', 'Jardim Colúmbia III', '86707-815', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6409, 'Foz do Iguaçu', 'Caratinga', 'Jardim Residencial São Roque', '85853-709', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6410, 'Pinhais', 'Caratuval', 'Planta Ubirajara', '83325-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6411, 'Arapongas', 'Caraúna', 'Jardim Lorena', '86707-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6412, 'Curitiba', 'Caravelas', 'Campo Comprido', '81240-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6413, 'Francisco Beltrão', 'Carazinho', 'Cristo Rei', '85602-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6414, 'Foz do Iguaçu', 'Carazinho', 'Parque Residencial Três Fronteiras', '85855-615', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6415, 'Telêmaco Borba', 'Carbonato', 'Vila São Francisco de Assis', '84264-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6416, 'Foz do Iguaçu', 'Cardeal', 'Portal da Foz', '85859-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6417, 'Francisco Beltrão', 'Cardeal', 'Padre Ulrico', '85604-478', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6418, 'Londrina', 'Cardeal', 'Jacomo Violin', '86088-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6419, 'Ponta Grossa', 'Cardeal', 'Chapada', '84064-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6420, 'Ponta Grossa', 'Cardeal', 'Colônia Dona Luiza', '84046-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6421, 'Maringá', 'Cardeal', 'Parque Hortência', '87075-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6422, 'Arapongas', 'Cardeal', 'Vila Aparecida', '86707-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6423, 'Cambé', 'Cardeal', 'Conjunto Habitacional Waldomiro M Gomes', '86182-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6424, 'Araucária', 'Cardeal', 'Capela Velha', '83706-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6425, 'Campo Mourão', 'Cardeal', 'Jardim Tropical I', '87310-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6426, 'Cascavel', 'Cardeal', 'Floresta', '85814-780', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6427, 'Curitiba', 'Cardeal', 'Campo Comprido', '81200-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6428, 'Arapongas', 'Cardeal-do-bico-amarelo', 'Conjunto Águias', '86704-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6429, 'Arapongas', 'Cardeal-roxo', 'Conjunto Padre Bernardo Merckel', '86706-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6430, 'Londrina', 'Cardeal-vermelho', 'Paraíso', '86078-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6431, 'Cascavel', 'Cardoso', 'Universitário', '85819-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6432, 'Arapongas', 'Cariama', 'Vila Bernardes', '86705-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6433, 'Apucarana', 'Caribés', 'Núcleo Habitacional Colonial', '86812-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6434, 'Ponta Grossa', 'Caridon', 'Neves', '84021-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6435, 'Foz do Iguaçu', 'Carijós', 'Jardim Tarobá', '85856-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6436, 'Londrina', 'Carijós', 'Paraná', '86026-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6437, 'Cascavel', 'Carijós', 'Santa Cruz', '85806-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6438, 'Cascavel', 'Carimãs', 'Santo Onofre', '85806-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6439, 'Maringá', 'Cariovaldo Ferreira', 'Zona 08', '87050-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6440, 'Londrina', 'Cariris', 'Novo Mundo', '86026-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6441, 'Cascavel', 'Cariris', 'Santa Cruz', '85806-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6442, 'Apucarana', 'Cariris', 'Núcleo Habitacional Colonial', '86812-426', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6443, 'Cambé', 'Cariris', 'Jardim Tupi', '86183-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6444, 'Curitiba', 'Carl Jung', 'Barreirinha', '82700-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6445, 'Ponta Grossa', 'Carl Sanburg', 'Cará-cará', '84043-619', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6446, 'Guarapuava', 'Carla Selhorst de Souza', 'São Cristóvão', '85063-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6447, 'São José dos Pinhais', 'Carlito Dissenha', 'Costeira', '83015-716', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6448, 'Piraquara', 'Carlito Gomes', 'Vila Fuck', '83305-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6449, 'Almirante Tamandaré', 'Carlito Guimarães de Brito', 'Jardim Casa Blanca', '83513-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6450, 'Ponta Grossa', 'Carlito Tozetto', 'Estrela', '84050-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6451, 'Castro', 'Carlo Antônio Ciappina', 'Jardim Social Arapongas', '84174-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6452, 'Guarapuava', 'Carlópolis', 'Boqueirão', '85023-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6453, 'Ponta Grossa', 'Carlópolis', 'Cará-cará', '84032-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6454, 'Apucarana', 'Carlópolis', 'Vila São Carlos', '86800-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6455, 'Curitiba', 'Carlópolis', 'Pinheirinho', '81880-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6456, 'Toledo', 'Carlos Abel Munaretto', 'Panorama', '85911-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6457, 'Curitiba', 'Carlos Alberto de Druzina', 'Boqueirão', '81670-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6458, 'Curitiba', 'Carlos Alberto de Lima Fagundes', 'Fazendinha', '81320-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6459, 'Colombo', 'Carlos Alberto Dugonski', 'Jardim Viviane', '83407-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6460, 'Londrina', 'Carlos Alberto Franco Lichti', 'Conjunto Professora Hilda Mandarino', '86080-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6461, 'Piraquara', 'Carlos Alberto Frederico', 'Vila Ipanema', '83301-037', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6462, 'Araucária', 'Carlos Alberto Luczyszyn', 'Tindiquera', '83708-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6463, 'Curitiba', 'Carlos Alexandre', 'Tatuquara', '81470-285', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6464, 'Curitiba', 'Carlos Alfredo de Moraes', 'Cajuru', '82950-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6465, 'Curitiba', 'Carlos Amoretty Osório', 'Sítio Cercado', '81920-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6466, 'Londrina', 'Carlos Antônio Arenghi', 'Jardim Império do Sol', '86073-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6467, 'Curitiba', 'Carlos Antônio Bento de Araújo', 'Cidade Industrial', '81460-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6468, 'Toledo', 'Carlos Antônio Bolson', 'Jardim Planalto', '85904-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6469, 'Curitiba', 'Carlos Antônio de Azevedo', 'Jardim Botânico', '80210-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6470, 'Londrina', 'Carlos Aparecido de Carvalho', 'Catuaí Parque Residence', '86047-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6471, 'Londrina', 'Carlos Augusto Aldenucci', 'Champagnat', '86062-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6472, 'Curitiba', 'Carlos Augusto Aldenucci', 'Sítio Cercado', '81910-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6473, 'Curitiba', 'Carlos Augusto Cornelsen', 'Bom Retiro', '80520-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6474, 'Pinhais', 'Carlos Augusto do Nascimento', 'Prive Bois de Boulogne', '83330-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6475, 'Apucarana', 'Carlos Augusto Góis', 'Jardim Aviação', '86812-516', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6476, 'Curitiba', 'Carlos Augusto Piovezan', 'São João', '82030-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6477, 'Ponta Grossa', 'Carlos B. Max', 'Uvaranas', '84026-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6478, 'Curitiba', 'Carlos Bachmamn Sobrinho', 'Santa Cândida', '82630-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6479, 'Apucarana', 'Carlos Balthazar', 'Vila Nova', '86812-065', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6480, 'Campo Largo', 'Carlos Barausse', 'Vila Andreassa Miranda', '83605-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6481, 'Toledo', 'Carlos Barbosa', 'Vila Industrial', '85904-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6482, 'Toledo', 'Carlos Barbosa', 'Parque Residencial Gisela', '85905-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6483, 'Curitiba', 'Carlos Baroni', 'Bom Retiro', '80520-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6484, 'Cascavel', 'Carlos Bartolomeu Cancelli', 'Cancelli', '85811-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6485, 'Campo Mourão', 'Carlos Behrens', 'Jardim Laura', '87300-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6486, 'Piraquara', 'Carlos Belão', 'Vila Juliana', '83306-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6487, 'Campo Largo', 'Carlos Benato', 'Conjunto Águas Claras', '83602-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6488, 'Curitiba', 'Carlos Benato', 'São Braz', '82320-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6489, 'Curitiba', 'Carlos Benetti', 'Vista Alegre', '80810-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6490, 'Foz do Iguaçu', 'Carlos Benitez', 'Jardim do Horto', '85854-560', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6491, 'Londrina', 'Carlos Bergossi', 'Conjunto Parigot de Souza 3', '86081-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6492, 'Pinhais', 'Carlos Bernardo Michel', 'Jardim Guairacá', '83324-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6493, 'Ponta Grossa', 'Carlos Blageski', 'Ronda', '84051-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6494, 'Curitiba', 'Carlos Blanck', 'Portão', '81070-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6495, 'Cambé', 'Carlos Borges', 'Vila Atalaia', '86181-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6496, 'Maringá', 'Carlos Borrasca', 'Zona 08', '87050-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6497, 'Curitiba', 'Carlos Cadamuro', 'Santa Cândida', '82630-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6498, 'Londrina', 'Carlos Caetano', 'Conjunto Farid Libos', '86087-165', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6499, 'Pato Branco', 'Carlos Caldari', 'Bancários', '85504-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6500, 'Curitiba', 'Carlos Calderon', 'Bacacheri', '82600-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6501, 'Maringá', 'Carlos Cândido', 'Jardim Santa Alice', '87040-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6502, 'Londrina', 'Carlos Capelari', 'Kennedy', '86060-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6503, 'Apucarana', 'Carlos Caramori', 'Núcleo Habitacional Marcos Freire', '86805-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6504, 'Foz do Iguaçu', 'Carlos Castanharo', 'Jardim Niterói', '85853-716', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6505, 'Cascavel', 'Carlos Cavalcante', 'Cataratas', '85818-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6506, 'Foz do Iguaçu', 'Carlos Cavalcante de Albuquerque Neto', 'Vila Adriana II', '85854-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6507, 'Castro', 'Carlos Cavalcanti', 'Centro', '84165-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6508, 'Apucarana', 'Carlos Cavalcanti', 'Jardim Ponta Grossa', '86804-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6509, 'Curitiba', 'Carlos César Bruning', 'Uberaba', '81570-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6510, 'Curitiba', 'Carlos Cesarini', 'Bacacheri', '82515-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6511, 'Londrina', 'Carlos Chagas', 'Kase', '86026-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6512, 'Laranjeiras do Sul', 'Carlos Chagas', 'Getúlio Vargas', '85304-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6513, 'Maringá', 'Carlos Chagas', 'Zona 05', '87015-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6514, 'Ponta Grossa', 'Carlos Chagas', 'Jardim Carvalho', '84016-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6515, 'Piraquara', 'Carlos Chagas', 'Jardim Tropical', '83314-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6516, 'Cascavel', 'Carlos Chagas', 'Pacaembu', '85816-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6517, 'Cambé', 'Carlos Chagas', 'Parque Residencial Manela', '86185-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6518, 'Curitiba', 'Carlos Chagas', 'São Braz', '82015-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6519, 'Apucarana', 'Carlos Cilião', 'Loteamento Residencial Miguel Sochacki', '86802-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6520, 'Londrina', 'Carlos Clementino Moreira', 'Conjunto Residencial Doutor Alberto João Zortea', '86042-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6521, 'Cambé', 'Carlos Codato', 'Planta São Francisco', '86182-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6522, 'Curitiba', 'Carlos Coelho Júnior', 'Capão da Imbuia', '82810-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6523, 'Foz do Iguaçu', 'Carlos Coimbra', 'Jardim Florença', '85867-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6524, 'Guarapuava', 'Carlos Coimbra da Luz', 'Vila Bela', '85025-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6525, 'Paranavaí', 'Carlos Colnago', 'Jardim Ipê', '87706-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6526, 'Maringá', 'Carlos Correia Borges', 'Zona 05', '87015-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6527, 'Maringá', 'Carlos Corrêia Borges', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6528, 'Curitiba', 'Carlos Custel Filho', 'Ganchinho', '81935-317', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6529, 'Londrina', 'Carlos da Costa Branco', 'Nikko', '86047-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6530, 'Toledo', 'Carlos Dall''Agnolo', 'Vila Industrial', '85903-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6531, 'Londrina', 'Carlos de Almeida', 'São Lourenço', '86043-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6532, 'Londrina', 'Carlos de Buriasco', 'Portal de Versalhes 3', '86055-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6533, 'Curitiba', 'Carlos de Campos', 'Boa Vista', '82560-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6534, 'Curitiba', 'Carlos de Campos', 'Boa Vista', '82540-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6535, 'Ponta Grossa', 'Carlos de Carvalho', 'Uvaranas', '84032-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6536, 'Toledo', 'Carlos de Carvalho', 'Jardim Piccinin', '85904-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6537, 'Cascavel', 'Carlos de Carvalho', 'Centro', '85801-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6538, 'Cascavel', 'Carlos de Carvalho', 'Centro', '85810-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6539, 'Cascavel', 'Carlos de Carvalho', 'Parque São Paulo', '85803-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6540, 'Cascavel', 'Carlos de Carvalho', 'Ciro Nardi', '85802-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6541, 'Apucarana', 'Carlos de Carvalho', 'Jardim Ponta Grossa', '86805-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6542, 'Ponta Grossa', 'Carlos de Laet', 'Oficinas', '84035-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6543, 'Curitiba', 'Carlos de Laet', 'Hauer', '81610-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6544, 'Curitiba', 'Carlos de Laet', 'Boqueirão', '81650-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6545, 'Curitiba', 'Carlos de Laet', 'Boqueirão', '81730-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6546, 'Araucária', 'Carlos de Lima', 'Estação', '83705-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6547, 'Londrina', 'Carlos de Mantova', 'São Lourenço', '86043-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6548, 'Castro', 'Carlos Decker', 'Centro', '84165-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6549, 'Curitiba', 'Carlos Dietzsch', 'Portão', '80330-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6550, 'Curitiba', 'Carlos Dietzsch', 'Portão', '80330-001', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6551, 'São José dos Pinhais', 'Carlos Domingos Toazza', 'Afonso Pena', '83065-486', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6552, 'Francisco Beltrão', 'Carlos Drummond de Andrade', 'São Miguel', '85602-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6553, 'Cascavel', 'Carlos Drummond de Andrade', 'Nucleo de Produção III', '85811-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6554, 'Foz do Iguaçu', 'Carlos Drumond de Andrade', 'Parque Residencial Três Bandeiras', '85862-267', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6555, 'Guarapuava', 'Carlos Drumond de Andrade', 'Boqueirão', '85020-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6556, 'Paranaguá', 'Carlos Drumond de Andrade', 'Jardim Araçá', '83221-096', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6557, 'Pinhais', 'Carlos Drumond de Andrade', 'Planta Núcleo Colonial de Pinhais', '83321-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6558, 'Toledo', 'Carlos Drumond de Andrade', 'Jardim Europa', '85908-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6559, 'São José dos Pinhais', 'Carlos Drumond de Andrade', 'Costeira', '83015-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6560, 'Castro', 'Carlos Edson Martins de Oliveira', 'Jardim Social Primavera', '84174-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6561, 'Curitiba', 'Carlos Eduardo Leão', 'Alto da Glória', '80030-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6562, 'São José dos Pinhais', 'Carlos Eduardo Nichelli', 'Planta Quississana', '83085-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6563, 'Curitiba', 'Carlos Essenfelder', 'Boqueirão', '81650-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6564, 'Curitiba', 'Carlos Essenfelder', 'Boqueirão', '81730-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6565, 'Curitiba', 'Carlos Estrella Moreira', 'Pilarzinho', '82100-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6566, 'Paranavaí', 'Carlos Faber', 'Jardim Santa Cecília', '87702-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6567, 'Curitiba', 'Carlos Filizola', 'Cristo Rei', '80050-300', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6568, 'Colombo', 'Carlos Fontoura Falavinha', 'Jardim Uirapuru', '83406-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6569, 'Curitiba', 'Carlos Fracaro', 'Bigorrilho', '80710-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6570, 'Colombo', 'Carlos Francisco Prochaska', 'Jardim Viviane', '83407-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6571, 'Guarapuava', 'Carlos G. de Siqueira', 'Santana', '85070-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6572, 'Londrina', 'Carlos Galhardo', 'Conjunto Vivi Xavier', '86082-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6573, 'Curitiba', 'Carlos Garbaccio', 'Pilarzinho', '82100-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6574, 'Curitiba', 'Carlos Garibaldi Biazetto', 'Boa Vista', '82560-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6575, 'Curitiba', 'Carlos Gelenski', 'São João', '82030-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6576, 'Londrina', 'Carlos Gil', 'Cambezinho', '86040-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6577, 'Londrina', 'Carlos Gil', 'Jardim Primavera', '86086-415', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6578, 'Curitiba', 'Carlos Golinelli', 'Cidade Industrial', '81310-415', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6579, 'Guarapuava', 'Carlos Gomes', 'Vila Bela', '85027-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6580, 'Foz do Iguaçu', 'Carlos Gomes', 'Vila Pérola', '85865-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6581, 'Laranjeiras do Sul', 'Carlos Gomes', 'Getúlio Vargas', '85304-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6582, 'Londrina', 'Carlos Gomes', 'Petrópolis', '86015-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6583, 'Ponta Grossa', 'Carlos Gomes', 'Contorno', '84052-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6584, 'Maringá', 'Carlos Gomes', 'Zona 05', '87015-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6585, 'Ponta Grossa', 'Carlos Gomes', 'Centro', '84010-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6586, 'Paranavaí', 'Carlos Gomes', 'Jardim São Jorge', '87710-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6587, 'Paranavaí', 'Carlos Gomes', 'Jardim São Jorge', '87711-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6588, 'Piraquara', 'Carlos Gomes', 'Jardim Bela Vista', '83301-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6589, 'Toledo', 'Carlos Gomes', 'Jardim Europa', '85908-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6590, 'Umuarama', 'Carlos Gomes', 'Zona V', '87504-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6591, 'Sarandi', 'Carlos Gomes', 'Jardim Independência I', '87114-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6592, 'Sarandi', 'Carlos Gomes', 'Jardim Panorama', '87113-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6593, 'Cascavel', 'Carlos Gomes', 'Parque São Paulo', '85803-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6594, 'Cascavel', 'Carlos Gomes', 'Universitário', '85819-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6595, 'Campo Largo', 'Carlos Gomes', 'Vila Déa', '83609-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6596, 'Cascavel', 'Carlos Gomes', 'Centro', '85801-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6597, 'Cascavel', 'Carlos Gomes', 'Maria Luiza', '85819-351', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6598, 'Arapongas', 'Carlos Gomes', 'Aricanduva', '86706-590', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6599, 'Colombo', 'Carlos Gomes', 'Jardim Curitiba', '83406-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6600, 'Cascavel', 'Carlos Gomes', 'Ciro Nardi', '85802-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6601, 'Curitiba', 'Carlos Gomes', 'Centro', '80010-140', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6602, 'Curitiba', 'Carlos Gomes de Oliveira', 'Cidade Industrial', '81250-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6603, 'Curitiba', 'Carlos Gomes do Prado', 'Cristo Rei', '80050-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6604, 'São José dos Pinhais', 'Carlos Gusso', 'Águas Belas', '83040-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6605, 'Curitiba', 'Carlos Gusso', 'Pinheirinho', '81820-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6606, 'São José dos Pinhais', 'Carlos Hambrusch', 'Afonso Pena', '83045-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6607, 'Castro', 'Carlos Henrique Ensiedel', 'Jardim Social Arapongas', '84174-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6608, 'Curitiba', 'Carlos Hepp', 'São Braz', '82315-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6609, 'Londrina', 'Carlos Inácio Alves', 'Pérola', '86038-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6610, 'Curitiba', 'Carlos João Goudard', 'Fazendinha', '81330-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6611, 'Toledo', 'Carlos João Treis', 'Jardim Paulista', '85909-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6612, 'Foz do Iguaçu', 'Carlos José Rosa', 'Loteamento Universitário das Américas', '85870-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6613, 'Curitiba', 'Carlos Kampmann', 'Orleans', '82310-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6614, 'Foz do Iguaçu', 'Carlos Kapfemberg', 'Vila Boa Esperança', '85854-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6615, 'Curitiba', 'Carlos Klemtz', 'Fazendinha', '81320-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6616, 'Apucarana', 'Carlos Krizanowski', 'Centro', '86800-285', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6617, 'Foz do Iguaçu', 'Carlos Lacerda', 'Vila Brasília', '85864-200', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6618, 'Ponta Grossa', 'Carlos Lacerda', 'Boa Vista', '84071-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6619, 'Paranaguá', 'Carlos Leal Gomes', 'Parque São João', '83212-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6620, 'Francisco Beltrão', 'Carlos Legramante', 'Pinheirinho', '85603-177', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6621, 'Curitiba', 'Carlos Leinig Júnior', 'Vista Alegre', '80820-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6622, 'Curitiba', 'Carlos Leopoldo Glaser', 'Campo Comprido', '81220-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6623, 'Colombo', 'Carlos Luiz Walt', 'Jardim Guaíra', '83402-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6624, 'Foz do Iguaçu', 'Carlos Luz', 'Parque Presidente', '85863-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6625, 'Guarapuava', 'Carlos Luz', 'Boqueirão', '85020-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6626, 'Telêmaco Borba', 'Carlos Luz', 'Alto das Oliveiras', '84266-290', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6627, 'Curitiba', 'Carlos Manfron', 'Santa Felicidade', '82410-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6628, 'Apucarana', 'Carlos Massareto', 'Jardim Eldorado', '86802-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6629, 'Campo Mourão', 'Carlos Massareto', 'Jardim Santa Cruz', '87309-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6630, 'Apucarana', 'Carlos Massey', 'Núcleo Habitacional Djalma Mendes de Oliveira', '86806-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6631, 'Londrina', 'Carlos Masso', 'Dom Pedro II', '86073-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6632, 'Foz do Iguaçu', 'Carlos Matias A. Becker', 'Parque Residencial Itália', '85858-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6633, 'Toledo', 'Carlos Matias Becker', 'Vila Becker', '85902-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6634, 'Maringá', 'Carlos Maurício Duarte', 'Parque Tarumã', '87053-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6635, 'Maringá', 'Carlos Meneguetti', 'Jardim Cerro Azul', '87010-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6636, 'Londrina', 'Carlos Menolli', 'Maria Lúcia', '86072-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6637, 'Castro', 'Carlos Michalski', 'Jardim Bela Vista', '84165-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6638, 'Pato Branco', 'Carlos Michelon', 'Pinheiros', '85504-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6639, 'Curitiba', 'Carlos Mikos', 'Uberaba', '81590-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6640, 'São José dos Pinhais', 'Carlos Milano', 'Boneca do Iguaçu', '83040-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6641, 'Curitiba', 'Carlos Müller', 'Cidade Industrial', '81280-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6642, 'Curitiba', 'Carlos Munhoz da Rocha', 'Tatuquara', '81470-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6643, 'Apucarana', 'Carlos Nazato', 'Jardim Marissol II', '86807-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6644, 'Colombo', 'Carlos Nóbrega', 'Sapopema', '83407-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6645, 'Paranaguá', 'Carlos Oliveira da Velha', 'Jardim Samambaia', '83212-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6646, 'Ponta Grossa', 'Carlos Osternack', 'Estrela', '84040-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6647, 'Campo Mourão', 'Carlos Otto Roeder', 'Jardim Copacabana', '87302-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6648, 'Cambé', 'Carlos Ozias César', 'Jardim Vitória', '86184-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6649, 'Curitiba', 'Carlos Parize', 'Santa Felicidade', '82015-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6650, 'Londrina', 'Carlos Pavan', 'Jardim Pampulha', '86071-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6651, 'Curitiba', 'Carlos Perrini', 'Pilarzinho', '82120-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6652, 'Piraquara', 'Carlos Petersen', 'Vila Ipanema', '83301-046', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6653, 'Cascavel', 'Carlos Pierozan', 'Vila Tolentino', '85802-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6654, 'Curitiba', 'Carlos Pioli', 'Bom Retiro', '80520-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6655, 'Curitiba', 'Carlos Pisani', 'Xaxim', '81810-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6656, 'Pinhais', 'Carlos Poulhmann', 'Vila Maria Antonieta', '83331-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6657, 'Curitiba', 'Carlos Pradi', 'Jardim das Américas', '81530-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6658, 'São José dos Pinhais', 'Carlos Prattes', 'Ipê', '83055-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6659, 'Ponta Grossa', 'Carlos Primor', 'Uvaranas', '84031-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6660, 'Curitiba', 'Carlos Razera', 'Vista Alegre', '80810-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6661, 'Piraquara', 'Carlos Reichmann', 'Centro', '83301-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6662, 'Foz do Iguaçu', 'Carlos Roberto da Silva', 'Jardim Califórnia', '85867-488', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6663, 'Curitiba', 'Carlos Roberto Ferreira', 'Sítio Cercado', '81900-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6664, 'Paranaguá', 'Carlos Roberto Fontes', 'Jardim Samambaia', '83212-345', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6665, 'Curitiba', 'Carlos Roberto Kaseker', 'Alto Boqueirão', '81770-490', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6666, 'Curitiba', 'Carlos Rodrigues da Cruz', 'Capão da Imbuia', '82810-760', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6667, 'Maringá', 'Carlos Rossi', 'Parque Industrial Bandeirantes', '87070-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6668, 'Londrina', 'Carlos Rottman', 'Progresso', '86079-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6669, 'Londrina', 'Carlos Rubens Cicchil', 'Parque Residencial Michael Licha', '86078-667', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6670, 'Apucarana', 'Carlos Sartini Neto', 'Parque Industrial Zona Oeste II', '86800-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6671, 'Cambé', 'Carlos Sawade', 'Centro', '86181-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6672, 'Foz do Iguaçu', 'Carlos Sbaraini', 'Jardim Polo Centro', '85863-757', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6673, 'Toledo', 'Carlos Sbaraini', 'Panorama', '85915-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6674, 'Toledo', 'Carlos Sbaraini', 'Panorama', '85911-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6675, 'Colombo', 'Carlos Sbrissia', 'Jardim Paraná', '83412-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6676, 'São José dos Pinhais', 'Carlos Scherner', 'Braga', '83020-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6677, 'Londrina', 'Carlos Schiavon', 'Conjunto Semiramis Barros Braga', '86088-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6678, 'Apucarana', 'Carlos Schmidt', 'Vila São Luiz', '86804-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6679, 'Curitiba', 'Carlos Schott', 'Tarumã', '82530-345', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6680, 'São José dos Pinhais', 'Carlos Setin', 'Afonso Pena', '83045-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6681, 'Guarapuava', 'Carlos Soares', 'Boqueirão', '85022-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6682, 'Foz do Iguaçu', 'Carlos Sottomaior', 'Jardim Jupira', '85865-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6683, 'Londrina', 'Carlos Stallmann', 'Heimtal', '86084-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6684, 'Curitiba', 'Carlos Texeira Osternack', 'Santa Cândida', '82630-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6685, 'Araucária', 'Carlos Tissi', 'Costeira', '83709-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6686, 'Londrina', 'Carlos Vamberto Leal de Mello', 'Vale do Reno', '86047-306', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6687, 'Ponta Grossa', 'Carlos Vetorazzi', 'Colônia Dona Luiza', '84045-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6688, 'Araucária', 'Carlos Vicente Zapxon', 'Costeira', '83709-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6689, 'Curitiba', 'Carlos Wellner', 'Orleans', '82310-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6690, 'Foz do Iguaçu', 'Carlos Welter', 'Vila Yolanda', '85853-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6691, 'Apucarana', 'Carlos Zanon', 'Jardim Colonial II', '86812-548', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6692, 'Umuarama', 'Carlos Zelaquett', 'Parque Bandeirantes', '87504-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6693, 'Cambé', 'Carlota Codato', 'Jardim Boa Vista', '86191-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6694, 'Curitiba', 'Carlota Mion', 'Campina do Siqueira', '80740-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6695, 'Curitiba', 'Carlota Pereira de Queiroz', 'Cajuru', '82920-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6696, 'Almirante Tamandaré', 'Carlota Rodrigues Dias', 'Jardim Primavera', '83506-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6697, 'Curitiba', 'Carlota Straube de Araújo', 'Boa Vista', '82540-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6698, 'Curitiba', 'Carlota Straube de Araújo', 'Boa Vista', '82560-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6699, 'Curitiba', 'Carlota Volp', 'Alto Boqueirão', '81860-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6700, 'Pato Branco', 'Carmela', 'Bortot', '85504-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6701, 'Londrina', 'Carmela Dutra', 'Jardim Morumbi', '86036-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6702, 'Londrina', 'Carmela Dutra', 'Nossa Senhora de Lourdes', '86039-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6703, 'Curitiba', 'Carmela Tosato', 'São Braz', '82310-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6704, 'Cambé', 'Carmélia Bandrimarti Rafaeli', 'Jardim Vitória', '86184-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6705, 'Curitiba', 'Carmelina Cavassin', 'Barreirinha', '82220-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6706, 'Londrina', 'Carmelina Menegazzo Caminhoto', 'Catuaí Parque Residence', '86047-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6707, 'Cascavel', 'Carmelinda Zortéa Parmigiani', 'Cancelli', '85811-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6708, 'Londrina', 'Carmelino de Moraes', 'Alto da Colina', '86050-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6709, 'Curitiba', 'Carmello Greca Júnior', 'Xaxim', '81810-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6710, 'Londrina', 'Carmelo Ferraro', 'Jardim Nova Esperança', '86044-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6711, 'Curitiba', 'Carmelo Rangel', 'Batel', '80440-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6712, 'Foz do Iguaçu', 'Carmelo Serafin', 'Jardim Veraneio', '85855-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6713, 'Paranavaí', 'Carmem Miranda', 'Jardim São Jorge', '87711-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6714, 'São José dos Pinhais', 'Carmem Miranda', 'Afonso Pena', '83050-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6715, 'Toledo', 'Carmem Miranda', 'Jardim Santa Maria', '85903-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6716, 'Apucarana', 'Carmem Miranda', 'Núcleo Habitacional Castelo Branco', '86812-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6717, 'Cascavel', 'Carmem Miranda', 'Brasília', '85815-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6718, 'Curitiba', 'Carmem Miranda', 'Xaxim', '81810-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6719, 'Londrina', 'Carmem Romero', 'Eucaliptos', '86031-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6720, 'Londrina', 'Carmem Rubinho Sanches', 'Conjunto Novo Amparo 2', '86056-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6721, 'Piraquara', 'Carmem Santander', 'Vila Marumbi', '83304-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6722, 'Curitiba', 'Carmen da Silva', 'Cajuru', '82920-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6723, 'Londrina', 'Carmen Gimenas Pestana', 'Jardim Acapulco', '86045-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6724, 'Londrina', 'Carmen Ilhesca Batista', 'Jardim Maria Celina', '86081-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6725, 'Curitiba', 'Carmen Maito Stinglin', 'Portão', '80320-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6726, 'Londrina', 'Carmen Marcolla Pazini', 'Jardim Delta', '86065-827', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6727, 'Foz do Iguaçu', 'Carmen Miranda', 'Jardim Cláudia', '85852-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6728, 'Londrina', 'Carmen Miranda', 'Conjunto Vivi Xavier', '86082-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6729, 'Maringá', 'Carmen Miranda', 'Conjunto Residencial Cidade Alta', '87053-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6730, 'Campo Largo', 'Carmen Miranda', 'Vila Otto', '83607-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6731, 'Colombo', 'Carmen Zanon', 'Colônia Faria', '83412-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6732, 'Telêmaco Borba', 'Carmin', 'Vila São Francisco de Assis', '84264-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6733, 'Curitiba', 'Carminda Gonsalves Oliveira', 'Santa Cândida', '82620-355', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6734, 'Curitiba', 'Carmine de Luca', 'Cachoeira', '82710-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6735, 'Curitiba', 'Carmo', 'Boqueirão', '81650-320', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6736, 'Londrina', 'Carmo Antônio Salum', 'Jardim Acapulco', '86045-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6737, 'Telêmaco Borba', 'Carmo da Mata', 'Vila Rosa', '84272-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6738, 'Foz do Iguaçu', 'Carnaúba', 'Jardim Tropical', '85855-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6739, 'Araucária', 'Carnaúba', 'Estação', '83705-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6740, 'Apucarana', 'Carnaúba', 'Jardim Recanto dos Palmares', '86803-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6741, 'Cascavel', 'Carnaúba', 'Brasmadeira', '85814-118', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6742, 'Maringá', 'Carneiro Leão', 'Zona 01', '87014-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6743, 'Guarapuava', 'Carneiro Lobo', 'Morro Alto', '85065-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6744, 'Curitiba', 'Carneiro Lobo', 'Água Verde', '80240-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6745, 'Ponta Grossa', 'Carneiro Ribeiro', 'Uvaranas', '84030-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6746, 'Cascavel', 'Caroba', 'Parque Verde', '85807-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6747, 'Londrina', 'Carolina', 'Quebec', '86060-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6748, 'Curitiba', 'Carolina Castelli', 'Novo Mundo', '81050-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6749, 'Laranjeiras do Sul', 'Carolina Chrusciak Lemiezek', 'São Francisco', '85303-066', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6750, 'Londrina', 'Carolina Coleto Dematte', 'Jardim Pacaembu', '86079-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6751, 'Curitiba', 'Carolina Derosso', 'Xaxim', '81810-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6752, 'Cambé', 'Carolina do Norte', 'Jardim Golden Park', '86186-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6753, 'Curitiba', 'Carolina dos Anjos', 'Pinheirinho', '81150-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6754, 'Curitiba', 'Carolina Dybas', 'Umbará', '81930-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6755, 'Colombo', 'Carolina Frazão', 'Capivari', '83415-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6756, 'Foz do Iguaçu', 'Carolina Joslin Santos', 'Loteamento Universitário das Américas', '85870-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6757, 'São José dos Pinhais', 'Carolina Manaffes Ligoki', 'Barro Preto', '83015-805', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6758, 'Foz do Iguaçu', 'Carolina Nabuco', 'Jardim Central', '85864-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6759, 'Londrina', 'Carolina Nogueira da Costa', 'Conjunto Habitacional José Garcia Molina', '86080-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6760, 'Londrina', 'Carolina S. Garcia', 'Assis', '86085-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6761, 'Londrina', 'Carolina Vendrame Vaz Primo', 'Jardim Continental', '86081-176', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6762, 'Foz do Iguaçu', 'Carpa', 'Profilurb II', '85855-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6763, 'Maringá', 'Carqueja', 'Conjunto João de Barro Cidade Canção', '87053-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6764, 'Arapongas', 'Carrancho', 'Jardim Panorama', '86708-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6765, 'Arapongas', 'Carrapateiro', 'Conjunto Del Condor', '86703-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6766, 'Arapongas', 'Carrica', 'Jardim Lorena', '86707-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6767, 'São José dos Pinhais', 'Carteiro Vander Lúcio Matara', 'Roseira', '83060-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6768, 'Cascavel', 'Cartola', 'São Cristóvão', '85816-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6769, 'Cascavel', 'Cartola', 'Brasília', '85815-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6770, 'Foz do Iguaçu', 'Caruaru', 'Jardim Petropólis', '85868-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6771, 'Maringá', 'Caruaru', 'Vila Morangueira', '87040-330', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6772, 'Londrina', 'Carvalho', 'Leonor', '86071-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6773, 'Maringá', 'Carvalho', 'Parque Palmeiras', '87023-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6774, 'Ponta Grossa', 'Carvalho', 'Contorno', '84061-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6775, 'Sarandi', 'Carvalho', 'Jardim Monterey', '87112-807', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6776, 'Apucarana', 'Carvalho', 'Jardim Recanto dos Palmares', '86803-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6777, 'Cascavel', 'Carvalho', 'Brasmadeira', '85814-147', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6778, 'Colombo', 'Carvalho Aranha', 'Vila São Pedro', '83404-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6779, 'Laranjeiras do Sul', 'Cascavel', 'São Francisco', '85303-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6780, 'Foz do Iguaçu', 'Cascavel', 'Jardim Ipê', '85869-688', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6781, 'Francisco Beltrão', 'Cascavel', 'Marrecas', '85601-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6782, 'Pinhais', 'Cascavel', 'Jardim Alto Tarumã', '83325-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6783, 'Ponta Grossa', 'Cascavel', 'Chapada', '84062-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6784, 'Sarandi', 'Cascavel', 'Jardim Dom Bosco', '87111-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6785, 'Toledo', 'Cascavel', 'Jardim Carelli', '85906-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6786, 'Cascavel', 'Cascavel', 'Pioneiros Catarinenses', '85805-435', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6787, 'Almirante Tamandaré', 'Cascavel', 'Jardim Taíza', '83505-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6788, 'Cambé', 'Cascavel', 'Jardim Ana Eliza', '86188-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6789, 'Araucária', 'Cascavel', 'Iguaçu', '83701-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6790, 'Colombo', 'Cascavel', 'Jardim Guaraituba', '83410-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6791, 'Curitiba', 'Cascavel', 'Boqueirão', '81670-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6792, 'Curitiba', 'Cascavel', 'Boqueirão', '81750-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6793, 'Foz do Iguaçu', 'Cascudo', 'Profilurb I', '85855-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6794, 'Curitiba', 'Casemiro Augusto Rodacki', 'Cidade Industrial', '81280-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6795, 'Curitiba', 'Casemiro Bagge', 'Campo Comprido', '81210-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6796, 'Apucarana', 'Casemiro Blanski', 'Vila Shangri-La', '86812-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6797, 'Cascavel', 'Casemiro Chervinski', 'Pioneiros Catarinenses', '85805-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6798, 'Londrina', 'Casemiro de Abreu', 'Jardim Tatiani', '86070-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6799, 'Foz do Iguaçu', 'Casemiro de Abreu', 'Jardim Jupira', '85865-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6800, 'Pato Branco', 'Casemiro de Abreu', 'Santa Terezinha', '85506-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6801, 'Ponta Grossa', 'Casemiro de Abreu', 'Uvaranas', '84020-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6802, 'Cascavel', 'Casemiro de Abreu', 'Alto Alegre', '85805-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6803, 'Campo Largo', 'Casemiro de Abreu', 'São Marcos', '83602-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6804, 'Apucarana', 'Casemiro de Abreu', 'Jardim Celmira', '86808-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6805, 'São José dos Pinhais', 'Casemiro Gapski', 'Zaniolo', '83025-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6806, 'São José dos Pinhais', 'Casemiro Greboge', 'Ipê', '83055-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6807, 'Curitiba', 'Casemiro José Sikorski', 'Mossunguê', '81210-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6808, 'Foz do Iguaçu', 'Casemiro Kusbick', 'Jardim Dom Pedro I', '85856-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6809, 'Curitiba', 'Casemiro Mitczuk', 'Cidade Industrial', '81270-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6810, 'Ponta Grossa', 'Casemiro Popinigis', 'Orfãs', '84015-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6811, 'Ponta Grossa', 'Casemiro Reis', 'Nova Rússia', '84053-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6812, 'Guarapuava', 'Casemiro Rozmovski', 'Bonsucesso', '85045-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6813, 'Curitiba', 'Casemiro Tobias Oldakowski', 'Pinheirinho', '81870-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6814, 'Guarapuava', 'Casimiro de Abreu', 'Vila Bela', '85025-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6815, 'Pinhais', 'Casimiro de Abreu', 'Núcleo Colonial de Pinhais', '83321-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6816, 'São José dos Pinhais', 'Casimiro de Abreu', 'Colônia Rio Grande', '83025-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6817, 'Colombo', 'Casimiro de Abreu', 'Parque Monte Castelo', '83409-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6818, 'Curitiba', 'Casimiro José Marques de Abreu', 'Ahú', '82200-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6819, 'Curitiba', 'Casimiro Tosi', 'Capão da Imbuia', '82810-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6820, 'Cascavel', 'Cássia', 'Santa Cruz', '85806-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6821, 'Cascavel', 'Cassiano Jorge Fernandes', 'Maria Luiza', '85819-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6822, 'Cascavel', 'Cassiano Jorge Fernandes', 'Vila Tolentino', '85802-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6823, 'Londrina', 'Cassiano Ricardo', 'Petrópolis', '86015-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6824, 'Guarapuava', 'Cassiano Ricardo', 'Boqueirão', '85022-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6825, 'Foz do Iguaçu', 'Cassiano Ricardo', 'Vila Portes', '85865-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6826, 'Pinhais', 'Cassiano Ricardo', 'Núcleo Colonial de Pinhais', '83321-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6827, 'Pato Branco', 'Cassiano Ricardo', 'Anchieta', '85501-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6828, 'Toledo', 'Cassiano Ricardo', 'Jardim Bela Vista', '85908-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6829, 'Colombo', 'Cassiano Ricardo', 'Jardim Quitandinha', '83409-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6830, 'Ponta Grossa', 'Cassiano Ricardo Leite', 'Cará-cará', '84043-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6831, 'Toledo', 'Cassimiro de Abreu', 'Jardim Paraná', '85904-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6832, 'Londrina', 'Cássio Leite Machado', 'Colinas', '86056-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6833, 'Londrina', 'Cassiterita', 'Waldemar Hauer', '86030-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6834, 'Foz do Iguaçu', 'Castanheira', 'Jardim das Laranjeiras', '85868-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6835, 'Ponta Grossa', 'Castanheira', 'Contorno', '84061-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6836, 'Campo Mourão', 'Castanheira', 'Jardim Lar Paraná', '87305-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6837, 'Foz do Iguaçu', 'Castel Nuevo', 'Jardim Itamaraty', '85863-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6838, 'Foz do Iguaçu', 'Castelão', 'Portal da Foz', '85859-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6839, 'Foz do Iguaçu', 'Castelo', 'Jardim Canadá', '85869-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6840, 'Foz do Iguaçu', 'Castelo Branco', 'Vila Maracanã', '85852-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6841, 'Pato Branco', 'Castelo Branco', 'São Cristóvão', '85508-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6842, 'Telêmaco Borba', 'Castelo Branco', 'Centro', '84261-170', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6843, 'Sarandi', 'Castelo Branco', 'Vera Cruz', '87111-760', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6844, 'Almirante Tamandaré', 'Castelo Branco', 'Jardim São Carlos', '83507-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6845, 'Maringá', 'Castor', 'Jardim Castor', '87030-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6846, 'Curitiba', 'Castorino Augusto Rodrigues', 'Cajuru', '82940-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6847, 'Francisco Beltrão', 'Castro', 'Miniguaçu', '85605-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6848, 'Guarapuava', 'Castro', 'Bonsucesso', '85045-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6849, 'Londrina', 'Castro', 'Araucárias', '86060-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6850, 'Foz do Iguaçu', 'Castro', 'Jardim Paraná', '85867-230', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6851, 'Ponta Grossa', 'Castro', 'Jardim Carvalho', '84016-650', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6852, 'Ponta Grossa', 'Castro', 'Nova Rússia', '84053-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6853, 'São José dos Pinhais', 'Castro', 'Cruzeiro', '83010-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6854, 'Paranavaí', 'Castro', 'Jardim Ouro Branco', '87704-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6855, 'Paranaguá', 'Castro', 'Emboguaçu', '83209-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6856, 'Paranavaí', 'Castro', 'Jardim Ibirapuera', '87705-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6857, 'Toledo', 'Castro', 'Jardim Bressan', '85913-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6858, 'Cascavel', 'Castro', 'São Cristóvão', '85816-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6859, 'Colombo', 'Castro', 'Jardim Guaraituba', '83410-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6860, 'Apucarana', 'Castro', 'Vila Vera Cruz', '86804-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6861, 'Cascavel', 'Castro', 'Brasília', '85815-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6862, 'Curitiba', 'Castro', 'Água Verde', '80620-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6863, 'Foz do Iguaçu', 'Castro Alves', 'Jardim Dom Pedro I', '85856-607', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6864, 'Laranjeiras do Sul', 'Castro Alves', 'Centro', '85301-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6865, 'Francisco Beltrão', 'Castro Alves', 'São Miguel', '85602-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6866, 'Guarapuava', 'Castro Alves', 'Alto da XV', '85065-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6867, 'Londrina', 'Castro Alves', 'Jardim Tatiani', '86070-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6868, 'São José dos Pinhais', 'Castro Alves', 'Boneca do Iguaçu', '83040-520', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6869, 'Ponta Grossa', 'Castro Alves', 'Uvaranas', '84020-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6870, 'Maringá', 'Castro Alves', 'Zona 06', '87015-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6871, 'Pato Branco', 'Castro Alves', 'São Cristóvão', '85508-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6872, 'Sarandi', 'Castro Alves', 'Jardim Panorama', '87113-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6873, 'Umuarama', 'Castro Alves', 'Zona I-A', '87503-330', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6874, 'Telêmaco Borba', 'Castro Alves', 'Jardim Bonavila', '84264-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6875, 'Sarandi', 'Castro Alves', 'Jardim Independência I', '87114-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6876, 'Toledo', 'Castro Alves', 'Jardim Europa', '85908-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6877, 'Toledo', 'Castro Alves', 'Jardim Paulista', '85910-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6878, 'Colombo', 'Castro Alves', 'Jardim Curitiba', '83406-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6879, 'Campo Largo', 'Castro Alves', 'Vila Bancária', '83601-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6880, 'Cascavel', 'Castro Alves', 'Centro', '85810-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6881, 'Cascavel', 'Castro Alves', 'Independência', '85811-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6882, 'Cascavel', 'Castro Alves', 'Vila Tolentino', '85802-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6883, 'Cascavel', 'Castro Alves', 'Centro', '85801-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6884, 'Apucarana', 'Castro Alves', 'Jardim Ponta Grossa', '86805-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6885, 'Apucarana', 'Castro Alves', 'Jardim América', '86807-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6886, 'Curitiba', 'Castro Alves', 'Batel', '80240-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6887, 'Ponta Grossa', 'Castro Lopes', 'Ronda', '84051-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6888, 'Ponta Grossa', 'Castro Magalhães', 'Uvaranas', '84025-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6889, 'Curitiba', 'Castro Stefano', 'Campo Comprido', '81220-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6890, 'Ponta Grossa', 'Casuar', 'Colônia Dona Luiza', '84046-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6891, 'Arapongas', 'Casuar', 'Jardim Primavera', '86702-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6892, 'Londrina', 'Casuarina', 'Leonor', '86071-145', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6893, 'Cascavel', 'Casuarina', 'Parque Verde', '85807-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6894, 'Foz do Iguaçu', 'Catalão', 'Jardim Vasco da Gama', '85862-377', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6895, 'Curitiba', 'Catalina', 'Bacacheri', '82515-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6896, 'Apucarana', 'Catanduva', 'Jardim Ponta Grossa', '86805-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6897, 'Apucarana', 'Catanduva', 'Jardim América', '86807-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6898, 'Guarapuava', 'Catanduvas', 'Boqueirão', '85023-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6899, 'Francisco Beltrão', 'Catanduvas', 'Pinheirinho', '85603-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6900, 'Umuarama', 'Catanduvas', 'Jardim América', '87502-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6901, 'Cascavel', 'Catanduvas', 'São Cristóvão', '85816-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6902, 'Curitiba', 'Catanduvas', 'Cidade Industrial', '81230-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6903, 'Ponta Grossa', 'Catão Monclaro', 'Centro', '84020-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6904, 'Telêmaco Borba', 'Catar', 'Vila Esperança', '84272-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6905, 'Curitiba', 'Cataratas do Iguaçu', 'Atuba', '82860-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6906, 'Londrina', 'Catarina Barbieri Gomes', 'Avelino A Vieira', '86056-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6907, 'Curitiba', 'Catarina Basso Brunetti', 'São Braz', '82315-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6908, 'Almirante Tamandaré', 'Catarina Bonfim Mara', 'Vila Ajambi', '83504-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6909, 'Curitiba', 'Catarina Bressan Scarpin', 'Campo Comprido', '81220-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6910, 'Londrina', 'Catarina de Bora', 'Roveri', '86039-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6911, 'Foz do Iguaçu', 'Catarina de Nadai Singh', 'Cr 1', '85863-716', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6912, 'Araucária', 'Catarina Druszcz Gotfrid', 'Boqueirão', '83704-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6913, 'Curitiba', 'Catarina Ferrarini Ferreira', 'Santa Cândida', '82640-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6914, 'Curitiba', 'Catarina Gabardo', 'Xaxim', '81710-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6915, 'Campo Largo', 'Catarina Gadens', 'Planta Cyro Marques', '83607-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6916, 'Curitiba', 'Catarina Goossen', 'Xaxim', '81830-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6917, 'Arapongas', 'Catarina Humai', 'Centro', '86701-750', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6918, 'Araucária', 'Catarina Incot', 'Boqueirão', '83704-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6919, 'Colombo', 'Catarina Kanaut', 'Jardim Magnópolis', '83403-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6920, 'Curitiba', 'Catarina Margarida Luvizoto Gorda', 'Mossunguê', '81200-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6921, 'Curitiba', 'Catarina Odreski', 'Cidade Industrial', '81460-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6922, 'Almirante Tamandaré', 'Catarina Pedrosa de Moraes', 'Planta Nossa Senhora de Lourdes', '83506-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6923, 'Apucarana', 'Catarina Ponchio', 'Loteamento Santa Cândida', '86802-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6924, 'Curitiba', 'Catarina Scotti', 'Novo Mundo', '81020-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6925, 'Ponta Grossa', 'Catarina Stremel Mayer', 'Oficinas', '84045-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6926, 'Araucária', 'Catarina Tyrka', 'Sabiá', '83708-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6927, 'Foz do Iguaçu', 'Catarina Venz', 'Conjunto Libra II', '85858-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6928, 'Londrina', 'Catarina Victorio', 'Santa Rita 1', '86072-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6929, 'Araucária', 'Catarina Zeni Senegaglia', 'Boqueirão', '83704-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6930, 'Arapongas', 'Catatau', 'Jardim Colúmbia I', '86707-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6931, 'Paranavaí', 'Catete', 'Jardim Santos Dumont', '87706-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6932, 'Paranavaí', 'Catete', 'Jardim Ibirapuera', '87705-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6933, 'Curitiba', 'Catharina Dorigon', 'Mossunguê', '81210-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6934, 'Curitiba', 'Catharina Ivone Perasseta Gasparin', 'Pilarzinho', '82120-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6935, 'Curitiba', 'Catharina Jorge Mansur', 'Cidade Industrial', '81170-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6936, 'Umuarama', 'Catharina Naresse Françolin', 'Parque Bandeirantes', '87504-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6937, 'Curitiba', 'Catharina Potina de Mauro', 'Pilarzinho', '82100-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6938, 'Curitiba', 'Catharina Prodlik', 'Abranches', '82130-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6939, 'Arapongas', 'Catirumbava', 'Parque Industrial I', '86703-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6940, 'Arapongas', 'Catorrita', 'Jardim do Sol', '86705-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6941, 'Maringá', 'Catuaba', 'Jardim Vitória', '87023-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6942, 'Ponta Grossa', 'Catuaba', 'Uvaranas', '84033-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6943, 'Apucarana', 'Catuai', 'Jardim América', '86807-057', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6944, 'Umuarama', 'Catuaí', 'Zona IV', '87504-470', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6945, 'Cambé', 'Catuaí', 'Jardim do Café', '86186-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6946, 'Maringá', 'Catulo Cearense', 'Zona 05', '87015-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6947, 'Paranavaí', 'Catulo da Paixão', 'Jardim Novo Horizonte', '87711-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6948, 'Ponta Grossa', 'Catulo da Paixao Cearense', 'Centro', '84010-720', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6949, 'Foz do Iguaçu', 'Catulo da Paixão Cearense', 'Jardim Naipi', '85853-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6950, 'Apucarana', 'Catulo da Paixão Cearense', 'Núcleo Habitacional Castelo Branco', '86812-396', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6951, 'Curitiba', 'Catulo da Paixão Cearense', 'Cajuru', '82960-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6952, 'Cambé', 'Caturra', 'Jardim do Café', '86186-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6953, 'Foz do Iguaçu', 'Caturrita', 'Conjunto A', '85866-500', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6954, 'Curitiba', 'Cauby da Silva Rego', 'Sítio Cercado', '81910-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6955, 'Arapongas', 'Cauré', 'Jardim Aeroporto', '86702-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6956, 'Cascavel', 'Cavalaria', 'Região do Lago', '85812-245', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6957, 'Paranaguá', 'Cavalheiro Manoel Jordão', 'Parque São João', '83212-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6958, 'Londrina', 'Caviúna', 'Leonor', '86071-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6959, 'Maringá', 'Caviúna', 'Parque Palmeiras', '87023-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6960, 'Telêmaco Borba', 'Caviúna', 'Área 01', '84268-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6961, 'Campo Mourão', 'Caviúna', 'Jardim Santa Nilce I', '87308-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6962, 'Apucarana', 'Caviúna', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6963, 'Curitiba', 'Caviúna', 'Bairro Alto', '82860-430', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6964, 'Pato Branco', 'Caxambu', 'Santo Antônio', '85507-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6965, 'Maringá', 'Caxambu', 'Jardim Alvorada', '87030-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6966, 'Sarandi', 'Caxambu', 'Parque Residencial Nova Aliança', '87111-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6967, 'Piraquara', 'Caxias', 'Jardim Tropical', '83314-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6968, 'Guarapuava', 'Caxias do Sul', 'Alto Cascavel', '85031-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6969, 'Francisco Beltrão', 'Caxias do Sul', 'Pinheirinho', '85603-178', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6970, 'Londrina', 'Cayena', 'Santa Rosa', '86050-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6971, 'Francisco Beltrão', 'Ceará', 'Nossa Senhora Aparecida', '85601-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6972, 'Foz do Iguaçu', 'Ceará', 'Vila Remígio', '85852-140', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6973, 'Guarapuava', 'Ceará', 'Vila Carli', '85045-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6974, 'Paranaguá', 'Ceará', 'Vila do Povo', '83209-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6975, 'Piraquara', 'Ceará', 'Jardim dos Estados 3', '83307-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6976, 'Londrina', 'Ceará', 'Oriente', '86027-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6977, 'Paranavaí', 'Ceará', 'Centro', '87702-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6978, 'Ponta Grossa', 'Ceará', 'Olarias', '84035-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6979, 'Piraquara', 'Ceará', 'Jardim dos Estados 2', '83308-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6980, 'Maringá', 'Ceará', 'Jardim Alvorada', '87033-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6981, 'São José dos Pinhais', 'Ceará', 'Silveira da Motta', '83030-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6982, 'Umuarama', 'Ceará', 'Zona II', '87502-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6983, 'Toledo', 'Ceará', 'Conjunto Residencial Rossani', '85901-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6984, 'Telêmaco Borba', 'Ceará', 'Vila Ozorio', '84268-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6985, 'Sarandi', 'Ceará', 'Parque Residencial Nova Aliança', '87111-730', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6986, 'Apucarana', 'Ceará', 'Jardim Apucarana', '86804-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6987, 'Araucária', 'Ceará', 'Iguaçu', '83701-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6988, 'Colombo', 'Ceará', 'Vila Guaraci', '83404-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6989, 'Campo Largo', 'Ceará', 'Vila Itaqui', '83604-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6990, 'Almirante Tamandaré', 'Ceará', 'Vila Dolores', '83514-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6991, 'Almirante Tamandaré', 'Ceará', 'Jardim Formosa', '83511-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6992, 'Campo Largo', 'Ceará', 'Jardim Boa Vista', '83609-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6993, 'Curitiba', 'Ceará', 'Parolin', '80220-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6994, 'Curitiba', 'Cecília Aguiale Pinto', 'Alto Boqueirão', '81860-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6995, 'Curitiba', 'Cecília Camparin de Freitas', 'Cidade Industrial', '81350-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6996, 'Curitiba', 'Cecília do Rego Almeida', 'Cristo Rei', '80050-660', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6997, 'Curitiba', 'Cecília Marques da Luz', 'Atuba', '82630-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6998, 'Campo Largo', 'Cecília Martini Puppi', 'Vila Bancária', '83601-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (6999, 'Guarapuava', 'Cecília Meireles', 'Dos Estados', '85035-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7000, 'Foz do Iguaçu', 'Cecília Meireles', 'Jardim Central', '85864-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7001, 'Cambé', 'Cecília Meireles', 'Residencial Elizabeth', '86188-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7002, 'Almirante Tamandaré', 'Cecília Meireles', 'Vila Marta', '83508-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7003, 'Colombo', 'Cecília Meireles', 'Jardim Quitandinha', '83409-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7004, 'Curitiba', 'Cecília Meireles', 'São Lourenço', '82200-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7005, 'Londrina', 'Cecília Meirelles', 'Palermo', '86060-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7006, 'Curitiba', 'Cecília Mikosz', 'Taboão', '82130-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7007, 'Curitiba', 'Cecília Posselt Watter', 'Novo Mundo', '81020-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7008, 'Curitiba', 'Cecília Ribas Munhoz', 'Portão', '80320-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7009, 'Curitiba', 'Cecília Ribeiro', 'Novo Mundo', '81050-617', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7010, 'Londrina', 'Cecília Tofano', 'Aragarça', '86038-485', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7011, 'Londrina', 'Cecília Wolff', 'Portal de Versalhes 1', '86057-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7012, 'Londrina', 'Cecilio de Oliveira', 'Jatobá', '86043-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7013, 'Apucarana', 'Cecílio Luz', 'Loteamento Sanches dos Santos', '86806-578', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7014, 'São José dos Pinhais', 'Cecílio Maximiliano', 'São Sebastião', '83075-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7015, 'Curitiba', 'Cecílio Toniolo', 'Portão', '80320-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7016, 'Londrina', 'Ceconha', 'Conjunto Habitacional Violim', '86084-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7017, 'Ponta Grossa', 'Cedrilho', 'Uvaranas', '84033-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7018, 'Foz do Iguaçu', 'Cedro', 'Jardim Tropical', '85855-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7019, 'Guarapuava', 'Cedro', 'Industrial', '85053-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7020, 'Ponta Grossa', 'Cedro', 'Contorno', '84061-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7021, 'Ponta Grossa', 'Cedro', 'Colônia Dona Luiza', '84046-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7022, 'Piraquara', 'Cedro', 'Vila Santa Maria', '83306-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7023, 'Maringá', 'Cedro', 'Zona 08', '87050-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7024, 'Telêmaco Borba', 'Cedro', 'Área 01', '84268-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7025, 'Campo Mourão', 'Cedro', 'Jardim Santa Nilce I', '87308-230', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7026, 'Cascavel', 'Cedro', 'Recanto Tropical', '85807-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7027, 'Apucarana', 'Cedro', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7028, 'Araucária', 'Cedro', 'Estação', '83705-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7029, 'Curitiba', 'Cego Bento', 'Uberaba', '81560-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7030, 'Arapongas', 'Cegonha', 'Vila Araponguinha', '86705-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7031, 'Foz do Iguaçu', 'Cegonhas', 'Portal da Foz', '85859-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7032, 'Curitiba', 'Ceilão', 'Cajuru', '82960-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7033, 'Londrina', 'Celcino Alves de Almeida', 'Jardim São Jorge', '86082-837', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7034, 'Foz do Iguaçu', 'Celeste Azambuja Sottomaior', 'Jardim Eliza II', '85853-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7035, 'Londrina', 'Celeste Castanha de Barros', 'Jardim Acapulco', '86045-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7036, 'Colombo', 'Celeste Crozeta', 'Jardim João Paulo II', '83402-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7037, 'Campo Mourão', 'Celeste Keller Dec', 'Jardim Cidade Nova', '87308-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7038, 'Curitiba', 'Celeste Paschoal Milani', 'Santa Cândida', '82720-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7039, 'Londrina', 'Celeste Santato', 'Imperial', '86039-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7040, 'Curitiba', 'Celeste Santi', 'Ahú', '80530-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7041, 'Curitiba', 'Celeste Senegaglia', 'Cidade Industrial', '81270-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7042, 'Curitiba', 'Celeste Tortato Gabardo', 'Sítio Cercado', '81900-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7043, 'Araucária', 'Celeste Zeni Cantador', 'Boqueirão', '83704-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7044, 'São José dos Pinhais', 'Celestina Escolaro Foggiatto', 'Cruzeiro', '83010-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7045, 'Paranaguá', 'Celestinaldo Farias', 'Itiberê', '83206-356', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7046, 'Foz do Iguaçu', 'Celestino Castelli', 'Parque Presidente II', '85863-560', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7047, 'Pato Branco', 'Celestino Fornari', 'Pagnoncelli', '85509-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7048, 'Curitiba', 'Celestino Júnior', 'São Francisco', '80510-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7049, 'Curitiba', 'Celestino Messing de Siqueira', 'Cidade Industrial', '81350-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7050, 'Curitiba', 'Célia Cabral Salgueiro', 'Santa Felicidade', '82015-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7051, 'Londrina', 'Célia dos Santos Sá', 'Conjunto Semiramis Barros Braga', '86088-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7052, 'Toledo', 'Célia Mazzaferro', 'Conjunto Habitacional São Francisco', '85912-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7053, 'Piraquara', 'Célia Regina do Nascimento Goinski', 'Planta Amazonas', '83311-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7054, 'Curitiba', 'Célia Ribas Pimpão', 'Barreirinha', '82710-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7055, 'Foz do Iguaçu', 'Célia Rodrigues Pinto', 'Jardim Marisa', '85867-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7056, 'Campo Mourão', 'Célia Simão Broza', 'Jardim Modelo', '87309-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7057, 'São José dos Pinhais', 'Célia Terezinha Bassa', 'Colônia Murici', '83085-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7058, 'Londrina', 'Celide Fierli Barbosa', 'Jardim Alphaville', '86084-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7059, 'Curitiba', 'Celina Posselt Mansur', 'Novo Mundo', '81050-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7060, 'Curitiba', 'Celina Terezinha Canha', 'Alto Boqueirão', '81860-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7061, 'Cambé', 'Celino Liboni', 'Jardim Vila Rica', '86192-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7062, 'Araucária', 'Célio José Franceschi', 'Capela Velha', '83706-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7063, 'Pinhais', 'Célio José Pivova', 'Jardim Triângulo', '83331-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7064, 'Curitiba', 'Célio José Pivova', 'Uberaba', '81570-120', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7065, 'Ponta Grossa', 'Celmira Bento Macedo', 'Boa Vista', '84072-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7066, 'Guarapuava', 'Celmira Garcia Costa', 'Batel', '85015-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7067, 'Curitiba', 'Celso Aarão', 'Tatuquara', '81470-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7068, 'São José dos Pinhais', 'Celso Antônio Marochi', 'Guatupê', '83060-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7069, 'Foz do Iguaçu', 'Celso Benitez Rorato', 'Jardim Porto Belo', '85867-595', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7070, 'Curitiba', 'Celso Carneiro de Souza', 'Santa Felicidade', '82400-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7071, 'Curitiba', 'Celso César Osternack', 'Cajuru', '82980-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7072, 'São José dos Pinhais', 'Celso da Costa Ramos', 'Ipê', '83055-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7073, 'Londrina', 'Celso Dalazuana Sampaio', 'Residencial Veneza', '86038-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7074, 'Apucarana', 'Celso de Azevedo', 'Loteamento Santa Maria', '86813-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7075, 'Apucarana', 'Celso de Carvalho', 'Vila Brasil', '86800-287', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7076, 'Curitiba', 'Celso do Amaral Cattani', 'Bacacheri', '82600-365', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7077, 'Cascavel', 'Celso Esperança', 'Parque São Paulo', '85803-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7078, 'Foz do Iguaçu', 'Celso Fagundes', 'Jardim Bandeirantes', '85862-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7079, 'Londrina', 'Celso Garcia Cid', 'Conjunto Habitacional Flores', '86047-500', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7080, 'Londrina', 'Celso Garcia Cid', 'Conjunto Três Marcos', '86046-770', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7081, 'Londrina', 'Celso Garcia Cid', 'Parque das Indústrias', '86042-610', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7082, 'Londrina', 'Celso Garcia Cid', 'Jardim Sabará I', '86066-230', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7083, 'Londrina', 'Celso Garcia Cid', 'Parque Residencial Campos Elísios', '86044-290', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7084, 'Londrina', 'Celso Garcia Cid', 'Jardim Portal de Versalhes 1', '86057-250', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7085, 'Londrina', 'Celso Garcia Cid', 'Gleba Fazenda Palhano', '86057-350', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7086, 'Londrina', 'Celso Garcia Cid', 'Centro', '86010-490', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7087, 'Londrina', 'Celso Garcia Cid', 'Vila Siam', '86039-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7088, 'Umuarama', 'Celso Garcia Cid', 'Zona I', '87501-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7089, 'Cambé', 'Celso Garcia Cid', 'Parque Residencial Manela', '86185-520', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7090, 'Cambé', 'Celso Garcia Cid', 'Jardim Ana Eliza', '86187-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7091, 'Cambé', 'Celso Garcia Cid', 'Jardim Ana Eliza', '86188-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7092, 'Curitiba', 'Celso Joe Marques', 'Cidade Industrial', '81460-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7093, 'Curitiba', 'Celso Luiz do Vale', 'Uberaba', '81550-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7094, 'Maringá', 'Celso Paula Soares', 'Conjunto Habitacional Requião', '87047-457', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7095, 'Araucária', 'Celso Silva', 'Campina da Barra', '83709-845', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7096, 'Apucarana', 'Celso Soni', 'Recanto Mundo Novo', '86805-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7097, 'Curitiba', 'Celso Teixeira Pinto', 'Santa Cândida', '82630-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7098, 'Colombo', 'Celta', 'Vila Alto da Cruz II', '83405-210', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7099, 'Curitiba', 'Celzira Ressetti Stofella', 'Cajuru', '82920-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7100, 'Londrina', 'Cenira A. Ferreira', 'Giovani Lunardelli', '86037-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7101, 'Foz do Iguaçu', 'Cenobelino Rodrigues Cunha', 'Parque Morumbi II', '85859-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7102, 'Londrina', 'Centauro', 'Sol', '86070-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7103, 'Foz do Iguaçu', 'Centenário', 'Parque Morumbi II', '85858-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7104, 'Foz do Iguaçu', 'Centenário', 'Parque Morumbi II', '85859-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7105, 'Guarapuava', 'Centenário', 'São Cristóvão', '85060-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7106, 'Maringá', 'Centenário', 'Vila Christino', '87050-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7107, 'Campo Largo', 'Centenário', 'Centro', '83601-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7108, 'Araucária', 'Centenário', 'Barigui', '83707-610', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7109, 'Curitiba', 'Centenário', 'Cajuru', '82960-230', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7110, 'Piraquara', 'Centenário do Paraná', 'Jardim Bela Vista', '83301-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7111, 'Londrina', 'Centenário do Sul', 'Lindóia', '86031-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7112, 'Ponta Grossa', 'Centenário do Sul', 'Boa Vista', '84071-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7113, 'Castro', 'Central', 'Jardim Bela Vista', '84165-360', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7114, 'Apucarana', 'Central do Paraná', 'Jardim Diamantina', '86804-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7115, 'Apucarana', 'Central do Paraná', 'Jardim Ponta Grossa', '86807-315', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7116, 'Ponta Grossa', 'Central Paraná', 'Chapada', '84062-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7117, 'Cambé', 'Centro Cultural', 'Jardim Vila Rica', '86181-320', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7118, 'Foz do Iguaçu', 'Centro Novo', 'Loteamento Witt', '85862-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7119, 'Francisco Beltrão', 'Cenuce Abdala', 'Água Branca', '85601-331', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7120, 'Ponta Grossa', 'Cerâmica Guarani', 'Uvaranas', '84031-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7121, 'Francisco Beltrão', 'Cerejeira', 'São Cristóvão', '85601-366', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7122, 'Foz do Iguaçu', 'Cerejeira', 'Jardim das Laranjeiras', '85868-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7123, 'Ponta Grossa', 'Cerejeira', 'Contorno', '84061-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7124, 'Maringá', 'Cerejeira', 'Parque Palmeiras', '87023-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7125, 'Umuarama', 'Cerejeira', 'Jardim Paineiras', '87503-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7126, 'Telêmaco Borba', 'Cerejeira', 'Área 01', '84268-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7127, 'Cambé', 'Cerejeira', 'Vila Salomé', '86192-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7128, 'Cascavel', 'Cerejeira', 'Recanto Tropical', '85807-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7129, 'Almirante Tamandaré', 'Cerejeira', 'Loteamento Chico Mendes', '83505-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7130, 'Campo Largo', 'Cerejeira', 'Vila Dom Pedro II', '83608-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7131, 'Sarandi', 'Cerejeiras', 'Jardim Monterey', '87112-796', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7132, 'Maringá', 'Cerqueira Cezar', 'Zona 04', '87014-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7133, 'Maringá', 'Cerro Azul', 'Zona 02', '87010-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7134, 'Sarandi', 'Cerro Azul', 'Jardim Ibirapuera', '87112-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7135, 'Telêmaco Borba', 'Cerro Azul', 'Bela Vista do Paraíso', '84262-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7136, 'Almirante Tamandaré', 'Cerro Azul', 'Jardim Roma', '83504-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7137, 'Colombo', 'Cerro Azul', 'Jardim São José', '83410-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7138, 'Curitiba', 'Cerro Azul', 'Cidade Industrial', '81290-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7139, 'Maringá', 'Cerro Cora', 'Zona 06', '87015-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7140, 'Toledo', 'Cerro Cora', 'Vila Industrial', '85904-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7141, 'Toledo', 'Cerro Largo', 'Jardim Porto Alegre', '85906-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7142, 'Curitiba', 'Certemio de Costa', 'Sítio Cercado', '81900-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7143, 'Paranaguá', 'Cesalpino Passos', 'Bockmann', '83206-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7144, 'Londrina', 'César Beltrão Pernetta', 'Jardim Maria Celina', '86081-536', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7145, 'Ponta Grossa', 'César Burlamaki', 'Uvaranas', '84026-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7146, 'Londrina', 'César Casarin', 'Santiago', '86071-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7147, 'São José dos Pinhais', 'César Constantino Jacinto', 'Braga', '83020-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7148, 'Curitiba', 'César Correia de Souza Pinto Júnior', 'Santa Felicidade', '82015-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7149, 'Londrina', 'César de Oliveira Bertin', 'Jardim Vale Verde', '86040-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7150, 'Araucária', 'César Hasselmann', 'Boqueirão', '83704-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7151, 'Curitiba', 'César Misael Chaves', 'Taboão', '82130-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7152, 'Cambé', 'César Moreschi', 'Parque Residencial Ana Rosa', '86183-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7153, 'Apucarana', 'César Preto', 'Jardim Presidente Kennedy', '86809-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7154, 'Apucarana', 'César Zanoni', 'Jardim Adriane', '86807-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7155, 'Londrina', 'Cesarina Lima Camargo', 'Jardim Pacaembu', '86079-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7156, 'Ponta Grossa', 'Cesário Alvim', 'Olarias', '84035-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7157, 'Araucária', 'Cesário Furman', 'Chapada', '83705-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7158, 'Curitiba', 'Cesário Kuroski', 'Cidade Industrial', '81230-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7159, 'Ponta Grossa', 'Cessna', 'Cará-cará', '84043-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7160, 'Guarapuava', 'Céu Azul', 'Jardim das Américas', '85030-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7161, 'Pinhais', 'Céu Azul', 'Jardim Alto Tarumã', '83325-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7162, 'Sarandi', 'Céu Azul', 'Jardim Universal', '87114-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7163, 'Toledo', 'Céu Azul', 'Jardim Santa Maria', '85903-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7164, 'Cascavel', 'Céu Azul', 'Pacaembu', '85816-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7165, 'Curitiba', 'Céu Azul', 'Santa Cândida', '82630-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7166, 'Paranaguá', 'Cezar Alcides Frizzo', 'Vila São Vicente', '83209-156', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7167, 'Castro', 'Cezar Augusto Beck', 'Vila Rio Branco', '84172-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7168, 'Almirante Tamandaré', 'Cezar Augusto Ferri', 'Planta Almirante', '83508-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7169, 'Curitiba', 'Cezar Augusto Scandelari', 'Pilarzinho', '82100-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7170, 'Curitiba', 'Cezar Barreto', 'Sítio Cercado', '81900-760', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7171, 'Apucarana', 'Cézar Beletato', 'Jardim Catuaí III', '86802-629', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7172, 'Laranjeiras do Sul', 'Cezar Brondani', 'Centro', '85301-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7173, 'Curitiba', 'Cezar Constante Schiavon', 'Sítio Cercado', '81925-568', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7174, 'Maringá', 'Cezar Lattes', 'Jardim Alvorada', '87035-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7175, 'Apucarana', 'Cezar Marcos Navia', 'Jardim Morada do Sol', '86811-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7176, 'Curitiba', 'Cezar Pastre', 'Bigorrilho', '80710-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7177, 'Toledo', 'Cezar Pedrini', 'César Park', '85913-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7178, 'Guarapuava', 'Cezar Stange', 'Boqueirão', '85020-530', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7179, 'Cascavel', 'Cezário Bazaki', 'Região do Lago 3', '85819-785', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7180, 'Ponta Grossa', 'Cezario Breus', 'Boa Vista', '84073-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7181, 'Campo Largo', 'Cezário Curial', 'Vila Ferrari II', '83606-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7182, 'Curitiba', 'Cezário Curial', 'Pilarzinho', '82110-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7183, 'Sarandi', 'Cezário Mancine', 'Jardim Esperança III', '87112-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7184, 'Curitiba', 'Cezinando Dias Paredes', 'Boqueirão', '81730-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7185, 'Londrina', 'Cezira Dal Bosco Acauam', 'Residencial Loris Sahyun', '86040-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7186, 'Castro', 'CH-3', 'Castroville', '84178-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7187, 'Castro', 'CH-7', 'Castroville', '84178-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7188, 'Telêmaco Borba', 'Chade', 'Vila Esperança', '84272-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7189, 'Piraquara', 'Chafi Boazar', 'Centro', '83301-005', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7190, 'Ponta Grossa', 'Chafic Azim', 'Jardim Carvalho', '84016-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7191, 'Campo Mourão', 'Chafic Bader Maluf', 'Jardim Country Club', '87300-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7192, 'Londrina', 'Chafic Burihan', 'Jardim Campos Verdes', '86085-249', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7193, 'Toledo', 'Chalé de Minas', 'Jardim Paulista', '85910-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7194, 'Telêmaco Borba', 'Chanceler Horácio Laffer', 'Alto das Oliveiras', '84265-580', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7195, 'Telêmaco Borba', 'Chanceler Horácio Laffer', 'Centro', '84261-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7196, 'Curitiba', 'Chanceler Lauro Muller', 'Parolin', '80220-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7197, 'Curitiba', 'Chanceler Oswaldo Aranha', 'Hauer', '81630-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7198, 'Guarapuava', 'Chapecó', 'Bonsucesso', '85035-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7199, 'Francisco Beltrão', 'Chapecó', 'Pinheirinho', '85603-330', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7200, 'Foz do Iguaçu', 'Chapecó', 'Loteamento Campos do Iguaçu', '85857-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7201, 'Piraquara', 'Chapecó', 'Planta São Tiago', '83307-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7202, 'São José dos Pinhais', 'Chapecó', 'São Sebastião', '83075-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7203, 'Cascavel', 'Chapecó', 'Universitário', '85819-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7204, 'Curitiba', 'Chapecó', 'Cidade Industrial', '81230-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7205, 'São José dos Pinhais', 'Charles Darwin', 'Aristocrata', '83030-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7206, 'Curitiba', 'Charles Darwin', 'Barreirinha', '82220-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7207, 'Curitiba', 'Charles Dickens', 'Abranches', '82220-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7208, 'Curitiba', 'Charles Fourier', 'São Braz', '82015-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7209, 'Londrina', 'Charles Good Year', 'Industrial', '86063-340', 'Bosque', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7210, 'Londrina', 'Charles Lindemberg', 'Califórnia', '86040-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7211, 'Cascavel', 'Charles Lindemberg', 'Santos Dumont', '85804-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7212, 'Ponta Grossa', 'Charles Louis Jean Renaud', 'Jardim Carvalho', '84016-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7213, 'Curitiba', 'Charles Nicolle', 'Cajuru', '82940-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7214, 'Londrina', 'Charles Robert Darwin', 'Maringá', '86060-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7215, 'Telêmaco Borba', 'Charqueada', 'Área 02', '84269-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7216, 'Arapongas', 'Chauã', 'Jardim Colúmbia IV', '86707-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7217, 'Londrina', 'Chavantes', 'Vila Goes', '86026-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7218, 'Ponta Grossa', 'Chavantes', 'Oficinas', '84035-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7219, 'Ponta Grossa', 'Chefe Inácio de Lara', 'Oficinas', '84045-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7220, 'Ponta Grossa', 'Chefe João Frare', 'Oficinas', '84045-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7221, 'Londrina', 'Chefe Newton', 'Progresso', '86079-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7222, 'Londrina', 'Chepli Tanus Daher', 'Jardim Acapulco', '86045-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7223, 'Ponta Grossa', 'Cheripas', 'Oficinas', '84035-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7224, 'Ponta Grossa', 'Cherokee', 'Cará-cará', '84043-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7225, 'Laranjeiras do Sul', 'Chiassi Antônio Fae', 'Centro', '85301-316', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7226, 'Arapongas', 'Chibante', 'Jardim do Carmo', '86703-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7227, 'Guarapuava', 'Chicago', 'Santa Cruz', '85015-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7228, 'Maringá', 'Chicago', 'Jardim Los Angeles', '87080-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7229, 'Curitiba', 'Chichorro Júnior', 'Cabral', '80035-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7230, 'Paranaguá', 'Chico Mendes', 'Vila do Caic', '83215-698', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7231, 'Maringá', 'Chico Mendes', 'Zona 28', '87053-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7232, 'Toledo', 'Chico Mendes', 'Jardim La Salle', '85903-260', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7233, 'Colombo', 'Chico Mendes', 'Jardim Campo Alto', '83408-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7234, 'Piraquara', 'Chico Xavier', 'Jardim Veneza', '83310-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7235, 'Maringá', 'Chihiro Nakatani', 'Jardim Imperial', '87023-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7236, 'Curitiba', 'Childerico Beviláqua', 'Alto Boqueirão', '81830-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7237, 'Guarapuava', 'Chile', 'Morro Alto', '85067-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7239, 'Foz do Iguaçu', 'Chile', 'Jardim América', '85864-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7240, 'Francisco Beltrão', 'Chile', 'Miniguaçu', '85605-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7241, 'Laranjeiras do Sul', 'Chile', 'Cristo Rei', '85304-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7242, 'São José dos Pinhais', 'Chile', 'Cidade Jardim', '83035-200', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7243, 'Pato Branco', 'Chile', 'Jardim América', '85502-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7244, 'Maringá', 'Chile', 'Jardim Alvorada', '87033-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7245, 'Maringá', 'Chile', 'Ebenezer', '87035-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7246, 'Ponta Grossa', 'Chile', 'Ronda', '84051-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7247, 'Toledo', 'Chile', 'Centro', '85901-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7248, 'Telêmaco Borba', 'Chile', 'Socomim', '84266-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7249, 'Cascavel', 'Chile', 'Pacaembu', '85816-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7250, 'Cambé', 'Chile', 'Centro', '86181-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7251, 'Cambé', 'Chile', 'Jardim Vila Rica', '86192-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7252, 'Colombo', 'Chile', 'Jardim Rio Verde', '83405-330', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7253, 'Apucarana', 'Chile', 'Jardim Diamantina', '86804-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7254, 'Castro', 'Chile', 'Vila do Rosário', '84168-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7255, 'Almirante Tamandaré', 'Chile', 'Jardim São Francisco', '83501-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7256, 'Curitiba', 'Chile', 'Rebouças', '80215-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7257, 'Curitiba', 'Chile', 'Rebouças', '80220-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7258, 'Curitiba', 'Chile', 'Rebouças', '80220-181', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7259, 'Arapongas', 'Chimango', 'Conjunto Padre Chico', '86707-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7260, 'Londrina', 'China', 'São Vicente', '86046-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7261, 'Francisco Beltrão', 'China', 'Pinheirinho', '85606-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7262, 'Telêmaco Borba', 'China', 'Área 01', '84272-310', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7263, 'Apucarana', 'China', 'Vila Operária 1', '86808-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7264, 'Almirante Tamandaré', 'China', 'Vila Graziela', '83505-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7265, 'Londrina', 'Chipre', 'São Vicente', '86046-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7266, 'Arapongas', 'Chirito-branco', 'Jardim Colúmbia I', '86707-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7267, 'Arapongas', 'Chirito-de-colar', 'Jardim Colúmbia I', '86707-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7268, 'Arapongas', 'Choça', 'Jardim Colúmbia I', '86707-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7269, 'Arapongas', 'Choca-lustrosa', 'Conjunto Del Condor', '86703-318', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7270, 'Francisco Beltrão', 'Chopim', 'Padre Ulrico', '85604-479', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7271, 'Araucária', 'Chopim', 'Estação', '83705-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7272, 'Arapongas', 'Chopin-do-brejo', 'Parque Industrial II', '86703-746', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7273, 'Laranjeiras do Sul', 'Chopinzinho', 'Água Verde', '85302-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7274, 'Ponta Grossa', 'Chopinzinho', 'Ronda', '84051-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7275, 'Cascavel', 'Chopinzinho', 'Santa Cruz', '85806-757', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7276, 'Ponta Grossa', 'Chorão', 'Contorno', '84061-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7277, 'Arapongas', 'Chorão', 'Conjunto Palmares', '86706-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7278, 'Arapongas', 'Chororó-negro', 'Conjunto Novo Centauro', '86709-546', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7279, 'Paranavaí', 'Chozo Kamitami', 'Jardim Progresso', '87701-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7280, 'Curitiba', 'Christiano Schmitz', 'Xaxim', '81810-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7281, 'Curitiba', 'Christina Barletta Tuoto', 'Cidade Industrial', '81170-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7282, 'Curitiba', 'Christina Dresch Vialle', 'Santa Felicidade', '82020-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7283, 'Londrina', 'Christina Jorge', 'San Izidro', '86040-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7284, 'Ponta Grossa', 'Chuckri Mitri Nastas', 'Contorno', '84060-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7285, 'Londrina', 'Chuí', 'Jardim Agari', '86025-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7286, 'Cascavel', 'Chuí', 'Canadá', '85813-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7287, 'Apucarana', 'Chumbo', 'Parque Industrial Zona Norte', '86806-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7288, 'Arapongas', 'Chupa-dente', 'Jardim Aeroporto', '86702-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7289, 'Londrina', 'Chupim', 'Conjunto Habitacional Violim', '86084-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7290, 'Paranaguá', 'Chuva de Prata', 'Conjunto Nilson Neves', '83215-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7291, 'Ponta Grossa', 'Cianita', 'Neves', '84021-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7292, 'Guarapuava', 'Cianorte', 'Jardim das Américas', '85030-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7293, 'Foz do Iguaçu', 'Cianorte', 'Jardim das Palmeiras', '85869-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7294, 'Londrina', 'Cianorte', 'Champagnat', '86062-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7295, 'Ponta Grossa', 'Cianorte', 'Ronda', '84051-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7296, 'Pinhais', 'Cianorte', 'Jardim Pedro Demeterco', '83324-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7297, 'Toledo', 'Cianorte', 'Boa Esperança', '85909-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7298, 'Umuarama', 'Cianorte', 'Zona IV', '87504-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7299, 'Campo Mourão', 'Cianorte', 'Conjunto Residencial Antilhas', '87308-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7300, 'Campo Mourão', 'Cianorte', 'Jardim Alvorada', '87308-426', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7301, 'Cambé', 'Cianorte', 'Jardim Ana Eliza', '86188-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7302, 'Curitiba', 'Cícero', 'Santa Cândida', '82630-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7303, 'Piraquara', 'Cícero Brasil', 'Vila Susi', '83304-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7304, 'Curitiba', 'Cícero Franca', 'Cidade Industrial', '81170-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7305, 'Curitiba', 'Cícero Francisco dos Anjos', 'Alto Boqueirão', '81770-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7306, 'Curitiba', 'Cícero Jaime Bley', 'Bacacheri', '82515-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7307, 'Castro', 'Cícero Moraes Collet', 'Núcleo Habitacional Padre Piva', '84178-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7308, 'Foz do Iguaçu', 'Cícero Plácido dos Santos', 'Jardim Residencial Atlanta', '85856-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7309, 'Curitiba', 'Cícero Portes', 'Sítio Cercado', '81910-680', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7310, 'Castro', 'Cid Danton Kiel', 'Jardim Social Primavera', '84174-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7311, 'Curitiba', 'Cid Gonçalves', 'Cidade Industrial', '81240-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7312, 'Curitiba', 'Cid José dos Santos', 'Uberaba', '81590-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7313, 'Curitiba', 'Cid Marcondes de Albuquerque', 'Pinheirinho', '81820-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7314, 'Curitiba', 'Cid Marcondes de Albuquerque', 'Pinheirinho', '81825-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7315, 'Curitiba', 'Cidadania da Santa Felicidade', 'Santa Felicidade', '82030-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7316, 'Curitiba', 'Cidade Alto Paraná', 'Pinheirinho', '81880-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7317, 'Curitiba', 'Cidade de Antonina', 'Cajuru', '82960-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7318, 'Maringá', 'Cidade de Bréscia', 'Nucleo Social Papa João XXIII', '87080-630', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7319, 'Curitiba', 'Cidade de Caçador', 'Cidade Industrial', '81240-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7320, 'Curitiba', 'Cidade de Campos Novos', 'Cidade Industrial', '81250-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7321, 'Curitiba', 'Cidade de Capinzal', 'Cidade Industrial', '81240-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7322, 'Curitiba', 'Cidade de Concórdia', 'Cidade Industrial', '81290-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7323, 'Curitiba', 'Cidade de Coronel Freitas', 'Cidade Industrial', '81270-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7324, 'Curitiba', 'Cidade de Curitibanos', 'Cidade Industrial', '81270-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7325, 'Curitiba', 'Cidade de Cusco', 'Santo Inácio', '82010-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7326, 'Curitiba', 'Cidade de Descanso', 'Cidade Industrial', '81240-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7327, 'Curitiba', 'Cidade de Fênix', 'Atuba', '82860-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7328, 'Curitiba', 'Cidade de Figueira', 'Alto Boqueirão', '81860-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7329, 'Curitiba', 'Cidade de Franca', 'Seminário', '80310-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7330, 'Curitiba', 'Cidade de Goioerê', 'Alto Boqueirão', '81860-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7331, 'Londrina', 'Cidade de Guimarães', 'Erotildes', '86015-845', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7332, 'Curitiba', 'Cidade de Ilhota', 'Cidade Industrial', '81240-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7333, 'Curitiba', 'Cidade de Ituporanga', 'Sítio Cercado', '81910-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7334, 'Curitiba', 'Cidade de Laguna', 'Cidade Industrial', '81240-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7335, 'Maringá', 'Cidade de Leiria', 'Zona 01', '87013-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7336, 'Curitiba', 'Cidade de Mainz', 'Atuba', '82860-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7337, 'Curitiba', 'Cidade de Maravilha', 'Sítio Cercado', '81910-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7338, 'Curitiba', 'Cidade de Maria Helena', 'Cidade Industrial', '81250-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7339, 'Curitiba', 'Cidade de Missal', 'Atuba', '82860-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7340, 'Curitiba', 'Cidade de Montero', 'Cajuru', '82930-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7341, 'Curitiba', 'Cidade de Ouro', 'Sítio Cercado', '81910-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7342, 'Curitiba', 'Cidade de Palmas', 'Sítio Cercado', '81920-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7343, 'Curitiba', 'Cidade de Palmitos', 'Sítio Cercado', '81910-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7344, 'Curitiba', 'Cidade de Pien', 'Alto Boqueirão', '81860-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7345, 'Curitiba', 'Cidade de Pomerode', 'Cidade Industrial', '81230-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7346, 'Curitiba', 'Cidade de Rodeio', 'Cidade Industrial', '81270-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7347, 'Curitiba', 'Cidade de Santa Isabel do Ivai', 'Cidade Industrial', '81260-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7348, 'Curitiba', 'Cidade de Santa Isabel do Oeste', 'Cidade Industrial', '81310-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7349, 'Curitiba', 'Cidade de Santa Mariana', 'Sítio Cercado', '81910-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7350, 'Curitiba', 'Cidade de Saudades', 'Sítio Cercado', '81910-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7351, 'Curitiba', 'Cidade de Timbo', 'Cidade Industrial', '81250-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7352, 'Curitiba', 'Cidade de Três Barras', 'Cidade Industrial', '81270-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7353, 'Curitiba', 'Cidade de Tubarão', 'Cidade Industrial', '81240-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7354, 'Curitiba', 'Cidade de Uniflor', 'Cidade Industrial', '81240-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7355, 'Maringá', 'Cidade de Valença', 'Jardim Alvorada', '87033-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7356, 'Curitiba', 'Cidade de Vargeão', 'Cidade Industrial', '81240-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7357, 'Curitiba', 'Cidade de Vere', 'Santa Quitéria', '80310-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7358, 'Curitiba', 'Cidade de Videira', 'Cidade Industrial', '81240-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7359, 'Curitiba', 'Cidade de Xaxim', 'Sítio Cercado', '81910-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7360, 'São José dos Pinhais', 'Cidade Gaúcha', 'Águas Belas', '83010-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7361, 'Curitiba', 'Cidade Gaúcha', 'Cidade Industrial', '81250-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7362, 'Curitiba', 'Cidade Industrial Norte', 'Cidade Industrial', '81280-355', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7363, 'Curitiba', 'Cidade Jardim Olinda', 'Cidade Industrial', '81290-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7364, 'Curitiba', 'Cidade Modelo', 'Sítio Cercado', '81910-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7365, 'Telêmaco Borba', 'Cidade Nova', 'Área 10', '84266-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7366, 'Paranaguá', 'Cidenes de Paula', 'Vila São Vicente', '83209-159', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7367, 'São José dos Pinhais', 'Cidnei Grein Corrêa', 'Guatupê', '83060-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7368, 'Curitiba', 'Cidra', 'Uberaba', '81560-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7369, 'Cascavel', 'Ciências Sociais', 'Universitário', '85819-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7370, 'Arapongas', 'Cigana', 'Vila Aymoré', '86708-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7371, 'Arapongas', 'Cigarra', 'Jardim Morumbi', '86708-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7372, 'Arapongas', 'Cigarra-azulada', 'Jardim Colúmbia I', '86707-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7373, 'Ponta Grossa', 'Cinamomo', 'Contorno', '84061-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7374, 'Telêmaco Borba', 'Cinamomo', 'Área 01', '84268-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7375, 'Cascavel', 'Cinamono', 'Recanto Tropical', '85807-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7376, 'Guarapuava', 'Cinco', 'Santana', '85070-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7377, 'Foz do Iguaçu', 'Cinco', 'Três Pinheiros', '85856-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7378, 'Ponta Grossa', 'Cinco', 'Contorno', '84060-568', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7379, 'Ponta Grossa', 'Cinco', 'Chapada', '84064-568', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7380, 'Ponta Grossa', 'Cinco', 'Uvaranas', '84030-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7381, 'Ponta Grossa', 'Cinco', 'Chapada', '84062-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7382, 'Piraquara', 'Cinco', 'Chácara Águas Claras', '83309-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7383, 'Paranaguá', 'Cinco', 'Jardim Paraná', '83215-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7384, 'Piraquara', 'Cinco', 'Chácara Águas Claras', '83309-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7385, 'Ponta Grossa', 'Cinco', 'Uvaranas', '84030-739', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7386, 'Ponta Grossa', 'Cinco', 'Uvaranas', '84026-589', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7387, 'Ponta Grossa', 'Cinco', 'Contorno', '84060-589', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7388, 'Ponta Grossa', 'Cinco', 'Jardim Carvalho', '84016-509', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7389, 'Piraquara', 'Cinco', 'Chácara Águas Claras', '83309-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7390, 'Paranavaí', 'Cinco', 'Jardim Maringá', '87709-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7391, 'Ponta Grossa', 'Cinco', 'Jardim Carvalho', '84015-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7392, 'Ponta Grossa', 'Cinco', 'Uvaranas', '84022-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7393, 'Ponta Grossa', 'Cinco', 'Uvaranas', '84032-459', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7394, 'Paranaguá', 'Cinco', 'Vila Garcia', '83218-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7395, 'Paranavaí', 'Cinco', 'Conjunto Dona Josefa', '87708-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7396, 'Ponta Grossa', 'Cinco', 'Chapada', '84063-418', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7397, 'Telêmaco Borba', 'Cinco', 'Vila Santa Rita', '84263-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7398, 'Umuarama', 'Cinco', 'Jardim Maria Lúcia', '87501-658', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7399, 'Umuarama', 'Cinco', 'Jardim Beira Rio', '87507-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7400, 'Umuarama', 'Cinco', 'Jardim São Cristóvão', '87507-359', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7401, 'Sarandi', 'Cinco', 'Jardim Independência I', '87114-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7402, 'Campo Largo', 'Cinco', 'Jardim Keli Cristina', '83609-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7403, 'Campo Largo', 'Cinco', 'Vila Mariano Torres', '83608-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7404, 'Campo Largo', 'Cinco', 'Jardim das Acácias', '83603-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7405, 'Campo Largo', 'Cinco', 'Jardim Lorenzete', '83603-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7406, 'Campo Largo', 'Cinco', 'Jardim Florestal', '83602-027', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7407, 'Campo Largo', 'Cinco', 'Jardim das Palmas', '83602-048', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7408, 'Campo Largo', 'Cinco', 'Vila Torres I', '83609-560', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7409, 'Campo Largo', 'Cinco', 'Núcleo Habitacional Mathias Batista', '83604-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7410, 'Campo Largo', 'Cinco', 'Loteamento São Gerônimo', '83606-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7411, 'Almirante Tamandaré', 'Cinco', 'Vila Pacheco', '83511-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7412, 'Campo Largo', 'Cinco', 'Jardim Guarany I', '83608-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7413, 'Almirante Tamandaré', 'Cinco', 'Loteamento Marinoni', '83508-558', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7414, 'Almirante Tamandaré', 'Cinco', 'São Miguel', '83511-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7415, 'Campo Largo', 'Cinco', 'Vila Pompéia', '83608-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7416, 'Almirante Tamandaré', 'Cinco', 'Jardim das Oliveiras', '83502-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7417, 'Campo Largo', 'Cinco', 'Loteamento Helvidia', '83605-266', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7418, 'Campo Largo', 'Cinco', 'Moradias Bom Jesus', '83602-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7419, 'Campo Largo', 'Cinco', 'Vila São Luiz', '83608-238', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7420, 'Campo Largo', 'Cinco', 'Vila Gilcy', '83609-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7421, 'Almirante Tamandaré', 'Cinco', 'Jardim Tatiana', '83513-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7422, 'Colombo', 'Cinco de Fevereiro', 'Jardim Palmares', '83412-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7423, 'Telêmaco Borba', 'Cinco de Julho', 'Centro', '84265-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7424, 'Paranaguá', 'Cinco de Junho', 'Centro Histórico', '83203-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7425, 'Guarapuava', 'Cinco de Outubro', 'Trianon', '85012-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7426, 'Guarapuava', 'Cinco de Outubro', 'Trianon', '85015-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7427, 'Almirante Tamandaré', 'Cinfrônio de Andrade', 'Jardim do Norte', '83511-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7428, 'Francisco Beltrão', 'Cingapura', 'Pinheirinho', '85606-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7429, 'Cascavel', 'Cinira Rodrigues dos Santos', 'Cataratas', '85818-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7430, 'Campo Mourão', 'Cinqüenta e Cinco', 'Jardim Tropical I', '87310-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7431, 'Apucarana', 'Cinqüentenário da Cia', 'Loteamento Residencial Miguel Sochacki', '86802-366', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7432, 'Campo Mourão', 'Cinqüentenário de Campo Mourão', 'Centro', '87302-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7433, 'Cascavel', 'Cipreste', 'Parque Verde', '85807-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7434, 'Londrina', 'Ciprestes', 'Leonor', '86071-205', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7435, 'Maringá', 'Ciprestes', 'Jardim Vitória', '87023-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7436, 'Curitiba', 'Cipriana Gonçalves dos Santos Cardoso', 'Sítio Cercado', '81920-726', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7437, 'Curitiba', 'Cipriano Antônio Rigotto', 'Pilarzinho', '82120-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7438, 'Curitiba', 'Cipriano Barata de Almeida', 'Sítio Cercado', '81920-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7439, 'Castro', 'Cipriano Marques de Souza', 'Centro', '84165-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7440, 'São José dos Pinhais', 'Cipriano Nunes de Oliveira', 'Guatupê', '83060-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7441, 'Telêmaco Borba', 'Ciranda', 'Vila Esperança', '84272-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7442, 'Ponta Grossa', 'Cirema Becker', 'Contorno', '84060-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7443, 'Guarapuava', 'Cirene da Cruz', 'Boqueirão', '85020-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7444, 'Curitiba', 'Cireneo de Moraes', 'Atuba', '82860-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7445, 'Foz do Iguaçu', 'Ciríaco Rios', 'Vila São Sebastião', '85870-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7446, 'Pato Branco', 'Cirillo Caldato', 'Vila Verde', '85506-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7447, 'Almirante Tamandaré', 'Cirilo de Freitas', 'Planta Maria Clara', '83513-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7448, 'Foz do Iguaçu', 'Cirilo Morello', 'Loteamento Residencial Lagoa Vermelha', '85862-337', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7449, 'Curitiba', 'Cirilo Ortolani', 'Pilarzinho', '82100-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7450, 'Cascavel', 'Ciro Bocaneve', 'Santo Onofre', '85806-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7451, 'Londrina', 'Ciro da Rocha Leite', 'Shangri-La', '86070-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7452, 'Curitiba', 'Ciro de Castro', 'Cidade Industrial', '81230-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7453, 'Campo Mourão', 'Ciro Fernandes Lago', 'Jardim Aeroporto', '87310-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7454, 'Cascavel', 'Ciro Monteiro', 'Brasília', '85815-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7455, 'Curitiba', 'Ciro Silva', 'Água Verde', '80620-160', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7456, 'Londrina', 'Ciro Sperandio', 'Jardim Acapulco', '86045-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7457, 'Telêmaco Borba', 'Cirol', 'Área 02', '84269-070', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7458, 'Foz do Iguaçu', 'Cisne', 'Parque Morumbi III', '85859-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7459, 'Londrina', 'Cisne', 'Sol', '86070-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7460, 'Maringá', 'Cisne', 'Jardim Olímpico', '87070-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7461, 'Ponta Grossa', 'Cisne', 'Colônia Dona Luiza', '84046-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7462, 'Umuarama', 'Cisne', 'Jardim Alphavile', '87504-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7463, 'Araucária', 'Cisne', 'Estação', '83705-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7464, 'Cascavel', 'Cisne Branco', 'Floresta', '85814-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7465, 'Arapongas', 'Cisne-Branco', 'Jardim Lorena', '86707-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7466, 'Arapongas', 'Cisne-negro', 'Jardim Petrópolis', '86709-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7467, 'Arapongas', 'Cisqueiro', 'Conjunto Ulisses Guimarães', '86706-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7468, 'Curitiba', 'Citadella', 'Santa Felicidade', '82030-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7469, 'Maringá', 'Citrino', 'Jardim Brasil', '87083-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7470, 'Ponta Grossa', 'Citrino', 'Neves', '84021-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7471, 'Cascavel', 'Citrino', 'Esmeralda', '85806-515', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7472, 'Cascavel', 'Citrino', 'Esmeralda', '85806-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7473, 'Londrina', 'Clara Barton', 'Jardim Alah I', '86039-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7474, 'Curitiba', 'Clara Filla', 'São Braz', '82315-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7475, 'Curitiba', 'Clara Hepp Muller', 'Santa Felicidade', '82020-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7476, 'Curitiba', 'Clara Kuchenny', 'Abranches', '82130-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7477, 'Foz do Iguaçu', 'Clara Nunes', 'Jardim das Bandeiras', '85864-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7478, 'Guarapuava', 'Clara Nunes', 'Boqueirão', '85022-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7479, 'Londrina', 'Clara Nunes', 'Jardim Rosicler', '86072-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7480, 'Maringá', 'Clara Nunes', 'Conjunto Habitacional Itatiaia', '87045-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7481, 'Paranavaí', 'Clara Nunes', 'Jardim São Jorge', '87711-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7482, 'Cambé', 'Clara Nunes', 'Jardim Josiane', '86188-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7483, 'Cascavel', 'Clara Nunes', 'Brasília', '85815-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7484, 'Curitiba', 'Clara Nunes', 'Santa Cândida', '82640-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7485, 'Curitiba', 'Clara Polsin', 'Novo Mundo', '81020-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7486, 'Curitiba', 'Clara Sovinski Martins', 'Taboão', '82130-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7487, 'Curitiba', 'Clara Tedesco', 'Xaxim', '81720-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7488, 'Curitiba', 'Clara Tedesco', 'Boqueirão', '81670-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7489, 'Curitiba', 'Clara Vendramin', 'Mossunguê', '81200-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7490, 'Londrina', 'Clarice de Lima Castro', 'Nova Olinda', '86073-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7491, 'Foz do Iguaçu', 'Clarice Lispector', 'Jardim Cláudia', '85852-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7492, 'Pato Branco', 'Clarice Soares Cerqueira', 'Centro', '85501-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7493, 'Pato Branco', 'Clarice Soares Cerqueira', 'Amadori', '85502-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7494, 'São José dos Pinhais', 'Claridade', 'Guatupê', '83060-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7495, 'Francisco Beltrão', 'Clarisse Tiburski', 'São Miguel', '85602-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7496, 'Araucária', 'Claro Antônio Calado', 'Cachoeira', '83701-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7497, 'Curitiba', 'Claro S. de Lacerda', 'Cajuru', '82950-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7498, 'Campo Largo', 'Claudemir Pereira Monteiro', 'Jardim Rondinha', '83607-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7499, 'Londrina', 'Claudenice Neves', 'Alto da Boa Vista', '86083-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7500, 'Cascavel', 'Claudete Aguiar', '14 de Novembro', '85804-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7501, 'Curitiba', 'Claudete Baroni', 'Bacacheri', '82510-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7502, 'Toledo', 'Claudete Dal Bosco', 'Parque Residencial Pancera', '85902-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7503, 'Londrina', 'Claudete Martinelli', 'Jardim Tropical', '86087-639', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7504, 'Londrina', 'Claudeth de Souza', 'Conjunto Parigot de Souza 1', '86081-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7505, 'Cascavel', 'Cláudia Galante Padovani', 'Santa Felicidade', '85803-337', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7506, 'Ponta Grossa', 'Cláudia Ivone Carneiro', 'Contorno', '84060-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7507, 'Londrina', 'Cláudia Rizzi', 'Coliseu', '86076-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7508, 'São José dos Pinhais', 'Cláudia Soares', 'Braga', '83020-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7509, 'São José dos Pinhais', 'Cláudia Zaniolo Moss', 'Braga', '83020-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7510, 'Apucarana', 'Claudinei Paes', 'Núcleo Habitacional Heitor S Pinheiro', '86806-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7511, 'Colombo', 'Claudino Alves da Silva', 'Vila Campo Alto', '83408-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7512, 'Londrina', 'Claudino Ferreira dos Santos', 'Jardim dos Alpes III', '86045-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7513, 'Curitiba', 'Cláudio Alves de Lima', 'Sítio Cercado', '81900-749', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7514, 'Toledo', 'Cláudio Areco', 'Residencial Santa Clara', '85903-707', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7515, 'Curitiba', 'Cláudio Chatagnier', 'Bacacheri', '82520-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7516, 'Foz do Iguaçu', 'Cláudio Coutinho', 'Parque Morumbi II', '85859-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7517, 'Guarapuava', 'Cláudio Coutinho', 'Morro Alto', '85067-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7518, 'Umuarama', 'Cláudio Coutinho', 'Zona I-A', '87502-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7519, 'Curitiba', 'Cláudio da Luz Reis', 'Campo Comprido', '81220-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7520, 'Londrina', 'Cláudio Damiano Stasiak', 'Terra de Santana (I E II)', '86055-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7521, 'Almirante Tamandaré', 'Cláudio de Oliveira', 'Jardim Gerhusa', '83502-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7522, 'Londrina', 'Cláudio Donisete Cavalieri', 'Jardim Aruba', '86038-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7523, 'Curitiba', 'Cláudio Erbano', 'Sítio Cercado', '81925-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7524, 'Londrina', 'Cláudio Faissal', 'Residencial Vila Romana', '86031-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7525, 'Campo Largo', 'Cláudio Ferreira Borges', 'Vila Rivabem', '83605-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7526, 'Paranaguá', 'Cláudio Fontes', 'Vila São Vicente', '83209-206', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7527, 'São José dos Pinhais', 'Cláudio José Ravaglio', 'Rio Pequeno', '83070-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7528, 'Araucária', 'Cláudio Kicote', 'Tindiquera', '83708-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7529, 'Ponta Grossa', 'Cláudio Manoel da Costa', 'Ronda', '84051-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7530, 'Umuarama', 'Cláudio Manoel da Costa', 'Zona V', '87504-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7531, 'Cambé', 'Cláudio Manoel da Costa', 'Parque Residencial Manela', '86185-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7532, 'Curitiba', 'Cláudio Manoel da Costa', 'Bom Retiro', '80520-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7533, 'Curitiba', 'Cláudio Manoel de Loyola e Silva', 'Alto Boqueirão', '81850-155', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7534, 'Almirante Tamandaré', 'Cláudio Manoel Dias', 'Jardim Silvana', '83512-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7535, 'Londrina', 'Cláudio Manuel da Costa', 'Lago Parque', '86015-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7536, 'Pinhais', 'Cláudio Mehl', 'Planta Cláudio Mehl', '83326-255', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7537, 'Curitiba', 'Cláudio Paulino Dariva', 'Boa Vista', '82540-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7538, 'São José dos Pinhais', 'Cláudio Pereira da Cruz', 'Afonso Pena', '83065-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7539, 'Curitiba', 'Cláudio Todisco', 'Xaxim', '81810-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7540, 'Curitiba', 'Cláudio Tyszka', 'Sítio Cercado', '81920-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7541, 'Apucarana', 'Claudiomar Gonçalves', 'Núcleo Habitacional Heitor S Pinheiro', '86806-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7542, 'Curitiba', 'Claudionor de Jesus Afonso Barbosa', 'Sítio Cercado', '81900-765', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7543, 'Paranaguá', 'Claudionor Nascimento', 'Serraria do Rocha', '83221-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7544, 'Londrina', 'Claudionor Reis', 'Jardim Vale Azul', '86041-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7545, 'Londrina', 'Claudir Martinez Rossi', 'Santa Mônica', '86079-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7546, 'Curitiba', 'Clávio Molinari', 'Capão da Imbuia', '82810-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7547, 'Curitiba', 'Cledimara Lopes Probst', 'Santa Cândida', '82620-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7548, 'Curitiba', 'Cléia Mara Pereira Gomes', 'Cidade Industrial', '81450-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7549, 'São José dos Pinhais', 'Cleide Gozzi Shivinski', 'Braga', '83020-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7550, 'Curitiba', 'Cleide Iurk', 'Bacacheri', '82510-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7551, 'Curitiba', 'Clemens Albert Grimm', 'Santa Cândida', '82650-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7552, 'Curitiba', 'Clemente Albini', 'Pilarzinho', '82100-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7553, 'Toledo', 'Clemente Angeli', 'Jardim Europa', '85907-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7554, 'Curitiba', 'Clemente Casimiro Puppi', 'Vila Izabel', '80320-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7555, 'Araucária', 'Clemente Haluch', 'Capela Velha', '83706-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7556, 'Pinhais', 'Clemente Itsyo Horikoshi', 'Jardim Dona Carmem', '83326-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7557, 'Curitiba', 'Clemente Mendes Ferreira', 'Sítio Cercado', '81925-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7558, 'Curitiba', 'Clemente Mendes Ferreira', 'Sítio Cercado', '81920-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7559, 'São José dos Pinhais', 'Clemente Negoseke', 'Braga', '83020-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7560, 'Curitiba', 'Clemente Ritz', 'Cidade Industrial', '81250-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7561, 'Piraquara', 'Clemente Simião', 'Vila Juliana', '83306-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7562, 'Maringá', 'Clemente Zequim', 'Jardim Santa Rosa', '87060-027', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7563, 'São José dos Pinhais', 'Clemente Zetola', 'Três Marias', '83030-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7564, 'Maringá', 'Clementina Basseto', 'Zona 07', '87030-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7565, 'Maringá', 'Clementina de Jesus', 'Conjunto Habitacional Itatiaia', '87045-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7566, 'Curitiba', 'Clementina de Paula Ferreira', 'Xaxim', '81820-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7567, 'Cascavel', 'Clementina Ferreira de Oliveira', 'Parque Verde', '85807-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7568, 'Cascavel', 'Clementina Ferreira Oliveira', 'Parque Verde', '85807-725', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7569, 'Paranaguá', 'Clementina G.Ferreira', 'Ponta do Caju', '83203-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7570, 'Curitiba', 'Clementina Kulik', 'Santa Cândida', '82720-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7571, 'Curitiba', 'Clementina Mehl Muhlmann', 'Tingui', '82600-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7572, 'Colombo', 'Clementino Belo', 'Jardim Curitiba', '83414-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7573, 'Londrina', 'Clementino Ettore Luvisotto', 'Áurea', '86038-440', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7574, 'Campo Mourão', 'Clementino Farago', 'Conjunto Residencial Ilha Bela', '87309-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7575, 'Pinhais', 'Clementino Martins', 'Moradias Palmital', '83325-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7576, 'São José dos Pinhais', 'Cleonice Braga Fonseca', 'São Sebastião', '83075-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7577, 'Londrina', 'Cleta Odebrecht Pimentel', 'Jamile Dequech', '86048-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7578, 'Curitiba', 'Cleto da Silva', 'Boqueirão', '81650-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7579, 'Curitiba', 'Cleto da Silva', 'Boqueirão', '81670-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7580, 'Curitiba', 'Cleusa Salomão', 'Alto da Rua XV', '80050-070', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7581, 'Francisco Beltrão', 'Clevelândia', 'Vila Nova', '85601-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7582, 'Francisco Beltrão', 'Clevelândia', 'Vila Nova', '85605-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7583, 'Londrina', 'Clevelândia', 'Vitória', '86060-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7584, 'Londrina', 'Clevelândia', 'Vitória', '86060-640', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7585, 'Guarapuava', 'Clevelândia', 'Jardim das Américas', '85030-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7586, 'Ponta Grossa', 'Clevelândia', 'Ronda', '84051-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7587, 'São José dos Pinhais', 'Clevelândia', 'Silveira da Motta', '83030-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7588, 'Apucarana', 'Clevelândia', 'Vila São Carlos', '86800-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7589, 'Cascavel', 'Clevelândia', 'Santa Cruz', '85806-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7590, 'Colombo', 'Clevelândia', 'Jardim La Paloma', '83412-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7591, 'Curitiba', 'Clevelândia', 'Sítio Cercado', '81910-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7592, 'Curitiba', 'Clio Gloger Isfer', 'Barreirinha', '82700-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7593, 'Curitiba', 'Cliomar Silva de Souza', 'Cidade Industrial', '81240-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7594, 'Londrina', 'Clístenes', 'Guaporé', '86025-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7595, 'Maringá', 'Clodimar Pedrosa Lo', 'Loteamento Madrid', '87053-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7596, 'São José dos Pinhais', 'Clodoaldo Naumann', 'Afonso Pena', '83065-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7597, 'Cascavel', 'Clodoaldo Ursulano', 'Santa Felicidade', '85803-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7598, 'Araucária', 'Clodomir Senegaglia', 'Boqueirão', '83704-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7599, 'Curitiba', 'Clodomiro Avelleda', 'Campina do Siqueira', '80740-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7600, 'Telêmaco Borba', 'Clodomiro Fernandes', 'Nossa Senhora de Fátima', '84264-480', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7601, 'Curitiba', 'Clotário de Macedo Portugal Filho', 'Taboão', '82130-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7602, 'Campo Largo', 'Clotário Lopes', 'Jardim Bela Vista', '83605-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7603, 'Curitiba', 'Clotilde da Costa Ribeiro', 'Atuba', '82860-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7604, 'Curitiba', 'Clotilde Gaspar Riquelme', 'Capão da Imbuia', '82810-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7605, 'Paranavaí', 'Clóvis Avelar da Silva', 'Parque Morumbi', '87703-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7606, 'Cascavel', 'Clóvis Bevilacqua', 'São Cristóvão', '85816-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7607, 'Ponta Grossa', 'Clóvis Bevilácqua', 'Oficinas', '84035-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7608, 'Maringá', 'Clóvis Bevilaqua', 'Zona 04', '87014-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7609, 'Londrina', 'Clóvis Beviláqua', 'Zelina', '86015-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7610, 'Pinhais', 'Clóvis Beviláqua', 'Núcleo Colonial de Pinhais', '83321-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7611, 'Curitiba', 'Clóvis Beviláqua', 'Cabral', '80035-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7612, 'Curitiba', 'Clóvis Beviláqua Sobrinho', 'Uberaba', '81570-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7613, 'Apucarana', 'Clóvis da Fonseca', 'Jardim São Pedro', '86809-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7614, 'Apucarana', 'Clóvis da Fonseca', 'Centro', '86800-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7615, 'Londrina', 'Clóvis Júlio Mendes', 'Ponte Seca', '86042-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7616, 'Foz do Iguaçu', 'Clóvis Roberto Fontoura', 'Conjunto A', '85866-340', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7617, 'Ponta Grossa', 'Clóvis Sampaio Vargas', 'Colônia Dona Luiza', '84043-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7618, 'Londrina', 'Clóvis Tronchini', 'Cafezal 1', '86049-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7619, 'Foz do Iguaçu', 'Coaraci', 'Parque Imperatriz', '85862-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7620, 'Foz do Iguaçu', 'Coata', 'Conjunto A', '85861-370', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7621, 'Foz do Iguaçu', 'Cobre', 'Parque Ouro Verde', '85854-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7622, 'Maringá', 'Cocais', 'Jardim Tropical', '87080-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7623, 'Arapongas', 'Cocorocó', 'Jardim Colúmbia I', '86707-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7624, 'Curitiba', 'Cocos', 'Uberaba', '81560-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7625, 'Cambé', 'Codato', 'Centro', '86181-120', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7626, 'Foz do Iguaçu', 'Codegrande José da Rocha', 'Jardim Esmeralda', '85856-130', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7627, 'Foz do Iguaçu', 'Codorna', 'Portal da Foz', '85859-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7628, 'Francisco Beltrão', 'Codorna', 'Padre Eurico', '85604-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7629, 'Ponta Grossa', 'Codorna', 'Colônia Dona Luiza', '84043-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7630, 'Campo Mourão', 'Codorna', 'Vila Teixeira', '87300-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7631, 'Araucária', 'Codorna', 'Capela Velha', '83706-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7632, 'Arapongas', 'Codorna', 'Centro', '86701-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7633, 'Laranjeiras do Sul', 'Codornas', 'Vila Industrial', '85303-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7634, 'Arapongas', 'Codornix', 'Jardim Lorena', '86707-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7635, 'Campo Mourão', 'Coelho Júnior', 'Jardim Flórida', '87300-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7636, 'Londrina', 'Coelho Neto', 'Progresso', '86079-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7637, 'Pato Branco', 'Coelho Neto', 'São Cristóvão', '85508-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7638, 'Ponta Grossa', 'Coelho Neto', 'Uvaranas', '84026-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7639, 'Maringá', 'Coelho Neto', 'Zona 05', '87015-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7640, 'Umuarama', 'Coelho Neto', 'Jardim Vitória', '87509-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7641, 'Umuarama', 'Coelho Neto', 'Zona V', '87504-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7642, 'Londrina', 'Coentro', 'Jardim Novo Sabará', '86066-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7643, 'Londrina', 'Coimbra', 'Parque Residencial João Piza', '86041-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7644, 'Colombo', 'Coimbra', 'Parque Residencial Santa Terezinha', '83408-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7645, 'Francisco Beltrão', 'Coira', 'Pinheirinho', '85603-825', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7646, 'Paranavaí', 'Colegial', 'Jardim Guanabara', '87706-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7647, 'Arapongas', 'Colegial', 'Conjunto Ulisses Guimarães', '86706-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7648, 'Francisco Beltrão', 'Coleira', 'Padre Ulrico', '85604-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7649, 'Londrina', 'Coleirinha', 'Conjunto Habitacional Violim', '86084-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7650, 'Ponta Grossa', 'Coleirinha', 'Colônia Dona Luiza', '84043-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7651, 'Arapongas', 'Coleirinha', 'Vila Natal', '86701-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7652, 'Ponta Grossa', 'Coleirinho', 'Chapada', '84064-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7653, 'Araucária', 'Coleiro', 'Capela Velha', '83706-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7654, 'Arapongas', 'Coleiro-do-brejo', 'Jardim Colúmbia III', '86707-816', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7655, 'Foz do Iguaçu', 'Colerinha', 'Portal da Foz', '85859-387', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7656, 'Londrina', 'Coletor Anísio Ribas Bueno', 'Jardim Maria Celina', '86081-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7657, 'Arapongas', 'Colhereiro', 'Vila Aparecida', '86707-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7658, 'Guarapuava', 'Colibri', 'São Cristóvão', '85063-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7659, 'Foz do Iguaçu', 'Colibri', 'Portal da Foz', '85859-640', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7660, 'Francisco Beltrão', 'Colibri', 'Miniguaçu', '85605-460', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7661, 'Maringá', 'Colibri', 'Conjunto Habitacional Sanenge', '87070-710', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7662, 'Ponta Grossa', 'Colibri', 'Chapada', '84064-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7663, 'Umuarama', 'Colibri', 'Conjunto Patrimônio Umuarama', '87505-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7664, 'Araucária', 'Colibri', 'Estação', '83705-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7665, 'Campo Mourão', 'Colibri', 'Vila Teixeira', '87300-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7666, 'Curitiba', 'Colibri', 'Tingui', '82600-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7667, 'Londrina', 'Colina', 'Veraliz', '86062-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7668, 'Londrina', 'Colina Verde', 'Colina Verde Leste', '86061-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7669, 'Umuarama', 'Colina Verde', 'Jardim Sol Nascente', '87505-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7670, 'Umuarama', 'Colina Verde', 'Jardim Canadá II', '87505-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7671, 'Arapongas', 'Colio', 'Jardim do Café', '86706-208', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7672, 'Campo Mourão', 'Colméia', 'Jardim Alvorada', '87308-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7673, 'Curitiba', 'Colomba Merlin', 'Umbará', '81930-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7674, 'Londrina', 'Colômbia', 'Vila Brasil', '86010-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7675, 'Guarapuava', 'Colômbia', 'Morro Alto', '85063-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7676, 'Maringá', 'Colômbia', 'Jardim Alvorada', '87033-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7677, 'Paranaguá', 'Colômbia', 'Jardim América', '83209-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7678, 'Maringá', 'Colômbia', 'Ebenezer', '87035-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7679, 'Ponta Grossa', 'Colômbia', 'Ronda', '84051-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7680, 'Toledo', 'Colômbia', 'Parque Residencial Gisela', '85905-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7681, 'Telêmaco Borba', 'Colômbia', 'Vila Siqueira', '84266-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7682, 'Colombo', 'Colômbia', 'Jardim Rio Verde', '83405-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7683, 'Apucarana', 'Colômbia', 'Jardim Diamantina', '86804-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7684, 'Almirante Tamandaré', 'Colômbia', 'Jardim São Francisco', '83501-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7685, 'Curitiba', 'Colômbia', 'Bacacheri', '82510-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7686, 'Curitiba', 'Colombina Naide', 'Cajuru', '82930-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7687, 'Guarapuava', 'Colombo', 'Boqueirão', '85023-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7688, 'Maringá', 'Colombo', 'Zona 06', '87080-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7689, 'São José dos Pinhais', 'Colombo', 'Centro', '83005-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7690, 'Maringá', 'Colombo', 'Vila Nova', '87045-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7691, 'Ponta Grossa', 'Colombo', 'Estrela', '84050-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7692, 'Maringá', 'Colombo', 'Zona 07', '87030-120', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7693, 'Maringá', 'Colombo', 'Zona 07', '87030-121', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7694, 'Maringá', 'Colombo', 'Jardim Universitário', '87020-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7695, 'Maringá', 'Colombo', 'Zona 06', '87020-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7696, 'Maringá', 'Colombo', 'Parque Industrial Bandeirantes', '87070-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7697, 'Umuarama', 'Colombo', 'Zona VI', '87503-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7873, 'Curitiba', 'Constantin Frantzeros', 'Sítio Cercado', '81920-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7698, 'Campo Mourão', 'Colombo', 'Conjunto Habitacional Parigot de Souza', '87310-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7699, 'Colombo', 'Colombo', 'Parque Residencial Santa Terezinha II', '83408-800', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7700, 'Almirante Tamandaré', 'Colombo', 'Jardim Valma', '83507-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7701, 'Curitiba', 'Colombo', 'Juvevê', '80540-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7702, 'Telêmaco Borba', 'Colônia', 'Área 07', '84267-290', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7703, 'Campo Largo', 'Colônia Cristina', 'Jardim Florestal', '83602-340', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7704, 'Curitiba', 'Colônia Riviera', 'Cidade Industrial', '81290-100', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7705, 'Castro', 'Colônia Santa Leopoldina', 'Bom Sucesso', '84165-710', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7706, 'Castro', 'Colônia Terra Nova', 'Cantagalo', '84178-680', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7707, 'São José dos Pinhais', 'Colônia Zacarias', 'Colônia Zacarias', '83020-835', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7708, 'Apucarana', 'Colonial', 'Jardim das Flores I', '86810-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7709, 'Almirante Tamandaré', 'Colonial', 'Jardim Colonial', '83501-590', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7710, 'Francisco Beltrão', 'Colorado', 'Antônio de Paiva Cantelmo', '85603-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7711, 'Guarapuava', 'Colorado', 'Boqueirão', '85023-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7712, 'Ponta Grossa', 'Colorado', 'Chapada', '84062-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7713, 'São José dos Pinhais', 'Colorado', 'São Cristóvão', '83040-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7714, 'Pinhais', 'Colorado', 'Jardim Dona Joaquina II', '83325-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7715, 'Umuarama', 'Colorado', 'Conjunto Residencial Córrego Longe', '87504-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7716, 'Colombo', 'Colorado', 'Santa Gema', '83407-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7717, 'Campo Mourão', 'Colorado', 'Conjunto Habitacional Parigot de Souza', '87310-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7718, 'Cambé', 'Colorado', 'Jardim Golden Park', '86186-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7719, 'Curitiba', 'Colorado', 'Jardim Botânico', '80215-130', 'Viaduto', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7720, 'Arapongas', 'Colorado-de-peito-branco', 'Parque Industrial II', '86703-747', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7721, 'Cambé', 'Colossenses', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7722, 'Almirante Tamandaré', 'Colúmbia', 'Jardim Miragem', '83505-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7723, 'São José dos Pinhais', 'Comandante Aviador José P. Lepinski', 'Cruzeiro', '83010-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7724, 'Londrina', 'Comandante Carlos Alberto', 'Boa Vista', '86039-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7725, 'Cascavel', 'Comandante Carlos Alberto Doro', 'Santa Felicidade', '85803-336', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7726, 'Paranaguá', 'Comandante Didio Costa', 'Serraria do Rocha', '83221-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7727, 'Paranaguá', 'Comandante Didio Costa', 'Estradinha', '83206-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7728, 'Londrina', 'Comandante Ismael Guilherme', 'Califórnia', '86040-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7729, 'Londrina', 'Comandante João Ribeiro de Barros', 'Dom Pedro', '86039-640', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7730, 'Curitiba', 'Comandante José Jeiss Neto', 'Tatuquara', '81480-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7731, 'Ponta Grossa', 'Comandante Paulo Pinheiro Schmidt', 'Uvaranas', '84031-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7732, 'Londrina', 'Comandante Pedro Bortoloto', 'Santos Dumont', '86039-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7733, 'Londrina', 'Comandante Rhul', 'Califórnia', '86040-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7734, 'Arapongas', 'Combatente', 'Vila Edio', '86705-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7735, 'Curitiba', 'Comendador Alfredo Munhoz', 'Jardim Social', '82530-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7736, 'Almirante Tamandaré', 'Comendador Antônio Barros', 'Planta Vila Rica', '83507-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7737, 'Curitiba', 'Comendador Antônio Domingues de Barros', 'Bacacheri', '82520-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7738, 'Curitiba', 'Comendador Araújo', 'Centro', '80420-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7739, 'Londrina', 'Comendador Augusto Caminhoto', 'Petrópolis', '86015-655', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7740, 'Ponta Grossa', 'Comendador Ayrton Plaisant', 'Centro', '84010-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7741, 'Curitiba', 'Comendador Bortholo Pellanda Netto', 'Pinheirinho', '81870-165', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7742, 'Paranaguá', 'Comendador Correia Júnior', 'João Gualberto', '83203-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7743, 'Curitiba', 'Comendador Correia Júnior', 'Jardim das Américas', '81540-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7744, 'Curitiba', 'Comendador David dos Santos Pacheco', 'Vista Alegre', '80820-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7745, 'Curitiba', 'Comendador Fontana', 'Centro Cívico', '80030-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7746, 'Curitiba', 'Comendador Franco', 'Jardim Botânico', '80215-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7747, 'Curitiba', 'Comendador Franco', 'Guabirotuba', '81520-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7748, 'Curitiba', 'Comendador Franco', 'Uberaba', '81530-440', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7749, 'Curitiba', 'Comendador Franco', 'Uberaba', '81560-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7750, 'Curitiba', 'Comendador Franco', 'Uberaba', '81560-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7751, 'Curitiba', 'Comendador Jacques Van Erven', 'Portão', '81070-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7752, 'Curitiba', 'Comendador João Lackner', 'Guaíra', '80630-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7753, 'Curitiba', 'Comendador João Manoel da Cunha', 'Cajuru', '82960-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7754, 'Londrina', 'Comendador Júlio Fuganti', 'Bela Suiça', '86050-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7755, 'Curitiba', 'Comendador Lustosa de Andrade', 'Bom Retiro', '80520-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7756, 'Curitiba', 'Comendador Macedo', 'Centro', '80060-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7757, 'Castro', 'Comendador Manoel Inácio', 'Vila Rio Branco', '84172-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7758, 'Campo Largo', 'Comendador Mariano Torres', 'Loteamento Ouro Verde I', '83606-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7759, 'Ponta Grossa', 'Comendador Miro', 'Centro', '84010-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7760, 'Guarapuava', 'Comendador Norberto', 'Centro', '85010-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7761, 'Guarapuava', 'Comendador Norberto', 'Santa Cruz', '85015-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7762, 'Campo Mourão', 'Comendador Norberto Marcondes', 'Centro', '87302-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7763, 'Campo Mourão', 'Comendador Norberto Marcondes', 'Centro', '87303-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7764, 'Campo Mourão', 'Comendador Norberto Marcondes', 'Jardim Alvorada', '87308-580', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7765, 'Curitiba', 'Comendador Pinto Bandeira', 'Jardim das Américas', '81530-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7766, 'Curitiba', 'Comendador Roseira', 'Prado Velho', '80215-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7767, 'Curitiba', 'Comendador Santiago Colle', 'Ahú', '82200-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7768, 'Ponta Grossa', 'Comendador Wallace Pina', 'Boa Vista', '84071-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7769, 'Curitiba', 'Comendador Zake Sabbag', 'Atuba', '82630-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7770, 'Maringá', 'Comerciante Armando de Bello', 'Vila Esperança', '87020-470', 'Via', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7771, 'Maringá', 'Cometa', 'Jardim Universo', '87060-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7772, 'Sarandi', 'Cometa', 'Jardim Universal', '87114-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7773, 'Cascavel', 'Comil', 'Presidente', '85818-165', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7774, 'Londrina', 'Complexo Esportivo Joaquim G. Pereira', 'Champagnat', '86062-115', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7775, 'Maringá', 'Compositor Vila-lobos', 'Conjunto Habitacional Itatiaia', '87045-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7776, 'Telêmaco Borba', 'Conceição', 'Área 01', '84272-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7777, 'Sarandi', 'Conceição Aparecida de Magalhães', 'Parque Alvamar II', '87113-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7778, 'Londrina', 'Conceição Arenal', 'Cambará', '86039-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7779, 'Londrina', 'Conceição Augusta Barbosa de Góes', 'Conjunto Habitacional José Garcia Molina', '86080-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7780, 'Londrina', 'Conceição Augusta Barboza de Góes', 'Jardim Delta', '86065-826', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7781, 'Almirante Tamandaré', 'Conceição Cordeiro Pinto', 'Jardim Bela Vista', '83513-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7874, 'Ponta Grossa', 'Constantina Borsato', 'Uvaranas', '84031-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7782, 'Almirante Tamandaré', 'Conceição da Rocha Ramos', 'Jardim Novo Horizonte da Cachoeira', '83502-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7783, 'São José dos Pinhais', 'Conceição de Almeida e Silva', 'São Sebastião', '83075-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7784, 'Maringá', 'Conceição Maria da Rocha', 'Jardim Ivemar', '87065-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7785, 'Londrina', 'Concepcion Del Paraguay', 'Cambará', '86039-565', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7786, 'Ponta Grossa', 'Concorde', 'Cará-cará', '84043-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7787, 'Guarapuava', 'Concórdia', 'São Cristóvão', '85060-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7788, 'Piraquara', 'Concórdia', 'Planta São Tiago', '83307-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7789, 'São José dos Pinhais', 'Concórdia', 'São Sebastião', '83075-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7790, 'Telêmaco Borba', 'Concórdia', 'Jardim Adriane', '84272-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7791, 'Campo Largo', 'Concórdia', 'Jardim Rivabem', '83605-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7792, 'Cascavel', 'Concórdia', '14 de Novembro', '85804-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7793, 'Arapongas', 'Concris', 'Vila Industrial', '86706-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7794, 'Curitiba', 'Concriz', 'São Braz', '82315-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7795, 'Ponta Grossa', 'Conde de Irajá', 'Uvaranas', '84032-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7796, 'Ponta Grossa', 'Conde de Itaguahi', 'Uvaranas', '84032-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7797, 'Guarapuava', 'Conde de Linhares', 'Primavera', '85053-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7798, 'Ponta Grossa', 'Conde de Monsavaz', 'Olarias', '84035-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7799, 'Londrina', 'Conde de Nova Friburgo', 'Caiçaras', '86015-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7800, 'Curitiba', 'Conde de São João das Duas Barras', 'Boqueirão', '81670-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7801, 'Curitiba', 'Conde de São João das Duas Barras', 'Hauer', '81630-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7802, 'Guarapuava', 'Conde D''Eu', 'Vila Carli', '85040-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7803, 'Londrina', 'Conde D''Eu', 'Ok', '86040-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7804, 'Ponta Grossa', 'Conde D''Eu', 'Uvaranas', '84025-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7805, 'Curitiba', 'Conde dos Arcos', 'Lindóia', '81010-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7806, 'Paranavaí', 'Conde Francisco Matarazzo', 'Jardim São Jorge', '87710-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7807, 'Curitiba', 'Condessa Milton', 'Cajuru', '82950-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7808, 'Foz do Iguaçu', 'Condor', 'Portal da Foz', '85859-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7809, 'Londrina', 'Condor', 'Indústrias Leves', '86030-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7810, 'Maringá', 'Condor', 'Zona 08', '87050-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7811, 'Ponta Grossa', 'Condor', 'Colônia Dona Luiza', '84046-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7812, 'Cascavel', 'Condor', 'Floresta', '85814-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7813, 'Campo Largo', 'Condor', 'Vila Gilcy', '83609-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7814, 'Arapongas', 'Condor', 'Centro', '86701-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7815, 'Arapongas', 'Condor', 'Vila São João', '86708-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7816, 'Campo Mourão', 'Condor', 'Jardim Gutierres', '87300-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7817, 'Arapongas', 'Condor-dos-andes', 'Casa Família Arapongas IV', '86709-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7818, 'Paranaguá', 'Cônego Alcindino', 'Centro Histórico', '83203-330', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7819, 'Curitiba', 'Cônego Aníbal Maria Difrância', 'Uberaba', '81560-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7820, 'Guarapuava', 'Cônego Braga', 'Batel', '85015-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7821, 'Guarapuava', 'Cônego Braga', 'Centro', '85010-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7822, 'Curitiba', 'Cônego Januário da Cunha Barbosa', 'Jardim das Américas', '81530-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7823, 'Curitiba', 'Cônego Paulo Haroldo Ribeiro', 'Pinheirinho', '81870-016', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7824, 'Londrina', 'Confúcio', 'Califórnia', '86040-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7825, 'São José dos Pinhais', 'Confúcio', 'Aristocrata', '83030-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7826, 'Colombo', 'Confúcio', 'Jardim Campo Alto', '83408-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7827, 'Curitiba', 'Confúcio', 'Barreirinha', '82700-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7828, 'Pinhais', 'Congo', 'Vila Esplanada', '83320-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7829, 'Telêmaco Borba', 'Congo', 'Vila Esperança', '84272-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7830, 'Colombo', 'Congo', 'Vila Alto da Cruz II', '83405-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7831, 'Ponta Grossa', 'Congoinhas', 'Uvaranas', '84025-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7832, 'Ponta Grossa', 'Congonhas', 'Chapada', '84063-240', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7833, 'Cascavel', 'Congonhas', 'Santos Dumont', '85804-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7834, 'Telêmaco Borba', 'Congonhas do Campo', 'Área 06', '84271-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7835, 'Curitiba', 'Congonhinhas', 'Cidade Industrial', '81250-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7836, 'Almirante Tamandaré', 'Congregação', 'Jardim Formosa', '83511-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7837, 'Paranavaí', 'Conrado Fancelli', 'Jardim Progresso', '87701-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7838, 'Guarapuava', 'Conrado Kluber', 'Conradinho', '85055-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7839, 'Apucarana', 'Conrado Martinez Sanches', 'Residencial Parque da Raposa', '86812-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7840, 'Ponta Grossa', 'Conrado Pereira Ramos', 'Jardim Carvalho', '84015-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7841, 'Campo Mourão', 'Conrado Pochapski', 'Jardim Conrado', '87308-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7842, 'Londrina', 'Conrado Pusch', 'Tarobá', '86042-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7843, 'Ponta Grossa', 'Conrado Schiffer', 'Estrela', '84050-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7844, 'Cambé', 'Conrado Sheller', 'Jardim Vila Rica', '86192-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7845, 'Curitiba', 'Conselheiro Araújo', 'Centro', '80060-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7846, 'Ponta Grossa', 'Conselheiro Barradas', 'Uvaranas', '84025-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7847, 'Ponta Grossa', 'Conselheiro Cândido de Oliveira', 'Uvaranas', '84032-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7848, 'Curitiba', 'Conselheiro Carrão', 'Juvevê', '80040-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7849, 'Paranaguá', 'Conselheiro Corrêa', '29 de Julho', '83203-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7850, 'Paranaguá', 'Conselheiro Corrêa', 'Bockmann', '83206-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7851, 'Curitiba', 'Conselheiro Dantas', 'Prado Velho', '80220-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7852, 'Curitiba', 'Conselheiro Dantas', 'Rebouças', '80220-191', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7853, 'Guarapuava', 'Conselheiro Jesuíno Marcondes', 'Santa Cruz', '85015-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7854, 'Castro', 'Conselheiro Jesuíno Marcondes', 'Jardim dos Bancários', '84172-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7855, 'Ponta Grossa', 'Conselheiro João Alfredo', 'Orfãs', '84015-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7856, 'Ponta Grossa', 'Conselheiro Lafayete', 'Ronda', '84051-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7857, 'Curitiba', 'Conselheiro Laurindo', 'Centro', '80060-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7858, 'Curitiba', 'Conselheiro Laurindo', 'Rebouças', '80230-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7859, 'Apucarana', 'Conselheiro Pena', 'Loteamento Fortaleza', '86802-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7860, 'Curitiba', 'Conselheiro Raul Viana', 'Centro Cívico', '80530-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7861, 'Colombo', 'Conselheiro Saraiva', 'Jardim Curitiba', '83406-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7862, 'Paranaguá', 'Conselheiro Sinimbú', 'Centro Histórico', '83203-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7863, 'Maringá', 'Conselheiro Tobias', 'Zona 04', '87014-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7864, 'Curitiba', 'Conselheiro Tómas Coelho', 'Tarumã', '82800-030', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7865, 'Telêmaco Borba', 'Conselheiro Zacarias', 'Centro', '84261-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7866, 'São José dos Pinhais', 'Constância Rutelionis', 'Afonso Pena', '83050-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7867, 'Maringá', 'Constâncio Pereira Dias', 'Distrito Industrial', '87065-240', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7868, 'Pato Branco', 'Constante Andreatta', 'Santa Terezinha', '85506-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7869, 'Curitiba', 'Constante de Conto', 'Orleans', '81200-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7870, 'Curitiba', 'Constante Lunardon', 'Mossunguê', '81210-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7871, 'São José dos Pinhais', 'Constante Moro Sobrinho', 'Colônia Murici', '83085-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7872, 'Curitiba', 'Constante Zelak', 'Pinheirinho', '81870-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7875, 'Curitiba', 'Constantina Dória de Oliveira', 'Orleans', '82310-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7876, 'Curitiba', 'Constantino Alves de Oliveira', 'Cidade Industrial', '81450-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7877, 'Curitiba', 'Constantino Alves dos Reis', 'Tarumã', '82530-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7878, 'São José dos Pinhais', 'Constantino Ângelo Zaniolo', 'Centro', '83030-770', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7879, 'Curitiba', 'Constantino Bordignon', 'Prado Velho', '80215-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7880, 'Londrina', 'Constantino Bottino', 'Jardim Itatiaia 2', '86047-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7881, 'Curitiba', 'Constantino Falcão', 'Cascatinha', '82020-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7882, 'Curitiba', 'Constantino Fanini', 'Rebouças', '80215-410', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7883, 'Curitiba', 'Constantino José de Almeida', 'Xaxim', '81830-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7884, 'Curitiba', 'Constantino Lapkauskas', 'Capão da Imbuia', '82810-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7885, 'Ponta Grossa', 'Constantino Marochi', 'Boa Vista', '84070-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7886, 'Campo Largo', 'Constantino Marochi', 'Loteamento Ouro Verde I', '83606-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7887, 'Curitiba', 'Constantino Marochi', 'Alto da Glória', '80030-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7888, 'Curitiba', 'Constantino Nowazeski', 'Cajuru', '82900-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7889, 'Londrina', 'Constantino Paschoal', 'Heimtal', '86084-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7890, 'Londrina', 'Constantino Pialarissi', 'Portal de Versalhes 3', '86055-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7891, 'Curitiba', 'Constantino Tedesco', 'Boqueirão', '81670-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7892, 'Londrina', 'Constanza Benzi Foggia', 'Jardim Ilha do Mel', '86081-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7893, 'Foz do Iguaçu', 'Consuelo', 'Parque Imperatriz', '85862-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7894, 'Foz do Iguaçu', 'Consuelo', 'Jardim Ana Cristina', '85861-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7895, 'Castro', 'Consulesa Helena Van Der Berg', 'Vila Rio Branco', '84172-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7896, 'Curitiba', 'Contador João Tezeo', 'Alto Boqueirão', '81770-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7897, 'Ponta Grossa', 'Contenda', 'Estrela', '84050-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7898, 'Colombo', 'Contenda', 'Jardim La Paloma', '83412-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7899, 'Almirante Tamandaré', 'Contenda', 'Jardim Roma', '83504-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7900, 'Curitiba', 'Contenda', 'Sítio Cercado', '81910-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7901, 'Arapongas', 'Contorno Norte', 'Jardim Bandeirantes', '86703-690', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7902, 'Almirante Tamandaré', 'Contorno Norte', 'Jardim Marambaia', '83506-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7903, 'Almirante Tamandaré', 'Contorno Norte', 'Jardim Ipê', '83505-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7904, 'Almirante Tamandaré', 'Contorno Norte', 'Jardim Monterrey', '83507-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7905, 'Arapongas', 'Contorno Norte II', 'Jardim Universitário', '86703-720', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7906, 'São José dos Pinhais', 'Conuncio Carrano', 'Cidade Jardim', '83035-140', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7907, 'Guarapuava', 'Copacabana', 'Morro Alto', '85067-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7908, 'Francisco Beltrão', 'Copacabana', 'Pinheirinho', '85603-165', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7909, 'Londrina', 'Copacabana', 'Maringá', '86015-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7910, 'Umuarama', 'Copacabana', 'Jardim Tropical', '87508-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7911, 'Campo Largo', 'Copacabana', 'Jardim Rivabem', '83605-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7912, 'Cascavel', 'Copacabana', 'Brasília', '85815-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7913, 'Cascavel', 'Copacabana', 'Periolo', '85817-015', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7914, 'Curitiba', 'Copaíba', 'Bairro Alto', '82840-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7915, 'Ponta Grossa', 'Copal', 'Neves', '84021-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7916, 'Francisco Beltrão', 'Copel', 'Pinheirinho', '85603-440', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7917, 'Ponta Grossa', 'Copel', 'Chapada', '84063-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7918, 'Foz do Iguaçu', 'Copenhague', 'Jardim Liberdade', '85858-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7919, 'Colombo', 'Copenhague', 'Vila Santa Clara', '83405-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7920, 'Colombo', 'Copérnico', 'Vila Guarani', '83408-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7921, 'Foz do Iguaçu', 'Coqueiro', 'Jardim Quinta do Sol', '85853-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7922, 'Apucarana', 'Coqueiro', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7923, 'Maringá', 'Coqueiros', 'Conjunto João de Barro Itaparica', '87043-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7925, 'Ponta Grossa', 'Cora Coralina', 'Cará-cará', '84043-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7926, 'Cascavel', 'Cora Coralina', 'Alto Alegre', '85805-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7927, 'Curitiba', 'Cora Coralina', 'Santa Cândida', '82720-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7928, 'Londrina', 'Coração de Maria', 'Petrópolis', '86015-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7929, 'Umuarama', 'Coração de Maria', 'Parque Industrial I', '87507-056', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7930, 'Curitiba', 'Coração de Maria', 'Jardim Botânico', '80215-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7931, 'Ponta Grossa', 'Coração Imaculado de Maria', 'Estrela', '84050-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7932, 'Cascavel', 'Corais', 'Cataratas', '85818-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7933, 'Ponta Grossa', 'Coral', 'Neves', '84021-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7934, 'Cascavel', 'Coral', 'Pioneiros Catarinenses', '85805-436', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7935, 'Cambé', 'Coral', 'Conjunto Habitacional Cristal', '86182-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7936, 'Toledo', 'Coraldino Severo Vaz', 'Residencial Santa Clara', '85908-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7937, 'Laranjeiras do Sul', 'Corbélia', 'Água Verde', '85302-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7938, 'Guarapuava', 'Corbélia', 'Cascavel', '85025-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7939, 'Londrina', 'Corbélia', 'Champagnat', '86062-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7940, 'Pinhais', 'Corbélia', 'Jardim Alto Tarumã', '83325-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7941, 'São José dos Pinhais', 'Corbélia', 'Águas Belas', '83010-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7942, 'Telêmaco Borba', 'Corbélia', 'Nossa Senhora de Fátima', '84264-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7943, 'Toledo', 'Corbélia', 'Jardim La Salle', '85902-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7944, 'Toledo', 'Corbélia', 'Jardim Santa Maria', '85903-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7945, 'Colombo', 'Corbélia', 'Jardim La Paloma', '83412-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7946, 'Cascavel', 'Corbélia', 'Morumbi', '85817-440', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7947, 'Cascavel', 'Corbélia', 'Pacaembu', '85816-570', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7948, 'Apucarana', 'Corbélia', 'Jardim das Flores I', '86810-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7949, 'Curitiba', 'Corbélia', 'Sítio Cercado', '81910-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7950, 'Cascavel', 'Corcovado', 'Periolo', '85817-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7951, 'Londrina', 'Cordeiro de Farias', 'Sebastião de Melo César', '86084-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7952, 'Maringá', 'Córdoba', 'Vila Santo Antônio', '87030-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7953, 'Ponta Grossa', 'Cordovil do Meriti', 'Oficinas', '84045-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7954, 'Guarapuava', 'Coréia', 'São Cristóvão', '85063-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7955, 'Francisco Beltrão', 'Coréia', 'Pinheirinho', '85606-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7956, 'Ponta Grossa', 'Corimba', 'Cará-cará', '84043-728', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7957, 'Cambé', 'Coríntios', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7958, 'Cascavel', 'Coriolano Ferreira Santiago', 'Santa Felicidade', '85803-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7959, 'Maringá', 'Coripheu de Azevedo Marques', 'Vila Santo Antônio', '87030-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7960, 'Ponta Grossa', 'Corisco', 'Cará-cará', '84043-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7961, 'Arapongas', 'Cormorão', 'Jardim Lorena', '86707-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7962, 'Cascavel', 'Cornalina', 'Esmeralda', '85806-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7963, 'Apucarana', 'Cornélio Kloster', 'Jardim Vale do Sol', '86803-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7964, 'Londrina', 'Cornélio Pires', 'Jardim dos Alpes III', '86045-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7965, 'Guarapuava', 'Cornélio Procópio', 'Boqueirão', '85023-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7966, 'Ponta Grossa', 'Cornélio Procópio', 'Nova Rússia', '84053-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7967, 'Londrina', 'Cornélio Procópio', 'Aurora', '86060-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7968, 'Telêmaco Borba', 'Cornélio Procópio', 'Centro', '84261-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7969, 'Colombo', 'Cornélio Procópio', 'Jardim Anai', '83410-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7970, 'Cambé', 'Cornélio Procópio', 'Jardim Silvino', '86187-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7971, 'Curitiba', 'Cornélio Procópio', 'Cidade Industrial', '81250-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7972, 'Curitiba', 'Cornelius Pries', 'Xaxim', '81830-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7973, 'Arapongas', 'Coroa', 'Aricanduva', '86706-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7974, 'Toledo', 'Coroa do Norte', 'Jardim Concórdia', '85906-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7975, 'Guarapuava', 'Coroados', 'Vila Carli', '85040-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7976, 'Londrina', 'Coroados', 'São Paulo', '86026-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7977, 'Cascavel', 'Coroados', 'Santa Cruz', '85806-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7978, 'Arapongas', 'Corocoxó', 'Jardim Colúmbia IV', '86707-826', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7979, 'Curitiba', 'Coronel Adherbal Fortes de Sá', 'Seminário', '80740-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7980, 'Curitiba', 'Coronel Adolfo Guimarães', 'Jardim Social', '82520-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7981, 'Piraquara', 'Coronel Adyr Guimarães', 'Vila Militar I', '83303-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7982, 'Curitiba', 'Coronel Adyr Guimarães', 'Ahú', '82200-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7983, 'Curitiba', 'Coronel Agostinho Macedo', 'Centro Cívico', '80520-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7984, 'Curitiba', 'Coronel Airton Plaisant', 'Santa Quitéria', '80310-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7985, 'Curitiba', 'Coronel Airton Plaisant', 'Portão', '80330-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7986, 'Paranaguá', 'Coronel Alberto Gomes Veiga', 'Itiberê', '83206-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7987, 'Ponta Grossa', 'Coronel Alcebíades de Miranda', 'Boa Vista', '84073-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7988, 'Curitiba', 'Coronel Alfredo Ferreira da Costa', 'Jardim das Américas', '81540-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7989, 'Curitiba', 'Coronel Amazonas Marcondes', 'Cabral', '80035-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7990, 'Curitiba', 'Coronel Américo Walger', 'Alto Boqueirão', '81860-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7991, 'Toledo', 'Coronel Ângelo Mello', 'Conjunto Barão do Rio Branco II', '85905-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7992, 'Curitiba', 'Coronel Aníbal dos Santos', 'Fanny', '81030-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7993, 'Paranaguá', 'Coronel Antônio Bittencourt', 'Centro Histórico', '83203-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7994, 'Curitiba', 'Coronel Antônio Ricardo dos Santos', 'Hauer', '81610-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7995, 'Curitiba', 'Coronel Antônio Ricardo dos Santos', 'Hauer', '81630-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7996, 'Guarapuava', 'Coronel Antônio Villaça', 'Vila Bela', '85027-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7997, 'Toledo', 'Coronel Aparício Borges', 'Boa Esperança', '85909-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7998, 'Curitiba', 'Coronel Arthur Ferreira de Abreu', 'Capão da Imbuia', '82810-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (7999, 'Curitiba', 'Coronel Ary Pinho', 'Boa Vista', '82650-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8000, 'Curitiba', 'Coronel Assumpção', 'Alto da Rua XV', '80040-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8001, 'Curitiba', 'Coronel Augusto de Almeida Garret', 'Tarumã', '82820-520', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8002, 'Curitiba', 'Coronel Aviador José Biagini Moraes', 'Tatuquara', '81480-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8003, 'Curitiba', 'Coronel Aviador José Biancini Moraes', 'Tatuquara', '81480-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8004, 'Curitiba', 'Coronel Baeta de Faria', 'Jardim das Américas', '81530-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8005, 'Piraquara', 'Coronel Benedito Tertuliano Cordeiro', 'Vila Militar I', '83303-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8006, 'Curitiba', 'Coronel Benedito Tertuliano Cordeiro', 'Tingui', '82600-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8007, 'Curitiba', 'Coronel Benoit Pontes Cidreira', 'Boqueirão', '81750-155', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8008, 'Ponta Grossa', 'Coronel Bittencourt', 'Centro', '84010-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8009, 'Foz do Iguaçu', 'Coronel Caetano Rocha', 'Vila Yolanda', '85853-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8010, 'Londrina', 'Coronel Camisão', 'Jardim Europa', '86015-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8011, 'Ponta Grossa', 'Coronel Camisão', 'Uvaranas', '84031-020', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8012, 'Maringá', 'Coronel Camisão', 'Zona 05', '87015-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8013, 'Paranavaí', 'Coronel Camisão', 'Jardim São Jorge', '87710-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8014, 'Foz do Iguaçu', 'Coronel Carlos Bardelli', 'Jardim Marisa', '85867-618', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8015, 'Curitiba', 'Coronel Carlos Bardelli', 'Cajuru', '82940-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8016, 'Curitiba', 'Coronel Carlos de Almeida Assumpção', 'Cidade Industrial', '81260-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8017, 'Curitiba', 'Coronel Carlos Vieira de Camargo', 'Santa Felicidade', '82020-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8018, 'Campo Largo', 'Coronel Cezar Torres', 'Centro', '83601-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8019, 'Ponta Grossa', 'Coronel Claúdio', 'Centro', '84010-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8020, 'Guarapuava', 'Coronel Cleve', 'Centro', '85010-350', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8021, 'Curitiba', 'Coronel Cypriano Gomes da Silveira', 'Xaxim', '81830-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8022, 'Curitiba', 'Coronel Domingos Soares', 'Bairro Alto', '82820-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8023, 'Curitiba', 'Coronel Domingos Theodorico de Freitas', 'Sítio Cercado', '81925-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8024, 'Ponta Grossa', 'Coronel Dulcídio', 'Centro', '84010-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8025, 'Piraquara', 'Coronel Dulcídio', 'Vila Militar I', '83303-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8026, 'Curitiba', 'Coronel Dulcídio', 'Batel', '80250-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8027, 'Curitiba', 'Coronel Dulcídio', 'Batel', '80420-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8028, 'Curitiba', 'Coronel Elísio da Costa Marques', 'Cabral', '80540-360', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8029, 'Paranaguá', 'Coronel Elysio Pereira', 'Estradinha', '83206-000', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8030, 'Guarapuava', 'Coronel Emílio Carneiro Duarte', 'Vila Carli', '85040-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8031, 'Piraquara', 'Coronel Enéas', 'Vila Militar I', '83303-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8032, 'Curitiba', 'Coronel Enéas', 'São Francisco', '80020-150', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8033, 'Curitiba', 'Coronel Enock de Lima', 'Seminário', '80240-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8034, 'Curitiba', 'Coronel Evangelista dos Santos', 'Cajuru', '82970-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8035, 'Ponta Grossa', 'Coronel Fabrício Vieira', 'Uvaranas', '84030-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8036, 'Curitiba', 'Coronel Feliciano Ribeiro', 'Seminário', '80310-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8037, 'Piraquara', 'Coronel Francisco de Paula Moura', 'Vila Militar I', '83303-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8038, 'Curitiba', 'Coronel Francisco de Paula Moura Brito', 'Bacacheri', '82520-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8039, 'Curitiba', 'Coronel Francisco Hofffman dos Santos', 'Jardim das Américas', '81530-001', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8040, 'Curitiba', 'Coronel Francisco Hoffmann dos Santos', 'Jardim das Américas', '81530-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8041, 'Foz do Iguaçu', 'Coronel Francisco José Ludolf Gomes', 'Jardim Panorama', '85856-580', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8042, 'Cascavel', 'Coronel Francisco José Luiz Gomes', 'Parque São Paulo', '85803-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8043, 'Ponta Grossa', 'Coronel Generoso Martins de Araújo', 'Nova Rússia', '84053-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8044, 'Campo Mourão', 'Coronel Geraldo Gomes', 'Jardim Copacabana', '87302-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8045, 'Laranjeiras do Sul', 'Coronel Guilherme de Paula', 'Getúlio Vargas', '85304-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8046, 'Laranjeiras do Sul', 'Coronel Guilherme de Paula', 'Centro', '85301-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8047, 'Curitiba', 'Coronel Guilherme Theodoro Buest', 'Umbará', '81930-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8048, 'Piraquara', 'Coronel Herculano de Araújo', 'Vila Militar I', '83303-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8049, 'Curitiba', 'Coronel Herculano de Araújo', 'Novo Mundo', '81050-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8050, 'Curitiba', 'Coronel Hermínio Alves Cabral', 'Alto Boqueirão', '81770-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8051, 'Curitiba', 'Coronel Hoche Pedra Pires', 'Seminário', '80240-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8052, 'Curitiba', 'Coronel Hugo de Mattos Moura', 'Alto Boqueirão', '81850-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8053, 'Curitiba', 'Coronel Irazê Paes Brasil', 'Tarumã', '82800-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8054, 'Curitiba', 'Coronel Isaías Natel de Paula', 'Bom Retiro', '80520-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8055, 'Curitiba', 'Coronel Izaltino Pinho', 'Fanny', '81030-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8056, 'Curitiba', 'Coronel João Alencar Guimarães Filho', 'Cabral', '80035-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8057, 'Curitiba', 'Coronel João André Dias Paredes', 'Tatuquara', '81470-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8058, 'Araucária', 'Coronel João Antônio Xavier', 'Centro', '83702-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8059, 'Curitiba', 'Coronel João Batista Lopes', 'Cachoeira', '82710-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8060, 'Almirante Tamandaré', 'Coronel João Cândido de Oliveira', 'Vila Rachel', '83501-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8061, 'Curitiba', 'Coronel João Cândido de Oliveira', 'Taboão', '82130-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8062, 'Curitiba', 'Coronel João Cândido Muricy', 'Abranches', '82130-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8063, 'Curitiba', 'Coronel João da Silva Sampaio', 'Jardim Botânico', '80210-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8064, 'Cambé', 'Coronel João Gualberto', 'Jardim Silvino', '86188-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8065, 'Curitiba', 'Coronel João Guilherme Guimarães', 'Mercês', '80510-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8066, 'Curitiba', 'Coronel João Guilherme Guimarães', 'Bom Retiro', '80520-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8067, 'São José dos Pinhais', 'Coronel João José Massaneiro', 'Três Marias', '83005-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8068, 'Londrina', 'Coronel João Mangue Filho', 'Conjunto Habitacional  Alexandre Urbanas', '86037-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8069, 'Curitiba', 'Coronel João Maria Sobrinho', 'Vista Alegre', '82100-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8070, 'Curitiba', 'Coronel João Mattos Guedes', 'Ahú', '82200-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8071, 'Curitiba', 'Coronel João Meister Sobrinho', 'Pilarzinho', '82120-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8072, 'Curitiba', 'Coronel João Rodrigues da Silva Lapa', 'Tatuquara', '81480-216', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8073, 'Curitiba', 'Coronel Joaquim Antônio de Azevedo', 'Sítio Cercado', '81920-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8074, 'Curitiba', 'Coronel Joaquim Inácio Taborda Ribas', 'Bigorrilho', '80730-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8075, 'Curitiba', 'Coronel Joaquim Inácio Taborda Ribas', 'Bigorrilho', '80710-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8076, 'Curitiba', 'Coronel Joaquim Lacerda', 'Jardim das Américas', '81530-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8077, 'Curitiba', 'Coronel Joaquim Monteiro de Carvalho', 'Alto Boqueirão', '81860-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8078, 'Araucária', 'Coronel Joaquim Palhano', 'Centro', '83702-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8079, 'Curitiba', 'Coronel Joaquim Pereira de Macedo', 'Centro', '80410-160', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8080, 'Curitiba', 'Coronel Joaquim Sarmento', 'Bom Retiro', '80520-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8081, 'Castro', 'Coronel Jorge Marcondes', 'Vila Rio Branco', '84172-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8082, 'Ponta Grossa', 'Coronel José Antônio de Moraes Sarmento', 'Olarias', '84026-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8083, 'Curitiba', 'Coronel José Carvalho de Oliveira', 'Uberaba', '81570-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8084, 'Curitiba', 'Coronel José Gomes do Amaral', 'Água Verde', '80620-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8085, 'Curitiba', 'Coronel José Leal Fontoura', 'Xaxim', '81720-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8086, 'Paranaguá', 'Coronel José Lobo', 'Oceania', '83203-340', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8087, 'Ponta Grossa', 'Coronel José Miro de Freitas', 'Boa Vista', '84070-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8088, 'Apucarana', 'Coronel José P. de Castro', 'Jardim Iguatemi', '86810-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8089, 'Ponta Grossa', 'Coronel José Pedro de Carvalho', 'Nova Rússia', '84070-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8090, 'Curitiba', 'Coronel José Pereira de Morais', 'Jardim Social', '82530-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8091, 'Curitiba', 'Coronel Leonardo Pedro Wichert', 'Pilarzinho', '82115-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8092, 'Ponta Grossa', 'Coronel Leopoldo Alves Almeida', 'Uvaranas', '84030-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8093, 'Guarapuava', 'Coronel Luís Lustosa', 'Santa Cruz', '85015-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8094, 'Curitiba', 'Coronel Luiz Fernando Mariano', 'Cidade Industrial', '81350-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8095, 'Londrina', 'Coronel Luiz Gastão Richeter', 'Interlagos', '86035-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8096, 'Londrina', 'Coronel Luiz José dos Santos', 'Jardim Santo Ângelo', '86070-085', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8097, 'Apucarana', 'Coronel Luiz José dos Santos', 'Centro', '86800-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8098, 'Curitiba', 'Coronel Luiz José dos Santos', 'Boqueirão', '81650-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8099, 'Curitiba', 'Coronel Luiz José dos Santos', 'Xaxim', '81830-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8100, 'Curitiba', 'Coronel Luiz José dos Santos', 'Xaxim', '81710-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8101, 'Curitiba', 'Coronel Luiz José dos Santos', 'Boqueirão', '81670-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8102, 'São José dos Pinhais', 'Coronel Luiz Victorino Ordine', 'São Pedro', '83005-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8103, 'Guarapuava', 'Coronel Lustosa', 'Centro', '85010-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8104, 'Guarapuava', 'Coronel Lustosa', 'Batel', '85015-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8105, 'Piraquara', 'Coronel Machado Lopes', 'Jardim Santa Mônica', '83302-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8106, 'Piraquara', 'Coronel Manoel Alves Cordeiro', 'Vila Marumbi', '83304-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8107, 'Curitiba', 'Coronel Manoel Alves do Amaral', 'Jardim Social', '82520-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8108, 'Guarapuava', 'Coronel Manoel Marcondes', 'Batel', '85015-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8109, 'Curitiba', 'Coronel Menna Barreto Monclaro', 'Centro', '80420-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8110, 'Piraquara', 'Coronel Muniz de Aragão', 'Vila Militar I', '83303-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8111, 'Curitiba', 'Coronel Napoleão Marcondes Franca', 'Hugo Lange', '80040-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8112, 'Curitiba', 'Coronel Nelson Romero Stadler de Souza', 'Cidade Industrial', '81460-236', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8113, 'Curitiba', 'Coronel Newton Oliveira da Silva', 'Ganchinho', '81935-387', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8114, 'Piraquara', 'Coronel Nicolau Bley Neto', 'Vila Militar I', '83303-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8115, 'Curitiba', 'Coronel Nicolau Bley Neto', 'Cidade Industrial', '81250-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8116, 'Castro', 'Coronel Olegário de Macedo', 'Água Suja', '84165-690', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8117, 'Colombo', 'Coronel Oliveira Cabral', 'Jardim São Gabriel', '83407-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8118, 'Colombo', 'Coronel Olivério Cabral', 'Vila Carrano Júnior', '83409-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8119, 'Curitiba', 'Coronel Orlando Xavier Pombo', 'São Braz', '82015-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8120, 'Curitiba', 'Coronel Oscar Rodrigues', 'São Braz', '82300-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8121, 'Curitiba', 'Coronel Ottoni Maciel', 'Vila Izabel', '80320-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8122, 'Curitiba', 'Coronel Pedro Scherer Sobrinho', 'Cristo Rei', '80050-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8123, 'Curitiba', 'Coronel Pretextato Pena Forte T. Ribas', 'Santa Quitéria', '80310-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8124, 'Curitiba', 'Coronel Pretextato Pena Forte T. Ribas', 'Portão', '80330-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8125, 'Almirante Tamandaré', 'Coronel Procópio Gomes', 'Planta Vila Rica', '83507-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8126, 'São José dos Pinhais', 'Coronel Quadros', 'Cidade Jardim', '83035-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8127, 'Curitiba', 'Coronel Rivadávia Pereira de Moraes', 'Xaxim', '81810-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8128, 'Curitiba', 'Coronel Roberto Müller', 'Vista Alegre', '80820-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8129, 'Piraquara', 'Coronel Romão Rodrigues de Oliveira', 'Vila Militar I', '83303-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8130, 'Curitiba', 'Coronel Romão Rodrigues de Oliveira Branco', 'Jardim Social', '82520-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8131, 'Guarapuava', 'Coronel Saldanha', 'Alto da XV', '85065-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8132, 'Guarapuava', 'Coronel Saldanha', 'Centro', '85010-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8133, 'Guarapuava', 'Coronel Saldanha', 'Santa Cruz', '85015-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8134, 'Paranaguá', 'Coronel Santa Rita', 'Tuiuti', '83203-630', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8135, 'Paranaguá', 'Coronel Santa Rita', 'Industrial', '83221-675', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8136, 'Curitiba', 'Coronel Sílvio Van Erven', 'Bigorrilho', '80730-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8137, 'Ponta Grossa', 'Coronel Solano', 'Centro', '84010-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8138, 'Curitiba', 'Coronel Temístocles de Souza Brasil', 'Jardim Social', '82520-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8139, 'Curitiba', 'Coronel Verginio Leinig de Mello', 'Abranches', '82220-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8140, 'Toledo', 'Coronel Vicente', 'Jardim La Salle', '85903-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8141, 'Toledo', 'Coronel Vicente', 'Jardim La Salle', '85902-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8142, 'Curitiba', 'Coronel Victor Agner Kendrick', 'Sítio Cercado', '81910-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8143, 'Castro', 'Coronel Vidal Martins de Oliveira', 'Vila Rio Branco', '84172-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8144, 'Guarapuava', 'Coronel Vivida', 'Jardim das Américas', '85030-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8145, 'Laranjeiras do Sul', 'Coronel Vivida', 'Água Verde', '85302-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8146, 'Ponta Grossa', 'Coronel Vivida', 'Oficinas', '84036-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8147, 'Curitiba', 'Coronel Vivida', 'Alto Boqueirão', '81860-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8148, 'Curitiba', 'Coronel Wallace Scott Murray', 'Santa Cândida', '82640-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8149, 'Curitiba', 'Coronel Zacarias', 'Prado Velho', '80215-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8150, 'Curitiba', 'Coronel Zacarias Xavier', 'Tingui', '82620-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8151, 'Arapongas', 'Corredor', 'Conjunto Ulisses Guimarães', '86706-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8152, 'Ponta Grossa', 'Corredor A', 'Colônia Dona Luiza', '84043-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8153, 'Ponta Grossa', 'Corredor B', 'Colônia Dona Luiza', '84043-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8154, 'Ponta Grossa', 'Corredor C', 'Colônia Dona Luiza', '84043-556', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8155, 'Ponta Grossa', 'Corredor D', 'Colônia Dona Luiza', '84043-557', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8156, 'Campo Largo', 'Corredor de Servidão', 'Jardim Esmeralda', '83604-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8157, 'Guarapuava', 'Corredor dos Cajueiros', 'Conradinho', '85055-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8158, 'Foz do Iguaçu', 'Correia de Freitas', 'Jardim Curitibano I', '85869-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8159, 'Ponta Grossa', 'Correia de Freitas', 'Ronda', '84051-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8160, 'Paranaguá', 'Correia de Freitas', 'Centro Histórico', '83203-260', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8161, 'Guarapuava', 'Correia Pinto', 'Industrial', '85045-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8162, 'Telêmaco Borba', 'Corrente', 'Área 02', '84267-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8163, 'Pato Branco', 'Corretor Vilas Boas', 'Alvorada', '85508-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8164, 'Arapongas', 'Corriqueiro-do-campo', 'Jardim Colúmbia I', '86707-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8165, 'Arapongas', 'Corruira', 'Jardim São Cristóvão', '86709-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8166, 'Arapongas', 'Corruira', 'Jardim São Cristóvão', '86701-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8167, 'Foz do Iguaçu', 'Corruíra', 'Conjunto A', '85866-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8168, 'Francisco Beltrão', 'Corruíra', 'Padre Eurico', '85604-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8169, 'Ponta Grossa', 'Corruíra', 'Colônia Dona Luiza', '84043-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8170, 'Campo Mourão', 'Corruíra', 'Jardim Tropical I', '87310-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8171, 'Araucária', 'Corruíra', 'Capela Velha', '83706-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8172, 'Arapongas', 'Corruíra-açu', 'Jardim Bononi', '86703-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8173, 'Arapongas', 'Corruíra-do-brejo', 'Jardim Caravelle', '86702-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8174, 'Pinhais', 'Corrupião', 'Jardim Fênix', '83326-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8175, 'Ponta Grossa', 'Corrupião', 'Colônia Dona Luiza', '84043-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8176, 'Arapongas', 'Corrupião', 'Vila Industrial', '86706-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8177, 'Campo Mourão', 'Corrupião', 'Jardim Lar Paraná', '87305-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8178, 'Ponta Grossa', 'Corstiaan Hagers', 'Contorno', '84060-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8179, 'Arapongas', 'Corta-mar', 'Parque Veneza', '86701-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8180, 'Arapongas', 'Corucui', 'Vila Industrial', '86706-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8181, 'Foz do Iguaçu', 'Coruja', 'Conjunto A', '85866-100', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8182, 'Arapongas', 'Corujão', 'Jardim Colúmbia I', '86707-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8183, 'Arapongas', 'Corujão-de-topete', 'Conjunto Flamingos III', '86703-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8184, 'Arapongas', 'Coruja-preta', 'Parque Industrial V', '86702-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8185, 'Foz do Iguaçu', 'Corumbá', 'Jardim Dona Rocca', '85869-187', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8186, 'Guarapuava', 'Corumbá', 'Industrial', '85045-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8187, 'Sarandi', 'Corumbá', 'Jardim Gralha Azul', '87112-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8188, 'Telêmaco Borba', 'Corumbá', 'Vila São José', '84263-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8189, 'Campo Largo', 'Corumbá', 'Vila Dom Pedro', '83608-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8190, 'Foz do Iguaçu', 'Corupa', 'Jardim Jasmim', '85869-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8191, 'Foz do Iguaçu', 'Corvina', 'Conjunto A', '85860-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8192, 'Curitiba', 'Cosme Lockwood Gomm', 'Bigorrilho', '80710-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8193, 'Paranavaí', 'Cosmo Damiani Jacovozzi', 'Parque Morumbi', '87703-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8194, 'Apucarana', 'Costa Azul', 'Vila Formosa', '86802-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8195, 'Foz do Iguaçu', 'Costa e Silva', 'Cr 1', '85863-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8196, 'Pinhais', 'Costa e Silva', 'Vila Amélia', '83330-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8197, 'Toledo', 'Costa e Silva', 'Jardim Paraná', '85902-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8198, 'Umuarama', 'Costa e Silva', 'Zona V', '87504-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8199, 'Colombo', 'Costa e Silva', 'Jardim Quitandinha', '83409-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8200, 'Cascavel', 'Costa e Silva', 'Parque São Paulo', '85803-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8201, 'Colombo', 'Costa Lobo', 'Jardim Planalto', '83409-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8202, 'Guarapuava', 'Costa Rica', 'Boqueirão', '85023-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8203, 'Francisco Beltrão', 'Costa Rica', 'Antônio de Paiva Cantelmo', '85603-543', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8204, 'Pinhais', 'Costa Rica', 'Vl Dona Guiomar', '83320-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8205, 'Paranaguá', 'Costa Rica', 'Jardim América', '83209-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8206, 'Maringá', 'Costa Rica', 'Jardim Internorte', '87045-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8207, 'Ponta Grossa', 'Costa Rica', 'Ronda', '84051-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8208, 'Telêmaco Borba', 'Costa Rica', 'Alto das Oliveiras', '84266-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8209, 'Apucarana', 'Costa Rica', 'Recanto Mundo Novo', '86805-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8210, 'Colombo', 'Costa Rica', 'Jardim Bela Vista', '83404-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8211, 'Curitiba', 'Costa Rica', 'Bacacheri', '82510-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8212, 'Curitiba', 'Costa Rica', 'Bacacheri', '82515-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8213, 'Foz do Iguaçu', 'Cotia', 'Conjunto A', '85861-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8214, 'Foz do Iguaçu', 'Cotinga', 'Portal da Foz', '85859-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8215, 'Pinhais', 'Cotinga', 'Jardim Fênix', '83326-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8216, 'Arapongas', 'Cotinga', 'Jardim do Café', '86706-209', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8217, 'Francisco Beltrão', 'Cotovia', 'Padre Eurico', '85604-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8218, 'Londrina', 'Cotovia', 'Conjunto Habitacional Violim', '86084-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8219, 'Pinhais', 'Cotovia', 'Jardim Cláudia', '83326-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8220, 'Arapongas', 'Cotovia', 'Jardim do Café', '86706-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8221, 'Maringá', 'Cotovia do campo', 'Conjunto Habitacional Sanenge', '87075-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8222, 'Araucária', 'Coudelaria de Tindiquera', 'Sabiá', '83708-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8223, 'Araucária', 'Coudelaria de Tindiquera', 'Estação', '83705-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8224, 'Ponta Grossa', 'Couto de Magalhães', 'Nova Rússia', '84070-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8225, 'Foz do Iguaçu', 'Couto Pereira', 'Parque Morumbi', '85858-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8226, 'Curitiba', 'Cova da Iria', 'Tarumã', '82800-200', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8227, 'Maringá', 'Coxim', 'Parque Residencial Eldorado', '87025-610', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8228, 'Sarandi', 'Coxim', 'Jardim Esplanada', '87112-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8229, 'Foz do Iguaçu', 'Coxiu', 'Conjunto A', '85861-360', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8230, 'Foz do Iguaçu', 'Cravina', 'Vila Adriana', '85854-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8231, 'Londrina', 'Cravina', 'Santo Antônio', '86035-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8232, 'Ponta Grossa', 'Cravo', 'Contorno', '84060-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8233, 'Apucarana', 'Cravo', 'Jardim das Flores I', '86810-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8234, 'Arapongas', 'Crejuá', 'Conjunto Tropical', '86702-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8235, 'Pinhais', 'Crescêncio Batista', 'Conjunto Moradias Perdizes', '83326-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8236, 'Foz do Iguaçu', 'Criciuma', 'Jardim Petropólis', '85868-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8237, 'Guarapuava', 'Criciúma', 'Batel', '85015-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8238, 'São José dos Pinhais', 'Criciúma', 'Guatupê', '83060-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8239, 'Piraquara', 'Criciúma', 'Planta São Tiago', '83306-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8240, 'Londrina', 'Crisântemo', 'Indústrias', '86043-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8241, 'Ponta Grossa', 'Crisântemo', 'Contorno', '84060-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8242, 'Apucarana', 'Crisântemo', 'Jardim das Flores III', '86810-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8243, 'Araucária', 'Crisântemo', 'Campina da Barra', '83709-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8244, 'Ponta Grossa', 'Crisoberilo', 'Neves', '84021-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8245, 'Arapongas', 'Crispin', 'Jardim Portal das Flores', '86701-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8246, 'Cambé', 'Crispina Trujilo Rasteiro', 'Conjunto Residencial Roberto Conceição', '86183-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8247, 'Toledo', 'Crissiumal', 'Jardim La Salle', '85903-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8248, 'Toledo', 'Crissiumal', 'Jardim La Salle', '85902-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8249, 'Foz do Iguaçu', 'Cristais', 'Parque Ouro Verde', '85854-050', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8250, 'Londrina', 'Cristal', 'Waldemar Hauer', '86030-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8251, 'Maringá', 'Cristal', 'Jardim Real', '87083-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8252, 'Umuarama', 'Cristal', 'Conjunto Residencial Ouro Branco', '87508-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8253, 'Campo Mourão', 'Cristal', 'Jardim Tropical I', '87310-237', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8254, 'Cascavel', 'Cristal', 'Esmeralda', '85806-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8255, 'Telêmaco Borba', 'Cristal da Rocha', 'Área 04', '84266-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8256, 'Guarapuava', 'Cristalina', 'Santana', '85070-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8257, 'Londrina', 'Cristian César Moretto', 'Jardim Pioneiros', '86036-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8258, 'Curitiba', 'Cristiano Airozo', 'Cidade Industrial', '81240-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8259, 'Guarapuava', 'Cristiano Francisco Dal Passo', 'Conradinho', '85045-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8260, 'Ponta Grossa', 'Cristiano Hardt Júnior', 'Estrela', '84050-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8261, 'Ponta Grossa', 'Cristiano Justus Júnior', 'Boa Vista', '84070-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8262, 'Guarapuava', 'Cristiano Kugler', 'Boqueirão', '85020-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8263, 'Castro', 'Cristiano Kugler', 'Jardim São Francisco', '84174-030', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8264, 'Apucarana', 'Cristiano Kussmaul', 'Jardim Menegazzo', '86802-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8265, 'Londrina', 'Cristiano Machado', 'Campo Belo', '86062-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8266, 'Ponta Grossa', 'Cristiano Otoni', 'Olarias', '84035-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8267, 'Curitiba', 'Cristiano Strobel', 'Xaxim', '81710-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8268, 'Curitiba', 'Cristiano Strobel', 'Xaxim', '81750-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8269, 'Curitiba', 'Cristiano Strobel', 'Xaxim', '81720-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8270, 'Foz do Iguaçu', 'Cristiano Wandscheer', 'Jardim Iguaçu', '85853-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8271, 'Foz do Iguaçu', 'Cristiano Weirich', 'Centro', '85851-140', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8272, 'Ponta Grossa', 'Cristiano Zander', 'Uvaranas', '84025-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8273, 'Castro', 'Cristiano Zens', 'Jardim Social Primavera', '84174-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8274, 'Londrina', 'Cristina Maruci', 'Santa Joana', '86044-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8275, 'Guarapuava', 'Cristina Zimmer', 'Boqueirão', '85022-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8276, 'Sarandi', 'Cristo Libertador', 'Parque Residencial Bom Pastor', '87114-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8277, 'Sarandi', 'Cristo Redentor', 'Parque Residencial Bom Pastor', '87114-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8278, 'Cascavel', 'Cristo Redentor', 'Pioneiros Catarinenses', '85805-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8279, 'Cascavel', 'Cristo Redentor', 'Ciro Nardi', '85802-055', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8280, 'Francisco Beltrão', 'Cristo Rei', 'Cristo Rei', '85602-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8281, 'Campo Mourão', 'Cristo Rei', 'Jardim Tropical II', '87310-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8282, 'Cascavel', 'Cristo Rei', 'Centro', '85812-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8283, 'Apucarana', 'Cristo Rei', 'Loteamento Santa Cândida', '86802-405', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8284, 'Londrina', 'Cristoval Fernandes Moreno', 'Cafezal', '86045-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8285, 'Curitiba', 'Cristovan Ruiz', 'Barreirinha', '82210-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8286, 'Londrina', 'Cristóvão Cardoso de Barros', 'Jardim Novo Sabará', '86066-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8287, 'Foz do Iguaçu', 'Cristóvão Colombo', 'Profilurb I', '85855-570', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8288, 'Londrina', 'Cristóvão Colombo', 'Aeroporto', '86036-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8289, 'Guarapuava', 'Cristóvão Colombo', 'Vila Bela', '85027-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8290, 'São José dos Pinhais', 'Cristóvão Colombo', 'Ipê', '83055-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8291, 'Pato Branco', 'Cristóvão Colombo', 'Aeroporto', '85503-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8292, 'Maringá', 'Cristóvão Colombo', 'Vila Nova', '87045-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8293, 'Piraquara', 'Cristóvão Colombo', 'Vila Ipanema', '83301-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8294, 'Toledo', 'Cristóvão Colombo', 'Jardim Paulista', '85909-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8295, 'Telêmaco Borba', 'Cristóvão Colombo', 'Nossa Senhora de Fátima', '84264-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8296, 'Sarandi', 'Cristóvão Colombo', 'Novo Panorama', '87113-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8297, 'Colombo', 'Cristóvão Colombo', 'Jardim Central', '83409-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8298, 'Cascavel', 'Cristóvão Colombo', 'Pioneiros Catarinenses', '85805-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8299, 'Apucarana', 'Cristóvão Colombo', 'Jardim Aclimação', '86811-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8300, 'Almirante Tamandaré', 'Cristóvão Colombo', 'Jardim São Carlos', '83507-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8301, 'Curitiba', 'Cristóvão Colombo', 'Umbará', '81930-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8302, 'Londrina', 'Crocefisso Pisconti', 'Parque Residencial Alcântara', '86047-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8303, 'Arapongas', 'Crocoio', 'Jardim Universitário', '86702-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8304, 'Londrina', 'Cromita', 'Ideal', '86030-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8305, 'Cambé', 'Crônicas', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8306, 'Pato Branco', 'Cruz Alta', 'Santo Antônio', '85507-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8307, 'Cascavel', 'Cruz Alta', 'Canadá', '85813-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8308, 'Francisco Beltrão', 'Cruz e Souza', 'São Miguel', '85602-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8309, 'Londrina', 'Cruz e Souza', 'Conjunto Residencial Vale do Arvoredo', '86047-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8310, 'Foz do Iguaçu', 'Cruz e Souza', 'Vila Portes', '85865-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8311, 'Ponta Grossa', 'Cruz e Souza', 'Orfãs', '84015-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8312, 'Colombo', 'Cruz e Souza', 'Jardim Quitandinha', '83409-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8313, 'Curitiba', 'Cruz e Souza', 'Guabirotuba', '81510-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8314, 'Guarapuava', 'Cruz Machado', 'Alto Cascavel', '85031-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8315, 'Ponta Grossa', 'Cruz Machado', 'Orfãs', '84051-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8316, 'Pato Branco', 'Cruz Machado', 'Menino Deus', '85502-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8317, 'Telêmaco Borba', 'Cruz Machado', 'Vila São Vicente de Paula', '84262-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8318, 'Toledo', 'Cruz Machado', 'Vila Industrial', '85904-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8319, 'São José dos Pinhais', 'Cruz Machado', 'São Pedro', '83005-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8320, 'Castro', 'Cruz Machado', 'Invernada do Matadouro', '84174-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8321, 'Castro', 'Cruz Machado', 'Vila Rio Branco', '84172-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8322, 'Curitiba', 'Cruz Machado', 'Centro', '80410-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8323, 'Arapongas', 'Cruza-bico', 'Jardim do Café', '86706-206', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8324, 'Foz do Iguaçu', 'Cruzeiro', 'Mata Verde', '85853-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8325, 'Guarapuava', 'Cruzeiro', 'Morro Alto', '85065-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8326, 'Toledo', 'Cruzeiro', 'Walter Fontana', '85909-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8327, 'Castro', 'Cruzeiro', 'Vila do Rosário', '84168-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8328, 'Cascavel', 'Cruzeiro', 'Universitário', '85819-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8329, 'Ponta Grossa', 'Cruzeiro do Oeste', 'Ronda', '84051-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8330, 'Campo Mourão', 'Cruzeiro do Oeste', 'Centro', '87302-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8331, 'Curitiba', 'Cruzeiro do Oeste', 'Augusta', '81290-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8332, 'Foz do Iguaçu', 'Cruzeiro do Sul', 'Jardim Eldorado', '85853-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8333, 'Londrina', 'Cruzeiro do Sul', 'Bela Suiça', '86050-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8334, 'Londrina', 'Cruzeiro do Sul', 'Sol', '86070-380', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8335, 'Londrina', 'Cruzeiro do Sul', 'Leste Oeste', '86072-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8336, 'São José dos Pinhais', 'Cruzeiro do Sul', 'Afonso Pena', '83045-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8337, 'Maringá', 'Cruzeiro do Sul', 'Residencial Regente', '87045-738', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8338, 'Pinhais', 'Cruzeiro do Sul', 'Jardim Pedro Demeterco', '83324-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8339, 'Sarandi', 'Cruzeiro do Sul', 'Jardim Universal', '87114-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8340, 'Apucarana', 'Cruzeiro do Sul', 'Jardim Vale do Sol', '86803-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8341, 'Curitiba', 'Cruzeiro do Sul', 'Sítio Cercado', '81900-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8342, 'Maringá', 'Cuba', 'Vila Morangueira', '87040-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8343, 'Maringá', 'Cuba', 'Parque Residencial Tuiuti', '87043-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8344, 'Pinhais', 'Cuba', 'Jardim Luzitano', '83320-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8345, 'Toledo', 'Cuba', 'Pacaembu', '85910-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8346, 'Apucarana', 'Cuba', 'Recanto Mundo Novo', '86805-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8347, 'Colombo', 'Cubas', 'Jardim Bela Vista', '83404-565', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8348, 'Guarapuava', 'Cubatão', 'Boqueirão', '85020-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8349, 'Pato Branco', 'Cubatão', 'São Roque', '85507-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8350, 'Castro', 'Cubatão', 'Jardim Social Arapongas', '84174-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8351, 'Arapongas', 'Cucurutado', 'Jardim Colúmbia I', '86707-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8352, 'Guarapuava', 'Cuiabá', 'Conradinho', '85060-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8353, 'Foz do Iguaçu', 'Cuiabá', 'Conjunto C', '85870-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8354, 'Londrina', 'Cuiabá', 'Portuguesa', '86026-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8355, 'São José dos Pinhais', 'Cuiabá', 'Águas Belas', '83010-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8356, 'Piraquara', 'Cuiabá', 'Vila Vicente Macedo', '83303-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8357, 'Maringá', 'Cuiabá', 'Parque Residencial Cidade Nova', '87023-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8358, 'Pinhais', 'Cuiabá', 'Conjunto Residencial Renato Bonilauri', '83325-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8359, 'Toledo', 'Cuiabá', 'Jardim Porto Alegre', '85906-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8360, 'Sarandi', 'Cuiabá', 'Jardim Gralha Azul', '87112-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8361, 'Telêmaco Borba', 'Cuiabá', 'Vila Santa Rita', '84263-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8362, 'Umuarama', 'Cuiabá', 'Zona V', '87504-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8363, 'Cascavel', 'Cuiabá', 'Ciro Nardi', '85802-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8364, 'Cascavel', 'Cuiabá', 'Maria Luiza', '85819-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8365, 'Cascavel', 'Cuiabá', 'Alto Alegre', '85805-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8366, 'Apucarana', 'Cuiabá', 'Jardim Ponta Grossa', '86804-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8367, 'Cambé', 'Cuiabá', 'Vila Guarani', '86182-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8368, 'Curitiba', 'Cuiabá', 'Cajuru', '82940-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8369, 'Curitiba', 'Cuiabá', 'Cajuru', '82930-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8370, 'Foz do Iguaçu', 'Cuica', 'Conjunto A', '85860-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8371, 'Cambé', 'Cuirico Dolfini', 'Parque Residencial Ana Rosa', '86183-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8372, 'Londrina', 'Cuité', 'Marabá', '86035-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8373, 'Arapongas', 'Cuitelão', 'Jardim Aeroporto', '86702-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8374, 'Foz do Iguaçu', 'Cumbaca', 'Conjunto A', '85860-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8375, 'Cascavel', 'Cumbica', 'Santos Dumont', '85804-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8376, 'Londrina', 'Cunhatai', 'Antares', '86036-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8377, 'Guarapuava', 'Cupertinópolis', 'Morro Alto', '85067-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8378, 'Londrina', 'Cupiuba', 'Santa Rita 1', '86071-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8379, 'Londrina', 'Curiango', 'Conjunto Habitacional Violim', '86084-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8380, 'Maringá', 'Curiango', 'Conjunto Residencial Ney Braga', '87075-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8381, 'Campo Mourão', 'Curiango', 'Conjunto Habitacional Milton Luiz Pereira', '87306-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8382, 'Arapongas', 'Curiango', 'Jardim Lorena', '86707-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8383, 'Arapongas', 'Curiango-claro', 'Jardim Colúmbia I', '86707-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8384, 'Pinhais', 'Curiangos', 'Loteamento Alphaville Graciosa', '83327-158', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8385, 'Arapongas', 'Curiango-tesoura', 'Jardim Colúmbia I', '86707-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8386, 'Arapongas', 'Curica', 'Vila Industrial', '86706-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8387, 'Arapongas', 'Curicaca', 'Vila Aparecida', '86707-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8388, 'Foz do Iguaçu', 'Curimbatá', 'Profilurb I', '85855-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8389, 'Londrina', 'Curió', 'Conjunto Habitacional Violim', '86084-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8390, 'Francisco Beltrão', 'Curió', 'Padre Eurico', '85604-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8391, 'Ponta Grossa', 'Curió', 'Colônia Dona Luiza', '84043-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8392, 'Maringá', 'Curió', 'Conjunto Habitacional Sanenge', '87070-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8393, 'Umuarama', 'Curió', 'Jardim Alphavile', '87504-667', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8394, 'Sarandi', 'Curió', 'Conjunto Floresta', '87112-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8395, 'Apucarana', 'Curió', 'Núcleo Habitacional Michel Soni', '86813-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8396, 'Araucária', 'Curió', 'Estação', '83705-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8397, 'Cascavel', 'Curió', 'Floresta', '85814-750', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8398, 'Foz do Iguaçu', 'Curiós', 'Portal da Foz', '85859-500', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8399, 'Guarapuava', 'Curitiba', 'Bonsucesso', '85045-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8400, 'Foz do Iguaçu', 'Curitiba', 'Conjunto C', '85870-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8401, 'Foz do Iguaçu', 'Curitiba', 'Jardim Paraná', '85867-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8402, 'Londrina', 'Curitiba', 'Barbeta', '86078-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8403, 'Francisco Beltrão', 'Curitiba', 'Vila Maria Delani', '85605-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8404, 'Francisco Beltrão', 'Curitiba', 'Centro', '85601-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8405, 'Laranjeiras do Sul', 'Curitiba', 'São Francisco', '85303-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8406, 'Maringá', 'Curitiba', 'Zona 04', '87014-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8407, 'Ponta Grossa', 'Curitiba', 'Nova Rússia', '84053-130', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8408, 'Piraquara', 'Curitiba', 'Planta Araçatuba', '83301-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8409, 'Paranavaí', 'Curitiba', 'Centro', '87702-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8410, 'Paranavaí', 'Curitiba', 'Centro', '87703-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8411, 'Paranaguá', 'Curitiba', 'Parque São João', '83212-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8412, 'São José dos Pinhais', 'Curitiba', 'Ouro Fino', '83015-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8413, 'Pato Branco', 'Curitiba', 'Cristo Rei', '85507-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8414, 'Ponta Grossa', 'Curitiba', 'Olarias', '84035-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8415, 'Paranavaí', 'Curitiba', 'Vila City', '87709-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8416, 'Paranavaí', 'Curitiba', 'Jardim Ouro Branco', '87704-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8417, 'Sarandi', 'Curitiba', 'Jardim Cometa', '87112-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8418, 'Telêmaco Borba', 'Curitiba', 'Centro', '84261-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8419, 'Umuarama', 'Curitiba', 'Zona V', '87504-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8420, 'Toledo', 'Curitiba', 'Boa Esperança', '85909-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8421, 'Cascavel', 'Curitiba', 'Alto Alegre', '85805-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8422, 'Almirante Tamandaré', 'Curitiba', 'Jardim Valma', '83507-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8423, 'Almirante Tamandaré', 'Curitiba', 'Jardim Gramados', '83504-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8424, 'Cascavel', 'Curitiba', 'Ciro Nardi', '85802-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8425, 'Cambé', 'Curitiba', 'Vila Mesquita', '86182-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8426, 'Campo Mourão', 'Curitiba', 'Jardim Vitória', '87303-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8427, 'Apucarana', 'Curitiba', 'Centro', '86800-005', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8428, 'Araucária', 'Curitiba', 'Iguaçu', '83701-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8429, 'Colombo', 'Curitiba', 'Jardim Curitiba', '83406-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8430, 'Curitiba', 'Curitiba Araucária RFF', 'Cidade Industrial', '81350-580', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8431, 'Curitiba', 'Curitiba Araucária RFF', 'Portão', '81070-490', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8432, 'Foz do Iguaçu', 'Curiúva', 'Jardim Belvedere II', '85867-608', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8433, 'Ponta Grossa', 'Curiúva', 'Uvaranas', '84025-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8434, 'São José dos Pinhais', 'Curiúva', 'Braga', '83020-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8435, 'Telêmaco Borba', 'Curiúva', 'Área 02', '84267-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8436, 'Curitiba', 'Curiúva', 'Barreirinha', '82650-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8437, 'Arapongas', 'Curriqueiro', 'Jardim Coroados', '86707-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8438, 'Arapongas', 'Curriqueiro-dos-campos', 'Jardim Colúmbia I', '86707-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8439, 'Toledo', 'Curt Bercht', 'Jardim Porto Alegre', '85906-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8440, 'Curitiba', 'Curt Frederich Dallmann', 'Alto Boqueirão', '81850-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8441, 'Curitiba', 'Curt Roters', 'Boqueirão', '81750-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8442, 'Pinhais', 'Curua', 'Loteamento Alphaville Graciosa', '83327-089', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8443, 'Campo Mourão', 'Curucaca', 'Centro', '87301-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8444, 'Arapongas', 'Curucuturi', 'Parque Industrial', '86703-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8445, 'Umuarama', 'Curumbá', 'Jardim Iguaçu', '87501-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8446, 'Telêmaco Borba', 'Curumins', 'Nossa Senhora do Perpétuo Socorro', '84265-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8447, 'Umuarama', 'Curupai', 'Zona I-A', '87501-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8448, 'Foz do Iguaçu', 'Curupaiti', 'Jardim Itamaraty', '85863-060', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8449, 'Curitiba', 'Curupaitis', 'Portão', '80330-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8450, 'Curitiba', 'Curupaitis', 'Santa Quitéria', '80310-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8451, 'Curitiba', 'Curupis', 'Portão', '80330-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8452, 'Curitiba', 'Curupis', 'Santa Quitéria', '80310-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8453, 'Cascavel', 'Custódio de Mesquita', 'Brasília', '85815-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8454, 'Foz do Iguaçu', 'Custódio Pires', 'Jardim Olaria', '85867-386', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8455, 'Pinhais', 'Custódio Ribas', 'Conjunto Residencial Inocoop', '83326-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8456, 'Londrina', 'Custódio Tavares da Silva', 'Ernani de Moura Lima', '86037-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8457, 'Ponta Grossa', 'Custódio Vaz', 'Boa Vista', '84070-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8458, 'Londrina', 'Cuzco', 'Bela Suiça', '86050-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8459, 'Londrina', 'Cyntia Kiyomi Tackahashi', 'Jardim das Américas', '86076-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8460, 'Londrina', 'Cypriano Campinha', 'Conjunto Habitacional  Alexandre Urbanas', '86037-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8461, 'Curitiba', 'Cypriano Ribeiro Cid', 'Sítio Cercado', '81920-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8462, 'Londrina', 'Cypriano Spoladore', 'Monte Carlo', '86073-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8463, 'Ponta Grossa', 'Cyrena Stahlschmith Martins', 'Colônia Dona Luiza', '84046-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8464, 'Curitiba', 'Cyrillo Merlin', 'Novo Mundo', '81010-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8465, 'Curitiba', 'Cyro Correia Pereira', 'Cidade Industrial', '81170-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8466, 'Curitiba', 'Cyro Correia Pereira', 'Cidade Industrial', '81450-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8467, 'São José dos Pinhais', 'Cyro Pellizzari', 'Campina', '83015-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8468, 'Curitiba', 'Cyro Vellozo', 'Prado Velho', '80215-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8469, 'Foz do Iguaçu', 'D', 'Conjunto C', '85870-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8470, 'Ponta Grossa', 'D', 'Uvaranas', '84025-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8471, 'Ponta Grossa', 'D', 'Ronda', '84051-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8472, 'Ponta Grossa', 'D', 'Cará-cará', '84043-438', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8473, 'Ponta Grossa', 'D', 'Ronda', '84050-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8474, 'Maringá', 'D', 'Vila Vardelina', '87080-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8475, 'Ponta Grossa', 'D', 'Cará-cará', '84045-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8476, 'Paranavaí', 'D', 'Vila Operária', '87708-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8477, 'Paranavaí', 'D', 'Vila Alta', '87708-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8478, 'Ponta Grossa', 'D', 'Uvaranas', '84031-288', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8479, 'Paranavaí', 'D', 'Jardim São Cristóvão', '87702-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8480, 'Ponta Grossa', 'D', 'Contorno', '84060-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8481, 'Ponta Grossa', 'D', 'Uvaranas', '84032-478', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8482, 'Umuarama', 'D', 'Parque Industrial II', '87507-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8483, 'Umuarama', 'D', 'Parque Dom Pedro I', '87508-017', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8484, 'Umuarama', 'D', 'Jardim Carolina', '87501-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8485, 'Umuarama', 'D', 'Núcleo Cruzeiro', '87509-618', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8486, 'Campo Largo', 'D', 'Jardim Tropical', '83602-057', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8487, 'Almirante Tamandaré', 'D', 'Jardim Marrocos', '83511-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8488, 'Almirante Tamandaré', 'D', 'Jardim São Caetano', '83507-153', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8489, 'Campo Largo', 'D', 'Popular Nova', '83602-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8490, 'Campo Largo', 'D', 'Jardim Emília', '83607-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8491, 'Almirante Tamandaré', 'D', 'Jardim Alvorada', '83505-216', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8492, 'Almirante Tamandaré', 'D', 'Parque Timbu', '83514-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8493, 'Campo Largo', 'D', 'Vila Alzira', '83608-247', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8494, 'Campo Largo', 'D', 'Vila Torres I', '83609-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8495, 'Campo Largo', 'D', 'Jardim Três Rios', '83603-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8496, 'Castro', 'D', 'Vila do Rosário', '84168-076', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8497, 'Castro', 'D', 'Jardim Bela Vista', '84165-418', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8498, 'Campo Mourão', 'D', 'Distrito Industrial I', '87306-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8499, 'Arapongas', 'D-1', 'Jardim Caravelle', '86702-660', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8500, 'Londrina', 'da Abolição', 'Nóbrega', '86025-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8501, 'Campo Mourão', 'da Abolição', 'Conjunto Habitacional Mendes', '87306-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8502, 'Cambé', 'da Abolição', 'Jardim Vila Rica', '86192-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8503, 'Maringá', 'da Adolfo Alves Ferreira', 'Vila Marumby', '87005-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8504, 'Londrina', 'da Aeronáutica', 'Caravelle', '86039-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8505, 'Colombo', 'da Águia', 'Jardim Santa Cruz', '83401-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8506, 'Londrina', 'da Águia-imperial', 'Paraíso', '86078-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8507, 'Paranavaí', 'da Alegria', 'Vila Alta', '87708-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8508, 'Guarapuava', 'da Alvorada', 'Santana', '85070-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8509, 'Londrina', 'da Amizade', 'Carnascialli', '86077-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8510, 'Toledo', 'da Amizade', 'Conjunto Residencial Rossani', '85901-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8511, 'Cascavel', 'da Amizade', '14 de Novembro', '85804-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8512, 'Apucarana', 'da Amizade', 'Núcleo Habitacional da Fraternidade', '86801-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8513, 'Castro', 'da Amizade', 'Jardim Social Arapongas', '84174-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8514, 'Campo Mourão', 'da Amizade', 'Jardim Izabel', '87309-135', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8515, 'Curitiba', 'da Amizade', 'Uberaba', '81560-680', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8516, 'Londrina', 'da Andorinha', 'Waldemar Hauer', '86030-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8517, 'Ponta Grossa', 'da Andorinha', 'Chapada', '84064-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8518, 'Colombo', 'da Andorinha', 'Jardim Georgina', '83401-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8519, 'Colombo', 'da Araponga', 'Planta Santa Tereza', '83401-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8520, 'Colombo', 'da Arara', 'Jardim Ana Rosa I', '83401-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8521, 'Colombo', 'da Aroeira', 'Vila Cordeiro', '83411-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8522, 'Apucarana', 'da Árvore', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-365', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8523, 'Sarandi', 'da Ascensão', 'Parque Residencial Bom Pastor', '87114-532', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8524, 'Cambé', 'da Assembléia', 'Jardim Alvorada', '86191-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8525, 'Curitiba', 'da Assembléia', 'Cajuru', '82970-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8526, 'Foz do Iguaçu', 'da Bandeira', 'Jardim Social I', '85853-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8527, 'Cascavel', 'da Bandeira', 'Centro', '85812-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8528, 'Curitiba', 'da Bandeira', 'São Francisco', '80520-060', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8529, 'Curitiba', 'da Bandeira', 'Cabral', '80035-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8530, 'Umuarama', 'da Bíblia', 'Zona I', '87501-055', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8531, 'Apucarana', 'da Bíblia', 'Loteamento Biguaçu', '86808-450', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8532, 'Campo Mourão', 'da Bica', 'Conjunto Residencial Ilha Bela', '87309-098', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8533, 'Colombo', 'da Boca-de-leão', 'Parque Monte Castelo', '83411-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8534, 'Londrina', 'da Bondade', 'Carnascialli', '86077-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8535, 'Colombo', 'da Bromélia', 'Parque Monte Castelo', '83411-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8536, 'São José dos Pinhais', 'da Cachoeira', 'Colônia Zacarias', '83025-000', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8537, 'Campo Largo', 'da Cachoeira', 'Fazendinha', '83607-440', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8538, 'Colombo', 'da Canafístula', 'Parque do Embu', '83414-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8539, 'Pinhais', 'da Canela', 'Jardim Pio XII', '83328-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8540, 'Curitiba', 'da Canela', 'Barreirinha', '82710-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8541, 'Londrina', 'da Canoagem', 'Igapó', '86015-840', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8542, 'Maringá', 'da Capela', 'Jardim América', '87045-330', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8543, 'Curitiba', 'da Capitania', 'Guabirotuba', '81520-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8544, 'Londrina', 'da Carioca', 'Ipanema', '86015-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8545, 'Curitiba', 'da Carioca', 'Cajuru', '82970-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8546, 'Colombo', 'da Carnaúba', 'Parque do Embu', '83414-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8547, 'Colombo', 'da Castanheira', 'Jardim Nossa Senhora das Graças', '83407-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8548, 'Maringá', 'da Catedral', 'Zona Central', '87010-530', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8549, 'Cambé', 'da Catedral', 'Jardim Alvorada', '86191-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8550, 'Pato Branco', 'da Cerâmica', 'Trevo Patinhos', '85504-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8551, 'Londrina', 'da Cerejeira', 'Interlagos', '86035-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8552, 'Colombo', 'da Cerejeira', 'Jardim Nossa Senhora das Graças', '83407-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8553, 'Curitiba', 'da Cidadania da Fazendinha', 'Fazendinha', '81320-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8554, 'Curitiba', 'da Cidadania do Carmo', 'Boqueirão', '81650-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8555, 'Curitiba', 'da Cidadania do Pinheirinho', 'Capão Raso', '81130-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8556, 'Curitiba', 'da Colônia Augusta', 'Augusta', '81260-060', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8557, 'Campo Largo', 'da Colônia Riviera', 'Ferraria', '83608-680', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8558, 'Cascavel', 'da Colonização', 'Nova Cidade', '85803-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8559, 'Curitiba', 'da Colonização Menonita', 'Boqueirão', '81670-120', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8560, 'Apucarana', 'da Comunidade', 'Núcleo Habitacional da Fraternidade', '86801-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8561, 'Apucarana', 'da Concórdia', 'Núcleo Habitacional da Fraternidade', '86801-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8562, 'Curitiba', 'da Constituição', 'Pinheirinho', '81150-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8563, 'Castro', 'da Constituinte de 1932', 'Centro', '84165-445', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8564, 'Pato Branco', 'da Copel', 'Vila Isabel', '85504-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8565, 'Colombo', 'da Coruja', 'Jardim Santa Cruz', '83401-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8566, 'Colombo', 'da Cotovia', 'Planta Santa Tereza', '83401-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8567, 'Telêmaco Borba', 'da Cruz', 'Vila São Francisco de Assis', '84264-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8568, 'Curitiba', 'da Divina Providência', 'Santa Quitéria', '80310-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8569, 'Londrina', 'da Ema', 'Paraíso', '86078-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8570, 'Cambé', 'da Ermida', 'Jardim Alvorada', '86191-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8571, 'Colombo', 'da Erva Mate', 'Capivari', '83415-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8572, 'Curitiba', 'da Espanha', 'Bigorrilho', '80430-170', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8573, 'Londrina', 'da Esperança', 'Carnascialli', '86077-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8574, 'Paranavaí', 'da Esperança', 'Vila Alta', '87708-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8575, 'Cambé', 'da Esperança', 'Jardim Alvorada', '86191-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8576, 'Umuarama', 'da Estação', 'Zona VI', '87503-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8577, 'Paranavaí', 'da Faculdade', 'Jardim Nakamura', '87701-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8578, 'Toledo', 'da Faculdade', 'Jardim La Salle', '85903-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8579, 'Cascavel', 'da Fag', 'Santa Cruz', '85806-096', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8580, 'Londrina', 'da Fartura', 'Carnascialli', '86077-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8581, 'Curitiba', 'da Fazenda', 'Guabirotuba', '81520-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8582, 'Londrina', 'da Fé', 'Carnascialli', '86077-075', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8583, 'Londrina', 'da Felicidade', 'Carnascialli', '86077-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8584, 'Toledo', 'da Felicidade', 'Boa Esperança', '85909-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8585, 'Cambé', 'da Figueira', 'Planta São Francisco', '86182-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8586, 'Colombo', 'da Flor-de-cera', 'Parque Monte Castelo', '83411-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8587, 'Colombo', 'da Flor-de-lis', 'Parque Monte Castelo', '83411-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8588, 'Londrina', 'da Framboesa', 'Marabá', '86035-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8589, 'Curitiba', 'da Franca', 'Seminário', '80240-450', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8590, 'Londrina', 'da Fraternidade', 'Carnascialli', '86077-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8591, 'Curitiba', 'da Fundição', 'Guabirotuba', '81520-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8592, 'Londrina', 'da Gabiroba', 'Marabá', '86035-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8593, 'Colombo', 'da Gabirobeira', 'Jardim Nossa Senhora das Graças', '83407-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8594, 'Curitiba', 'da Galícia', 'Bigorrilho', '80430-070', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8595, 'Sarandi', 'da Galiléia', 'Parque Residencial Bom Pastor', '87114-538', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8596, 'Colombo', 'da Gama', 'Vila Petrópolis', '83409-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8597, 'Pato Branco', 'da Garagem', 'Centro', '85501-520', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8598, 'Colombo', 'da Garça', 'Planta Santa Tereza', '83401-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8599, 'Paranaguá', 'da Gardênia', 'Conjunto Nilson Neves', '83215-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8600, 'Cascavel', 'da Gávea', 'Morumbi', '85817-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8601, 'Londrina', 'da Ginástica Olímpica', 'Jardim Olímpico', '86056-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8602, 'Maringá', 'da Glória', 'Jardim da Glória', '87047-070', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8603, 'Curitiba', 'da Glória', 'Centro Cívico', '80030-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8604, 'Colombo', 'da Goiabeira', 'Jardim Nossa Senhora das Graças', '83407-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8605, 'Pinhais', 'da Graciosa', 'Jardim Boa Vista', '83327-000', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8606, 'Pinhais', 'da Graciosa', 'Planta Jacob Mehl', '83326-670', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8607, 'Colombo', 'da Graciosa', 'Jardim Santa Mônica', '83412-460', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8608, 'Colombo', 'da Graciosa', 'Walfrido do Rosário', '83413-200', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8609, 'Londrina', 'da Groselha', 'Marabá', '86035-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8610, 'Londrina', 'da Harmonia', 'Carnascialli', '86077-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8611, 'Londrina', 'da Humildade', 'Carnascialli', '86077-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8612, 'Toledo', 'da Igreja', 'Boa Esperança', '85909-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8613, 'Londrina', 'da Igualdade', 'Carnascialli', '86077-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8614, 'Londrina', 'da Imbuia', 'Marumbi', '86071-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8615, 'Colombo', 'da Imbuia', 'Parque do Embu', '83414-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8616, 'Curitiba', 'da Imbuia', 'Barreirinha', '82710-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8617, 'Cascavel', 'da Imigração', 'Nova Cidade', '85803-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8618, 'Curitiba', 'da Imperatriz', 'Boa Vista', '82540-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8619, 'Pato Branco', 'da Inconfidência', 'São Cristóvão', '85508-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8620, 'Guarapuava', 'da Independência', 'Centro', '85010-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8621, 'Maringá', 'da Independência', 'Jardim Alvorada', '87035-140', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8622, 'Cambé', 'da Independência', 'Jardim Alvorada', '86191-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8623, 'Apucarana', 'da Independência', 'Jardim América', '86807-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8624, 'Curitiba', 'da Independência', 'São Braz', '82310-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8625, 'Curitiba', 'da Integração', 'Bairro Alto', '82840-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8626, 'Curitiba', 'da Invernada', 'Guabirotuba', '81520-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8627, 'Londrina', 'da Irmandade', 'Carnascialli', '86077-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8628, 'Colombo', 'da Jaboticabeira', 'Jardim Nossa Senhora das Graças', '83407-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8629, 'Colombo', 'da Jaqueira', 'Jardim Nossa Senhora das Graças', '83407-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8630, 'Apucarana', 'da José Szamrek', 'Vila Shangri-La', '86812-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8631, 'Londrina', 'da Justiça', 'Carnascialli', '86077-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8632, 'Sarandi', 'da Laguna', 'Jardim Independência III', '87114-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8633, 'Cascavel', 'da Laminadora', 'Pioneiros Catarinenses', '85805-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8634, 'Londrina', 'da Lapa', 'Bela Vista', '86015-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8635, 'Francisco Beltrão', 'da Lapa', 'Pinheirinho', '85603-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8636, 'Guarapuava', 'da Lapa', 'São Cristóvão', '85060-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8637, 'Maringá', 'da Lapa', 'Jardim Mandacaru', '87080-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8638, 'Cascavel', 'da Lapa', 'Ciro Nardi', '85819-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8639, 'Cambé', 'da Lapa', 'Jardim Morumbi', '86191-767', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8640, 'Curitiba', 'da Lapa', 'Centro', '80010-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8641, 'Londrina', 'da Liberdade', 'Carnascialli', '86077-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8642, 'Laranjeiras do Sul', 'da Liberdade', 'São Francisco', '85303-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8643, 'Maringá', 'da Liberdade', 'Jardim Santa Rita', '87050-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8644, 'Paranavaí', 'da Liberdade', 'Jardim Santos Dumont', '87706-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8645, 'Toledo', 'da Liberdade', 'Centro', '85900-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8646, 'Campo Largo', 'da Liberdade', 'Jardim Rivabem', '83605-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8647, 'Curitiba', 'da Liberdade', 'Bairro Alto', '82840-280', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8648, 'Colombo', 'da Lira', 'Planta Santa Tereza', '83401-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8649, 'Londrina', 'da Lua', 'Sol', '86070-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8650, 'Curitiba', 'da Lua', 'Sítio Cercado', '81910-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8651, 'Cambé', 'da Luz', 'Jardim Morumbi', '86191-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8652, 'Londrina', 'da Macieira', 'Marabá', '86035-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8653, 'Colombo', 'da Mangueira', 'Jardim Nossa Senhora das Graças', '83407-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8654, 'Londrina', 'da Maratona', 'Jardim Olímpico', '86056-270', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8655, 'Telêmaco Borba', 'da Marinha', 'Jardim Alegre', '84268-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8656, 'Paranavaí', 'da Matriz', 'Jardim São Jorge', '87711-540', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8657, 'Curitiba', 'da Mina do Ouro', 'Santo Inácio', '82010-510', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8658, 'Sarandi', 'da Misericórdia', 'Parque Residencial Bom Pastor', '87114-536', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8659, 'Colombo', 'da Moca', 'Vila Yara', '83408-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8660, 'Colombo', 'da Montanha Santa', 'Campestre', '83415-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8661, 'Cambé', 'da Mooca', 'Jardim Morumbi', '86191-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8662, 'Sarandi', 'da Multiplicação', 'Parque Residencial Bom Pastor', '87114-537', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8663, 'Ponta Grossa', 'da Música', 'Oficinas', '84040-330', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8664, 'Foz do Iguaçu', 'da Nascente', 'Conjunto B', '85867-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8665, 'Cascavel', 'da Nascente', '14 de Novembro', '85804-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8666, 'Londrina', 'da Natureza', 'Parque Residencial João Piza', '86041-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8667, 'Campo Mourão', 'da Natureza', 'Jardim Tropical I', '87310-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8668, 'Araucária', 'da Natureza', 'Campina da Barra', '83709-780', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8669, 'Sarandi', 'da Nave', 'Parque São Pedro', '87112-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8670, 'Colombo', 'da Nogueira', 'Parque do Embu', '83414-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8671, 'Curitiba', 'da Nogueira', 'Barreirinha', '82710-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8672, 'Apucarana', 'da Olaria', 'Residencial Parque da Raposa', '86812-670', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8673, 'Telêmaco Borba', 'da Ordem', 'Nossa Senhora do Perpétuo Socorro', '84265-260', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8674, 'Campo Largo', 'da Ordem', 'Jardim Rivabem', '83605-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8675, 'Curitiba', 'da Ordem', 'Pinheirinho', '81880-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8676, 'Foz do Iguaçu', 'da Palmeira', 'Conjunto B', '85867-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8677, 'Colombo', 'da Papoula', 'Parque Monte Castelo', '83411-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8678, 'Londrina', 'da Patativa', 'Paraíso', '86078-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8679, 'Colombo', 'da Patativa', 'Jardim Santa Cruz', '83401-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8680, 'Apucarana', 'da Pátria', 'Jardim Menegazzo', '86802-035', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8681, 'Laranjeiras do Sul', 'da Paz', 'São Francisco', '85303-106', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8682, 'Londrina', 'da Paz', 'Portal de Versalhes 1', '86057-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8683, 'Londrina', 'da Paz', 'Carnascialli', '86077-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8684, 'Piraquara', 'da Paz', 'Planta Deodoro', '83304-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8685, 'Paranavaí', 'da Paz', 'Jardim Vania', '87708-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8686, 'Paranaguá', 'da Paz', 'Campo Grande', '83203-700', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8687, 'Paranavaí', 'da Paz', 'Jardim Alvorada', '87707-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8688, 'Paranavaí', 'da Paz', 'Vila Alta', '87708-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8689, 'Sarandi', 'da Paz', 'Parque Alvamar', '87113-500', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8690, 'Apucarana', 'da Paz', 'Núcleo Habitacional da Fraternidade', '86801-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8691, 'Colombo', 'da Paz', 'Colônia Faria', '83411-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8692, 'Campo Mourão', 'da Paz', 'Conjunto Habitacional Mendes', '87306-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8693, 'Curitiba', 'da Paz', 'Centro', '80060-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8694, 'Cascavel', 'da Pedreira', '14 de Novembro', '85804-180', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8695, 'Campo Largo', 'da Pedreira', 'Centro', '83601-300', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8696, 'Colombo', 'da Pedreira', 'Campo Pequeno', '83404-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8697, 'Maringá', 'da Penha', 'Zona 06', '87080-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8698, 'Londrina', 'da Pereira', 'Interlagos', '86035-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8699, 'Colombo', 'da Pereira', 'Vila Santa Helena', '83406-490', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8700, 'Curitiba', 'da Peroba', 'Barreirinha', '82710-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8701, 'Londrina', 'da Perseverança', 'Carnascialli', '86077-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8702, 'Toledo', 'da Piscina', 'Jardim Paulista', '85909-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8703, 'Campo Largo', 'da Polônia', 'Centro', '83601-225', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8704, 'Curitiba', 'da Polônia', 'Cristo Rei', '80050-190', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8705, 'Curitiba', 'da Porteira', 'Guabirotuba', '81520-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8706, 'Telêmaco Borba', 'da Prainha', 'Área 02', '84267-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8707, 'Colombo', 'da Prata', 'Parque do Embu', '83414-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8708, 'Cascavel', 'da Prata', 'Morumbi', '85817-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8709, 'Curitiba', 'da Primavera', 'Pilarzinho', '82120-540', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8710, 'Curitiba', 'da Primavera', 'Mossunguê', '81210-060', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8711, 'Paranavaí', 'da Proclamação', 'Jardim Santos Dumont', '87706-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8712, 'Cambé', 'da Proclamação', 'Jardim Vila Rica', '86192-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8713, 'Londrina', 'da Prosperidade', 'Carnascialli', '86077-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8714, 'Sarandi', 'da Providência', 'Parque Residencial Bom Pastor', '87114-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8715, 'Campo Mourão', 'da Província', 'Jardim Pio XII', '87306-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8716, 'Curitiba', 'da Quintagem', 'Guabirotuba', '81520-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8717, 'Cascavel', 'da Quitanda', '14 de Novembro', '85804-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8718, 'Colombo', 'da Raiz-do-sol', 'Parque Monte Castelo', '83411-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8719, 'Campo Largo', 'da Ratada', 'Jardim Esmeralda', '83602-330', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8720, 'Laranjeiras do Sul', 'da República', 'São Francisco', '85303-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8721, 'Foz do Iguaçu', 'da República', 'Parque Presidente I', '85863-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8722, 'Paranaguá', 'da República', 'Centro Histórico', '83203-007', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8723, 'Pato Branco', 'da República', 'São Cristóvão', '85508-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8724, 'Paranavaí', 'da República', 'Jardim Santos Dumont', '87706-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8725, 'Cambé', 'da República', 'Jardim Alvorada', '86191-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8726, 'Curitiba', 'da República', 'Portão', '80610-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8727, 'Curitiba', 'da República', 'Parolin', '80220-430', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8728, 'Curitiba', 'da República', 'Guaíra', '80630-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8729, 'Sarandi', 'da Ressurreição', 'Parque Residencial Bom Pastor', '87114-531', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8730, 'Colombo', 'da Ribeira', 'Vila Guarani', '83408-000', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8731, 'Colombo', 'da Ribeira', 'Jardim Cristina', '83411-000', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8732, 'Curitiba', 'da Ribeira', 'Atuba', '82860-000', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8733, 'Curitiba', 'da Ronda', 'Guabirotuba', '81520-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8734, 'São José dos Pinhais', 'da Roseira', 'Roseira', '83070-010', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8735, 'São José dos Pinhais', 'da Roseira', 'São Sebastião', '83075-010', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8736, 'Colombo', 'da Saíra', 'Jardim Ana Rosa II', '83401-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8737, 'Sarandi', 'da Samaritana', 'Parque Residencial Bom Pastor', '87114-543', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8738, 'Francisco Beltrão', 'da Sanepar', 'Nossa Senhora Aparecida', '85601-816', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8739, 'Sarandi', 'da Santa Ceia', 'Parque Residencial Bom Pastor', '87114-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8740, 'Londrina', 'da Saudade', 'Jardim Higienópolis', '86015-120', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8741, 'Guarapuava', 'da Saudade', 'Trianon', '85012-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8742, 'Guarapuava', 'da Saudade', 'Centro', '85010-110', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8743, 'Piraquara', 'da Saúde', 'Jardim Diguimabri', '83307-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8744, 'Ponta Grossa', 'da Secretária', 'Periquitos', '84065-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8745, 'Curitiba', 'da Sesmaria', 'Guabirotuba', '81520-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8746, 'Londrina', 'da Simpatia', 'Carnascialli', '86077-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8747, 'Campo Mourão', 'da Soja', 'Jardim Alvorada', '87308-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8748, 'Cascavel', 'da Soja', 'Cataratas', '85818-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8749, 'Curitiba', 'da Sorocaba', 'Guabirotuba', '81520-430', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8750, 'Londrina', 'da Sorte', 'Carnascialli', '86077-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8751, 'Campo Largo', 'da Subestação de Enologia', 'Vila Bancária', '83601-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8752, 'Curitiba', 'da Suíça', 'Cabral', '80035-190', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8753, 'Londrina', 'da Ternura', 'Carnascialli', '86077-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8754, 'Cascavel', 'da Tijuca', 'Morumbi', '85817-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8755, 'Colombo', 'da Tiriva', 'Planta Santa Tereza', '83401-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8756, 'Cambé', 'da Torre', 'Parque Residencial Cambé', '86191-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8757, 'Sarandi', 'da Transfiguração', 'Parque Residencial Bom Pastor', '87114-534', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8758, 'Curitiba', 'da Trindade', 'Cajuru', '82920-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8759, 'Colombo', 'da Tulipa', 'Parque Monte Castelo', '83411-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8760, 'Curitiba', 'da Ucrânia', 'Bigorrilho', '80730-430', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8761, 'Londrina', 'da União', 'Carnascialli', '86077-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8762, 'Cascavel', 'da União', '14 de Novembro', '85804-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8763, 'Londrina', 'da Urca', 'Ipanema', '86015-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8764, 'Colombo', 'da Uva', 'Parque do Embu', '83401-520', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8765, 'Colombo', 'da Uva', 'Parque do Embu', '83414-300', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8766, 'Colombo', 'da Uva', 'Jardim Arapongas', '83402-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8767, 'Londrina', 'da Videira', 'Juquita', '86035-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8768, 'Londrina', 'da Virtude', 'Carnascialli', '86077-055', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8769, 'Londrina', 'da Vitória', 'Carnascialli', '86077-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8770, 'Colombo', 'da Vitória-régia', 'Parque Monte Castelo', '83411-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8771, 'Castro', 'Dácio José de Quadros', 'Cantagalo', '84178-440', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8772, 'Curitiba', 'Dagoberto de Moura', 'Pinheirinho', '81870-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8773, 'Curitiba', 'Dagoberto Leitner', 'Boa Vista', '82640-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8774, 'Apucarana', 'Dagoberto Pusch', 'Jardim Figueira', '86801-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8775, 'Ponta Grossa', 'Daily Luís Wambier', 'Orfãs', '84015-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8776, 'Ponta Grossa', 'Dair Daher', 'Boa Vista', '84071-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8777, 'Ponta Grossa', 'Daisy Durski', 'Boa Vista', '84073-178', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8778, 'Curitiba', 'Daisy Luci Berno', 'Guaíra', '80630-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8779, 'Curitiba', 'Daisy Luci Berno', 'Parolin', '80220-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8780, 'Curitiba', 'Daisy Luci Berno', 'Portão', '80610-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8781, 'Curitiba', 'Dalcy Silva', 'Alto Boqueirão', '81860-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8782, 'Curitiba', 'Dalila Lopes Costa', 'Uberaba', '81550-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8783, 'Curitiba', 'Dalila Rolim Vargas', 'Novo Mundo', '81050-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8784, 'Londrina', 'Dallas', 'Lima Azevedo', '86060-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8785, 'Guarapuava', 'Dallas', 'Santana', '85070-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8786, 'Francisco Beltrão', 'Dallas', 'Antônio de Paiva Cantelmo', '85603-117', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8787, 'Sarandi', 'Dallas', 'Jardim Califórnia', '87112-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8788, 'Piraquara', 'Dallila Miranda Chiquetto', 'Planta Granjas Eldorado', '83309-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8789, 'Colombo', 'Dalmira Souza Lunardon', 'Vila São Paulo', '83411-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8790, 'Campo Mourão', 'Dalmo Albuquerque', 'Jardim Joana D''Arc', '87300-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8791, 'Laranjeiras do Sul', 'Dalmo Putini', 'Vila Industrial', '85303-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8792, 'Cambé', 'Dalto', 'Parque Residencial Ana Rosa', '86183-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8793, 'Colombo', 'Dalto Nicoleti', 'Planta Boros', '83413-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8794, 'Pato Branco', 'Dalton Trevisan', 'Jardim Primavera', '85502-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8795, 'Cascavel', 'Dalton Trevisan', 'Interlagos', '85814-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8796, 'Curitiba', 'Dalva de Oliveira', 'Tatuquara', '81470-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8797, 'Londrina', 'Dalva de Oliveira', 'Indústrias Leves', '86030-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8798, 'Maringá', 'Dalva de Oliveira', 'Conjunto Residencial Cidade Alta', '87053-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8799, 'Paranavaí', 'Dalva de Oliveira', 'Jardim São Jorge', '87711-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8800, 'Apucarana', 'Dalva de Oliveira', 'Núcleo Habitacional Castelo Branco', '86812-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8801, 'Cascavel', 'Dalva de Oliveira', 'Brasília', '85815-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8802, 'Guarapuava', 'Dalva Ribas Muller', 'Morro Alto', '85065-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8803, 'Curitiba', 'Dalva Teresinha Pires', 'Cidade Industrial', '81350-598', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8804, 'Curitiba', 'Dalvino Nunes da Lapa', 'Capão da Imbuia', '82800-350', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8805, 'Almirante Tamandaré', 'Dalzira Sila', 'Pacotuba', '83513-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8806, 'Guarapuava', 'Damasco', 'Morro Alto', '85070-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8807, 'Londrina', 'Damasco', 'Damasco', '86035-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8808, 'Campo Mourão', 'Damasco', 'Conjunto Habitacional Montes Claros', '87310-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8809, 'Curitiba', 'Damasina Bittencourt Macedo', 'Santa Cândida', '82640-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8810, 'Ponta Grossa', 'Damburita', 'Neves', '84021-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8811, 'Londrina', 'Damian Simão Quezada', 'Colinas', '86056-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8812, 'Arapongas', 'Dançador', 'Jardim Bandeirantes', '86703-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8813, 'Arapongas', 'Dançador-de-coroa-vermelha', 'Jardim São Bento', '86706-718', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8814, 'Arapongas', 'Dançador-grande', 'Jardim Petrópolis', '86709-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8815, 'Arapongas', 'Dançador-verde', 'Jardim São Rafael', '86703-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8816, 'Arapongas', 'Dançador-vermelho', 'Jardim São Carlos', '86704-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8817, 'Arapongas', 'Dançarino', 'Conjunto Tropical', '86702-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8818, 'Arapongas', 'Dançarino-azeitona', 'Jardim Nova Baroneza', '86706-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8819, 'Arapongas', 'Dançarino-de-cauda-fina', 'Parque Industrial II', '86703-748', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8820, 'Arapongas', 'Dançarino-de-coroa-azul', 'Conjunto Águias', '86704-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8821, 'Arapongas', 'Dançarino-negro', 'Conjunto Del Condor', '86703-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8822, 'Arapongas', 'Dançarino-rosado', 'Parque Veneza', '86701-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8823, 'Curitiba', 'Daniel Brambila', 'Cidade Industrial', '81310-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8824, 'Londrina', 'Daniel C. Vianna', 'Jamile Dequech', '86048-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8825, 'Curitiba', 'Daniel Cesário Pereira', 'Santa Felicidade', '82410-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8826, 'Colombo', 'Daniel Cheremeta', 'Jardim Aurora', '83411-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8827, 'Guarapuava', 'Daniel Cleve', 'Bonsucesso', '85055-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8828, 'Curitiba', 'Daniel Comboni', 'Fazendinha', '81330-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8829, 'Curitiba', 'Daniel de Camargo', 'Cidade Industrial', '81310-416', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8830, 'Londrina', 'Daniel de Oliveira Campos', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8831, 'Curitiba', 'Daniel Egg', 'Cidade Industrial', '81250-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8832, 'Londrina', 'Daniel Estevão Vieira', 'Jardim Paris', '86082-069', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8833, 'Londrina', 'Daniel Gonçalves', 'Conjunto Habitacional Órion', '86065-546', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8834, 'Colombo', 'Daniel Guimarães', 'Planta Boros', '83413-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8835, 'Araucária', 'Daniel Inckot', 'Cachoeira', '83701-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8836, 'Ponta Grossa', 'Daniel José da Silva', 'Contorno', '84060-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8837, 'Curitiba', 'Daniel Mikovski', 'Fazendinha', '81320-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8838, 'Campo Mourão', 'Daniel Motta Cordeiro', 'Conjunto Habitacional Milton Luiz Pereira', '87306-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8839, 'Toledo', 'Daniel Nardi', 'Vila Industrial', '85904-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8840, 'Pato Branco', 'Daniel Pagnoncelli', 'La Salle', '85505-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8841, 'Curitiba', 'Daniel Petersen', 'Cidade Industrial', '81250-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8842, 'São José dos Pinhais', 'Daniel Precoma', 'Ipê', '83055-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8843, 'Apucarana', 'Daniel Rodrigues', 'Vila Rural Nova Ukrania', '86810-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8844, 'Pinhais', 'Daniel Schulz', 'Moradias Palmital', '83325-604', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8845, 'Araucária', 'Daniel Sobania', 'Fazenda Velha', '83703-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8846, 'Londrina', 'Daniel Vicente da Silva', 'Casone', '86084-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8847, 'Campo Mourão', 'Daniele Slomp Bussarelo', 'Jardim Paulino', '87306-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8848, 'Telêmaco Borba', 'Danielle', 'Alto das Oliveiras', '84266-520', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8849, 'Sarandi', 'Danilo Massuia', 'Jardim Parque', '87114-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8850, 'Francisco Beltrão', 'Danilo Motter', 'Antônio de Paiva Cantelmo', '85603-534', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8851, 'Londrina', 'Danilo Orcelli', 'Paulista', '86075-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8852, 'Cascavel', 'Danilo Paladini', 'Santa Felicidade', '85803-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8853, 'Curitiba', 'Danilo Pedro Schreiner', 'Alto Boqueirão', '81850-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8854, 'Guarapuava', 'Danilo Ribas', 'Boqueirão', '85020-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8855, 'Londrina', 'Danilson José Tumiotto', 'Residencial Abussafe', '86037-768', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8856, 'Piraquara', 'Dante Aligheri', 'Jardim Esmeralda', '83301-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8857, 'Laranjeiras do Sul', 'Dante Alighieri', 'Centro', '85301-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8858, 'Curitiba', 'Dante Alighieri', 'Jardim Botânico', '80210-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8859, 'Curitiba', 'Dante Angelote', 'Bairro Alto', '82820-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8860, 'Curitiba', 'Dante Bertoni', 'Santa Felicidade', '82410-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8861, 'São José dos Pinhais', 'Dante César Alves da Rocha', 'Ouro Fino', '83015-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8862, 'Curitiba', 'Dante Gasparin', 'Novo Mundo', '81050-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8863, 'Maringá', 'Dante Ghiseline', 'Conjunto Habitacional Requião', '87047-487', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8864, 'Ponta Grossa', 'Dante La Valle', 'Cará-cará', '84043-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8865, 'Curitiba', 'Dante Luiz Júnior', 'Capão Raso', '81020-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8866, 'Curitiba', 'Dante Melara', 'Cajuru', '82920-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8867, 'Curitiba', 'Dante Melara', 'Cajuru', '82930-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8868, 'Curitiba', 'Dante Millarch', 'Santa Felicidade', '82015-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8869, 'Curitiba', 'Dante Onofrio', 'Xaxim', '81830-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8870, 'Londrina', 'Dante Zanon', 'Jardim Alto do Cafezal', '86049-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8871, 'Londrina', 'Danúbio', 'Parque Residencial João Piza', '86041-145', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8872, 'Londrina', 'Danyelle Bouças Fernandes', 'Jardim Tropical', '86087-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8873, 'Curitiba', 'Darci Ariarte Mallin', 'São Braz', '82015-805', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8874, 'Curitiba', 'Darci Cordeiro', 'Alto Boqueirão', '81770-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8875, 'Campo Largo', 'Darci Costa', 'Jardim Paraíso Mineral', '83606-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8876, 'Curitiba', 'Darci Luísa Belarmino', 'Umbará', '81930-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8877, 'Curitiba', 'Darci Scotti', 'Tatuquara', '81940-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8878, 'Curitiba', 'Darci Vargas', 'Cidade Industrial', '81250-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8879, 'São José dos Pinhais', 'Darci Variki', 'Guatupê', '83060-219', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8880, 'Londrina', 'Darcirio Egger', 'Shangri-La', '86070-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8881, 'Curitiba', 'Darcize Gobi', 'Pilarzinho', '82100-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8882, 'Curitiba', 'Darcy Ferreira Andrade', 'Uberaba', '81580-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8883, 'Curitiba', 'Darcy Nigro Saways', 'Santa Cândida', '82640-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8884, 'Ponta Grossa', 'Darcy Pelissari', 'Ronda', '84051-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8885, 'Curitiba', 'Darcy Ribeiro', 'Cajuru', '82920-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8886, 'São José dos Pinhais', 'Darcy Setim', 'São Domingos', '83040-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8887, 'Ponta Grossa', 'Darcy Taques de Araújo', 'Neves', '84020-769', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8888, 'Maringá', 'Darcy Vargas', 'Zona 04', '87014-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8889, 'Guarapuava', 'Dario Borges de Lis', 'São Cristóvão', '85063-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8890, 'Foz do Iguaçu', 'Dario Camargo', 'Cohapar III', '85858-540', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8891, 'Castro', 'Dario de Macedo', 'Vila Santa Cruz', '84168-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8892, 'Guarapuava', 'Dario Ferreira Caldas', 'Morro Alto', '85065-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8893, 'Curitiba', 'Dario Lopes dos Santos', 'Rebouças', '80210-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8894, 'São José dos Pinhais', 'Dario Marchesini', 'Guatupê', '83060-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8895, 'Foz do Iguaçu', 'Dario Nogueira dos Santos', 'Centro', '85851-065', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8896, 'Curitiba', 'Dario Nogueira dos Santos', 'Santa Cândida', '82720-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8897, 'Londrina', 'Dario Veloso', 'Baldan', '86060-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8898, 'Ponta Grossa', 'Dario Veloso', 'Uvaranas', '84026-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8899, 'Pinhais', 'Dario Veloso', 'Planta Núcleo Colonial de Pinhais', '83321-310', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8900, 'Ponta Grossa', 'Dario Veloso', 'Uvaranas', '84025-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8901, 'Castro', 'Darlei José Borges da Costa', 'Jardim Social Arapongas', '84174-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8902, 'Curitiba', 'Dartagnan Vargas', 'Santa Felicidade', '82030-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8903, 'Apucarana', 'Dartagnann Correia da Silva Bertoia', 'Núcleo Habitacional João Goulart', '86807-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8904, 'Guarapuava', 'Darvilho G. da Costa', 'Bonsucesso', '85035-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8905, 'Maringá', 'Darville Antônio Huergo', 'Parque das Laranjeiras', '87083-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8906, 'Londrina', 'Darvim Mariano', 'Jardim San Diego', '86073-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8907, 'Colombo', 'Darwin', 'Jardim Campo Alto', '83408-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8908, 'Londrina', 'das Acácias', 'Leonor', '86071-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8909, 'Foz do Iguaçu', 'das Acácias', 'Conjunto B', '85867-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8910, 'Guarapuava', 'das Acácias', 'Trianon', '85012-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8911, 'Pato Branco', 'das Acácias', 'Novo Horizonte', '85507-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8912, 'Pinhais', 'das Acácias', 'Planta Karla', '83328-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8913, 'Maringá', 'das Acácias', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8914, 'São José dos Pinhais', 'das Acácias', 'Costeira', '83015-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8915, 'Paranaguá', 'das Acácias', 'Conjunto Nilson Neves', '83215-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8916, 'Umuarama', 'das Acácias', 'Parque das Jaboticabeiras', '87509-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8917, 'Curitiba', 'das Acácias', 'Mossunguê', '81210-180', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8918, 'Araucária', 'das Acácias', 'Campina da Barra', '83709-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8919, 'Curitiba', 'das Acácias', 'Barreirinha', '82700-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8920, 'Campo Mourão', 'das Acácias', 'Jardim Araucária', '87301-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8921, 'Campo Largo', 'das Acácias', 'Jardim das Acácias', '83603-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8922, 'Londrina', 'das Açucenas', 'Colina Verde', '86050-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8923, 'Cascavel', 'das Açucenas', 'Guarujá', '85804-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8924, 'Pato Branco', 'das Adálias', 'Novo Horizonte', '85507-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8925, 'Cascavel', 'das Agro-indústrias', 'Presidente', '85818-117', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8926, 'Foz do Iguaçu', 'das Águias', 'Portal da Foz', '85859-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8927, 'Maringá', 'das Águias', 'Parque Hortência', '87075-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8928, 'Sarandi', 'das Águias', 'Conjunto Floresta', '87112-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8929, 'Campo Mourão', 'das Águias', 'Conjunto Habitacional Milton Luiz Pereira', '87306-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8930, 'Curitiba', 'das Águias', 'Cidade Industrial', '81450-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8931, 'Maringá', 'das Alamandas', 'Jardim San Remo', '87060-266', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8932, 'Campo Mourão', 'das Alfazemas', 'Jardim Santa Nilce II', '87308-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8933, 'Araucária', 'das Amapolas', 'Campina da Barra', '83709-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8934, 'Telêmaco Borba', 'das Amazonas', 'Área 03', '84271-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8935, 'Paranavaí', 'das Ameixas', 'Vila Alta', '87708-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8936, 'Guarapuava', 'das Ameixeiras', 'São Cristóvão', '85060-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8937, 'Londrina', 'das Ameixeiras', 'Marabá', '86035-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8938, 'Colombo', 'das Ameixeiras', 'Jardim Nossa Senhora das Graças', '83407-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8939, 'Londrina', 'das Américas', 'San Fernando', '86040-410', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8940, 'São José dos Pinhais', 'das Américas', 'Três Marias', '83030-640', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8941, 'Piraquara', 'das Américas', 'Planta York', '83307-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8942, 'Piraquara', 'das Américas', 'Jardim Santa Mônica', '83302-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8943, 'Maringá', 'das Américas', 'Zona 08', '87050-550', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8944, 'Sarandi', 'das Américas', 'Jardim Castelo', '87112-566', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8945, 'Cascavel', 'das Américas', 'Brasília', '85815-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8946, 'Cascavel', 'das Américas', 'Periolo', '85817-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8947, 'Guarapuava', 'das Amoreiras', 'Morro Alto', '85067-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8948, 'Almirante Tamandaré', 'das Amoreiras', 'Jardim Marize', '83507-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8949, 'Colombo', 'das Amoreiras', 'Jardim Nossa Senhora das Graças', '83407-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8950, 'Laranjeiras do Sul', 'das Andorinhas', 'Vila Industrial', '85303-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8951, 'São José dos Pinhais', 'das Andorinhas', 'Afonso Pena', '83045-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8952, 'Pato Branco', 'das Andorinhas', 'Planalto', '85509-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8953, 'Maringá', 'das Andorinhas', 'Jardim Novo Horizonte', '87010-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8954, 'Piraquara', 'das Andorinhas', 'Planta Guarituba Pequena', '83310-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8955, 'Sarandi', 'das Andorinhas', 'Conjunto Floresta', '87112-660', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8956, 'Telêmaco Borba', 'das Andorinhas', 'Jardim São Silvestre', '84270-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8957, 'Campo Largo', 'das Andorinhas', 'Jardim Lise', '83605-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8958, 'Campo Mourão', 'das Andorinhas', 'Jardim Gutierres', '87300-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8959, 'Cascavel', 'das Andorinhas', 'Floresta', '85814-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8960, 'Apucarana', 'das Andorinhas', 'Vila Vera Cruz', '86804-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8961, 'Almirante Tamandaré', 'das Andorinhas', 'Loteamento Montparnasse', '83508-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8962, 'Curitiba', 'das Andorinhas', 'Novo Mundo', '81020-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8963, 'Colombo', 'das Angélicas', 'Parque Monte Castelo', '83411-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8964, 'Telêmaco Borba', 'das Antas', 'Área 02', '84267-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8965, 'Pato Branco', 'das Arapongas', 'Planalto', '85509-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8966, 'Telêmaco Borba', 'das Arapongas', 'Jardim São Silvestre', '84270-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8967, 'Almirante Tamandaré', 'das Arapongas', 'Jardim Marize', '83507-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8968, 'Londrina', 'das Araras', 'Vitória Régia', '86038-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8969, 'Guarapuava', 'das Araras', 'Boqueirão', '85022-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8970, 'Laranjeiras do Sul', 'das Araras', 'Vila Industrial', '85303-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8971, 'Francisco Beltrão', 'das Araras', 'Luther King', '85605-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8972, 'Pato Branco', 'das Araras', 'Planalto', '85509-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8973, 'Paranaguá', 'das Araras', 'Jardim Esperança', '83218-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8974, 'Piraquara', 'das Araras', 'Recreio da Serra', '83305-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8975, 'São José dos Pinhais', 'das Araras', 'Afonso Pena', '83045-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8976, 'Umuarama', 'das Araras', 'Jardim Alphavile', '87504-668', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8977, 'Sarandi', 'das Araras', 'Conjunto Floresta', '87112-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8978, 'Telêmaco Borba', 'das Araras', 'Jardim São Silvestre', '84270-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8979, 'Almirante Tamandaré', 'das Araras', 'Loteamento Montparnasse', '83508-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8980, 'Cascavel', 'das Araras', 'Floresta', '85814-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8981, 'Campo Largo', 'das Araras', 'Vila Gilcy', '83609-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8982, 'Curitiba', 'das Araras', 'Novo Mundo', '81020-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8983, 'Curitiba', 'das Araucárias', 'Tatuquara', '81470-015', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8984, 'Laranjeiras do Sul', 'das Araucárias', 'Cristo Rei', '85304-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8985, 'Pinhais', 'das Araucárias', 'Jardim Pio XII', '83328-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8986, 'Campo Mourão', 'das Araucárias', 'Jardim Araucária', '87301-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8987, 'Araucária', 'das Araucárias', 'Thomaz Coelho', '83707-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8988, 'Pinhais', 'das Aroeiras', 'Loteamento Alphaville Graciosa', '83327-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8989, 'Umuarama', 'das Arvores', 'Jardim Tangará', '87501-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8990, 'Foz do Iguaçu', 'das Assucenas', 'Jardim Eliza II', '85854-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8991, 'Foz do Iguaçu', 'das Assucenas', 'Jardim Eliza I', '85853-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8992, 'Londrina', 'das Avencas', 'Damasco', '86035-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8993, 'Pinhais', 'das Avencas', 'Jardim Pio XII', '83328-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8994, 'Sarandi', 'das Avencas', 'Jardim Verão', '87111-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8995, 'Umuarama', 'das Avencas', 'Parque das Jaboticabeiras', '87509-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8996, 'Cascavel', 'das Avencas', 'Guarujá', '85804-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8997, 'Colombo', 'das Avencas', 'Vila Vale das Flores', '83411-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8998, 'Pato Branco', 'das Avestruzes', 'Planalto', '85509-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (8999, 'Londrina', 'das Azaléias', 'Colina Verde', '86050-560', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9000, 'Foz do Iguaçu', 'das Azaléias', 'Jardim Eliza II', '85855-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9001, 'São José dos Pinhais', 'das Azaléias', 'Costeira', '83015-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9002, 'Pato Branco', 'das Azaléias', 'Novo Horizonte', '85507-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9003, 'Maringá', 'das Azaléias', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9004, 'Umuarama', 'das Azaléias', 'Parque das Laranjeiras', '87507-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9005, 'Campo Mourão', 'das Azaléias', 'Jardim Araucária', '87301-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9006, 'Cascavel', 'das Azaléias', 'Guarujá', '85804-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9007, 'Curitiba', 'das Azaléias', 'Campo Comprido', '81210-170', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9008, 'Londrina', 'das Bananeiras', 'Interlagos', '86035-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9009, 'Colombo', 'das Bananeiras', 'Jardim Nossa Senhora das Graças', '83407-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9010, 'Londrina', 'das Bandeiras', 'Vila Canziani', '86010-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9011, 'Pato Branco', 'das Bandeiras', 'São Cristóvão', '85508-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9012, 'Maringá', 'das Bandeiras', 'Parque das Bandeiras', '87023-525', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9013, 'Campo Largo', 'das Bandeiras', 'Loteamento Yara', '83605-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9014, 'Curitiba', 'das Bateias', 'Guabirotuba', '81520-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9015, 'Londrina', 'das Begônias', 'Ouro Branco', '86042-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9016, 'Foz do Iguaçu', 'das Begônias', 'Jardim Eliza II', '85854-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9017, 'São José dos Pinhais', 'das Begônias', 'Cruzeiro', '83015-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9018, 'Umuarama', 'das Begônias', 'Núcleo Cruzeiro', '87509-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9019, 'Telêmaco Borba', 'das Begônias', 'Jardim Alegre', '84268-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9020, 'Cascavel', 'das Begônias', 'Guarujá', '85804-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9021, 'Pinhais', 'das Bétulas', 'Loteamento Alphaville Graciosa', '83327-126', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9022, 'Foz do Iguaçu', 'das Boninas', 'Jardim Cecília', '85854-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9023, 'São José dos Pinhais', 'das Bracatingas', 'Rio Pequeno', '83085-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9024, 'Paranaguá', 'das Bracatingas', 'Jardim Iguaçu', '83210-009', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9025, 'Umuarama', 'das Bromélias', 'Núcleo Cruzeiro', '87509-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9026, 'Almirante Tamandaré', 'das Bromélias', 'Vila da Glória', '83505-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9027, 'Curitiba', 'das Buganvílias', 'Mossunguê', '81210-190', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9028, 'Paranaguá', 'das Cabreúvas', 'Jardim Iguaçu', '83210-005', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9029, 'Laranjeiras do Sul', 'das Cabriúvas', 'Cristo Rei', '85304-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9030, 'Londrina', 'das Camélias', 'Ouro Branco', '86042-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9031, 'Guarapuava', 'das Camélias', 'Trianon', '85012-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9032, 'Maringá', 'das Camélias', 'Jardim Los Angeles', '87060-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9033, 'Paranaguá', 'das Camélias', 'Conjunto Nilson Neves', '83215-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9034, 'São José dos Pinhais', 'das Camélias', 'Afonso Pena', '83050-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9035, 'Piraquara', 'das Camélias', 'Planta Guarituba Pequena', '83310-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9036, 'Sarandi', 'das Camélias', 'Jardim Verão', '87111-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9037, 'Toledo', 'das Camélias', 'Jardim Social', '85902-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9038, 'Araucária', 'das Camélias', 'Campina da Barra', '83709-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9039, 'Castro', 'das Camélias', 'Jardim Termas Riviera', '84182-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9040, 'Campo Mourão', 'das Camélias', 'Jardim Araucária', '87301-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9041, 'Cascavel', 'das Camélias', 'Guarujá', '85804-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9042, 'Cambé', 'das Camélias', 'Jardim Ana Eliza', '86188-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9043, 'Campo Largo', 'das Camélias', 'Loteamento Miranda', '83605-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9044, 'Almirante Tamandaré', 'das Camélias', 'Loteamento Nova Morada', '83504-696', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9045, 'Colombo', 'das Camélias', 'Parque Monte Castelo', '83411-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9046, 'Curitiba', 'das Camélias', 'Campo Comprido', '81210-160', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9047, 'Foz do Iguaçu', 'das Campânulas', 'Vila Adriana', '85854-570', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9048, 'Laranjeiras do Sul', 'das Canafístulas', 'Cristo Rei', '85304-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9049, 'Laranjeiras do Sul', 'das Canelas', 'Cristo Rei', '85304-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9050, 'Cambé', 'das Capitanias', 'Jardim Vila Rica', '86192-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9051, 'Curitiba', 'das Carmelitas', 'Boqueirão', '81650-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9052, 'Curitiba', 'das Carmelitas', 'Boqueirão', '81730-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9053, 'Curitiba', 'das Carmelitas', 'Hauer', '81610-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9054, 'Maringá', 'das Carnaúbas', 'Parque das Bandeiras', '87023-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9055, 'Pinhais', 'das Carpas', 'Loteamento Alphaville Graciosa', '83327-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9056, 'Londrina', 'das Castanheiras', 'Leonor', '86071-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9057, 'Maringá', 'das Castanheiras', 'Parque Residencial Aeroporto', '87055-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9058, 'São José dos Pinhais', 'das Castanheiras', 'Rio Pequeno', '83085-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9059, 'Araucária', 'das Castanheiras', 'Estação', '83705-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9060, 'Londrina', 'das Casuarinas', 'Colina Verde', '86050-580', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9061, 'Foz do Iguaçu', 'das Cataratas', 'Vila Yolanda', '85853-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9062, 'Pato Branco', 'das Cegonhas', 'Planalto', '85509-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9063, 'Guarapuava', 'das Cerejeiras', 'Morro Alto', '85067-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9064, 'Sarandi', 'das Cerejeiras', 'Jardim Monterey', '87112-786', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9065, 'Araucária', 'das Cerejeiras', 'Estação', '83705-340', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9066, 'Campo Mourão', 'das Cerejeiras', 'Jardim Araucária', '87301-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9067, 'Curitiba', 'das Cerejeiras', 'Barreirinha', '82700-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9068, 'Cascavel', 'das Chácaras', 'Coqueiral', '85807-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9069, 'Umuarama', 'das Clivias', 'Parque das Jaboticabeiras', '87509-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9070, 'Londrina', 'das Codornas', 'Waldemar Hauer', '86030-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9071, 'Maringá', 'das Codornas', 'Conjunto Habitacional Sanenge', '87075-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9072, 'Paranaguá', 'das Codornas', 'Jardim Esperança', '83218-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9073, 'Campo Largo', 'das Codornas', 'Jardim Lise', '83605-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9074, 'Curitiba', 'das Codornas', 'Novo Mundo', '81020-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9075, 'Paranaguá', 'das Colônias', 'Jardim Esperança', '83218-190', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9076, 'Sarandi', 'das Contelações', 'Jardim Universal', '87114-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9077, 'Foz do Iguaçu', 'das Corbélias', 'Jardim Nossa Senhora da Luz', '85853-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9078, 'Cascavel', 'das Cores', 'Brasília', '85815-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9079, 'Londrina', 'das Corruíras', 'Indústrias Leves', '86030-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9080, 'Curitiba', 'das Corruíras', 'Novo Mundo', '81020-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9081, 'Paranaguá', 'das Corticeiras', 'Jardim Iguaçu', '83210-006', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9082, 'Londrina', 'das Costureiras', 'Newton Guimarães', '86082-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9083, 'Curitiba', 'das Cotovias', 'Novo Mundo', '81020-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9084, 'Colombo', 'das Cravelinas', 'Parque Monte Castelo', '83411-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9085, 'Guarapuava', 'das Crianças', 'Santana', '85070-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9086, 'Foz do Iguaçu', 'das Crisálidas', 'Jardim Eliza I', '85853-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9087, 'Guarapuava', 'das Dálias', 'Trianon', '85012-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9088, 'Foz do Iguaçu', 'das Dálias', 'Jardim das Flores', '85855-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9089, 'Maringá', 'das Dálias', 'Jardim Maravilha', '87080-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9090, 'Umuarama', 'das Dálias', 'Parque das Jaboticabeiras', '87509-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9091, 'Sarandi', 'das Dálias', 'Jardim Verão', '87111-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9092, 'Colombo', 'das Dálias', 'Vila Vale das Flores', '83411-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9093, 'Araucária', 'das Dálias', 'Campina da Barra', '83709-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9094, 'Cascavel', 'das Dálias', 'Guarujá', '85804-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9095, 'Guarapuava', 'das Domésticas', 'Núcleo Habitacional 2000', '85064-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9096, 'Campo Mourão', 'das Emas', 'Conjunto Habitacional Milton Luiz Pereira', '87306-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9097, 'Cambé', 'das Embaixadas', 'Jardim Alvorada', '86191-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9098, 'Londrina', 'das Enfermeiras', 'Newton Guimarães', '86082-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9099, 'Londrina', 'das Esmeraldas', 'Waldemar Hauer', '86030-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9100, 'Pinhais', 'das Esmeraldas', 'Chácaras Atuba', '83325-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9101, 'Curitiba', 'das Esmeraldas', 'Abranches', '82130-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9102, 'Sarandi', 'das Estrelas', 'Jardim Universal', '87114-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9103, 'Guarapuava', 'das Figueiras', 'São Cristóvão', '85060-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9104, 'Campo Mourão', 'das Figueiras', 'Jardim Araucária', '87301-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9105, 'Colombo', 'das Figueiras', 'Jardim Nossa Senhora das Graças', '83407-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9106, 'Umuarama', 'das Fitonias', 'Parque das Jaboticabeiras', '87509-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9107, 'Umuarama', 'das Floreiras', 'Jardim Petrópolis', '87506-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9108, 'Guarapuava', 'das Flores', 'Conradinho', '85045-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9109, 'Francisco Beltrão', 'das Flores', 'Nossa Senhora Aparecida', '85601-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9110, 'Londrina', 'das Flores', 'Ouro Branco', '86042-105', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9111, 'São José dos Pinhais', 'das Flores', 'Guatupê', '83060-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9112, 'Pinhais', 'das Flores', 'Planta Karla', '83328-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9113, 'Pinhais', 'das Flores', 'Planta Walde Rosi Galvão', '83328-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9114, 'Paranaguá', 'das Flores', 'Jardim Samambaia', '83212-290', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9115, 'Ponta Grossa', 'das Flores', 'Oficinas', '84035-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9116, 'Ponta Grossa', 'das Flores', 'Uvaranas', '84025-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9117, 'Pato Branco', 'das Flores', 'Alvorada', '85508-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9118, 'Telêmaco Borba', 'das Flores', 'Jardim Alegre', '84268-430', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9119, 'Toledo', 'das Flores', 'Coopagro', '85903-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9120, 'Campo Mourão', 'das Flores', 'Jardim Tropical II', '87310-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9121, 'Cascavel', 'das Flores', 'Guarujá', '85804-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9122, 'Arapongas', 'das Flores', 'Jardim Liberdade', '86706-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9123, 'Campo Mourão', 'das Flores', 'Jardim Cidade Nova', '87308-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9124, 'Araucária', 'das Flores', 'Campina da Barra', '83709-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9125, 'Colombo', 'das Flores', 'Parque Monte Castelo', '83411-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9126, 'Castro', 'das Flores', 'Jardim Termas Riviera', '84182-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9127, 'São José dos Pinhais', 'das Funcionárias', 'Costeira', '83015-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9128, 'Colombo', 'das Funcionárias', 'Vila Vale das Flores', '83411-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9129, 'Guarapuava', 'das Gaivotas', 'São Cristóvão', '85063-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9130, 'Pinhais', 'das Gaivotas', 'Loteamento Alphaville Graciosa', '83327-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9131, 'São José dos Pinhais', 'das Gaivotas', 'Colônia Rio Grande', '83025-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9132, 'Pato Branco', 'das Gaivotas', 'Planalto', '85509-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9133, 'Campo Mourão', 'das Gaivotas', 'Jardim Gutierres', '87300-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9134, 'Cascavel', 'das Gaivotas', 'Floresta', '85814-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9135, 'Campo Largo', 'das Gaivotas', 'Vila Dona Fina', '83609-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9136, 'Curitiba', 'das Gaivotas', 'Novo Mundo', '81020-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9137, 'Sarandi', 'das Galaxias', 'Jardim Universal', '87114-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9138, 'Londrina', 'das Garças', 'Conjunto Habitacional Violim', '86084-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9139, 'Guarapuava', 'das Garças', 'Batel', '85015-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9140, 'Francisco Beltrão', 'das Garças', 'Luther King', '85605-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9141, 'São José dos Pinhais', 'das Garças', 'Afonso Pena', '83045-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9142, 'Pinhais', 'das Garças', 'Loteamento Alphaville Graciosa', '83327-149', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9143, 'Paranaguá', 'das Garças', 'Jardim Esperança', '83218-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9144, 'Pato Branco', 'das Garças', 'Planalto', '85509-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9145, 'Sarandi', 'das Garças', 'Conjunto Floresta', '87112-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9146, 'Campo Mourão', 'das Garças', 'Jardim Gutierres', '87300-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9147, 'Cascavel', 'das Garças', 'Floresta', '85814-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9148, 'Maringá', 'das Gardênias', 'Jardim Los Angeles', '87080-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9149, 'Umuarama', 'das Gardênias', 'Parque das Jaboticabeiras', '87509-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9150, 'Cascavel', 'das Gardênias', 'Guarujá', '85804-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9151, 'Campo Mourão', 'das Gardênias', 'Jardim Santa Nilce II', '87308-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9152, 'Colombo', 'das Gerberas', 'Vila Vale das Flores', '83411-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9153, 'Campo Mourão', 'das Glórias', 'Jardim Lar Paraná', '87305-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9154, 'Cascavel', 'das Gloxíneas', 'Guarujá', '85804-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9155, 'Londrina', 'das Goiabeiras', 'Marabá', '86035-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9156, 'Guarapuava', 'das Goiabeiras', 'Conradinho', '85060-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9157, 'Paranaguá', 'das Goiabeiras', 'Jardim Samambaia', '83212-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9158, 'Curitiba', 'das Goiabeiras', 'Cidade Industrial', '81450-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9159, 'Umuarama', 'das Graças', 'Parque Industrial I', '87507-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9160, 'Londrina', 'das Grevíleas', 'Colina Verde', '86050-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9161, 'Maringá', 'das Grevíleas', 'Parque das Grevíleas', '87025-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9162, 'Sarandi', 'das Grevíleas', 'Jardim Monterey', '87112-809', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9163, 'Campo Mourão', 'das Grevíleas', 'Jardim Lar Paraná', '87305-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9164, 'Curitiba', 'das Grevíleas', 'Barreirinha', '82700-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9165, 'Guarapuava', 'das Guabirobeiras', 'Morro Alto', '85067-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9166, 'Laranjeiras do Sul', 'das Guajuviras', 'Cristo Rei', '85304-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9167, 'Foz do Iguaçu', 'das Guianas', 'Jardim América', '85864-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9168, 'Pinhais', 'das Guianas', 'Vila Varginha', '83320-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9169, 'Umuarama', 'das Gurucaias', 'Zona I', '87501-255', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9170, 'Foz do Iguaçu', 'das Hortências', 'Jardim Oriente', '85855-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9171, 'Guarapuava', 'das Hortências', 'Trianon', '85012-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9172, 'Paranaguá', 'das Hortências', 'Vila dos Comerciários', '83215-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9173, 'Francisco Beltrão', 'das Hortênsias', 'Nossa Senhora Aparecida', '85601-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9174, 'Londrina', 'das Hortênsias', 'Ouro Branco', '86042-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9175, 'Guarapuava', 'das Hortênsias', 'Trianon', '85017-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9176, 'São José dos Pinhais', 'das Hortênsias', 'Guatupê', '83060-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9177, 'Piraquara', 'das Hortênsias', 'Planta Guarituba Pequena', '83310-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9178, 'Pato Branco', 'das Hortênsias', 'Novo Horizonte', '85507-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9179, 'Pinhais', 'das Hortênsias', 'Planta Walde Rosi Galvão', '83328-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9180, 'Maringá', 'das Hortênsias', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9181, 'Umuarama', 'das Hortênsias', 'Parque das Jaboticabeiras', '87509-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9182, 'Sarandi', 'das Hortênsias', 'Jardim Primaverão', '87111-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9183, 'Toledo', 'das Hortênsias', 'Jardim Social', '85902-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9184, 'Cascavel', 'das Hortênsias', 'Recanto Tropical', '85807-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9185, 'Cambé', 'das Hortênsias', 'Jardim Ana Eliza', '86188-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9186, 'Castro', 'das Hortênsias', 'Jardim Termas Riviera', '84182-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9187, 'Colombo', 'das Hortênsias', 'Parque Monte Castelo', '83411-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9188, 'Curitiba', 'das Hortênsias', 'Mossunguê', '81210-070', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9189, 'Maringá', 'das Imbaúbas', 'Parque das Bandeiras', '87023-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9190, 'Pinhais', 'das Imbuias', 'Loteamento Alphaville Graciosa', '83327-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9191, 'São José dos Pinhais', 'das Imbuias', 'Rio Pequeno', '83085-546', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9192, 'Londrina', 'das Indústrias', 'Cidadela', '86072-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9193, 'Maringá', 'das Indústrias', 'Jardim América', '87045-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9194, 'Umuarama', 'das Indústrias', 'Zona VII', '87503-510', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9195, 'Cascavel', 'das Indústrias', 'Presidente', '85818-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9196, 'Curitiba', 'das Indústrias', 'Cidade Industrial', '81170-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9197, 'Curitiba', 'das Indústrias', 'Cidade Industrial', '81310-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9198, 'Londrina', 'das Jaboticabeiras', 'Jardim Morumbi', '86035-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9199, 'Guarapuava', 'das Jabuticabeiras', 'Morro Alto', '85067-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9200, 'Foz do Iguaçu', 'das Laranjas', 'Conjunto B', '85867-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9201, 'Guarapuava', 'das Laranjeiras', 'São Cristóvão', '85060-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9202, 'Laranjeiras do Sul', 'das Laranjeiras', 'Centro', '85301-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9203, 'Pinhais', 'das Laranjeiras', 'Planta Karla', '83328-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9204, 'Maringá', 'das Laranjeiras', 'Jardim Tropical', '87080-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9205, 'Toledo', 'das Laranjeiras', 'Boa Esperança', '85909-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9206, 'São José dos Pinhais', 'das Laranjeiras', 'Rio Pequeno', '83085-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9207, 'Colombo', 'das Laranjeiras', 'Jardim Nossa Senhora das Graças', '83407-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9208, 'Almirante Tamandaré', 'das Laranjeiras', 'Vila Tanguá', '83508-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9209, 'Campo Mourão', 'das Laranjeiras', 'Conjunto Habitacional Mendes', '87306-386', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9210, 'Cambé', 'das Laranjeiras', 'Planta São Francisco', '86182-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9211, 'Apucarana', 'das Lebres', 'Vila das Lebres', '86800-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9212, 'Guarapuava', 'das Limeira', 'São Cristóvão', '85060-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9213, 'Londrina', 'das Limeiras', 'Marabá', '86035-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9214, 'Campo Mourão', 'das Lontras', 'Jardim Pio XII', '87306-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9215, 'Guarapuava', 'das Macieiras', 'São Cristóvão', '85060-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9216, 'Maringá', 'das Macieiras', 'Jardim Bertioga', '87055-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9217, 'Colombo', 'das Macieiras', 'Jardim Nossa Senhora das Graças', '83407-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9218, 'Londrina', 'das Magnólias', 'Ouro Branco', '86042-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9219, 'Pinhais', 'das Magnólias', 'Jardim Pio XII', '83328-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9220, 'Umuarama', 'das Magnólias', 'Parque das Jaboticabeiras', '87509-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9221, 'São José dos Pinhais', 'das Magnólias', 'Costeira', '83015-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9222, 'Campo Mourão', 'das Magnólias', 'Jardim Araucária', '87301-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9223, 'Cambé', 'das Magnólias', 'Jardim Ana Eliza', '86188-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9224, 'Curitiba', 'das Magnólias', 'Campo Comprido', '81210-110', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9225, 'São José dos Pinhais', 'das Malvas', 'Costeira', '83015-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9226, 'Colombo', 'das Malvas', 'Parque Monte Castelo', '83411-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9227, 'Curitiba', 'das Mangueiras', 'Barreirinha', '82700-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9228, 'Londrina', 'das Mangueiras', 'Jardim Morumbi', '86035-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9229, 'Maringá', 'das Mangueiras', 'Jardim Tropical', '87080-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9230, 'Cambé', 'das Mangueiras', 'Planta São Francisco', '86182-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9231, 'Guarapuava', 'das Margaridas', 'São Cristóvão', '85060-600', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9232, 'Foz do Iguaçu', 'das Margaridas', 'Jardim Eliza I', '85853-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9233, 'Paranaguá', 'das Margaridas', 'Conjunto Nilson Neves', '83215-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9234, 'Piraquara', 'das Margaridas', 'Recreio da Serra', '83305-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9235, 'Pato Branco', 'das Margaridas', 'Novo Horizonte', '85507-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9236, 'Londrina', 'das Margaridas', 'Ouro Branco', '86042-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9237, 'Maringá', 'das Margaridas', 'Jardim Maravilha', '87080-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9238, 'Toledo', 'das Margaridas', 'Centro', '85901-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9239, 'Sarandi', 'das Margaridas', 'Jardim Primaverão', '87111-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9240, 'São José dos Pinhais', 'das Margaridas', 'Costeira', '83015-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9241, 'Umuarama', 'das Margaridas', 'Parque das Jaboticabeiras', '87509-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9242, 'Arapongas', 'das Margaridas', 'Jardim Liberdade', '86706-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9243, 'Campo Largo', 'das Margaridas', 'Loteamento Miranda', '83605-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9244, 'Cambé', 'das Margaridas', 'Jardim Ana Eliza', '86188-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9245, 'Campo Mourão', 'das Margaridas', 'Jardim Paulista', '87310-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9246, 'Almirante Tamandaré', 'das Margaridas', 'Loteamento Nova Morada', '83504-700', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9247, 'Colombo', 'das Margaridas', 'Vila Vale das Flores', '83411-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9248, 'Cascavel', 'das Margaridas', 'Guarujá', '85804-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9249, 'Curitiba', 'das Margaridas', 'Campo de Santana', '81490-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9250, 'Londrina', 'das Maritacas', 'Indusville', '86031-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9251, 'Londrina', 'das Maritacas', 'Indústrias Leves', '86030-330', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9252, 'Colombo', 'das Mimoseiras', 'Jardim Nossa Senhora das Graças', '83407-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9253, 'Foz do Iguaçu', 'das Missões', 'Centro', '85851-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9254, 'Foz do Iguaçu', 'das Missões', 'Vila Portes', '85865-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9255, 'Foz do Iguaçu', 'das Missões', 'Jardim Festugato', '85864-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9256, 'Umuarama', 'das Missões', 'Zona IV', '87504-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9257, 'Campo Mourão', 'das Missões', 'Jardim Tropical II', '87310-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9258, 'Londrina', 'das Nações', 'Alto da Boa Vista', '86083-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9259, 'Sarandi', 'das Nações', 'Jardim Dom Bosco', '87111-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9260, 'Araucária', 'das Nações', 'Estação', '83706-630', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9261, 'Cambé', 'das Nações', 'Jardim Alvorada', '86191-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9262, 'Araucária', 'das Nações', 'Estação', '83705-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9263, 'Curitiba', 'das Nações', 'Alto da Rua XV', '80050-140', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9264, 'São José dos Pinhais', 'das Nações Unidas', 'Cidade Jardim', '83035-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9265, 'Colombo', 'das Olarias', 'Jardim Marambaia', '83404-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9266, 'Curitiba', 'das Olarias', 'Santa Cândida', '82630-160', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9267, 'Londrina', 'das Olimpíadas', 'Jardim Higienópolis', '86020-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9268, 'Guarapuava', 'das Oliveiras', 'Industrial', '85053-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9269, 'Londrina', 'das Oliveiras', 'Leonor', '86071-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9270, 'São José dos Pinhais', 'das Oliveiras', 'São Sebastião', '83075-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9271, 'Campo Mourão', 'das Oliveiras', 'Conjunto Habitacional Montes Claros', '87310-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9272, 'Colombo', 'das Oliveiras', 'Parque do Embu', '83414-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9273, 'Almirante Tamandaré', 'das Oliveiras', 'Loteamento Chico Mendes', '83505-766', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9274, 'Curitiba', 'das Oliveiras', 'Barreirinha', '82700-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9275, 'Cascavel', 'das Onze Horas', 'Guarujá', '85804-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9276, 'Umuarama', 'das Onze-horas', 'Parque das Jaboticabeiras', '87509-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9277, 'Foz do Iguaçu', 'das Orcas', 'Parque Ouro Verde', '85855-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9278, 'Londrina', 'das Orquídeas', 'Ouro Branco', '86042-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9279, 'Foz do Iguaçu', 'das Orquídeas', 'Vila Adriana', '85855-146', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9280, 'Guarapuava', 'das Orquídeas', 'Trianon', '85012-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9281, 'Paranaguá', 'das Orquídeas', 'Conjunto Nilson Neves', '83215-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9282, 'Maringá', 'das Orquídeas', 'Jardim Maravilha', '87080-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9283, 'Piraquara', 'das Orquídeas', 'Planta Guarituba Pequena', '83310-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9284, 'Piraquara', 'das Orquídeas', 'Recreio da Serra', '83305-580', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9285, 'Pato Branco', 'das Orquídeas', 'Novo Horizonte', '85507-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9286, 'Sarandi', 'das Orquídeas', 'Jardim Verão', '87111-620', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9287, 'São José dos Pinhais', 'das Orquídeas', 'Guatupê', '83060-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9288, 'Toledo', 'das Orquídeas', 'Jardim Social', '85902-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9289, 'Umuarama', 'das Orquídeas', 'Parque das Laranjeiras', '87507-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9290, 'Colombo', 'das Orquídeas', 'Parque Monte Castelo', '83411-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9291, 'Cambé', 'das Orquídeas', 'Jardim Ana Eliza', '86188-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9292, 'Araucária', 'das Orquídeas', 'Campina da Barra', '83709-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9293, 'Cascavel', 'das Orquídeas', 'Guarujá', '85804-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9294, 'Campo Largo', 'das Orquídeas', 'Loteamento Miranda', '83605-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9295, 'Curitiba', 'das Orquídeas', 'Cidade Industrial', '81450-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9296, 'Londrina', 'das Paineiras', 'Santa Rita 1', '86071-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9297, 'Foz do Iguaçu', 'das Paineiras', 'Jardim do Horto', '85854-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9298, 'Pinhais', 'das Paineiras', 'Loteamento Alphaville Graciosa', '83327-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9299, 'Paranaguá', 'das Paineiras', 'Jardim Iguaçu', '83210-017', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9300, 'Campo Mourão', 'das Paineiras', 'Jardim Araucária', '87301-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9301, 'Curitiba', 'das Paineiras', 'Barreirinha', '82700-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9302, 'Foz do Iguaçu', 'das Palmas', 'Jardim das Flores', '85855-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9303, 'Umuarama', 'das Palmas', 'Parque das Laranjeiras', '87507-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9304, 'São José dos Pinhais', 'das Palmas', 'Afonso Pena', '83050-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9305, 'Sarandi', 'das Palmas', 'Jardim Verão', '87111-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9306, 'Colombo', 'das Palmas', 'Vila Vale das Flores', '83411-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9307, 'Cascavel', 'das Palmas', 'Guarujá', '85804-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9308, 'Almirante Tamandaré', 'das Palmas', 'Loteamento Nova Morada', '83504-679', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9309, 'Araucária', 'das Palmas', 'Campina da Barra', '83709-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9310, 'Guarapuava', 'das Palmeiras', 'Industrial', '85053-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9311, 'Francisco Beltrão', 'das Palmeiras', 'Nossa Senhora Aparecida', '85601-800', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9312, 'Maringá', 'das Palmeiras', 'Parque Palmeiras', '87023-170', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9313, 'Piraquara', 'das Palmeiras', 'Jardim Santa Mônica', '83302-240', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9314, 'Maringá', 'das Palmeiras', 'Jardim Paris', '87083-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9315, 'Pinhais', 'das Palmeiras', 'Jardim Pio XII', '83328-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9316, 'Maringá', 'das Palmeiras', 'Parque Palmeiras', '87023-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9317, 'Paranaguá', 'das Palmeiras', 'Jardim Samambaia', '83212-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9318, 'Sarandi', 'das Palmeiras', 'Jardim Verão', '87111-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9319, 'Umuarama', 'das Palmeiras', 'Jardim Tangará', '87501-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9320, 'Toledo', 'das Palmeiras', 'Jardim La Salle', '85903-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9321, 'Campo Largo', 'das Palmeiras', 'Vila Dom Pedro II', '83608-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9322, 'Colombo', 'das Palmeiras', 'Vila Cordeiro', '83411-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9323, 'Cascavel', 'das Palmeiras', 'Coqueiral', '85807-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9324, 'Araucária', 'das Palmeiras', 'Estação', '83705-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9325, 'Cascavel', 'das Pampulhas', 'Presidente', '85818-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9326, 'Londrina', 'das Papoulas', 'Ouro Branco', '86042-210', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9327, 'Foz do Iguaçu', 'das Papoulas', 'Vila Adriana', '85854-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9328, 'Guarapuava', 'das Papoulas', 'Trianon', '85012-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9329, 'Paranaguá', 'das Papoulas', 'Conjunto Nilson Neves', '83215-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9330, 'Maringá', 'das Papoulas', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9331, 'Toledo', 'das Papoulas', 'Jardim Social', '85902-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9332, 'Campo Mourão', 'das Papoulas', 'Jardim Santa Nilce II', '87308-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9333, 'Araucária', 'das Papoulas', 'Campina da Barra', '83709-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9334, 'Piraquara', 'das Patativas', 'Recreio da Serra', '83305-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9335, 'Telêmaco Borba', 'das Pedras', 'Vila São Francisco de Assis', '84264-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9336, 'Guarapuava', 'das Perdizes', 'Boqueirão', '85022-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9337, 'Pinhais', 'das Perdizes', 'Loteamento Alphaville Graciosa', '83327-147', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9338, 'Paranaguá', 'das Perdizes', 'Jardim Esperança', '83218-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9339, 'Umuarama', 'das Perdizes', 'Jardim Alphavile', '87504-666', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9340, 'Cascavel', 'das Perdizes', 'Floresta', '85814-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9341, 'Campo Mourão', 'das Perdizes', 'Conjunto Habitacional Milton Luiz Pereira', '87306-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9342, 'Campo Largo', 'das Perdizes', 'Vila Gilcy', '83609-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9343, 'Curitiba', 'das Perdizes', 'Novo Mundo', '81020-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9344, 'Guarapuava', 'das Pereiras', 'São Cristóvão', '85060-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9345, 'Ponta Grossa', 'das Pereiras', 'Chapada', '84064-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9346, 'Laranjeiras do Sul', 'das Perobas', 'Cristo Rei', '85304-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9347, 'Almirante Tamandaré', 'das Perobas', 'Loteamento Chico Mendes', '83505-758', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9348, 'Colombo', 'das Perobeiras', 'Vila Cordeiro', '83411-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9349, 'Cascavel', 'das Perpétuas', 'Guarujá', '85804-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9350, 'Guarapuava', 'das Petúnias', 'Trianon', '85012-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9351, 'Londrina', 'das Petúnias', 'Ouro Branco', '86042-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9352, 'Paranaguá', 'das Petúnias', 'Conjunto Nilson Neves', '83215-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9353, 'Piraquara', 'das Petúnias', 'Recreio da Serra', '83305-660', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9354, 'Umuarama', 'das Petúnias', 'Parque das Jaboticabeiras', '87509-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9355, 'Cascavel', 'das Petúnias', 'Guarujá', '85804-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9356, 'Campo Mourão', 'das Petúnias', 'Jardim Santa Nilce II', '87308-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9357, 'Guarapuava', 'das Pitangueiras', 'Morro Alto', '85067-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9358, 'Foz do Iguaçu', 'das Pitangueiras', 'Loteamento Bourbon', '85854-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9359, 'Foz do Iguaçu', 'das Pitangueiras', 'Jardim Guaíra', '85855-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9360, 'Paranaguá', 'das Pitangueiras', 'Jardim Samambaia', '83212-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9361, 'São José dos Pinhais', 'das Pitangueiras', 'Rio Pequeno', '83085-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9362, 'Almirante Tamandaré', 'das Pitangueiras', 'Jardim Ipanema', '83507-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9363, 'Colombo', 'das Pitangueiras', 'Jardim Nossa Senhora das Graças', '83407-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9364, 'Londrina', 'das Pombas', 'Conjunto Habitacional Violim', '86088-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9365, 'Maringá', 'das Pombas', 'Jardim Pássaros', '87075-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9366, 'São José dos Pinhais', 'das Pombas', 'Afonso Pena', '83045-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9367, 'Apucarana', 'das Pombas', 'Núcleo Habitacional Michel Soni', '86813-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9368, 'Arapongas', 'das Pombas', 'Centro', '86701-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9369, 'Cascavel', 'das Pombas', 'Floresta', '85814-800', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9370, 'Campo Mourão', 'das Pombas', 'Jardim Gutierres', '87300-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9371, 'Colombo', 'das Pombas', 'Planta Santa Tereza', '83401-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9372, 'Paranaguá', 'das Praias', 'Jardim Esperança', '83218-180', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9373, 'Maringá', 'das Primaveras', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9374, 'Umuarama', 'das Primaveras', 'Parque das Laranjeiras', '87507-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9375, 'São José dos Pinhais', 'das Prímulas', 'Costeira', '83015-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9376, 'Umuarama', 'das Prímulas', 'Parque das Jaboticabeiras', '87509-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9377, 'Sarandi', 'das Profecias', 'Parque Residencial Bom Pastor', '87114-533', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9378, 'Guarapuava', 'das Profissões', 'Núcleo Habitacional 2000', '85064-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9379, 'Almirante Tamandaré', 'das Quaresmeiras', 'Loteamento Chico Mendes', '83505-748', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9380, 'Curitiba', 'das Rolas', 'Novo Mundo', '81020-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9381, 'Guarapuava', 'das Rosas', 'Trianon', '85012-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9382, 'Foz do Iguaçu', 'das Rosas', 'Jardim das Flores', '85855-147', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9383, 'Maringá', 'das Rosas', 'Jardim Maravilha', '87080-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9384, 'Pinhais', 'das Rosas', 'Planta Karla', '83328-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9385, 'Pato Branco', 'das Rosas', 'Novo Horizonte', '85507-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9386, 'Piraquara', 'das Rosas', 'Planta Guarituba Pequena', '83310-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9387, 'Paranaguá', 'das Rosas', 'Conjunto Nilson Neves', '83215-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9388, 'Toledo', 'das Rosas', 'Jardim Social', '85902-466', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9389, 'Telêmaco Borba', 'das Rosas', 'Jardim Alegre', '84268-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9390, 'São José dos Pinhais', 'das Rosas', 'Afonso Pena', '83050-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9391, 'Sarandi', 'das Rosas', 'Jardim Rosas', '87111-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9392, 'Almirante Tamandaré', 'das Rosas', 'Vila da Glória', '83505-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9393, 'Campo Mourão', 'das Rosas', 'Jardim Araucária', '87301-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9394, 'Campo Largo', 'das Rosas', 'Loteamento Miranda', '83605-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9395, 'Arapongas', 'das Rosas', 'Jardim Liberdade', '86706-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9396, 'Araucária', 'das Rosas', 'Campina da Barra', '83709-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9397, 'Colombo', 'das Rosas', 'Vila Vale das Flores', '83411-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9398, 'Cascavel', 'das Rosas', 'Guarujá', '85804-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9399, 'Cambé', 'das Rosas', 'Jardim Ana Eliza', '86188-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9400, 'Castro', 'das Rosas', 'Jardim Termas Riviera', '84182-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9401, 'Curitiba', 'das Rosas', 'Mossunguê', '81210-080', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9402, 'Piraquara', 'das Roseiras', 'Chácara Águas Claras', '83308-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9403, 'Ponta Grossa', 'das Roseiras', 'Contorno', '84060-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9404, 'Curitiba', 'das Roseiras', 'Cidade Industrial', '81450-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9405, 'Curitiba', 'das Sabiás', 'Novo Mundo', '81020-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9406, 'Guarapuava', 'das Salvias', 'Boqueirão', '85023-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9407, 'Campo Mourão', 'das Salvias', 'Jardim Santa Nilce II', '87308-187', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9408, 'Foz do Iguaçu', 'das Samambaias', 'Loteamento Bourbon', '85854-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9409, 'Maringá', 'das Samambaias', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9410, 'Pinhais', 'das Samambaias', 'Jardim Pio XII', '83328-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9411, 'Piraquara', 'das Samambaias', 'Recreio da Serra', '83305-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9412, 'Sarandi', 'das Samambaias', 'Jardim Verão', '87111-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9413, 'Umuarama', 'das Samambaias', 'Parque das Jaboticabeiras', '87509-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9414, 'Telêmaco Borba', 'das Samambaias', 'Jardim Alegre', '84268-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9415, 'Campo Mourão', 'das Samambaias', 'Jardim Araucária', '87301-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9416, 'Colombo', 'das Samambaias', 'Jardim das Violetas', '83411-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9417, 'São José dos Pinhais', 'das Sapopemas', 'Rio Pequeno', '83085-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9418, 'Guarapuava', 'das Secretárias', 'Núcleo Habitacional 2000', '85064-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9419, 'Almirante Tamandaré', 'das Senzalas', 'Jardim Apucarana', '83505-165', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9420, 'Pato Branco', 'das Sereias', 'Planalto', '85509-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9421, 'Guarapuava', 'das Seringueiras', 'Industrial', '85053-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9422, 'Maringá', 'das Seringueiras', 'Parque das Bandeiras', '87023-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9423, 'Pinhais', 'das Seringueiras', 'Jardim Pio XII', '83328-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9424, 'São José dos Pinhais', 'das Seringueiras', 'Rio Pequeno', '83085-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9425, 'Colombo', 'das Seringueiras', 'Vila Vale das Flores', '83411-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9426, 'Campo Mourão', 'das Seringueiras', 'Jardim Araucária', '87301-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9427, 'Curitiba', 'das Seringueiras', 'Bairro Alto', '82840-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9428, 'Foz do Iguaçu', 'das Sibipirunas', 'Loteamento Bourbon', '85854-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9429, 'Maringá', 'das Sibipirunas', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9430, 'Campo Mourão', 'das Sibipirunas', 'Jardim Araucária', '87301-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9431, 'Londrina', 'das Siriemas', 'Vitória Régia', '86038-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9432, 'Pato Branco', 'das Siriemas', 'Planalto', '85509-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9433, 'Londrina', 'das Tamareiras', 'Jardim Morumbi', '86035-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9434, 'Curitiba', 'das Tangerinas', 'Uberaba', '81590-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9435, 'Piraquara', 'das Tilápias', 'Recreio da Serra', '83305-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9436, 'Pinhais', 'das Tilápias', 'Loteamento Alphaville Graciosa', '83327-096', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9437, 'Campo Mourão', 'das Tilápias', 'Jardim Lar Paraná', '87305-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9438, 'Maringá', 'das Tipuanas', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9439, 'Campo Mourão', 'das Tipuanas', 'Jardim Araucária', '87301-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9440, 'Pato Branco', 'das Torres', 'Bortot', '85504-710', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9441, 'Maringá', 'das Torres', 'Parque das Laranjeiras', '87080-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9442, 'Maringá', 'das Torres', 'Jardim Olímpico', '87083-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9443, 'Maringá', 'das Torres', 'Parque Industrial 200', '87035-560', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9444, 'Maringá', 'das Torres', 'Jardim Ipanema', '87053-340', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9445, 'São José dos Pinhais', 'das Torres', 'São Cristóvão', '83040-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9446, 'São José dos Pinhais', 'das Torres', 'São Pedro', '83005-450', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9447, 'Sarandi', 'das Torres', 'Jardim Monterey', '87112-816', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9448, 'Cascavel', 'das Torres', 'Santa Cruz', '85806-095', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9449, 'Cascavel', 'das Torres', '14 de Novembro', '85804-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9450, 'Cascavel', 'das Torres', 'Floresta', '85814-620', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9451, 'Cascavel', 'das Torres', 'Parque Verde', '85807-679', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9452, 'Almirante Tamandaré', 'das Torres', 'Jardim Formosa', '83511-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9453, 'Colombo', 'das Torres', 'Jardim Uirapuru', '83406-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9454, 'Campo Largo', 'das Torres', 'Jardim Social', '83606-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9455, 'Curitiba', 'das Tropas', 'Guabirotuba', '81520-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9456, 'Londrina', 'das Tulipas', 'Ouro Branco', '86042-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9457, 'Guarapuava', 'das Tulipas', 'Trianon', '85012-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9458, 'Foz do Iguaçu', 'das Tulipas', 'Jardim Eliza II', '85855-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9459, 'Piraquara', 'das Tulipas', 'Planta Guarituba Pequena', '83310-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9460, 'Paranaguá', 'das Tulipas', 'Conjunto Nilson Neves', '83215-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9461, 'Sarandi', 'das Tulipas', 'Jardim Verão', '87111-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9462, 'Castro', 'das Tulipas', 'Jardim Termas Riviera', '84182-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9463, 'Cambé', 'das Tulipas', 'Jardim Ana Eliza', '86188-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9464, 'Cascavel', 'das Tulipas', 'Guarujá', '85804-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9465, 'Almirante Tamandaré', 'das Tulipas', 'Loteamento Nova Morada', '83504-705', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9466, 'Campo Mourão', 'das Tulipas', 'Jardim Santa Nilce II', '87308-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9467, 'Araucária', 'das Tulipas', 'Campina da Barra', '83709-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9468, 'Almirante Tamandaré', 'das Tulipas', 'Loteamento Nova Morada', '83504-677', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9469, 'Guarapuava', 'das Videiras', 'São Cristóvão', '85060-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9470, 'Guarapuava', 'das Violetas', 'Trianon', '85012-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9471, 'Londrina', 'das Violetas', 'Ouro Branco', '86042-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9472, 'Foz do Iguaçu', 'das Violetas', 'Jardim Eliza I', '85853-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9473, 'Pato Branco', 'das Violetas', 'Novo Horizonte', '85507-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9474, 'Maringá', 'das Violetas', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9475, 'Umuarama', 'das Violetas', 'Parque das Laranjeiras', '87507-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9476, 'Toledo', 'das Violetas', 'Jardim Social', '85902-467', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9477, 'Sarandi', 'das Violetas', 'Jardim Verão', '87111-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9478, 'São José dos Pinhais', 'das Violetas', 'Costeira', '83015-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9479, 'Cascavel', 'das Violetas', 'Guarujá', '85804-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9480, 'Campo Largo', 'das Violetas', 'Loteamento Miranda', '83605-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9481, 'Colombo', 'das Violetas', 'Parque Monte Castelo', '83411-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9482, 'Campo Mourão', 'das Violetas', 'Jardim Santa Nilce II', '87308-186', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9483, 'Cambé', 'das Violetas', 'Jardim Ana Eliza', '86188-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9484, 'Araucária', 'das Violetas', 'Campina da Barra', '83709-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9485, 'Castro', 'das Violetas', 'Jardim Termas Riviera', '84182-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9486, 'Almirante Tamandaré', 'das Violetas', 'Loteamento Nova Morada', '83504-695', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9487, 'Londrina', 'das Zeladoras', 'Newton Guimarães', '86082-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9488, 'Londrina', 'Davenir Marques Viana', 'Jamile Dequech', '86048-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9489, 'Paranavaí', 'Davi Alves', 'Jardim Ipê', '87707-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9490, 'Apucarana', 'Davi Pretti', 'Parque Bela Vista', '86803-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9491, 'Paranavaí', 'Davi Roque', 'Jardim São Jorge', '87711-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9492, 'Curitiba', 'Davi Xavier da Silva', 'Cidade Industrial', '81305-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9493, 'Curitiba', 'David Abbud', 'Santa Felicidade', '82410-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9494, 'Curitiba', 'David Abrão', 'Bigorrilho', '80710-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9495, 'Guarapuava', 'David Alves de Góes', 'Boqueirão', '85023-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9496, 'Toledo', 'David Arcari', 'Jardim Bressan', '85913-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9497, 'Curitiba', 'David Biz', 'Ahú', '80540-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9498, 'Curitiba', 'David Bodziak', 'Cachoeira', '82710-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9499, 'Foz do Iguaçu', 'David Bordim', 'Jardim Boa Vista', '85864-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9500, 'Francisco Beltrão', 'David Cadore', 'Antônio de Paiva Cantelmo', '85603-570', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9501, 'São José dos Pinhais', 'David Campista', 'Afonso Pena', '83045-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9502, 'Curitiba', 'David Carneiro', 'São Francisco', '80530-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9503, 'Foz do Iguaçu', 'David Cordeiro', 'Jardim Panorama', '85856-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9504, 'Campo Mourão', 'David Curi', 'Centro', '87302-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9505, 'Ponta Grossa', 'David de Oliveira Gomes', 'Boa Vista', '84072-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9506, 'Curitiba', 'David de Souza Camargo', 'Prado Velho', '80220-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9507, 'Francisco Beltrão', 'David Donadel', 'Antônio de Paiva Cantelmo', '85603-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9508, 'Curitiba', 'David Escuissato', 'Fazendinha', '81330-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9509, 'Maringá', 'David Faustino de Souza', 'Parque Tarumã', '87053-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9510, 'Curitiba', 'David Geronasso', 'Boa Vista', '82540-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9511, 'Curitiba', 'David Geronasso', 'Boa Vista', '82560-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9512, 'Ponta Grossa', 'David Hilgemberg Júnior', 'Boa Vista', '84072-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9513, 'Ponta Grossa', 'David Hilgemberg Sobrinho', 'Nova Rússia', '84053-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9514, 'São José dos Pinhais', 'David Hume', 'Aristocrata', '83030-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9515, 'Curitiba', 'David Hume', 'Pilarzinho', '82110-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9516, 'Londrina', 'David Livingstone', 'Tomy', '86036-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9517, 'Curitiba', 'David Martins Lass', 'Cascatinha', '82020-786', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9518, 'Cascavel', 'David Mascarello', 'Presidente', '85818-157', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9519, 'Foz do Iguaçu', 'David Muffato', 'Jardim Comercial das Bandeiras', '85864-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9520, 'São José dos Pinhais', 'David Nascimento', 'Costeira', '83015-686', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9521, 'Londrina', 'David Nasser', 'Conjunto Vivi Xavier', '86082-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9522, 'Londrina', 'David Pavan', 'São Lourenço', '86043-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9523, 'Sarandi', 'David Pavão', 'Jardim Verão', '87111-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9524, 'Ponta Grossa', 'David Pelissari', 'Uvaranas', '84030-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9525, 'São José dos Pinhais', 'David Pinto da Rocha', 'Afonso Pena', '83065-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9526, 'Colombo', 'David Raussis', 'Vila Rosemari Galvão', '83411-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9527, 'Londrina', 'David Santos Filho', 'Jardim Neman Sahyun', '86041-287', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9528, 'Curitiba', 'David Silveira da Motta', 'Bigorrilho', '80730-050', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9529, 'Curitiba', 'David Tows', 'Xaxim', '81830-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9530, 'Curitiba', 'David Tows', 'Sítio Cercado', '81920-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9531, 'Curitiba', 'David Tows', 'Sítio Cercado', '81910-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9532, 'Cambé', 'David Trevizan', 'Jardim Itália', '86192-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9533, 'Araucária', 'David Wzorek', 'Thomaz Coelho', '83707-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9534, 'Sarandi', 'Daytona', 'Jardim Califórnia', '87112-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9535, 'Curitiba', 'de Himeji', 'Mercês', '80510-370', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9536, 'Curitiba', 'de Itu', 'Guabirotuba', '81520-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9537, 'Apucarana', 'de Josué Pires da Silva', 'Jardim Eldorado', '86802-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9538, 'Cascavel', 'de Napoli', 'Brasília', '85815-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9539, 'Londrina', 'de Pinedo', 'Novo Aeroporto', '86039-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9540, 'Curitiba', 'de Rondônia', 'Guabirotuba', '81510-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9541, 'Curitiba', 'Dea Taques de Mesquita', 'Sítio Cercado', '81920-735', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9542, 'Londrina', 'Débora', 'Nossa Senhora de Lourdes', '86039-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9543, 'Londrina', 'Débora Eloá Muniz Silva', 'Conjunto Residencial Vale do Arvoredo', '86047-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9544, 'Ponta Grossa', 'Debret', 'Orfãs', '84070-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9545, 'Almirante Tamandaré', 'Debret', 'Jardim Campos Elísios', '83508-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9546, 'Toledo', 'Décia Terezinha do Prado', 'Parque Residencial Gisela', '85905-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9547, 'Curitiba', 'Décio Barreto', 'Cidade Industrial', '81305-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9548, 'Maringá', 'Décio Burali', 'Parque Tarumã', '87053-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9549, 'Foz do Iguaçu', 'Décio Pignatari', 'Vila Borges', '85858-325', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9550, 'Ponta Grossa', 'Décio Vergani', 'Uvaranas', '84030-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9551, 'Foz do Iguaçu', 'Décio Vilares', 'Jardim Vasco da Gama', '85862-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9552, 'Apucarana', 'Dédalos', 'Vila Nova', '86812-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9553, 'Foz do Iguaçu', 'Dedé Nunes', 'Parque Morumbi IV', '85858-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9554, 'Curitiba', 'Dedier Deslandes de Souza', 'Tatuquara', '81470-226', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9555, 'Cambé', 'Defendente Mazzei', 'Recanto Santa Andréa', '86189-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9556, 'Colombo', 'Degas', 'Jardim Adriana', '83408-479', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9557, 'Londrina', 'Dei Loyola Soares', 'Jardim Bom Pastor', '86082-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9558, 'São José dos Pinhais', 'Dejanira Bastos Tozo', 'Ipê', '83055-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9559, 'São José dos Pinhais', 'Del Rey', 'Miringuava', '83090-170', 'Conjunto', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9560, 'Curitiba', 'Delaide Benato Bieda', 'Cidade Industrial', '81460-308', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9561, 'Londrina', 'Delaine Negro', 'Alto da Colina', '86055-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9562, 'Campo Mourão', 'Delcides Constantino Miguel', 'Conjunto Habitacional Milton Luiz Pereira', '87306-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9563, 'Curitiba', 'Delegada Ieda Cristina Ribeiro', 'Tatuquara', '81470-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9564, 'Laranjeiras do Sul', 'Delegado Atílio Joris Fistarol', 'São Francisco', '85303-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9565, 'Curitiba', 'Delegado Bruno de Almeida', 'Campo de Santana', '81490-000', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9566, 'Curitiba', 'Delegado Bruno de Almeida', 'Campo de Santana', '81480-000', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9567, 'Curitiba', 'Delegado Edward Resende Pimenta', 'Santo Inácio', '82010-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9568, 'Curitiba', 'Delegado Leopoldo Belczak', 'Capão da Imbuia', '82810-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9569, 'Curitiba', 'Delegado Leopoldo Belczak', 'Capão da Imbuia', '82800-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9570, 'Curitiba', 'Delegado Leopoldo Belczak', 'Cristo Rei', '80050-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9571, 'Sarandi', 'Delegado Luiz Amaro', 'Jardim Dom Bosco', '87111-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9572, 'Londrina', 'Delegado Matias Sampaio', 'São Lourenço', '86043-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9573, 'Curitiba', 'Delegado Miguel Zacarias', 'Boa Vista', '82650-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9574, 'Curitiba', 'Delegado Naby Paraná', 'Capão Raso', '81110-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9575, 'Curitiba', 'Delegado Ozias Algauer', 'Ganchinho', '81935-397', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9576, 'Curitiba', 'Delegado Ruy Rebello Vieira', 'Sítio Cercado', '81920-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9577, 'Almirante Tamandaré', 'Delegado Theolindo Batista de Siqueira', 'Jardim Paraíso', '83512-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9578, 'Curitiba', 'Delegado Trindade', 'Santa Quitéria', '80310-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9579, 'Guarapuava', 'Delfim Moreira', 'Boqueirão', '85020-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9580, 'Foz do Iguaçu', 'Delfim Moreira', 'Parque Presidente', '85863-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9581, 'Londrina', 'Delfim Moreira', 'Hedy', '86062-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9582, 'Pinhais', 'Delfim Moreira', 'Vila Amélia', '83330-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9583, 'Telêmaco Borba', 'Delfim Moreira', 'Alto das Oliveiras', '84265-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9584, 'Cascavel', 'Delfim Moreira', 'Presidente', '85818-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9585, 'Londrina', 'Delfina Barroni', 'João Paz', '86087-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9586, 'Curitiba', 'Delfina Braga Visinoni', 'Orleans', '81200-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9587, 'Ponta Grossa', 'Delfino de Carvalho', 'Ronda', '84051-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9588, 'Cascavel', 'Delfino Dias do Prado', 'Maria Luiza', '85819-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9589, 'Guarapuava', 'Delfino Xavier de Paula', 'Boqueirão', '85020-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9590, 'Paranaguá', 'Delhi', 'Parque Agari', '83215-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9591, 'Curitiba', 'Delmar Carvalho', 'Novo Mundo', '81050-616', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9592, 'Curitiba', 'Delmiro Fetter dos Santos', 'Cajuru', '82950-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9593, 'Curitiba', 'Delourdes Loiola de Paula', 'Uberaba', '81590-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9594, 'Curitiba', 'Delphim Moreira', 'Seminário', '80240-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9595, 'Foz do Iguaçu', 'Delso Victor E. Bortolini', 'Jardim Porto Belo', '85867-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9596, 'Ponta Grossa', 'Delta', 'Oficinas', '84035-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9597, 'Londrina', 'Delvina Borges Gonçalves', 'Conjunto Café', '86038-075', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9598, 'Araucária', 'Dely de Brito Soares', 'Costeira', '83708-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9599, 'Pinhais', 'Delza Souza Borges', 'Jardim Triângulo', '83331-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9600, 'Curitiba', 'Demerval da Costa e Silva', 'Augusta', '81260-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9601, 'Curitiba', 'Demétrio da Costa', 'Santa Cândida', '82630-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9602, 'São José dos Pinhais', 'Demétrio Elias Djazi', 'Afonso Pena', '83045-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9603, 'Maringá', 'Demétrio Koteski', 'Jardim Alamar', '87014-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9604, 'Curitiba', 'Demétrio Kotovei', 'Umbará', '81930-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9605, 'Curitiba', 'Demétrio Lezan', 'Uberaba', '81570-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9606, 'Maringá', 'Demétrio Ribeiro', 'Zona 07', '87030-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9607, 'Ponta Grossa', 'Demétrio Ribeiro', 'Uvaranas', '84030-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9608, 'Curitiba', 'Demétrio Romaniuk', 'Fazendinha', '81070-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9609, 'Apucarana', 'Demétrio Santos Moreira', 'Vila São José', '86800-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9610, 'Apucarana', 'Demétrio Truch', 'Núcleo Habitacional José Mercadante', '86804-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9611, 'Laranjeiras do Sul', 'Democracia', 'São Francisco', '85303-105', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9612, 'Pato Branco', 'Democracia', 'Cristo Rei', '85506-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9613, 'Londrina', 'Demóstenes', 'Guaporé', '86025-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9614, 'Curitiba', 'Denezar Andrade de Jesus', 'Boqueirão', '81750-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9615, 'Apucarana', 'Denhei Kanashiro', 'Jardim Aeroporto', '86812-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9616, 'Curitiba', 'Denilson Felipe de Lima', 'Cidade Industrial', '81305-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9617, 'Londrina', 'Denilton dos Santos', 'Conjunto Habitacional Bronzzetti', '86037-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9618, 'São José dos Pinhais', 'Denis Diderot', 'Aristocrata', '83030-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9619, 'Londrina', 'Denis Papin', 'Industrial', '86063-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9620, 'Curitiba', 'Denise Maria Carneiro de Oliveira', 'Sítio Cercado', '81925-186', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9621, 'Curitiba', 'Denise Maria Scremin', 'Cajuru', '82920-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9622, 'Curitiba', 'Denizart Pacheco de Carvalho', 'Fanny', '81030-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9623, 'Curitiba', 'Deocleciano de Paula Xavier', 'Pilarzinho', '82120-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9624, 'Foz do Iguaçu', 'Deoclécio Barbosa Portinho', 'Vila Boa Esperança', '85854-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9625, 'Londrina', 'Deoclécio José da Rosa', 'Jardim Tropical', '86087-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9626, 'Colombo', 'Deoclécio Valente', 'Vila São Gabriel', '83406-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9627, 'Curitiba', 'Deoclides Pinto Cordeiro', 'Umbará', '81930-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9628, 'Curitiba', 'Deodato Ribas Sabóia', 'Cidade Industrial', '81315-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9629, 'Piraquara', 'Deodoro', 'Planta Santo Antônio', '83301-505', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9630, 'Campo Mourão', 'Deodoro', 'Jardim Flórida', '87300-095', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9631, 'Ponta Grossa', 'Deodoro Alves Quintilhano', 'Contorno', '84052-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9632, 'Laranjeiras do Sul', 'Deolinda Oliveira Luz', 'Getúlio Vargas', '85304-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9633, 'Campo Mourão', 'Deolindo Gussão', 'Jardim Izabel', '87309-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9634, 'Londrina', 'Deolindo Luppi', 'Residencial Portal do Sol', '86082-786', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9635, 'Apucarana', 'Deolindo Massambani', 'Parque Bela Vista', '86803-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9636, 'Londrina', 'Deolindo Pesciotti', 'Residencial Vila Romana', '86031-806', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9637, 'Curitiba', 'Deolino Bertolini', 'Cidade Industrial', '81460-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9638, 'Cascavel', 'Deonildo Caranhato', 'Santa Cruz', '85806-086', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9639, 'Londrina', 'Deonísio Negri', 'Marabá', '86035-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9640, 'São José dos Pinhais', 'Deputada Ivete Vargas', 'Guatupê', '83060-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9641, 'Curitiba', 'Deputado Acyr José', 'Cajuru', '82970-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9642, 'Londrina', 'Deputado Agnaldo Pereira Lima', 'Monte Belo', '86041-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9643, 'Curitiba', 'Deputado Agostinho Rodrigues', 'Taboão', '82130-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9644, 'São José dos Pinhais', 'Deputado Aníbal Khuri', 'Afonso Pena', '83050-696', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9645, 'Curitiba', 'Deputado Antônio Baby', 'Batel', '80240-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9646, 'Curitiba', 'Deputado Antônio Lopes Júnior', 'Bacacheri', '82520-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9647, 'São José dos Pinhais', 'Deputado Antônio Sylvio Cunha Bueno', 'Guatupê', '83060-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9648, 'Londrina', 'Deputado Ardinal Ribas', 'Jardim São Francisco de Assis', '86067-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9649, 'Maringá', 'Deputado Ardinal Ribas', 'Zona 07', '87030-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9650, 'Curitiba', 'Deputado Ardinal Ribas', 'Capão Raso', '81130-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9651, 'Ponta Grossa', 'Deputado Ari Kiffuri', 'Colônia Dona Luiza', '84046-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9652, 'Londrina', 'Deputado Arnaldo Busato', 'Portal de Versalhes 3', '86055-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9653, 'São José dos Pinhais', 'Deputado Arnaldo Faivro Busato', 'Afonso Pena', '83045-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9654, 'Ponta Grossa', 'Deputado Ary Kffury', 'Colônia Dona Luiza', '84046-080', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9655, 'Curitiba', 'Deputado Atílio de Almeida Barbosa', 'Boa Vista', '82560-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9656, 'Curitiba', 'Deputado Benedito Lúcio Machado', 'Xaxim', '81810-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9657, 'Sarandi', 'Deputado Borsari Neto', 'Jardim Independência I', '87113-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9658, 'Curitiba', 'Deputado Carlos Renê Egg', 'Santa Felicidade', '82410-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9659, 'Curitiba', 'Deputado Carneiro de Campos', 'Hugo Lange', '80040-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9660, 'Curitiba', 'Deputado Chafic Curi', 'Vista Alegre', '80810-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9661, 'Colombo', 'Deputado Cunha Bueno', 'Jardim Califórnia', '83403-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9662, 'Curitiba', 'Deputado Cunha Bueno', 'Cidade Industrial', '81450-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9663, 'Curitiba', 'Deputado Divonsir Borba Cortes', 'Tatuquara', '81480-227', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9664, 'Curitiba', 'Deputado Domício Scaramella', 'Sítio Cercado', '81925-597', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9665, 'Curitiba', 'Deputado Edgar Távora', 'Barreirinha', '82700-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9666, 'Ponta Grossa', 'Deputado Edmar Luiz Costa', 'Uvaranas', '84030-545', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9667, 'Ponta Grossa', 'Deputado Edmar Luiz Costa', 'Uvaranas', '84030-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9668, 'Curitiba', 'Deputado Edmar Luiz Costa', 'Cidade Industrial', '81230-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9669, 'Curitiba', 'Deputado Emílio Carlos', 'Ahú', '80540-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9670, 'São José dos Pinhais', 'Deputado Ernesto Moro Redeschi', 'Braga', '83020-227', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9671, 'Curitiba', 'Deputado Estéfano Mikilita', 'Portão', '81070-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9672, 'Londrina', 'Deputado Fernando Ferrari', 'Campo Belo', '86062-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9673, 'Curitiba', 'Deputado Fernando Ferrari', 'São Lourenço', '82200-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9674, 'Curitiba', 'Deputado Gabriel Sampaio', 'Cidade Industrial', '81270-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9675, 'São José dos Pinhais', 'Deputado Heitor Alencar Furtado', 'Cidade Jardim', '83035-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9676, 'Colombo', 'Deputado Heitor Alencar Furtado', 'Jardim das Flores', '83402-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9677, 'Curitiba', 'Deputado Heitor Alencar Furtado', 'Cidade Industrial', '81280-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9678, 'Curitiba', 'Deputado Heitor Alencar Furtado', 'Campina do Siqueira', '80740-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9679, 'Curitiba', 'Deputado Heitor Alencar Furtado', 'Mossunguê', '81200-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9680, 'Londrina', 'Deputado Heitor de Alencar Furtado', 'Conjunto Habitacional João Paz', '86087-035', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9681, 'Maringá', 'Deputado Heitor de Alencar Furtado', 'Jardim Iguaçu', '87060-630', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9682, 'Curitiba', 'Deputado Homero Silva', 'Mercês', '80710-270', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9683, 'Curitiba', 'Deputado Iracy Vianna', 'Capão Raso', '81110-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9684, 'Laranjeiras do Sul', 'Deputado Ivan Ferreira do Amaral', 'São Francisco', '85303-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9685, 'Araucária', 'Deputado Ivan Ferreira do Amaral', 'Boqueirão', '83704-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9686, 'Toledo', 'Deputado Ivo Rocha', 'Jardim Porto Alegre', '85906-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9687, 'Curitiba', 'Deputado João Ferreira Neves', 'Vista Alegre', '80820-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9688, 'São José dos Pinhais', 'Deputado João Leopoldo Jacomel', 'Braga', '83020-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9689, 'Araucária', 'Deputado João Leopoldo Jacomel', 'Iguaçu', '83701-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9690, 'Curitiba', 'Deputado João Ribeiro Júnior', 'Cidade Industrial', '81350-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9691, 'Curitiba', 'Deputado Joaquim José Pedrosa', 'Cabral', '80035-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9692, 'Curitiba', 'Deputado Joaquim Linhares de Lacerda', 'Seminário', '80240-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9693, 'Londrina', 'Deputado José Afonso', 'Mazzei', '86015-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9694, 'Maringá', 'Deputado José Alves dos Santos', 'Parque Hortência', '87075-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9695, 'Maringá', 'Deputado José Alves dos Santos', 'Jardim Brasil', '87083-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9696, 'Curitiba', 'Deputado José Hoffmann', 'Vista Alegre', '80820-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9697, 'Curitiba', 'Deputado Ladislau Lachowski', 'Vista Alegre', '80810-370', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9698, 'Guarapuava', 'Deputado Lauro Sodré Lopes', 'Santana', '85070-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9699, 'Curitiba', 'Deputado Leoberto Leal', 'Guabirotuba', '81510-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9700, 'São José dos Pinhais', 'Deputado Luiz Gabriel Sampaio', 'Guatupê', '83060-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9701, 'Curitiba', 'Deputado Mário César Stamm', 'Tarumã', '82530-425', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9702, 'Curitiba', 'Deputado Mário de Barros', 'Juvevê', '80530-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9703, 'Curitiba', 'Deputado Miguel Buffara', 'Jardim das Américas', '81520-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9704, 'Curitiba', 'Deputado Neo Martins', 'Novo Mundo', '81030-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9705, 'Londrina', 'Deputado Nilson Ribas', 'Bancários', '86062-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9706, 'Curitiba', 'Deputado Nilson Ribas', 'Seminário', '80740-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9707, 'Curitiba', 'Deputado Olívio Belich', 'Bom Retiro', '80520-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9708, 'Curitiba', 'Deputado Paulo Wright', 'Cidade Industrial', '81270-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9709, 'Curitiba', 'Deputado Pinheiro Júnior', 'Umbará', '81930-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9710, 'Maringá', 'Deputado Renato Celidônio', 'Zona 01', '87013-220', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9711, 'Curitiba', 'Deputado Rivadávia Vargas', 'Vista Alegre', '80820-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9712, 'Curitiba', 'Deputado Tenório Cavalcanti', 'Uberaba', '81590-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9713, 'Curitiba', 'Deputado Ulisses Guimarães', 'Pinheirinho', '81870-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9714, 'Curitiba', 'Deputado Waldemiro Pedroso', 'Novo Mundo', '81050-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9715, 'Curitiba', 'Deputado Wanderley Júnior', 'Ahú', '82200-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9716, 'São José dos Pinhais', 'Derly Maria Pereira Singer Cardoso', 'Cidade Jardim', '83035-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9717, 'Toledo', 'Dervil Michelin', 'César Park', '85913-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9718, 'Curitiba', 'Desembargador Acyr Saldanha Loyola', 'Hugo Lange', '80040-190', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9719, 'Curitiba', 'Desembargador Albuquerque Maranhão', 'Jardim Social', '82530-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9720, 'Curitiba', 'Desembargador Alcebíades de Almeida Faria', 'Jardim Social', '82520-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9721, 'Curitiba', 'Desembargador Antônio de Paula', 'Boqueirão', '81750-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9722, 'Curitiba', 'Desembargador Antônio de Paula', 'Xaxim', '81720-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9723, 'Curitiba', 'Desembargador Antônio de Paula', 'Boqueirão', '81730-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9724, 'Umuarama', 'Desembargador Antônio Ferreira da Costa', 'Zona I', '87501-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9725, 'Curitiba', 'Desembargador Antônio Franco Ferreira da Costa', 'Cajuru', '82960-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9726, 'Curitiba', 'Desembargador Antônio Leopoldo dos Santos', 'Boa Vista', '82560-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9727, 'Curitiba', 'Desembargador Aristóxenes Bittencourt', 'Tarumã', '82800-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9728, 'Curitiba', 'Desembargador Armando Carneiro', 'Portão', '80610-230', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9729, 'Curitiba', 'Desembargador Arthur Leme', 'Bacacheri', '82510-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9730, 'Curitiba', 'Desembargador Augusto Guimarães Cortes', 'Campina do Siqueira', '80740-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9731, 'Curitiba', 'Desembargador Aurélio Feijó', 'Boa Vista', '82510-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9732, 'Curitiba', 'Desembargador Benvindo Valente', 'São Francisco', '80520-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9733, 'Curitiba', 'Desembargador Carlos Pinheiro Guimarães', 'Sítio Cercado', '81920-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9734, 'Curitiba', 'Desembargador Carlos Pinheiro Guimarães', 'Sítio Cercado', '81925-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9735, 'Curitiba', 'Desembargador Cid Campelo', 'Cidade Industrial', '81170-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9736, 'Curitiba', 'Desembargador Cid Campelo', 'Cidade Industrial', '81350-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9737, 'Curitiba', 'Desembargador Cid Campelo', 'Cidade Industrial', '81250-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9738, 'Londrina', 'Desembargador Clotário Portugal', 'Bom Retiro', '86025-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9739, 'Campo Largo', 'Desembargador Clotário Portugal', 'Centro', '83601-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9740, 'Apucarana', 'Desembargador Clotário Portugal', 'Centro', '86800-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9741, 'Curitiba', 'Desembargador Clotário Portugal', 'Centro', '80410-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9742, 'Curitiba', 'Desembargador Conrado Ericksen', 'Bacacheri', '82520-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9743, 'Curitiba', 'Desembargador Costa Carvalho', 'Batel', '80440-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9744, 'Curitiba', 'Desembargador Edison Nobre de Lacerda', 'Santa Felicidade', '82410-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9745, 'Telêmaco Borba', 'Desembargador Edmundo Mercer Júnior', 'Centro', '84261-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9746, 'Paranaguá', 'Desembargador Ermelino de Leão', 'Oceania', '83203-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9747, 'Curitiba', 'Desembargador Ermelino de Leão', 'Centro', '80410-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9748, 'São José dos Pinhais', 'Desembargador Ernâni Almeida de Abreu', 'Afonso Pena', '83045-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9749, 'Curitiba', 'Desembargador Ernâni Almeida de Abreu', 'Tatuquara', '81480-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9750, 'Curitiba', 'Desembargador Ernani Guarita Cartaxo', 'Capão Raso', '81130-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9751, 'Guarapuava', 'Desembargador Ernâni Guarita Cartaxo', 'Alto da XV', '85065-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9752, 'Curitiba', 'Desembargador Eros Nascimento Gradowski', 'Pilarzinho', '82115-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9753, 'Curitiba', 'Desembargador Estanislau Cardoso', 'Xaxim', '81810-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9754, 'Curitiba', 'Desembargador Eudoro Cavalcanti de Albuquerque', 'Tatuquara', '81480-197', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9755, 'Cascavel', 'Desembargador Ferreira da Costa', 'São Cristóvão', '85816-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9756, 'Curitiba', 'Desembargador Francisco de Paula Xavier Filho', 'Sítio Cercado', '81920-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9757, 'Curitiba', 'Desembargador Francisco de Paula Xavier Filho', 'Sítio Cercado', '81925-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9758, 'Maringá', 'Desembargador Franco Ferreira da Costa', 'Zona Central', '87013-170', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9759, 'São José dos Pinhais', 'Desembargador Henrique Nogueira Dorfmund', 'Cidade Jardim', '83035-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9760, 'Londrina', 'Desembargador Hugo Simas', 'Country Club', '86060-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9761, 'Paranaguá', 'Desembargador Hugo Simas', 'Centro Histórico', '83203-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9762, 'Toledo', 'Desembargador Hugo Simas', 'Walter Fontana', '85909-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9763, 'Curitiba', 'Desembargador Hugo Simas', 'Bom Retiro', '80520-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9764, 'Curitiba', 'Desembargador Isaías Beviláqua', 'Mercês', '80430-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9765, 'Curitiba', 'Desembargador James Portugal', 'Santa Cândida', '82640-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9766, 'São José dos Pinhais', 'Desembargador James Portugal Macedo', 'Braga', '83020-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9767, 'Curitiba', 'Desembargador João Antônio de Barros Júnior', 'Xaxim', '81810-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9768, 'Curitiba', 'Desembargador João José Arruda Júnior', 'Sítio Cercado', '81925-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9769, 'Curitiba', 'Desembargador Joaquim de Oliveira Sobrinho', 'Jardim das Américas', '81530-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9770, 'Ponta Grossa', 'Desembargador Joaquim Ferreira Guimarães', 'Jardim Carvalho', '84015-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9771, 'Curitiba', 'Desembargador Joaquim Ferreira Guimarães', 'Tatuquara', '81480-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9772, 'Curitiba', 'Desembargador Joaquim Penido Monteiro', 'Jardim Social', '82520-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9773, 'Apucarana', 'Desembargador Jorge Andriguetto', 'Centro', '86800-066', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9774, 'Curitiba', 'Desembargador José Carlos Ribeiro Ribas', 'Pilarzinho', '82130-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9775, 'Curitiba', 'Desembargador José Pacheco Júnior', 'Pilarzinho', '80520-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9776, 'Paranaguá', 'Desembargador Lauro Lopes', 'Raia', '83206-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9777, 'Ponta Grossa', 'Desembargador Lauro Lopes', 'Jardim Carvalho', '84015-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9778, 'Umuarama', 'Desembargador Lauro Lopes', 'Zona I', '87501-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9779, 'Curitiba', 'Desembargador Lauro Sodré Lopes', 'Portão', '81320-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9780, 'Curitiba', 'Desembargador Luiz Antônio Pires C. Albuquerque', 'Tatuquara', '81480-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9781, 'Curitiba', 'Desembargador Luiz Antônio Pires C. Albuquerque', 'Tatuquara', '81470-206', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9782, 'Curitiba', 'Desembargador Manoel de Lacerda Pinto', 'Bacacheri', '82600-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9783, 'São José dos Pinhais', 'Desembargador Marçal Justen', 'Centro', '83005-590', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9784, 'Curitiba', 'Desembargador Marçal Justen', 'Tatuquara', '81480-218', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9785, 'Curitiba', 'Desembargador Mercer Júnior', 'Cajuru', '82900-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9786, 'Curitiba', 'Desembargador Miguel Thomaz Pessoa', 'Cidade Industrial', '81270-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9787, 'Curitiba', 'Desembargador Motta', 'Centro', '80430-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9788, 'Curitiba', 'Desembargador Motta', 'Centro', '80420-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9789, 'Curitiba', 'Desembargador Motta', 'Água Verde', '80250-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9790, 'Umuarama', 'Desembargador Munhoz de Mello', 'Zona I', '87501-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9791, 'Curitiba', 'Desembargador Otávio do Amaral', 'Bigorrilho', '80710-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9792, 'Curitiba', 'Desembargador Otávio do Amaral', 'Bigorrilho', '80730-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9793, 'Paranaguá', 'Desembargador Santa Rita', 'Padre Jackson', '83221-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9794, 'Curitiba', 'Desembargador Vatel Gonçalves Pereira', 'Sítio Cercado', '81920-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9795, 'Curitiba', 'Desembargador Vieira Cavalcanti', 'Mercês', '80810-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9796, 'Curitiba', 'Desembargador Vieira Cavalcanti', 'São Francisco', '80510-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9797, 'Ponta Grossa', 'Desembargador Westphalem', 'Oficinas', '84036-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9798, 'Curitiba', 'Desembargador Westphalen', 'Rebouças', '80220-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9799, 'Curitiba', 'Desembargador Westphalen', 'Centro', '80010-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9800, 'Curitiba', 'Desembargador Westphalen', 'Parolin', '80220-031', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9801, 'Curitiba', 'Desembargador Westphalen', 'Rebouças', '80230-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9802, 'Curitiba', 'Desembargador Zeferino Krukoski', 'Alto da Rua XV', '80050-630', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9803, 'Curitiba', 'Desidério Brugnholo', 'Capão Raso', '81130-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9804, 'Francisco Beltrão', 'Desolina Galvão', 'Marrecas', '85601-476', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9805, 'Londrina', 'Detroit', 'Lima Azevedo', '86060-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9806, 'Curitiba', 'Deusdedite de Araújo', 'Cidade Industrial', '81315-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9807, 'Curitiba', 'Deusdete Palmeira Silva', 'Cidade Industrial', '81460-227', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9808, 'Londrina', 'Devanir Sanches Toppa', 'Jardim Alto do Cafezal', '86049-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9809, 'Londrina', 'Deyse do Nascimento Weffort', 'Jardim Paris', '86082-096', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9810, 'Ponta Grossa', 'Dez', 'Boa Vista', '84073-249', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9811, 'Ponta Grossa', 'Dez', 'Uvaranas', '84032-468', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9812, 'Ponta Grossa', 'Dez', 'Jardim Carvalho', '84016-519', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9813, 'Ponta Grossa', 'Dez', 'Chapada', '84064-577', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9814, 'Ponta Grossa', 'Dez', 'Contorno', '84060-598', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9815, 'Ponta Grossa', 'Dez', 'Uvaranas', '84022-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9816, 'Ponta Grossa', 'Dez', 'Contorno', '84060-577', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9817, 'Paranavaí', 'Dez', 'Jardim Ouro Branco', '87702-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9818, 'Ponta Grossa', 'Dez', 'Uvaranas', '84026-598', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9819, 'Ponta Grossa', 'Dez', 'Chapada', '84063-427', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9820, 'Ponta Grossa', 'Dez', 'Uvaranas', '84030-748', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9821, 'Ponta Grossa', 'Dez', 'Uvaranas', '84030-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9822, 'Sarandi', 'Dez', 'Jardim Nova Independência I', '87114-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9823, 'Umuarama', 'Dez', 'Jardim Maria Lúcia', '87501-667', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9824, 'Almirante Tamandaré', 'Dez', 'Jardim Tatiana', '83513-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9825, 'Campo Largo', 'Dez', 'Jardim Lorenzete', '83603-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9826, 'Almirante Tamandaré', 'Dez', 'Jardim das Oliveiras', '83502-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9827, 'Campo Largo', 'Dez', 'Jardim das Acácias', '83603-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9828, 'Campo Largo', 'Dez', 'Vila Pompéia', '83608-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9829, 'Campo Largo', 'Dez', 'Moradias Bom Jesus', '83602-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9830, 'Campo Largo', 'Dez', 'Loteamento São Gerônimo', '83606-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9831, 'Almirante Tamandaré', 'Dez', 'Jardim Cíntia Mara', '83513-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9832, 'Almirante Tamandaré', 'Dez', 'Loteamento Marinoni', '83508-567', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9833, 'Londrina', 'Dez de Dezembro', 'Igapó', '86046-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9834, 'Londrina', 'Dez de Dezembro', 'Nova', '86040-750', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9835, 'Londrina', 'Dez de Dezembro', 'Lago Igapó', '86026-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9836, 'Londrina', 'Dez de Dezembro', 'Helena', '86010-840', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9837, 'Foz do Iguaçu', 'Dez de Junho', 'Centro', '85851-355', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9838, 'Maringá', 'Dez de Maio', 'Zona 07', '87030-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9839, 'Pato Branco', 'Dez de Maio', 'Anchieta', '85501-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9840, 'Piraquara', 'Dez de Novembro', 'Vila Marumbi', '83304-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9841, 'Francisco Beltrão', 'Dez de Outubro', 'São Miguel', '85602-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9842, 'Guarapuava', 'Dez de Setembro', 'Morro Alto', '85065-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9843, 'Ponta Grossa', 'Dezenove', 'Uvaranas', '84022-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9844, 'Ponta Grossa', 'Dezenove', 'Chapada', '84064-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9845, 'Paranavaí', 'Dezenove', 'Parque Morumbi', '87703-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9846, 'Ponta Grossa', 'Dezenove', 'Jardim Carvalho', '84016-538', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9847, 'Sarandi', 'Dezenove', 'Jardim Nova Independência I', '87114-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9848, 'Cambé', 'Dezenove', 'Jardim São Paulo', '86191-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9849, 'Paranaguá', 'Dezenove de Abril', 'Vila Guarani', '83221-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9850, 'Cambé', 'Dezenove de Abril', 'Jardim União', '86185-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9851, 'Francisco Beltrão', 'Dezenove de Dezembro', 'São Cristóvão', '85601-700', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9852, 'Londrina', 'Dezenove de Dezembro', 'Centro', '86020-070', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9853, 'Ponta Grossa', 'Dezenove de Dezembro', 'Centro', '84010-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9854, 'Maringá', 'Dezenove de Dezembro', 'Zona 06', '87080-185', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9855, 'Maringá', 'Dezenove de Dezembro', 'Zona 04', '87015-610', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9856, 'Umuarama', 'Dezenove de Dezembro', 'Zona I', '87503-700', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9950, 'Curitiba', 'Dinarte de Jesus', 'Pilarzinho', '82110-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9857, 'Telêmaco Borba', 'Dezenove de Dezembro', 'Nossa Senhora do Perpétuo Socorro', '84265-570', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9858, 'Cambé', 'Dezenove de Dezembro', 'Jardim União', '86185-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9859, 'Campo Mourão', 'Dezenove de Dezembro', 'Centro', '87303-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9860, 'Curitiba', 'Dezenove de Dezembro', 'Centro', '80020-260', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9861, 'Pinhais', 'Dezenove de Novembro', 'Jardim Pinhais', '83323-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9862, 'Cambé', 'Dezenove de Novembro', 'Jardim União', '86185-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9863, 'Colombo', 'Dezenove de Novembro', 'Jardim Palmares', '83412-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9864, 'Ponta Grossa', 'Dezesseis', 'Uvaranas', '84030-758', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9865, 'Ponta Grossa', 'Dezesseis', 'Jardim Carvalho', '84016-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9866, 'Ponta Grossa', 'Dezesseis', 'Uvaranas', '84022-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9867, 'Ponta Grossa', 'Dezesseis', 'Contorno', '84060-608', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9868, 'Paranavaí', 'Dezesseis', 'Parque Morumbi', '87703-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9869, 'Ponta Grossa', 'Dezesseis', 'Chapada', '84064-587', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9870, 'Almirante Tamandaré', 'Dezesseis', 'Loteamento Marinoni', '83508-577', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9871, 'Campo Largo', 'Dezesseis', 'Jardim Guarany I', '83608-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9872, 'Maringá', 'Dezesseis de Abril', 'Jardim Alamar', '87014-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9873, 'Londrina', 'Dezesseis de Dezembro', 'Alto da Boa Vista', '86083-415', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9874, 'Campo Mourão', 'Dezesseis de Março', 'Jardim Pio XII', '87306-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9875, 'Ponta Grossa', 'Dezessete', 'Chapada', '84064-588', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9876, 'Ponta Grossa', 'Dezessete', 'Chapada', '84062-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9877, 'Paranavaí', 'Dezessete', 'Parque Morumbi', '87703-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9878, 'Ponta Grossa', 'Dezessete', 'Jardim Carvalho', '84016-536', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9879, 'Ponta Grossa', 'Dezessete', 'Uvaranas', '84022-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9880, 'Almirante Tamandaré', 'Dezessete', 'Loteamento Marinoni', '83508-578', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9881, 'Campo Largo', 'Dezessete', 'Jardim Guarany I', '83608-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9882, 'Guarapuava', 'Dezessete de Julho', 'Trianon', '85015-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9883, 'Guarapuava', 'Dezessete de Julho', 'Trianon', '85012-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9884, 'Guarapuava', 'Dezessete de Julho', 'Santana', '85070-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9885, 'Castro', 'Dezessete de Maio', 'Jardim Bela Vista', '84165-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9886, 'Ponta Grossa', 'Dezoito', 'Uvaranas', '84022-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9887, 'Ponta Grossa', 'Dezoito', 'Jardim Carvalho', '84016-537', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9888, 'Paranavaí', 'Dezoito', 'Parque Morumbi', '87703-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9889, 'Ponta Grossa', 'Dezoito', 'Chapada', '84064-589', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9890, 'Almirante Tamandaré', 'Dezoito', 'Loteamento Marinoni', '83508-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9891, 'Foz do Iguaçu', 'Dezoito de Junho', 'Vila Itajubá', '85852-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9892, 'Ponta Grossa', 'Dezoito de Setembro', 'Ronda', '84051-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9893, 'Foz do Iguaçu', 'Di Cavalcanti', 'Jardim Boa Vista', '85864-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9894, 'Foz do Iguaçu', 'Di Cavalcanti', 'Vila Portes', '85865-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9895, 'Umuarama', 'Di Cavalcanti', 'Conjunto Residencial Ouro Preto', '87504-597', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9896, 'Cascavel', 'Di Cavalcanti', 'Country', '85813-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9897, 'Londrina', 'Diacui', 'Antares', '86036-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9898, 'Telêmaco Borba', 'Diacui', 'Área 06', '84271-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9899, 'Foz do Iguaçu', 'Diadema', 'Jardim Curitibano', '85869-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9900, 'Guarapuava', 'Diadema', 'Industrial', '85053-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9901, 'Francisco Beltrão', 'Diadema', 'Pinheirinho', '85603-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9902, 'Londrina', 'Diamante', 'Ideal', '86030-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9903, 'Ponta Grossa', 'Diamante', 'Neves', '84021-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9904, 'Maringá', 'Diamante', 'Jardim Real', '87083-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9905, 'Umuarama', 'Diamante', 'Conjunto Residencial Ouro Branco', '87508-258', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9906, 'Telêmaco Borba', 'Diamante', 'Área 04', '84266-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9907, 'Cambé', 'Diamante', 'Conjunto Habitacional Cristal', '86182-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9908, 'Cascavel', 'Diamante', 'Esmeralda', '85806-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9909, 'Curitiba', 'Diamante do Norte', 'Cidade Industrial', '81250-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9910, 'Foz do Iguaçu', 'Diamante do Sul', 'Jardim Ipanema', '85862-316', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9911, 'Foz do Iguaçu', 'Diamantina', 'Jardim Petropólis', '85868-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9912, 'Guarapuava', 'Diamantina', 'Vila Carli', '85040-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9913, 'Toledo', 'Diamantina', 'Boa Esperança', '85909-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9914, 'Telêmaco Borba', 'Diamantina', 'Núcleo Bandeirantes', '84269-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9915, 'Umuarama', 'Diamantina', 'Parque Tarumã', '87508-218', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9916, 'Cascavel', 'Diamantina', 'Presidente', '85818-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9917, 'Almirante Tamandaré', 'Diamantina', 'Jardim Ipê', '83505-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9918, 'Sarandi', 'Diamantino', 'Jardim Itamaraty', '87112-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9919, 'Curitiba', 'Diamira Valério Ruthes', 'Campo de Santana', '81490-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9920, 'Ponta Grossa', 'Dias da Rocha Filho', 'Oficinas', '84036-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9921, 'Curitiba', 'Dias da Rocha Filho', 'Alto da Rua XV', '80040-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9922, 'Londrina', 'Dib Libos', 'Boa Vista', '86039-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9923, 'Curitiba', 'Dicésar Plaisant', 'Jardim Social', '82520-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9924, 'São José dos Pinhais', 'Diciolina Alberti Pereira', 'Silveira da Motta', '83030-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9925, 'Curitiba', 'Dídimo Agapito da Veiga', 'Cajuru', '82970-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9926, 'Curitiba', 'Dídimo Cercal da Silva', 'Santa Felicidade', '82010-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9927, 'Curitiba', 'Didio Sampaio', 'Sítio Cercado', '81900-748', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9928, 'Almirante Tamandaré', 'Didio Santos', 'Vila Santa Terezinha', '83501-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9929, 'Foz do Iguaçu', 'Diego Inácio Vera', 'Jardim São Paulo I', '85856-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9930, 'Colombo', 'Diesel', 'Vila Guarani', '83408-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9931, 'Curitiba', 'Dilair Silvério', 'Santa Cândida', '82720-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9932, 'Colombo', 'Dilceu Antônio Valente', 'Jardim Abigail', '83409-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9933, 'Curitiba', 'Dilermando Pereira de Almeida', 'Pinheirinho', '81870-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9934, 'Toledo', 'Dilermando Reis', 'Jardim Panambi', '85904-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9935, 'Curitiba', 'Dilson Luiz', 'Tatuquara', '81940-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9936, 'Colombo', 'Dilvete Santos Ribeiro', 'Jardim dos Eucaliptos', '83408-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9937, 'Curitiba', 'Dimas de Abreu', 'São Braz', '82315-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9938, 'Cascavel', 'Dimas Pires Bastos', 'Country', '85813-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9939, 'Londrina', 'Dimas Ramos da Silva', 'Jacutinga', '86087-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9940, 'Londrina', 'Dimitri Popoff', 'Conjunto Habitacional Bronzzetti', '86037-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9941, 'Foz do Iguaçu', 'Dina Sfat', 'Jardim Dom Pedro I', '85856-606', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9942, 'Curitiba', 'Dina Sfat', 'Tatuquara', '81470-257', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9943, 'Guarapuava', 'Dinamarca', 'Industrial', '85053-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9944, 'Londrina', 'Dinamarca', 'Igapó', '86046-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9945, 'Cambé', 'Dinamarca', 'Centro', '86181-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9946, 'Cambé', 'Dinamarca', 'Vila Guarani', '86182-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9947, 'Apucarana', 'Dinamarca', 'Jardim Ana Maria', '86808-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9948, 'Francisco Beltrão', 'Dinarci Menon', 'Sadia', '85606-406', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9949, 'Curitiba', 'Dinarte Caprilhone', 'São João', '82030-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9951, 'Almirante Tamandaré', 'Dinarte José Batista', 'Loteamento Recanto dos Papagaios', '83512-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9952, 'Curitiba', 'Dinarte Pinto', 'Cidade Industrial', '81315-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9953, 'Guarapuava', 'Dinarte Saul Araújo', 'Industrial', '85053-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9954, 'Arapongas', 'Dinduculo', 'Jardim do Café', '86706-207', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9955, 'Maringá', 'Dinerolli Labatut', 'Jardim Nilza', '87065-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9956, 'Curitiba', 'Diniz Joaquim Geremias', 'Uberaba', '81570-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9957, 'Apucarana', 'Diniz José Silvério', 'Jardim Laranjeiras', '86811-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9959, 'Curitiba', 'Dino Gabrielli', 'Cidade Industrial', '81230-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9960, 'Maringá', 'Dino Múcio', 'Conjunto Habitacional Requião', '87047-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9961, 'Curitiba', 'Dino Paolini', 'Caximba', '81490-320', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9962, 'Curitiba', 'Dinorá Cardoso de Lima', 'Prado Velho', '80215-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9963, 'Maringá', 'Dinorah Knabben Perin', 'Loteamento Batel', '87043-426', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9964, 'Apucarana', 'Diógenes', 'Vila Nova', '86812-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9965, 'São José dos Pinhais', 'Diógenes Abelardino da Silva', 'Miringuava', '83090-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9966, 'Campo Mourão', 'Diógenes Alves Cabral', 'Jardim Capricórnio', '87301-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9967, 'Araucária', 'Diógenes Brasil Lobato', 'Centro', '83702-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9968, 'Curitiba', 'Diógenes do Brasil Lobato', 'Tingui', '82620-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9969, 'Londrina', 'Diógenes Pomposo', 'Jardim Esperança', '86046-675', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9970, 'Curitiba', 'Diógenes Ridgley Raciop', 'Tarumã', '82800-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9971, 'Pato Branco', 'Diogo Antônio Feijó', 'La Salle', '85505-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9972, 'Almirante Tamandaré', 'Diogo Antônio Feijó', 'Vila Grécia', '83502-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9973, 'Curitiba', 'Diogo Mugiatti', 'Boqueirão', '81730-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9974, 'Curitiba', 'Diogo Mugiatti', 'Boqueirão', '81750-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9975, 'Laranjeiras do Sul', 'Diogo Pinto', 'Centro', '85301-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9976, 'Curitiba', 'Diogo Pinto de Azevedo Portugal', 'Abranches', '82130-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9977, 'Maringá', 'Diogo Zuliani', 'Jardim Alvorada', '87033-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9978, 'Ponta Grossa', 'Diolando João Pedro Scremin', 'Uvaranas', '84030-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9979, 'São José dos Pinhais', 'Diolinda Ricardina de Jesus', 'São Sebastião', '83075-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9980, 'Curitiba', 'Diomar David Dalledone Júnior', 'Uberaba', '81560-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9981, 'Curitiba', 'Diomar Wambier', 'Uberaba', '81560-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9982, 'São José dos Pinhais', 'Diomira Moro Zen', 'Colônia Rio Grande', '83025-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9983, 'São José dos Pinhais', 'Diomiro Chiuratto', 'Planta Quississana', '83085-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9984, 'Londrina', 'Dionezio Cruzatte', 'Igarite', '86081-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9985, 'Curitiba', 'Dionira Moletta Klemtz', 'Santa Quitéria', '81320-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9986, 'Londrina', 'Dionísia Oliveira Tavares', 'Ernani de Moura Lima', '86037-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9987, 'São José dos Pinhais', 'Dionísio Alves Fontes', 'Afonso Pena', '83065-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9988, 'Curitiba', 'Dionísio Cerqueira', 'Cidade Industrial', '81240-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9989, 'Londrina', 'Dionísio Kloster Sampaio', 'Shangri-La', '86070-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9990, 'São José dos Pinhais', 'Dionísio Nabosne', 'Planta Quississana', '83085-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9991, 'Londrina', 'Dionísio Netto Teixeira', 'Estados', '86083-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9992, 'Francisco Beltrão', 'Dionísio Passe', 'Luther King', '85605-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9993, 'Londrina', 'Dionísio Pereira de Castro', 'Santa Izabel', '86031-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9994, 'Londrina', 'Dionísio Pesarini', 'Portal de Versalhes 1', '86057-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9995, 'Paranavaí', 'Dionísio Telmo Chagas', 'Jardim Videira', '87711-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9996, 'Cascavel', 'Dionísio Vanderlei Miotto', 'Cataratas', '85818-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9997, 'Toledo', 'Dionísio Veronese', 'Jardim Europa', '85908-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9998, 'São José dos Pinhais', 'Dionízia Itália Bino', 'Silveira da Motta', '83030-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (9999, 'Curitiba', 'Dionizio Baglioli', 'Guabirotuba', '81510-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10000, 'Foz do Iguaçu', 'Dionizio Cogo', 'Jardim Esmeralda', '85856-140', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10001, 'São José dos Pinhais', 'Dionízio Dal''Negro', 'Colônia Rio Grande', '83025-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10002, 'Toledo', 'Dionizio Falbota', 'Jardim Recanto', '85902-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10003, 'Curitiba', 'Dionízio João Rossi Borguezani', 'Pinheirinho', '81870-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10004, 'Curitiba', 'Dionízio Markovicz', 'Cidade Industrial', '81240-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10005, 'Londrina', 'Dionyl Hebert Koch', 'Barbeta', '86078-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10006, 'Londrina', 'Diorge Palomares Rufino', 'Pinheiros', '86063-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10007, 'Londrina', 'Diorgenes de Lima Bravo', 'Franciscato', '86043-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10008, 'Foz do Iguaçu', 'Diosnel Saldivar', 'Jardim Porto Belo', '85867-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10009, 'Londrina', 'Dirce Ferreira Coelho', 'Jardim Acapulco', '86045-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10010, 'Maringá', 'Dirce Mari Schuinka Ribeiro', 'Conjunto Habitacional Requião', '87047-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10011, 'Almirante Tamandaré', 'Dircélia Santos Perussi Rosa', 'Loteamento Chico Mendes', '83505-777', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10012, 'Londrina', 'Dirceu Bertolaccini', 'Indústrias', '86043-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10013, 'Ponta Grossa', 'Dirceu Blageski', 'Contorno', '84060-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10014, 'Maringá', 'Dirceu Fernandes Souza', 'Jardim Vila Rica', '87050-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10015, 'Curitiba', 'Dirceu José Guimarães', 'Boqueirão', '81650-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10016, 'São José dos Pinhais', 'Dirceu Montanarim', 'Planta Quississana', '83085-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10017, 'São José dos Pinhais', 'Dirceu Sá Ribas', 'Guatupê', '83060-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10018, 'Curitiba', 'Dirceu Simões de Medeiros', 'Cajuru', '82980-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10019, 'Umuarama', 'Disaburo Yokohama', 'Parque Cidade Jardim', '87506-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10020, 'Sarandi', 'Discípulos de Emaus', 'Parque Residencial Bom Pastor', '87114-548', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10021, 'Cascavel', 'Distribuidora', '14 de Novembro', '85804-126', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10022, 'Maringá', 'Distrito Federal', 'Chácara Paulista', '87005-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10023, 'Paranavaí', 'Distrito Federal', 'Centro', '87701-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10024, 'Arapongas', 'Ditui', 'Conjunto Ulisses Guimarães', '86706-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10025, 'Curitiba', 'Diva Machado da Luz', 'Sítio Cercado', '81925-188', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10026, 'Apucarana', 'Diva Nadir', 'Vila Formosa', '86802-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10027, 'Apucarana', 'Diva Pimenta Bovo', 'Núcleo Habitacional Castelo Branco', '86812-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10028, 'Curitiba', 'Diva Regnier Barrozo', 'Umbará', '81930-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10029, 'São José dos Pinhais', 'Diva Siqueira Santos', 'Guatupê', '83060-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10030, 'Curitiba', 'Divair Luiz dos Santos', 'Alto Boqueirão', '81770-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10031, 'Curitiba', 'Divina Pastora', 'Mercês', '80810-150', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10032, 'Almirante Tamandaré', 'Divina Rodrigues de Souza', 'Jardim Campo Verde', '83502-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10033, 'Maringá', 'Divino Bortolotto', 'Jardim Cidade Monções', '87060-356', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10034, 'Pinhais', 'Divino Sala', 'Planta Vila Bordignon', '83325-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10035, 'Curitiba', 'Divoeny Julieta Cabral', 'Taboão', '82130-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10036, 'São José dos Pinhais', 'Divonzir Luciano', 'Afonso Pena', '83050-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10037, 'Curitiba', 'Djalma Ferreira Maciel', 'Lindóia', '81010-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10038, 'Guarapuava', 'Djalma Fonseca Caldas', 'Santana', '85070-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10039, 'Londrina', 'Djalma Marques da Silva Acauan', 'Conjunto Novo Amparo 2', '86056-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10040, 'Araucária', 'Djalma Pizatto Fruet', 'Cachoeira', '83701-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10041, 'Curitiba', 'Djalma Soares', 'Boa Vista', '82540-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10042, 'Ponta Grossa', 'do Abacateiro', 'Periquitos', '84065-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10043, 'Piraquara', 'do Abacateiro', 'Planta Guarituba Pequena', '83310-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10044, 'Francisco Beltrão', 'do Abdul Sebastião Pholmann', 'Cristo Rei', '85602-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10045, 'Londrina', 'do Aço', 'Jardim São Francisco de Assis', '86067-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10046, 'Curitiba', 'do Aço', 'Cidade Industrial', '81350-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10047, 'Colombo', 'do Acor', 'Planta Santa Tereza', '83401-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10048, 'Guarapuava', 'do Açude', 'Conradinho', '85055-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10049, 'Ponta Grossa', 'do Advogado', 'Periquitos', '84065-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10050, 'Paranavaí', 'do Aeroporto', 'Jardim Santos Dumont', '87706-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10051, 'Maringá', 'do Aeroporto', 'Zona 08', '87050-450', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10052, 'Paranaguá', 'do Agapanto', 'Conjunto Nilson Neves', '83215-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10053, 'Colombo', 'do Alecrim', 'Parque Monte Castelo', '83411-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10054, 'Foz do Iguaçu', 'do Alegrete', 'Centro', '85851-115', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10055, 'Londrina', 'do Aleijadinho', 'Jardim Londrilar', '86010-700', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10056, 'Cascavel', 'do Aleijadinho', 'Universitário', '85819-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10057, 'Guarapuava', 'do Alumínio', 'Industrial', '85045-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10058, 'São José dos Pinhais', 'do Amanhã', 'Guatupê', '83060-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10059, 'São José dos Pinhais', 'do Amanhecer', 'Guatupê', '83060-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10060, 'Curitiba', 'do Amapá', 'Vista Alegre', '80810-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10061, 'Campo Mourão', 'do Amor Divino', 'Conjunto Habitacional Mendes', '87306-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10062, 'Cascavel', 'do Amor-perfeito', 'Guarujá', '85804-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10063, 'Foz do Iguaçu', 'do Angico', 'Conjunto B', '85867-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10064, 'Colombo', 'do Angico', 'Parque do Embu', '83414-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10065, 'Curitiba', 'do Anhangava', 'Uberaba', '81550-370', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10066, 'Colombo', 'do Araçaeiro', 'Jardim Nossa Senhora das Graças', '83407-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10067, 'Londrina', 'do Araticum', 'Meton', '86035-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10068, 'Londrina', 'do Atletismo', 'Jardim Olímpico', '86056-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10069, 'Colombo', 'do Avestruz', 'Planta Santa Tereza', '83401-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10070, 'Colombo', 'do Azulão', 'Jardim Santa Cruz', '83401-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10071, 'Ponta Grossa', 'do Bancário', 'Periquitos', '84065-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10072, 'Curitiba', 'do Barigui', 'Cidade Industrial', '81450-020', 'Estrada Velha', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10073, 'Curitiba', 'do Barigui', 'Cidade Industrial', '81250-460', 'Estrada Velha', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10074, 'Curitiba', 'do Barnabé', 'Boqueirão', '81730-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10075, 'Londrina', 'do Basquetebol', 'Jardim Olímpico', '86056-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10076, 'Curitiba', 'do Batel', 'Batel', '80420-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10077, 'Cascavel', 'do Beco', 'Ciro Nardi', '85802-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10078, 'Colombo', 'do Beija-flor', 'Planta Santa Tereza', '83401-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10079, 'Colombo', 'do Bem-te-vi', 'Planta Santa Tereza', '83401-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10080, 'Pato Branco', 'do Beto', 'Centro', '85501-015', 'Ladeira', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10081, 'Colombo', 'do Bico-de-lacre', 'Planta Santa Tereza', '83401-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10082, 'Campo Mourão', 'do Bicudo', 'Jardim Paulista', '87310-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10083, 'Londrina', 'do Biribol', 'Conjunto Novo Amparo 2', '86056-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10084, 'Londrina', 'do Biribol', 'Conjunto Novo Amparo 2', '86056-355', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10085, 'Paranaguá', 'do Bockmann', 'Bockmann', '83206-260', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10086, 'Colombo', 'do Bom Senhor', 'Parque Monte Castelo', '83411-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10087, 'Colombo', 'do Bonito-Lindo', 'Jardim Santa Cruz', '83401-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10088, 'Foz do Iguaçu', 'do Bosque', 'Conjunto B', '85867-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10089, 'Guarapuava', 'do Bosque', 'Conradinho', '85035-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10090, 'Umuarama', 'do Bosque', 'Jardim Social', '87506-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10091, 'Campo Mourão', 'do Bosque', 'Jardim Araucária', '87301-340', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10092, 'Cambé', 'do Braz', 'Jardim Morumbi', '86191-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10093, 'Telêmaco Borba', 'do Britador', 'Núcleo Bandeirantes', '84269-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10094, 'Londrina', 'do Café', 'Conjunto Café', '86038-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10095, 'Piraquara', 'do Café', 'Jardim Bela Vista', '83301-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10096, 'Paranavaí', 'do Café', 'Jardim São Jorge', '87710-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10097, 'Piraquara', 'do Café', 'Jardim Bela Vista', '83301-065', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10098, 'Paranaguá', 'do Café', 'Jardim Paranaguá', '83218-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10099, 'Cambé', 'do Café', 'Planta São Francisco', '86182-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10100, 'Cascavel', 'do Café', 'Cataratas', '85818-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10101, 'Maringá', 'do Caju', 'Jardim Bertioga', '87055-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10102, 'Colombo', 'do Cajueiro', 'Jardim Nossa Senhora das Graças', '83407-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10103, 'Curitiba', 'do Camacuan', 'Uberaba', '81550-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10104, 'Foz do Iguaçu', 'do Campanario', 'Conjunto B', '85867-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10105, 'Colombo', 'do Camping', 'Vila Ana Maria', '83413-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10106, 'Londrina', 'do Canário', 'Waldemar Hauer', '86030-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10107, 'Colombo', 'do Canário', 'Jardim Ana Rosa II', '83401-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10108, 'Curitiba', 'do Capanema', 'Jardim Botânico', '80060-195', 'Viaduto', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10109, 'Colombo', 'do Cardeal', 'Jardim Ana Rosa I', '83401-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10110, 'Arapongas', 'do Cardeal-do-sul', 'Jardim São Carlos', '86704-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10111, 'Ponta Grossa', 'do Carpinteiro', 'Periquitos', '84065-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10112, 'Colombo', 'do Carvalho', 'Vila Florestal Grajaú', '83411-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10113, 'Telêmaco Borba', 'do Cascalho', 'Vila São Francisco de Assis', '84264-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10114, 'Londrina', 'do Cedro', 'Leonor', '86071-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10115, 'Foz do Iguaçu', 'do Cedro', 'Conjunto B', '85867-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10116, 'Toledo', 'do Cedro', 'Jardim Paulista', '85909-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10117, 'Cambé', 'do Cedro', 'Vila Salomé', '86192-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10118, 'Colombo', 'do Cedro', 'Parque do Embu', '83414-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10119, 'Curitiba', 'do Cedro', 'Barreirinha', '82710-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10120, 'Pato Branco', 'do Cemiterio', 'Bortot', '85504-005', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10121, 'Umuarama', 'do Centro', 'Jardim Paraíso', '87505-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10122, 'Castro', 'do Chafariz', 'Vila Rio Branco', '84172-265', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10123, 'Curitiba', 'do Chimarrão', 'Guabirotuba', '81520-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10124, 'Colombo', 'do Cipreste', 'Parque do Embu', '83414-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10125, 'Colombo', 'do Cisne', 'Planta Santa Tereza', '83401-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10126, 'Apucarana', 'do Colégio', 'Vila do Colégio', '86808-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10127, 'Colombo', 'do Coleirinho', 'Jardim Santa Cruz', '83401-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10128, 'Londrina', 'do Colibri', 'Vitória Régia', '86038-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10129, 'Colombo', 'do Colibri', 'Planta Santa Tereza', '83401-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10130, 'Francisco Beltrão', 'do Colono', 'Pinheirinho', '85606-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10131, 'Ponta Grossa', 'do Comerciário', 'Periquitos', '84065-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10132, 'Maringá', 'do Comércio', 'Zona 06', '87080-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10133, 'Campo Largo', 'do Comércio', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10134, 'Cascavel', 'do Comércio', 'Maria Luiza', '85819-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10135, 'Curitiba', 'do Comércio 24 Horas', 'Centro', '80410-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10136, 'Guarapuava', 'do Condor', 'Primavera', '85050-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10137, 'Colombo', 'do Condor', 'Planta Santa Tereza', '83401-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10138, 'Cambé', 'do Congresso', 'Parque Residencial Cambé', '86191-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10139, 'Cascavel', 'do Construtor', 'Universitário', '85819-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10140, 'Ponta Grossa', 'do Contabilista', 'Periquitos', '84065-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10141, 'Cascavel', 'do Contador', 'Universitário', '85819-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10142, 'Foz do Iguaçu', 'do Contorno', 'Conjunto B', '85867-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10143, 'Paranaguá', 'do Correia Velho', 'Vila Paranaguá', '83221-720', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10144, 'Paranaguá', 'do Correia Velho', 'Itiberê', '83206-365', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10145, 'Ponta Grossa', 'do Corruíra', 'Chapada', '84064-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10146, 'Colombo', 'do Cravo', 'Parque Monte Castelo', '83411-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10147, 'São José dos Pinhais', 'do Crepúsculo', 'Guatupê', '83060-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10148, 'Colombo', 'do Curió', 'Jardim Ana Rosa II', '83401-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10149, 'Campo Largo', 'do Curió', 'Vila Dona Fina', '83609-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10150, 'Colombo', 'do Damasqueiro', 'Jardim Nossa Senhora das Graças', '83407-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10151, 'Ponta Grossa', 'do Dentista', 'Periquitos', '84065-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10152, 'Cascavel', 'do Desenvolvimento', 'Presidente', '85818-128', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10153, 'Paranavaí', 'do Divino', 'Jardim São Jorge', '87710-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10154, 'Ponta Grossa', 'do Eletricista', 'Periquitos', '84065-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10155, 'Paranaguá', 'do Emboguaçu', 'Emboguaçu', '83206-430', 'Estrada Velha', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10156, 'Ponta Grossa', 'do Encanador', 'Periquitos', '84065-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10157, 'Cascavel', 'do Encanador', 'Universitário', '85819-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10158, 'Guarapuava', 'do Enfermeiro', 'Santana', '85070-720', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10159, 'Ponta Grossa', 'do Enfermeiro', 'Periquitos', '84065-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10160, 'Curitiba', 'do Ervateiro', 'Guabirotuba', '81520-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10161, 'Guarapuava', 'do Escoteiro', 'Santana', '85070-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10162, 'Londrina', 'do Escoteiro', 'Los Angeles', '86020-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10163, 'Curitiba', 'do Escriturário', 'Boqueirão', '81730-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10164, 'Curitiba', 'do Evangelho Quadrangular', 'Cidade Industrial', '81315-600', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10165, 'Ponta Grossa', 'do Expedicionário', 'Centro', '84051-005', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10166, 'Maringá', 'do Expedicionário', 'Zona 04', '87015-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10167, 'São José dos Pinhais', 'do Expedicionário', 'Centro', '83005-005', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10168, 'Cascavel', 'do Expedicionário', 'Maria Luiza', '85819-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10169, 'Curitiba', 'do Expedicionário', 'Centro', '80060-180', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10170, 'Colombo', 'do Faisão', 'Planta Santa Tereza', '83401-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10171, 'Colombo', 'do Falcão', 'Jardim Santa Cruz', '83401-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10172, 'Ponta Grossa', 'do Farmacêutico', 'Periquitos', '84065-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10173, 'Cascavel', 'do Feijão', 'Cataratas', '85818-738', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10174, 'Cascavel', 'do Feitor', 'Universitário', '85819-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10175, 'Colombo', 'do Flamboyant', 'Parque do Embu', '83414-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10176, 'Colombo', 'do Flamingo', 'Planta Santa Tereza', '83401-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10177, 'Curitiba', 'do Fogo', 'Guabirotuba', '81520-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10178, 'Londrina', 'do Futebol', 'Jardim Olímpico', '86056-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10179, 'Colombo', 'do Galo-da-serra', 'Jardim Santa Cruz', '83401-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10180, 'Curitiba', 'do Ganchinho', 'Umbará', '81930-160', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10181, 'Londrina', 'do Garapeiro', 'Vila Ipiranga', '86010-645', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10182, 'Curitiba', 'do Gari', 'Boqueirão', '81730-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10183, 'Telêmaco Borba', 'do Garimpeiro', 'Vila São Francisco de Assis', '84265-640', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10184, 'Londrina', 'do Garimpo', 'Penterich', '86010-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10185, 'Curitiba', 'do Garimpo', 'Guabirotuba', '81520-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10186, 'Colombo', 'do Gaturamo', 'Jardim Monte Tabor', '83401-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10187, 'Apucarana', 'do Gera', 'Jardim Bom Jesus da Lapa', '86808-025', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10188, 'Colombo', 'do Gerânio', 'Parque Monte Castelo', '83411-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10189, 'Cascavel', 'do Girassol', 'Guarujá', '85804-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10190, 'Colombo', 'do Girassol', 'Vila Vale das Flores', '83411-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10191, 'Pato Branco', 'do Grupo', 'Centro', '85501-125', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10192, 'Curitiba', 'do Grupo Escolar', 'Campo Comprido', '81270-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10193, 'Curitiba', 'do Guairicana', 'Uberaba', '81550-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10194, 'Londrina', 'do Guaraná', 'Marabá', '86035-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10195, 'Curitiba', 'do Guarumbi', 'Uberaba', '81590-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10196, 'Curitiba', 'do Guarumbi', 'Uberaba', '81550-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10197, 'Toledo', 'do Herval', 'Maracanã', '85910-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10198, 'Curitiba', 'do Herval', 'Alto da Rua XV', '80050-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10199, 'Londrina', 'do Hipismo', 'Jardim Olímpico', '86056-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10200, 'Londrina', 'do Iatismo', 'Jardim Olímpico', '86056-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10201, 'Londrina', 'do Imbu', 'Maira', '86035-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10202, 'Cascavel', 'do Imigrante', 'Centro', '85801-005', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10203, 'Cambé', 'do Império', 'Jardim São José', '86192-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10204, 'Maringá', 'do Ingá', 'Zona 01', '87013-320', 'Parque', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10205, 'Colombo', 'do Ingá', 'Parque do Embu', '83414-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10206, 'Curitiba', 'do Ingá', 'Barreirinha', '82700-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10207, 'Paranavaí', 'do Ipê', 'Vila Alta', '87708-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10208, 'Colombo', 'do Ipê', 'Parque Monte Castelo', '83411-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10209, 'Cambé', 'do Ipiranga', 'Jardim Morumbi', '86191-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10210, 'Londrina', 'do Jaburu', 'Waldemar Hauer', '86030-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10211, 'Colombo', 'do Jaburu', 'Planta Santa Tereza', '83401-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10212, 'Colombo', 'do Jaçanã', 'Planta Santa Tereza', '83401-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10213, 'Colombo', 'do Jacarandá', 'Parque do Embu', '83414-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10214, 'Curitiba', 'do Jacarandá', 'Barreirinha', '82700-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10215, 'Londrina', 'do Jambolão', 'Maira', '86035-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10216, 'Curitiba', 'do Japão', 'Água Verde', '80240-180', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10217, 'Colombo', 'do Jaraguá', 'Parque Monte Castelo', '83411-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10218, 'Toledo', 'do Jardineiro', 'Boa Esperança', '85909-236', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10219, 'Curitiba', 'do Jardineiro', 'Boqueirão', '81730-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10220, 'Londrina', 'do Jasmim', 'Ouro Branco', '86042-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10221, 'Piraquara', 'do Jasmim', 'Planta Guarituba Pequena', '83310-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10222, 'Piraquara', 'do Jatobá', 'Planta Guarituba Pequena', '83310-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10223, 'Colombo', 'do Jatobá', 'Vila Florestal Grajaú', '83411-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10224, 'Londrina', 'do Jenipapo', 'Maira', '86035-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10225, 'Curitiba', 'do Jequitibá', 'Cidade Industrial', '81450-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10226, 'Colombo', 'do João-de-barro', 'Jardim Georgina', '83401-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10227, 'Apucarana', 'do Joaquim Furlan', 'Parque Bela Vista', '86803-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10228, 'Paranaguá', 'do José Rizental', 'Leblon', '83203-755', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10229, 'Colombo', 'do Juazeiro', 'Parque do Embu', '83414-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10230, 'Londrina', 'do Judô', 'Jardim Olímpico', '86056-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10231, 'Cascavel', 'do Kalanchue', 'Guarujá', '85804-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10232, 'Maringá', 'do Lavradio', 'Parque Residencial Aeroporto (2ª Parte)', '87055-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10233, 'Curitiba', 'do Lazareto', 'Bom Retiro', '80520-080', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10234, 'Campo Mourão', 'do Lazer', 'Jardim Tropical II', '87310-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10235, 'Colombo', 'do Limoeiro', 'Jardim Nossa Senhora das Graças', '83407-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10236, 'Colombo', 'do Louro', 'Parque do Embu', '83414-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10237, 'Londrina', 'do Maçon', 'San Remo', '86062-275', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10238, 'Colombo', 'do Mamoeiro', 'Jardim Nossa Senhora das Graças', '83407-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10239, 'Cascavel', 'do Manjericão', 'Guarujá', '85804-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10240, 'Sarandi', 'do Mar', 'Parque São Pedro', '87112-525', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10241, 'Ponta Grossa', 'do Marceneiro', 'Periquitos', '84065-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10242, 'Colombo', 'do Marfim', 'Parque do Embu', '83414-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10243, 'Curitiba', 'do Marfim', 'Barreirinha', '82700-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10244, 'Ponta Grossa', 'do Mecânico', 'Periquitos', '84065-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10245, 'Ponta Grossa', 'do Médico', 'Periquitos', '84065-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10246, 'Londrina', 'do Melão', 'Marabá', '86035-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10247, 'Cascavel', 'do Milho', 'Cataratas', '85818-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10248, 'Curitiba', 'do Minerador', 'Guabirotuba', '81520-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10249, 'Londrina', 'do Morango', 'Interlagos', '86035-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10250, 'Ponta Grossa', 'do Motorista', 'Periquitos', '84065-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10251, 'Colombo', 'do Nambu', 'Planta Santa Tereza', '83401-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10252, 'Colombo', 'do Noitibo', 'Planta Santa Tereza', '83401-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10253, 'Curitiba', 'do Operador', 'Boqueirão', '81730-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10254, 'Cascavel', 'do Operário', 'Presidente', '85818-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10255, 'Curitiba', 'do Ouro', 'Guabirotuba', '81520-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10256, 'Almirante Tamandaré', 'do Pacotuba', 'Pacotuba', '83514-550', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10257, 'Ponta Grossa', 'do Padeiro', 'Periquitos', '84065-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10258, 'Maringá', 'do Padre', 'Jardim São Silvestre', '87055-020', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10259, 'Colombo', 'do Papagaio', 'Jardim Ana Rosa I', '83401-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10260, 'Colombo', 'do Pardal', 'Jardim Ana Rosa I', '83401-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10261, 'Londrina', 'do Parque', 'Monte Carlo', '86040-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10262, 'Colombo', 'do Paruru', 'Jardim Ana Rosa II', '83401-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10263, 'Colombo', 'do Passáro-Preto', 'Jardim Santa Cruz', '83401-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10264, 'Colombo', 'do Pau-brasil', 'Parque do Embu', '83414-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10265, 'Londrina', 'do Pavão', 'Indústrias Leves', '86030-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10266, 'Colombo', 'do Pavão', 'Planta Santa Tereza', '83401-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10267, 'Ponta Grossa', 'do Pedreiro', 'Periquitos', '84065-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10268, 'Londrina', 'do Pelicano', 'Paraíso', '86078-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10269, 'Colombo', 'do Pelicano', 'Planta Santa Tereza', '83401-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10270, 'Colombo', 'do Pequi', 'Vila Florestal Grajaú', '83411-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10271, 'Umuarama', 'do Perímetro', 'Zona VI', '87503-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10272, 'Londrina', 'do Pêssego', 'Marabá', '86035-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10273, 'Colombo', 'do Petrel', 'Planta Santa Tereza', '83401-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10274, 'Francisco Beltrão', 'do Picadão', 'Jardim Novo Mundo', '85602-685', 'Estrada Velha', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10275, 'Campo Mourão', 'do Picadeiro', 'Conjunto Residencial Ilha Bela', '87309-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10276, 'São José dos Pinhais', 'do Pica-pau', 'Colônia Rio Grande', '83025-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10277, 'Sarandi', 'do Pica-pau', 'Conjunto Floresta', '87112-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10278, 'Colombo', 'do Pingüim', 'Planta Santa Tereza', '83401-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10279, 'Toledo', 'do Pinhal', 'Boa Esperança', '85909-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10280, 'Londrina', 'do Pinhão', 'Marabá', '86035-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10281, 'Cascavel', 'do Pinhão', 'Cataratas', '85818-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10282, 'Colombo', 'do Pinheiro', 'Parque do Embu', '83414-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10283, 'Londrina', 'do Pinho', 'Marumbi', '86071-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10284, 'Colombo', 'do Pintagol', 'Planta Santa Tereza', '83401-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10285, 'Cascavel', 'do Pintor', 'Universitário', '85819-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10286, 'Colombo', 'do Piriquito', 'Jardim Ana Rosa II', '83401-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10287, 'Ponta Grossa', 'do Policial', 'Periquitos', '84065-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10288, 'Londrina', 'do Polo Aquático', 'Jardim Olímpico', '86056-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10289, 'Colombo', 'do Porto', 'Parque Residencial Santa Terezinha', '83408-760', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10290, 'Pato Branco', 'do Príncipe', 'São Cristóvão', '85508-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10291, 'Ponta Grossa', 'do Professor', 'Periquitos', '84065-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10292, 'Colombo', 'do Quiri', 'Parque do Embu', '83414-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10293, 'Ponta Grossa', 'do Radialista', 'Periquitos', '84065-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10294, 'Curitiba', 'do Radialista', 'Rebouças', '80230-170', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10295, 'Telêmaco Borba', 'do Recanto', 'Área 02', '84267-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10296, 'Curitiba', 'do Redentor', 'São Francisco', '80520-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10297, 'Colombo', 'do Rio', 'Vila Campo Alto', '83408-327', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10298, 'Paranaguá', 'do Rócio', 'Alboitt', '83221-595', 'Estrada Velha', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10299, 'Paranaguá', 'do Rócio', 'Industrial', '83203-785', 'Estrada Velha', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10300, 'Ponta Grossa', 'do Rosário', 'Centro', '84010-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10301, 'Toledo', 'do Rosário', 'Parque Residencial Pancera', '85902-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10302, 'Cascavel', 'do Rosário', 'Ciro Nardi', '85802-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10303, 'Colombo', 'do Rosário', 'Centro', '83414-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10304, 'Castro', 'do Rosário', 'Centro', '84165-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10305, 'Curitiba', 'do Rosário', 'Centro', '80020-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10306, 'São José dos Pinhais', 'do Rotary', 'São Cristóvão', '83005-165', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10307, 'Londrina', 'do Rouxinol', 'Waldemar Hauer', '86030-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10308, 'São José dos Pinhais', 'do Rouxinol', 'Afonso Pena', '83045-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10309, 'Colombo', 'do Sabiá', 'Jardim Ana Rosa II', '83401-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10310, 'Londrina', 'do Sabiá-do-campo', 'Rui Barbosa', '86031-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10311, 'Londrina', 'do Salto Triplo', 'Jardim Olímpico', '86056-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10312, 'Londrina', 'do Sanhaço', 'Paraíso', '86078-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10313, 'Ponta Grossa', 'do Sanhaço', 'Chapada', '84064-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10314, 'Colombo', 'do Sanhaço', 'Jardim Ana Rosa II', '83401-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10315, 'Colombo', 'do Sassafrás', 'Parque do Embu', '83414-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10316, 'Curitiba', 'do Semeador', 'Cidade Industrial', '81270-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10317, 'Francisco Beltrão', 'do Seminário', 'Miniguaçu', '85605-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10318, 'Apucarana', 'do Seminário', 'Jardim Bela Vista', '86811-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10319, 'Cambé', 'do Senado', 'Jardim Casa Grande', '86191-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10320, 'Curitiba', 'do Servidor Público', 'Cidade Industrial', '81315-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10321, 'Ponta Grossa', 'do Siriri', 'Chapada', '84064-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10322, 'Londrina', 'do Sol', 'Sol', '86070-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10323, 'Cambé', 'do Sol', 'Parque Maracanã', '86185-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10324, 'Cascavel', 'do Sol', 'Santa Felicidade', '85803-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10325, 'Curitiba', 'do Sol', 'Sítio Cercado', '81910-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10326, 'Londrina', 'do Tamarino', 'Marabá', '86035-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10327, 'Campo Largo', 'do Tanque', 'Jardim Clímax', '83608-250', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10328, 'Colombo', 'do Tarumã', 'Jardim Nossa Senhora das Graças', '83407-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10329, 'Londrina', 'do Teatro', 'Santa Rita 1', '86071-495', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10330, 'Curitiba', 'do Terço', 'Bigorrilho', '80710-430', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10331, 'Colombo', 'do Timbo', 'Parque do Embu', '83414-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10332, 'Pato Branco', 'do Torto', 'Morro da Cruz', '85505-185', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10333, 'Curitiba', 'do Trabalho', 'Pinheirinho', '81880-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10334, 'Colombo', 'do Tracua', 'Parque Monte Castelo', '83411-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10335, 'Curitiba', 'do Tratorista', 'Boqueirão', '81730-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10336, 'Cascavel', 'do Trevo', 'Guarujá', '85804-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10337, 'Londrina', 'do Trevo-branco', 'Ouro Branco', '86042-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10338, 'Cascavel', 'do Trigo', 'Cataratas', '85818-737', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10339, 'Guarapuava', 'do Triunfo', 'Conradinho', '85035-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10340, 'Londrina', 'do Tucano', 'Indústrias Leves', '86030-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10341, 'Colombo', 'do Tucano', 'Jardim Ana Rosa I', '83401-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10342, 'Londrina', 'do Tuím', 'Vitória Régia', '86038-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10343, 'Curitiba', 'do Tupipiá', 'Uberaba', '81550-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10344, 'Londrina', 'do Uirapuru', 'Waldemar Hauer', '86030-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10345, 'Colombo', 'do Uirapuru', 'Jardim Santa Cruz', '83401-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10346, 'Cascavel', 'do Vale', 'Nova Cidade', '85803-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10347, 'Curitiba', 'do Verbo Divino', 'Bom Retiro', '80520-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10348, 'Curitiba', 'do Viamão', 'Guabirotuba', '81520-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10349, 'Ponta Grossa', 'do Vigilante', 'Periquitos', '84065-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10350, 'Londrina', 'do Voleibol', 'Jardim Olímpico', '86056-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10351, 'Colombo', 'do Xaxim', 'Vila Florestal Grajaú', '83411-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10352, 'Arapongas', 'Dodo', 'Parque Siomara', '86705-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10353, 'Curitiba', 'Dogivaldo Antônio da Silva', 'Cidade Industrial', '81350-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10354, 'Almirante Tamandaré', 'Doglacir Colodel', 'Jardim Dona Belizaria', '83513-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10355, 'Curitiba', 'Dognor Cunha', 'Novo Mundo', '81050-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10356, 'Londrina', 'Dois', 'Três Marcos', '86046-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10357, 'Foz do Iguaçu', 'Dois', 'Conjunto Residencial Yang Ming', '85854-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10358, 'Foz do Iguaçu', 'Dois', 'Três Pinheiros', '85856-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10359, 'Piraquara', 'Dois', 'Chácara Águas Claras', '83309-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10360, 'Paranavaí', 'Dois', 'Jardim Maringá', '87709-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10361, 'Ponta Grossa', 'Dois', 'Olarias', '84026-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10362, 'Paranavaí', 'Dois', 'Conjunto Dona Josefa', '87708-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10363, 'Ponta Grossa', 'Dois', 'Chapada', '84062-017', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10364, 'Ponta Grossa', 'Dois', 'Chapada', '84064-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10365, 'Ponta Grossa', 'Dois', 'Cará-cará', '84043-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10366, 'Ponta Grossa', 'Dois', 'Contorno', '84060-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10367, 'Ponta Grossa', 'Dois', 'Boa Vista', '84072-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10368, 'Piraquara', 'Dois', 'Chácara Águas Claras', '83309-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10369, 'Paranavaí', 'Dois', 'Jardim Marcela', '87706-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10370, 'Piraquara', 'Dois', 'Chácara Águas Claras', '83309-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10371, 'Londrina', 'Dois', 'Residencial Vila Romana', '86031-815', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10372, 'Ponta Grossa', 'Dois', 'Uvaranas', '84025-590', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10373, 'Ponta Grossa', 'Dois', 'Chapada', '84063-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10374, 'Ponta Grossa', 'Dois', 'Uvaranas', '84030-477', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10375, 'Ponta Grossa', 'Dois', 'Contorno', '84060-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10376, 'Ponta Grossa', 'Dois', 'Chapada', '84062-018', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10377, 'Ponta Grossa', 'Dois', 'Oficinas', '84035-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10378, 'Ponta Grossa', 'Dois', 'Uvaranas', '84030-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10379, 'Ponta Grossa', 'Dois', 'Jardim Carvalho', '84016-506', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10380, 'Ponta Grossa', 'Dois', 'Uvaranas', '84030-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10381, 'Ponta Grossa', 'Dois', 'Uvaranas', '84022-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10382, 'Paranaguá', 'Dois', 'Jardim Paraná', '83215-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10383, 'Paranaguá', 'Dois', 'Vila Garcia', '83218-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10384, 'Maringá', 'Dois', 'Chácaras Aeroporto', '87053-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10385, 'Ponta Grossa', 'Dois', 'Chapada', '84062-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10386, 'Ponta Grossa', 'Dois', 'Uvaranas', '84026-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10387, 'Ponta Grossa', 'Dois', 'Uvaranas', '84032-456', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10388, 'Ponta Grossa', 'Dois', 'Jardim Carvalho', '84016-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10389, 'Ponta Grossa', 'Dois', 'Estrela', '84050-275', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10390, 'Umuarama', 'Dois', 'Jardim Monte Carlo', '87506-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10391, 'Umuarama', 'Dois', 'Jardim São Cristóvão', '87507-356', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10392, 'Umuarama', 'Dois', 'Jardim Indaiá', '87501-590', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10393, 'Umuarama', 'Dois', 'Parque Industrial Comercial Novo Horizonte', '87507-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10394, 'Umuarama', 'Dois', 'Jardim Beira Rio', '87507-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10395, 'Sarandi', 'Dois', 'Jardim Independência I', '87114-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10396, 'Telêmaco Borba', 'Dois', 'Vila Santa Rita', '84263-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10397, 'Umuarama', 'Dois', 'Jardim Maria Lúcia', '87501-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10398, 'Almirante Tamandaré', 'Dois', 'Jardim das Oliveiras', '83502-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10399, 'Campo Largo', 'Dois', 'Jardim Santa Luzia', '83606-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10400, 'Almirante Tamandaré', 'Dois', 'Loteamento Recanto dos Papagaios', '83512-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10401, 'Campo Largo', 'Dois', 'Vila São Luiz', '83608-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10402, 'Campo Largo', 'Dois', 'Vila Conceição', '83608-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10403, 'Campo Largo', 'Dois', 'Jardim Lorenzete', '83603-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10404, 'Campo Largo', 'Dois', 'Loteamento São Gerônimo', '83606-176', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10405, 'Campo Largo', 'Dois', 'Jardim Paraíso Mineral', '83606-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10406, 'Almirante Tamandaré', 'Dois', 'Loteamento Marinoni', '83508-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10407, 'Almirante Tamandaré', 'Dois', 'Jardim Dona Wanda', '83514-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10408, 'Almirante Tamandaré', 'Dois', 'Jardim Maria Luiza', '83514-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10409, 'Almirante Tamandaré', 'Dois', 'Jardim Tatiana', '83513-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10410, 'Almirante Tamandaré', 'Dois', 'São Miguel', '83511-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10411, 'Campo Largo', 'Dois', 'Jardim Florestal', '83602-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10412, 'Campo Largo', 'Dois', 'Vila Mariano Torres', '83608-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10413, 'Campo Largo', 'Dois', 'Vila Pompéia', '83608-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10414, 'Campo Largo', 'Dois', 'Jardim Keli Cristina', '83609-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10415, 'Campo Largo', 'Dois', 'Jardim Guarany I', '83608-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10416, 'Almirante Tamandaré', 'Dois', 'Jardim Valença', '83512-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10417, 'Campo Largo', 'Dois', 'Jardim Clímax', '83608-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10418, 'Campo Largo', 'Dois', 'Loteamento Helvidia', '83605-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10419, 'Campo Largo', 'Dois', 'Jardim das Palmeiras', '83602-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10420, 'Campo Largo', 'Dois', 'Jardim das Palmas', '83602-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10421, 'Almirante Tamandaré', 'Dois', 'Planta Bela Vista', '83514-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10422, 'Campo Largo', 'Dois', 'Jardim das Acácias', '83603-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10423, 'Almirante Tamandaré', 'Dois', 'Jardim Planalto', '83514-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10424, 'Almirante Tamandaré', 'Dois', 'Jardim Areias', '83514-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10425, 'Campo Largo', 'Dois', 'Núcleo Habitacional Mathias Batista', '83604-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10426, 'Foz do Iguaçu', 'Dois Irmãos', 'Jardim Paraná', '85867-657', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10427, 'Foz do Iguaçu', 'Dois Vizinhos', 'Jardim Lancaster', '85869-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10428, 'Francisco Beltrão', 'Dois Vizinhos', 'Marrecas', '85601-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10429, 'Curitiba', 'Dois Vizinhos', 'Xaxim', '81820-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10430, 'Apucarana', 'Dolor Antônio Felisbino', 'Jardim Pinheiros', '86803-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10431, 'Curitiba', 'Dolores da Silva', 'Alto Boqueirão', '81770-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10432, 'Curitiba', 'Dolores de Souza Pacheco', 'Boa Vista', '82650-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10433, 'Foz do Iguaçu', 'Dolores Duran', 'Conjunto Habitacional Plazza', '85862-225', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10434, 'Londrina', 'Dolores Duran', 'Jardim São João', '86027-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10435, 'Maringá', 'Dolores Duran', 'Conjunto Residencial Cidade Alta', '87053-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10436, 'Apucarana', 'Dolores Duran', 'Núcleo Habitacional Castelo Branco', '86812-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10437, 'Curitiba', 'Dolores Duran', 'Xaxim', '81810-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10438, 'Cambé', 'Dolores Garcia Burgo', 'Jardim José Favaro', '86183-787', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10439, 'Londrina', 'Dolores Garcia Nieiro', 'Monte Belo', '86041-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10440, 'Curitiba', 'Dolores Guedes', 'Tatuquara', '81480-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10441, 'Londrina', 'Dolores Maria Bruno', 'Califórnia', '86040-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10442, 'Londrina', 'Dolores Peralta', 'Waldemar Hauer', '86030-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10443, 'São José dos Pinhais', 'Dolovico Pissaia', 'Afonso Pena', '83050-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10444, 'Umuarama', 'Dom Afonso', 'Parque Dom Bosco', '87505-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10445, 'Umuarama', 'Dom Alberto', 'Parque Dom Bosco', '87505-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10446, 'Curitiba', 'Dom Alberto Gonçalves', 'Bom Retiro', '80520-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10447, 'Curitiba', 'Dom Alberto Gonçalves', 'Mercês', '80510-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10448, 'Guarapuava', 'Dom Álvaro Nunes Cabeza de Vaca', 'Batel', '85015-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10449, 'Umuarama', 'Dom Antonino', 'Parque Dom Bosco', '87505-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10450, 'Ponta Grossa', 'Dom Antônio Mazarotto', 'Jardim Carvalho', '84015-770', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10451, 'Londrina', 'Dom Aquino', 'Colonial', '86047-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10452, 'Toledo', 'Dom Armando Círio', 'Jardim Concórdia', '85906-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10453, 'Apucarana', 'Dom Armando Lombardi', 'Vila Brasil', '86802-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10454, 'Curitiba', 'Dom Ático', 'Seminário', '80240-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10455, 'Cascavel', 'Dom Avelar Brandão Vilela', 'Parque Verde', '85807-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10456, 'Umuarama', 'Dom Basílio', 'Parque Dom Bosco', '87505-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10457, 'Umuarama', 'Dom Bonifácio', 'Parque Dom Bosco', '87505-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10458, 'Londrina', 'Dom Bosco', 'Iguaçu', '86060-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10459, 'Guarapuava', 'Dom Bosco', 'Bonsucesso', '85045-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10460, 'Ponta Grossa', 'Dom Bosco', 'Neves', '84020-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10461, 'Umuarama', 'Dom Bosco', 'Parque Dom Bosco', '87505-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10462, 'Campo Mourão', 'Dom Bosco', 'Jardim Lar Paraná', '87305-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10463, 'Curitiba', 'Dom Bosco', 'Novo Mundo', '81050-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10464, 'Toledo', 'Dom Carmine Rocco', 'Jardim Canaã', '85914-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10465, 'Toledo', 'Dom Carmine Rocco', 'Parque Residencial Pancera', '85902-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10466, 'Foz do Iguaçu', 'Dom Carmino Rocco', 'Jardim Guaíra', '85855-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10467, 'Umuarama', 'Dom Eleutério', 'Parque Dom Bosco', '87505-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10468, 'Umuarama', 'Dom Eugênio', 'Parque Dom Bosco', '87505-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10469, 'Londrina', 'Dom Fernando', 'Aeroporto', '86036-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10470, 'Curitiba', 'Dom Geraldo Fernandes', 'Hauer', '81610-030', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10471, 'Londrina', 'Dom Henrique', 'Aeroporto', '86036-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10472, 'Umuarama', 'Dom Hilário', 'Parque Dom Bosco', '87505-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10473, 'Cascavel', 'Dom Inácio Klause', 'Interlagos', '85814-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10474, 'Campo Mourão', 'Dom Jaime Luiz Coelho', 'Jardim Lar Paraná', '87305-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10475, 'Curitiba', 'Dom João Braga', 'Vista Alegre', '80810-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10476, 'Cascavel', 'Dom João IV', 'Universitário', '85819-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10477, 'Londrina', 'Dom João VI', 'Jardim Guararapes', '86038-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10478, 'Ponta Grossa', 'Dom João VI', 'Jardim Carvalho', '84016-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10479, 'Piraquara', 'Dom João VI', 'Jardim Bela Vista', '83301-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10480, 'Pato Branco', 'Dom João VI', 'Alvorada', '85508-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10481, 'Sarandi', 'Dom João VI', 'Jardim Panorama', '87113-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10482, 'Sarandi', 'Dom João VI', 'Jardim Independência I', '87114-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10483, 'Apucarana', 'Dom João VI', 'Jardim Independência', '86811-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10484, 'Campo Mourão', 'Dom João VI', 'Jardim Lar Paraná', '87305-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10485, 'Almirante Tamandaré', 'Dom João VI', 'Vila Grécia', '83502-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10486, 'Curitiba', 'Dom João VI', 'Cajuru', '82900-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10487, 'Curitiba', 'Dom José de Camargo Barros', 'Cidade Industrial', '81350-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10488, 'Apucarana', 'Dom José Marello', 'Vila Feliz', '86808-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10489, 'Curitiba', 'Dom José Marello', 'Xaxim', '81710-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10490, 'Maringá', 'Dom Manoel da Silveira d''Elboux', 'Zona 05', '87015-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10491, 'Toledo', 'Dom Manoel da Silveira d''Elboux', 'Centro', '85900-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10492, 'Campo Largo', 'Dom Manoel da Silveira d''Elboux', 'Bom Jesus', '83601-410', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10493, 'Araucária', 'Dom Manoel da Silveira del''Boux', 'Thomaz Coelho', '83707-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10494, 'Cascavel', 'Dom Manoel Konner', 'Interlagos', '85814-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10495, 'Curitiba', 'Dom Manuel da Silveira d''Elboux', 'Tarumã', '82800-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10496, 'Curitiba', 'Dom Orione', 'Santa Quitéria', '80310-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10497, 'Curitiba', 'Dom Orione', 'Portão', '80330-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10498, 'Curitiba', 'Dom Oscar Romero', 'Pilarzinho', '82115-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10499, 'Umuarama', 'Dom Patrício', 'Parque Dom Bosco', '87505-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10500, 'Cascavel', 'Dom Pedrito', 'Canadá', '85813-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10501, 'Pato Branco', 'Dom Pedro', 'Trevo da Guarany', '85501-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10502, 'Laranjeiras do Sul', 'Dom Pedro I', 'Getúlio Vargas', '85304-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10503, 'Londrina', 'Dom Pedro I', 'Jardim Tatiani', '86070-570', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10504, 'Londrina', 'Dom Pedro I', 'Sabará I', '86066-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10505, 'Pato Branco', 'Dom Pedro I', 'São Cristóvão', '85508-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10506, 'Maringá', 'Dom Pedro I', 'Vila Ipiranga', '87045-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10507, 'Piraquara', 'Dom Pedro I', 'Jardim Bela Vista', '83301-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10508, 'Ponta Grossa', 'Dom Pedro I', 'Oficinas', '84036-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10509, 'Sarandi', 'Dom Pedro I', 'Jardim Independência II', '87113-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10510, 'Apucarana', 'Dom Pedro I', 'Vila Operária Stabile', '86811-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10511, 'Campo Mourão', 'Dom Pedro I', 'Jardim Lar Paraná', '87305-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10512, 'Cambé', 'Dom Pedro I', 'Parque Residencial Manela', '86185-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10513, 'Curitiba', 'Dom Pedro I', 'Água Verde', '80620-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10514, 'Londrina', 'Dom Pedro II', 'Jardim Tatiani', '86070-450', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10515, 'Londrina', 'Dom Pedro II', 'Jardim Bandeirantes', '86061-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10516, 'Guarapuava', 'Dom Pedro II', 'Dos Estados', '85035-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10517, 'Foz do Iguaçu', 'Dom Pedro II', 'Centro', '85851-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10518, 'Francisco Beltrão', 'Dom Pedro II', 'São Miguel', '85602-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10519, 'Laranjeiras do Sul', 'Dom Pedro II', 'Getúlio Vargas', '85304-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10520, 'Paranavaí', 'Dom Pedro II', 'Jardim Paulista', '87709-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10521, 'Piraquara', 'Dom Pedro II', 'Jardim Bela Vista', '83301-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10522, 'Ponta Grossa', 'Dom Pedro II', 'Nova Rússia', '84053-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10523, 'São José dos Pinhais', 'Dom Pedro II', 'Afonso Pena', '83050-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10524, 'Umuarama', 'Dom Pedro II', 'Zona IV', '87504-440', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10525, 'Toledo', 'Dom Pedro II', 'Centro', '85902-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10526, 'Toledo', 'Dom Pedro II', 'Conjunto Residencial Rossani', '85901-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10527, 'Toledo', 'Dom Pedro II', 'Jardim Parizzotto', '85914-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10528, 'Telêmaco Borba', 'Dom Pedro II', 'Jardim Bonavila', '84264-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10529, 'Cambé', 'Dom Pedro II', 'Centro', '86181-160', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10530, 'Cascavel', 'Dom Pedro II', 'Centro', '85812-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10531, 'Almirante Tamandaré', 'Dom Pedro II', 'Jardim Buenos Aires', '83507-267', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10532, 'Campo Mourão', 'Dom Pedro II', 'Jardim Lar Paraná', '87305-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10533, 'Campo Largo', 'Dom Pedro II', 'Centro', '83601-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10534, 'Cascavel', 'Dom Pedro II', 'Centro', '85812-121', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10535, 'Almirante Tamandaré', 'Dom Pedro II', 'Jardim Iracema', '83508-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10536, 'Castro', 'Dom Pedro II', 'Centro', '84165-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10537, 'Apucarana', 'Dom Pedro II', 'Jardim Ponta Grossa', '86805-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10538, 'Curitiba', 'Dom Pedro II', 'Batel', '80420-060', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10539, 'Umuarama', 'Dom Ricardo', 'Parque Dom Bosco', '87505-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10540, 'Campo Largo', 'Dom Rodrigo', 'Loteamento Itaboa', '83605-000', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10541, 'Apucarana', 'Dom Romeu Alberti', 'Jardim Bela Vista', '86811-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10542, 'São José dos Pinhais', 'Domarino Dal Negro', 'Colônia Rio Grande', '83025-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10543, 'Londrina', 'Domenico Rotunno', 'Jardim Vale Verde', '86040-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10544, 'Curitiba', 'Domenico Tonatto', 'Cajuru', '82950-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10545, 'Cascavel', 'Domiciliano Teobaldo Bresolim', 'São Cristóvão', '85816-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10546, 'Cascavel', 'Domiciliano Teobaldo Bresolin', 'Brasília', '85815-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10547, 'Ponta Grossa', 'Domício da Gama', 'Olarias', '84035-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10548, 'Guarapuava', 'Domício Marcondes', 'Boqueirão', '85023-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10549, 'Londrina', 'Domingas de Moraes Minikoski', 'Conjunto Habitacional  Alexandre Urbanas', '86037-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10550, 'Piraquara', 'Domingas Gubert Zeni', 'Vila São Cristóvão', '83305-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10551, 'Curitiba', 'Domingas Nicco', 'Mossunguê', '81200-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10552, 'São José dos Pinhais', 'Domingas Scroccaro Marochi', 'Águas Belas', '83010-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10553, 'Curitiba', 'Domingas Vigo Zaninelli', 'Boa Vista', '82510-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10554, 'Curitiba', 'Domingos Agabito Budel', 'Butiatuvinha', '82400-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10555, 'Campo Largo', 'Domingos Andreassa', 'Vila Nova', '83605-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10556, 'Londrina', 'Domingos Antônio Marroni', 'Jardim Vale Verde', '86040-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10557, 'Curitiba', 'Domingos Antônio Moro', 'Pilarzinho', '82115-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10558, 'Curitiba', 'Domingos Baldan', 'Umbará', '81940-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10559, 'Curitiba', 'Domingos Batista Vizoli', 'Portão', '81070-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10560, 'Curitiba', 'Domingos Benatto', 'Butiatuvinha', '82320-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10561, 'Francisco Beltrão', 'Domingos Bertaiolli', 'Pinheirinho', '85606-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10562, 'Londrina', 'Domingos Bianchi', 'Cafezal 1', '86049-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10563, 'Londrina', 'Domingos Biasoni', 'Milton Gavetti', '86046-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10564, 'Cascavel', 'Domingos Bonavigo', 'Santa Felicidade', '85803-326', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10565, 'Guarapuava', 'Domingos Caetano do Amaral', 'Santa Cruz', '85015-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10566, 'Londrina', 'Domingos Cantagalli', 'Heimtal', '86084-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10567, 'Colombo', 'Domingos Cavalli', 'Jardim Santa Cândida', '83402-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10568, 'Campo Largo', 'Domingos Cavalli', 'Centro', '83601-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10569, 'Piraquara', 'Domingos Colaço', 'Jardim Itiberê', '83314-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10570, 'Curitiba', 'Domingos Colatusso', 'Cidade Industrial', '81270-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10571, 'Londrina', 'Domingos Conrado', 'Colúmbia', '86057-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10572, 'Campo Largo', 'Domingos Cordeiro', 'Jardim São Vicente', '83602-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10573, 'Campo Largo', 'Domingos Cordeiro', 'Centro', '83601-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10574, 'Curitiba', 'Domingos Dallabona', 'Santa Felicidade', '82300-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10575, 'Almirante Tamandaré', 'Domingos de Abreu', 'Planta Almirante', '83508-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10576, 'Londrina', 'Domingos de Ramos Teixeira', 'Jardim San Diego', '86073-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10577, 'Curitiba', 'Domingos Farias de Mello', 'Cidade Industrial', '81230-398', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10578, 'Guarapuava', 'Domingos Fernandes', 'Santana', '85070-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10579, 'Maringá', 'Domingos Fernandes de Souza', 'Conjunto Habitacional Requião', '87047-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10580, 'Curitiba', 'Domingos Fernandes Maia', 'Bairro Alto', '82820-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10581, 'Ponta Grossa', 'Domingos Ferreira Maciel', 'Colônia Dona Luiza', '84045-280', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10582, 'Ponta Grossa', 'Domingos Ferreira Pinto', 'Boa Vista', '84071-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10583, 'Curitiba', 'Domingos Festa Filho', 'Barreirinha', '82700-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10584, 'Colombo', 'Domingos Fracaro', 'Jardim Belo Rincão', '83412-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10585, 'Foz do Iguaçu', 'Domingos Francisco Zardo', 'Loteamento Universitário das Américas', '85870-597', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10586, 'Curitiba', 'Domingos Gabardo', 'Capão Raso', '81130-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10587, 'Curitiba', 'Domingos Giacomassi', 'Campo Comprido', '81220-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10588, 'Curitiba', 'Domingos Gomes de Oliveira', 'Campo de Santana', '81490-175', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10589, 'Curitiba', 'Domingos Gonçalves', 'Sítio Cercado', '81900-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10590, 'Umuarama', 'Domingos Gonçalves de Paula', 'Zona V', '87504-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10591, 'Colombo', 'Domingos Goradin', 'Jardim Belo Rincão', '83412-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10592, 'São José dos Pinhais', 'Domingos Grebogi', 'Zaniolo', '83025-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10593, 'Curitiba', 'Domingos Greca', 'Boa Vista', '82540-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10594, 'Curitiba', 'Domingos Gulin', 'Butiatuvinha', '82400-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10595, 'Maringá', 'Domingos Herrerias', 'Parque Residencial Aeroporto', '87055-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10596, 'Curitiba', 'Domingos Imbronizio', 'Mossunguê', '81200-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10597, 'Ponta Grossa', 'Domingos Jaguaribe', 'Uvaranas', '84032-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10598, 'Curitiba', 'Domingos Jorge Velho', 'Sítio Cercado', '81935-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10599, 'Guarapuava', 'Domingos Jorge Velho', 'Primavera', '85050-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10600, 'Cambé', 'Domingos Jorge Velho', 'Jardim Riviera', '86187-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10601, 'Colombo', 'Domingos Jorge Velho', 'Jardim Quitandinha', '83409-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10602, 'Cascavel', 'Domingos José Coutinho', 'São Cristóvão', '85816-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10603, 'Curitiba', 'Domingos Kurecki', 'Tatuquara', '81880-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10604, 'Curitiba', 'Domingos Leonardi', 'Tatuquara', '81480-187', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10605, 'Paranavaí', 'Domingos Lourenço de Almeida', 'Jardim Ipê', '87707-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10606, 'Pinhais', 'Domingos Maceno', 'Jardim Las Palmas', '83325-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10607, 'Guarapuava', 'Domingos Marcondes', 'Santana', '85070-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10608, 'Araucária', 'Domingos Martins Belo', 'Capela Velha', '83706-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10609, 'Pato Branco', 'Domingos Mattos', 'Cristo Rei', '85506-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10610, 'Maringá', 'Domingos Miao', 'Jardim Sol', '87023-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10611, 'Colombo', 'Domingos Mocelin', 'Jardim Belo Rincão', '83412-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10612, 'Francisco Beltrão', 'Domingos Moura', 'Marrecas', '85601-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10613, 'Ponta Grossa', 'Domingos Nascimento', 'Chapada', '84062-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10614, 'Curitiba', 'Domingos Nascimento', 'São Francisco', '80520-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10615, 'Toledo', 'Domingos Pasqualli', 'Jardim Pasqualli', '85905-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10616, 'Paranaguá', 'Domingos Peneda', 'Ponta do Caju', '83206-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10617, 'Paranaguá', 'Domingos Peneda', 'Itiberê', '83209-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10618, 'São José dos Pinhais', 'Domingos Perbiche', 'Colônia Murici', '83085-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10619, 'Curitiba', 'Domingos Pigatto', 'Tingui', '82620-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10620, 'Sarandi', 'Domingos Pilegi', 'Parque São Pedro', '87112-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10621, 'Almirante Tamandaré', 'Domingos Prosdócimo', 'Jardim Primavera', '83506-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10622, 'São José dos Pinhais', 'Domingos Ribeiro', 'Ipê', '83055-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10623, 'Curitiba', 'Domingos Ribeiro Batista', 'Cidade Industrial', '81170-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10624, 'Paranavaí', 'Domingos Sanches', 'Parque Morumbi', '87703-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10625, 'Francisco Beltrão', 'Domingos Santin', 'Marrecas', '85601-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10626, 'Almirante Tamandaré', 'Domingos Scucato', 'Jardim Monte Santo', '83501-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10627, 'Curitiba', 'Domingos Stival', 'Butiatuvinha', '82400-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10628, 'Colombo', 'Domingos Strapasson', 'Santa Gema', '83407-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10629, 'Curitiba', 'Domingos Strapasson', 'Santa Felicidade', '82320-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10630, 'Curitiba', 'Domingos Tomaz', 'Sítio Cercado', '81925-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10631, 'Cascavel', 'Domingos Toquetto', 'Santos Dumont', '85804-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10632, 'Ponta Grossa', 'Domingos Tozetto', 'Uvaranas', '84030-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10633, 'Campo Largo', 'Domingos Vaz da Silva', 'Jardim Busmayer', '83606-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10634, 'Umuarama', 'Domingos Zago', 'Jardim dos Príncipes', '87502-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10635, 'Francisco Beltrão', 'Domingos Zanette', 'Miniguaçu', '85605-565', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10636, 'Curitiba', 'Domingos Zanlorenzi', 'Campo Comprido', '81270-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10637, 'Curitiba', 'Dona Alice Tibiriçá', 'Bigorrilho', '80730-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10638, 'Curitiba', 'Dona Ana Neri', 'Guabirotuba', '81510-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10639, 'Guarapuava', 'Dona Anastácia', 'Boqueirão', '85023-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10640, 'Londrina', 'Dona Ângela Munhoz Moreno', 'Estados', '86082-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10641, 'Maringá', 'Dona Angelina', 'Jardim Mandacaru', '87080-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10642, 'Maringá', 'Dona Aziza Mariana Jorge', 'Parque das Grevíleas', '87025-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10643, 'Curitiba', 'Dona Bárbara Cid', 'Uberaba', '81580-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10644, 'Curitiba', 'Dona Branca do Nascimento Miranda', 'Pilarzinho', '82120-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10645, 'Almirante Tamandaré', 'Dona Brasília', 'Jardim Alvorada', '83505-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10646, 'Londrina', 'Dona Carlota', 'Cambará', '86039-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10647, 'Curitiba', 'Dona Eleusina Plaisant', 'Santa Quitéria', '80310-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10648, 'Curitiba', 'Dona Emma Hecke de Castro', 'Cajuru', '82970-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10649, 'Pato Branco', 'Dona Ernestina', 'Santa Terezinha', '85501-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10650, 'Almirante Tamandaré', 'Dona Eva', 'Jardim Arco Íris', '83504-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10651, 'Pinhais', 'Dona Hermínia Lupion', 'Vila Maria Antonieta', '83331-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10652, 'Curitiba', 'Dona Hermínia Lupion', 'Vista Alegre', '80820-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10653, 'Curitiba', 'Dona Honorina Valente', 'São Francisco', '80520-050', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10654, 'Almirante Tamandaré', 'Dona Idalina', 'Jardim Alvorada', '83505-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10655, 'Paranaguá', 'Dona Julieta', 'Vila Garcia', '83218-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10656, 'Maringá', 'Dona Leonor de Held', 'Jardim Alvorada', '87033-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10657, 'Londrina', 'Dona Leopoldina', 'Brasília', '86039-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10658, 'Foz do Iguaçu', 'Dona Lotte Knop Campos', 'Loteamento Universitário das Américas', '85870-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10659, 'Toledo', 'Dona Lúcia', 'Jardim Modelo', '85906-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10660, 'Toledo', 'Dona Lúcia', 'Jardim Planalto', '85904-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10661, 'Paranaguá', 'Dona Ludovica Borio', 'Serraria do Rocha', '83221-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10662, 'Paranaguá', 'Dona Ludovica Borio', 'Raia', '83206-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10663, 'Maringá', 'Dona Maria Gaspar Pedrosa Moleirinho', 'Jardim Novo Horizonte', '87010-120', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10664, 'Paranaguá', 'Dona Mariquinha J. Ramos', 'Ponta do Caju', '83206-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10665, 'Almirante Tamandaré', 'Dona Natália', 'Planta São Venâncio', '83504-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10666, 'Curitiba', 'Dona Nene', 'Atuba', '82860-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10667, 'Maringá', 'Dona Nilza de Oliveira Pipino', 'Vila Bosque', '87010-490', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10668, 'Curitiba', 'Dona Paulina', 'Bacacheri', '82515-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10669, 'Curitiba', 'Dona Sazá Lattes', 'Uberaba', '81540-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10670, 'Maringá', 'Dona Sophia Rasgulaeff', 'Jardim Alvorada', '87033-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10671, 'Maringá', 'Dona Sophia Rasgulaeff', 'Jardim Oásis', '87043-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10672, 'Maringá', 'Dona Sophia Rasgulaeff', 'Conjunto Residencial Parigot de Souza', '87047-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10673, 'Curitiba', 'Donaide Silveira da Costa', 'Tarumã', '82800-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10674, 'Foz do Iguaçu', 'Donato Colombelli', 'Jardim Bandeirantes', '85862-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10675, 'Curitiba', 'Donato Gracco', 'Sítio Cercado', '81920-768', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10676, 'Francisco Beltrão', 'Donatti', 'Alvorada', '85601-565', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10677, 'Curitiba', 'Donizete Custódio da Silva', 'Cidade Industrial', '81305-600', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10678, 'Curitiba', 'Doraci Dolores Keretch', 'Pinheirinho', '81870-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10679, 'Londrina', 'Doracy Machado', 'Residencial Portal de Piza', '86041-297', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10680, 'Ponta Grossa', 'Doralicio Correia', 'Uvaranas', '84031-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10681, 'Arapongas', 'Dó-ré-mi', 'Jardim Morumbi', '86708-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10682, 'Piraquara', 'Dorico Martins dos Santos', 'Jardim Caiçara', '83314-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10683, 'Curitiba', 'Dorilda Simões Vieira', 'Cidade Industrial', '81315-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10684, 'Araucária', 'Dorinha Jess Sfendrych', 'Estação', '83705-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10685, 'São José dos Pinhais', 'Dorinha Juck Cortes', 'Roseira', '83070-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10686, 'Guarapuava', 'Dorins', 'Vila Carli', '85040-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10687, 'Cambé', 'Dorins', 'Jardim Tupi', '86183-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10688, 'Curitiba', 'Dorival Almir Zagonel', 'Jardim Botânico', '80215-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10689, 'Londrina', 'Dorival Cavassani', 'Ernani de Moura Lima', '86037-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10690, 'Campo Largo', 'Dorival Costa', 'Vila Torres I', '83609-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10691, 'Foz do Iguaçu', 'Dorival de Brito', 'Parque Morumbi I', '85858-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10692, 'Castro', 'Dorival Garcia Kiel', 'Castroville', '84178-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10693, 'Curitiba', 'Dorival Pereira Jorge', 'Vila Izabel', '80320-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10694, 'Londrina', 'Dorival Prado de Camargo', 'Alto da Boa Vista', '86083-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10695, 'Paranavaí', 'Dorivaldo Peron', 'Jardim Canadá', '87708-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10696, 'Apucarana', 'Dorizon', 'Vila Vitória', '86802-265', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10697, 'Arapongas', 'Dorminhão', 'Parque Industrial II', '86703-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10698, 'Curitiba', 'Dorotéa Armelinda de Souza', 'Fazendinha', '81320-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10699, 'Curitiba', 'Dorothea Mercedes de Azevedo Pereira', 'Atuba', '82860-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10700, 'Castro', 'Dorothéa Wiedemann', 'Morada do Sol', '84172-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10701, 'Curitiba', 'Dorothy Pereira Garcia', 'São Braz', '82315-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10702, 'Piraquara', 'Dorvalina dos Santos', 'Planta Santa Lúcia', '83311-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10703, 'Curitiba', 'Dorvalino Moura Silva', 'Cidade Industrial', '81240-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10704, 'Guarapuava', 'dos Abacateiros', 'Conradinho', '85060-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10705, 'Londrina', 'dos Abacateiros', 'Interlagos', '86035-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10706, 'Colombo', 'dos Abacateiros', 'Jardim Nossa Senhora das Graças', '83407-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10707, 'Almirante Tamandaré', 'dos Abolicionistas', 'Jardim Kokot', '83505-122', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10708, 'Pinhais', 'dos Acauãs', 'Loteamento Alphaville Graciosa', '83327-156', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10709, 'Londrina', 'dos Açores', 'São Lourenço', '86026-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10710, 'Guarapuava', 'dos Açougueiros', 'Núcleo Habitacional 2000', '85064-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10711, 'Guarapuava', 'dos Administradores', 'Núcleo Habitacional 2000', '85064-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10712, 'Guarapuava', 'dos Advogados', 'Núcleo Habitacional 2000', '85064-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10713, 'Guarapuava', 'dos Agricultores', 'Núcleo Habitacional 2000', '85064-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10714, 'Londrina', 'dos Agricultores', 'Jardim União da Vitória', '86044-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10715, 'Apucarana', 'dos Agricultores', 'Colônia dos Novos Produtores', '86801-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10716, 'Telêmaco Borba', 'dos Aicás', 'Nossa Senhora do Perpétuo Socorro', '84265-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10717, 'Campo Mourão', 'dos Álamos', 'Jardim Araucária', '87301-380', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10718, 'Foz do Iguaçu', 'dos Alecrins', 'Vila Adriana', '85854-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10719, 'Maringá', 'dos Alecrins', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10720, 'Curitiba', 'dos Alecrins', 'Barreirinha', '82700-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10721, 'Londrina', 'dos Alfaiates', 'Jardim União da Vitória', '86044-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10722, 'Curitiba', 'dos Alfeneiros', 'Barreirinha', '82700-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10723, 'Curitiba', 'dos Alfeneiros', 'Boa Vista', '82560-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10724, 'Londrina', 'dos Amigos', 'Carnascialli', '86077-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10725, 'Londrina', 'dos Andes', 'Tabapoã', '86025-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10726, 'Maringá', 'dos Andradas', 'Zona 05', '87015-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10727, 'Pato Branco', 'dos Andradas', 'Cristo Rei', '85506-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10728, 'Laranjeiras do Sul', 'dos Angicos', 'Cristo Rei', '85304-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10729, 'Foz do Iguaçu', 'dos Antúrios', 'Jardim Eliza I', '85854-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10730, 'Londrina', 'dos Antúrios', 'Ouro Branco', '86042-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10731, 'Maringá', 'dos Antúrios', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10732, 'Telêmaco Borba', 'dos Antúrios', 'Jardim Alegre', '84268-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10733, 'Colombo', 'dos Antúrios', 'Jardim das Violetas', '83411-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10734, 'Cascavel', 'dos Antúrios', 'Guarujá', '85804-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10735, 'Curitiba', 'dos Antúrios', 'Cidade Industrial', '81310-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10736, 'Telêmaco Borba', 'dos Apaches', 'Nossa Senhora do Perpétuo Socorro', '84265-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10737, 'Ponta Grossa', 'dos Aposentados', 'Centro', '84020-660', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10738, 'Almirante Tamandaré', 'dos Apóstolos', 'Jardim Monterrey', '83507-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10739, 'Pinhais', 'dos Araçaris', 'Loteamento Alphaville Graciosa', '83327-148', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10740, 'Pinhais', 'dos Aracas', 'Loteamento Alphaville Graciosa', '83327-118', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10741, 'Almirante Tamandaré', 'dos Araças', 'Loteamento Chico Mendes', '83505-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10742, 'Guarapuava', 'dos Arquitetos', 'Núcleo Habitacional 2000', '85064-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10743, 'Londrina', 'dos Arquitetos', 'Jardim União da Vitória', '86044-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10744, 'Londrina', 'dos Artesãos', 'Newton Guimarães', '86082-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10745, 'Londrina', 'dos Astronautas', 'Paraíso', '86078-255', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10746, 'Francisco Beltrão', 'dos Bancarios', 'Vila Nova', '85605-290', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10747, 'Umuarama', 'dos Bancários', 'Parque 1º de Maio', '87509-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10748, 'Toledo', 'dos Bandeirantes', 'Jardim Paulista', '85910-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10749, 'Cambé', 'dos Bandeirantes', 'Jardim Riviera', '86187-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10750, 'Curitiba', 'dos Bandeirantes', 'Guabirotuba', '81520-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10751, 'Piraquara', 'dos Batistas', 'Jardim Esmeralda', '83301-370', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10752, 'Pinhais', 'dos Beija-flores', 'Loteamento Alphaville Graciosa', '83327-157', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10753, 'Piraquara', 'dos Beija-flores', 'Recreio da Serra', '83305-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10754, 'Curitiba', 'dos Beija-flores', 'Novo Mundo', '81020-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10755, 'Almirante Tamandaré', 'dos Bem-te-vis', 'Jardim Marize', '83507-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10756, 'Curitiba', 'dos Bem-te-vis', 'Novo Mundo', '81020-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10757, 'Curitiba', 'dos Bico-de-lacres', 'Novo Mundo', '81020-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10758, 'Guarapuava', 'dos Biólogos', 'Núcleo Habitacional 2000', '85064-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10759, 'Guarapuava', 'dos Bombeiros', 'Núcleo Habitacional 2000', '85064-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10760, 'Curitiba', 'dos Bombeiros', 'Cidade Industrial', '81450-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10761, 'Pinhais', 'dos Bosques', 'Capoeira Grande', '83329-000', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10762, 'São José dos Pinhais', 'dos Bosques', 'São Sebastião', '83075-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10763, 'Foz do Iguaçu', 'dos Brilhantes', 'Parque Ouro Verde', '85854-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10764, 'Foz do Iguaçu', 'dos Brilhantes', 'Parque Ouro Verde', '85855-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10765, 'Pinhais', 'dos Butiás', 'Loteamento Alphaville Graciosa', '83327-136', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10766, 'Guarapuava', 'dos Butiazeiros', 'Morro Alto', '85067-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10767, 'Colombo', 'dos Butiazeiros', 'Jardim Nossa Senhora das Graças', '83407-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10768, 'Cambé', 'dos Caçadores', 'Jardim Santo Antônio', '86182-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10769, 'Colombo', 'dos Cactos', 'Vila Vale das Flores', '83411-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10770, 'Guarapuava', 'dos Cadastradores', 'Núcleo Habitacional 2000', '85064-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10771, 'Cascavel', 'dos Caetés', 'Guarujá', '85804-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10772, 'Maringá', 'dos Cafezais', 'Zona 06', '87015-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10773, 'Piraquara', 'dos Caiapós', 'Vila Dalila', '83303-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10774, 'Paranaguá', 'dos Cajueiros', 'Jardim Samambaia', '83212-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10775, 'Guarapuava', 'dos Canários', 'Boqueirão', '85022-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10776, 'Laranjeiras do Sul', 'dos Canários', 'Vila Industrial', '85303-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10777, 'Piraquara', 'dos Canários', 'Planta Bosque Centenário', '83311-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10779, 'São José dos Pinhais', 'dos Canários', 'Afonso Pena', '83045-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10780, 'Sarandi', 'dos Canários', 'Conjunto Floresta', '87112-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10781, 'Telêmaco Borba', 'dos Canários', 'Jardim São Silvestre', '84270-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10782, 'Campo Largo', 'dos Canários', 'Jardim Lise', '83605-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10783, 'Cascavel', 'dos Canários', 'Floresta', '85814-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10784, 'Almirante Tamandaré', 'dos Canários', 'Loteamento Montparnasse', '83508-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10785, 'Curitiba', 'dos Canários', 'Novo Mundo', '81020-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10786, 'Curitiba', 'dos Capuchinhos', 'Mercês', '80810-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10787, 'Guarapuava', 'dos Caquizeiros', 'São Cristóvão', '85060-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10788, 'Londrina', 'dos Caquizeiros', 'Interlagos', '86035-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10789, 'Colombo', 'dos Caquizeiros', 'Jardim Nossa Senhora das Graças', '83407-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10790, 'Guarapuava', 'dos Cardeais', 'São Cristóvão', '85063-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10791, 'São José dos Pinhais', 'dos Cardeais', 'Afonso Pena', '83045-670', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10792, 'Pato Branco', 'dos Cardeais', 'Planalto', '85509-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10793, 'Piraquara', 'dos Cardeais', 'Recreio da Serra', '83305-510', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10794, 'Cambé', 'dos Carijós', 'Jardim Tupi', '86183-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10795, 'Londrina', 'dos Carpinteiros', 'Newton Guimarães', '86082-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10796, 'Guarapuava', 'dos Carpinteiros', 'Núcleo Habitacional 2000', '85064-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10797, 'Umuarama', 'dos Carpinteiros', 'Parque 1º de Maio', '87509-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10798, 'Londrina', 'dos Carteiros', 'Jardim União da Vitória', '86044-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10799, 'Pinhais', 'dos Carvalhos', 'Loteamento Alphaville Graciosa', '83327-119', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10800, 'Telêmaco Borba', 'dos Cataguases', 'Jardim Bonavila', '84264-120', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10801, 'Laranjeiras do Sul', 'dos Cedros', 'Cristo Rei', '85304-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10802, 'Maringá', 'dos Cedros', 'Parque Palmeiras', '87023-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10803, 'Pinhais', 'dos Cedros', 'Loteamento Alphaville Graciosa', '83327-117', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10804, 'São José dos Pinhais', 'dos Cedros', 'Rio Pequeno', '83085-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10805, 'Sarandi', 'dos Cedros', 'Jardim Monterey', '87112-797', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10806, 'Campo Largo', 'dos Cedros', 'Vila Dom Pedro II', '83608-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10807, 'Curitiba', 'dos Cedros', 'Barreirinha', '82700-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10808, 'Campo Mourão', 'dos Chacareiros', 'Jardim Tropical II', '87310-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10809, 'Maringá', 'dos Chorões', 'Parque Palmeiras', '87023-560', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10810, 'Guarapuava', 'dos Cisnes', 'Batel', '85015-600', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10811, 'Paranaguá', 'dos Cisnes', 'Jardim Esperança', '83218-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10812, 'Campo Mourão', 'dos Cisnes', 'Conjunto Habitacional Milton Luiz Pereira', '87306-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10813, 'Guarapuava', 'dos Coleiros', 'Boqueirão', '85022-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10814, 'Piraquara', 'dos Coleiros', 'Recreio da Serra', '83305-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10815, 'Pinhais', 'dos Colibris', 'Loteamento Alphaville Graciosa', '83327-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10816, 'Piraquara', 'dos Colibris', 'Recreio da Serra', '83305-520', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10817, 'Campo Mourão', 'dos Colonizadores', 'Jardim Francisco Ferreira Albuquerque', '87309-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10818, 'Piraquara', 'dos Coloreiros', 'Recreio da Serra', '83305-500', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10819, 'Londrina', 'dos Comerciantes', 'Jardim União da Vitória', '86044-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10820, 'Umuarama', 'dos Comerciantes', 'Parque 1º de Maio', '87509-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10821, 'Umuarama', 'dos Construtores', 'Parque 1º de Maio', '87509-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10822, 'Curitiba', 'dos Contabilistas', 'Uberaba', '81560-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10823, 'Guarapuava', 'dos Contadores', 'Núcleo Habitacional 2000', '85064-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10824, 'Guarapuava', 'dos Coqueirais', 'Morro Alto', '85067-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10825, 'Londrina', 'dos Coqueiros', 'Jardim Morumbi', '86035-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10826, 'Guarapuava', 'dos Coqueiros', 'Morro Alto', '85067-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10827, 'Maringá', 'dos Coqueiros', 'Parque das Bandeiras', '87023-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10828, 'Cambé', 'dos Coqueiros', 'Planta São Francisco', '86182-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10829, 'Almirante Tamandaré', 'dos Coqueiros', 'Loteamento Chico Mendes', '83505-769', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10830, 'Curitiba', 'dos Coqueiros', 'Bairro Alto', '82840-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10831, 'Londrina', 'dos Cozinheiros', 'Jardim União da Vitória', '86044-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10832, 'Foz do Iguaçu', 'dos Cravos', 'Jardim Eliza II', '85855-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10833, 'Londrina', 'dos Cravos', 'Ricardo', '86035-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10834, 'Maringá', 'dos Cravos', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10835, 'Paranaguá', 'dos Cravos', 'Conjunto Nilson Neves', '83215-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10836, 'São José dos Pinhais', 'dos Cravos', 'Afonso Pena', '83050-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10837, 'Pato Branco', 'dos Cravos', 'Novo Horizonte', '85507-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10838, 'Sarandi', 'dos Cravos', 'Jardim Verão', '87111-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10839, 'Umuarama', 'dos Cravos', 'Parque das Jaboticabeiras', '87509-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10840, 'Cascavel', 'dos Cravos', 'Guarujá', '85804-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10841, 'Araucária', 'dos Cravos', 'Campina da Barra', '83709-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10842, 'Curitiba', 'dos Cravos', 'Cidade Industrial', '81310-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10843, 'Foz do Iguaçu', 'dos Crisântemos', 'Jardim Santa Cecília', '85854-497', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10844, 'São José dos Pinhais', 'dos Crisântemos', 'Costeira', '83015-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10845, 'Umuarama', 'dos Crisântemos', 'Parque das Jaboticabeiras', '87509-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10846, 'Campo Mourão', 'dos Crisântemos', 'Jardim Santa Nilce II', '87308-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10847, 'Cascavel', 'dos Crisântemos', 'Guarujá', '85804-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10848, 'Colombo', 'dos Crisântemos', 'Parque Monte Castelo', '83411-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10849, 'Laranjeiras do Sul', 'dos Curiós', 'Vila Industrial', '85303-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10850, 'São José dos Pinhais', 'dos Curiós', 'Afonso Pena', '83045-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10851, 'Piraquara', 'dos Curiós', 'Recreio da Serra', '83305-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10852, 'Telêmaco Borba', 'dos Curiós', 'Jardim São Silvestre', '84270-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10853, 'Paranaguá', 'dos Dálias', 'Conjunto Nilson Neves', '83215-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10854, 'Guarapuava', 'dos Dentistas', 'Núcleo Habitacional 2000', '85064-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10855, 'Londrina', 'dos Desenhistas', 'Jardim União da Vitória', '86044-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10856, 'Guarapuava', 'dos Desenhistas', 'Núcleo Habitacional 2000', '85064-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10857, 'Curitiba', 'dos Dominicanos', 'Boa Vista', '82540-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10858, 'Curitiba', 'dos Dominicanos', 'Boa Vista', '82560-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10859, 'Guarapuava', 'dos Economistas', 'Núcleo Habitacional 2000', '85064-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10860, 'Curitiba', 'dos Editores', 'Mercês', '80410-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10861, 'Londrina', 'dos Eletrecistas', 'Newton Guimarães', '86082-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10862, 'Guarapuava', 'dos Eletricistas', 'Núcleo Habitacional 2000', '85064-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10863, 'Cambé', 'dos Emigrantes', 'Jardim São José', '86192-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10864, 'Campo Mourão', 'dos Encontros', 'Jardim Tropical II', '87310-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10865, 'Guarapuava', 'dos Engenheiros', 'Núcleo Habitacional 2000', '85064-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10866, 'Londrina', 'dos Escritores', 'Santa Rita 1', '86071-535', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10867, 'Colombo', 'dos Esportes', 'Vila Campo Alto', '83408-336', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10868, 'Sarandi', 'dos Estados', 'Jardim Castelo', '87112-567', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10869, 'Curitiba', 'dos Estados', 'Água Verde', '80610-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10870, 'Paranaguá', 'dos Estivadores', 'Tuiuti', '83203-670', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10871, 'Francisco Beltrão', 'dos Estudantes', 'Vila Maria Delani', '85605-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10872, 'Guarapuava', 'dos Eucaliptos', 'Conradinho', '85060-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10873, 'Foz do Iguaçu', 'dos Eucaliptos', 'Loteamento Bourbon', '85854-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10874, 'Laranjeiras do Sul', 'dos Eucaliptos', 'Cristo Rei', '85304-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10875, 'Pinhais', 'dos Eucaliptos', 'Jardim Pio XII', '83328-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10876, 'Piraquara', 'dos Eucaliptos', 'Planta Guarituba Pequena', '83310-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10877, 'São José dos Pinhais', 'dos Eucaliptos', 'Rio Pequeno', '83085-537', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10878, 'Toledo', 'dos Eucaliptos', 'Jardim Paulista', '85909-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10879, 'Sarandi', 'dos Eucaliptos', 'Jardim Rosas', '87111-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10880, 'Colombo', 'dos Eucaliptos', 'Jardim Adriana', '83408-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10881, 'Araucária', 'dos Eucaliptos', 'Estação', '83705-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10882, 'Campo Largo', 'dos Eucaliptos', 'Vila Dom Pedro II', '83608-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10883, 'Curitiba', 'dos Eucaliptos', 'Barreirinha', '82700-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10884, 'Londrina', 'dos Expedicionários', 'Conjunto Residencial Vale do Arvoredo', '86047-590', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10885, 'Paranavaí', 'dos Expedicionários', 'Jardim São Jorge', '87710-530', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10886, 'Paranaguá', 'dos Expedicionários', 'Ponta do Caju', '83206-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10887, 'Umuarama', 'dos Expedicionários', 'Zona V', '87504-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10888, 'Campo Mourão', 'dos Expedicionários', 'Jardim Copacabana', '87302-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10889, 'Campo Largo', 'dos Expedicionários', 'Bom Jesus', '83604-360', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10890, 'Araucária', 'dos Expedicionários Brasileiros', 'Centro', '83702-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10891, 'Pato Branco', 'dos Faisões', 'Planalto', '85509-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10892, 'Guarapuava', 'dos Falcões', 'Dos Estados', '85035-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10893, 'Guarapuava', 'dos Farmacêuticos', 'Núcleo Habitacional 2000', '85064-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10894, 'Londrina', 'dos Farmacêuticos', 'Jardim União da Vitória', '86044-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10895, 'Telêmaco Borba', 'dos Farrapos', 'Centro', '84261-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10896, 'Telêmaco Borba', 'dos Farroupilhas', 'Centro', '84261-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10897, 'São José dos Pinhais', 'dos Faveiros', 'Rio Pequeno', '83085-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10898, 'Umuarama', 'dos Feirantes', 'Parque 1º de Maio', '87509-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10899, 'Curitiba', 'dos Ferroviarios', 'Cajuru', '82920-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10900, 'Guarapuava', 'dos Fisioterapeutas', 'Núcleo Habitacional 2000', '85064-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10901, 'Paranaguá', 'dos Flamboyantes', 'Jardim Samambaia', '83212-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10902, 'Pinhais', 'dos Flamingos', 'Loteamento Alphaville Graciosa', '83327-146', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10903, 'Paranaguá', 'dos Flamingos', 'Jardim Esperança', '83218-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10904, 'Telêmaco Borba', 'dos Franças', 'Área 02', '84269-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10905, 'Piraquara', 'dos Funcionários', 'Planta Cruzeiro', '83304-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10906, 'Sarandi', 'dos Funcionários', 'Parque São Pedro', '87112-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10907, 'Araucária', 'dos Funcionários', 'Campina da Barra', '83709-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10908, 'Curitiba', 'dos Funcionários', 'Cabral', '80035-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10909, 'Londrina', 'dos Funileiros', 'Newton Guimarães', '86082-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10910, 'Paranaguá', 'dos Gansos', 'Jardim Esperança', '83218-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10911, 'Guarapuava', 'dos Garçons', 'Núcleo Habitacional 2000', '85064-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10912, 'Londrina', 'dos Garçons', 'Newton Guimarães', '86082-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10913, 'Apucarana', 'dos Garimpeiros', 'Colônia dos Novos Produtores', '86801-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10914, 'Londrina', 'dos Garis', 'Newton Guimarães', '86082-550', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10915, 'Guarapuava', 'dos Garis', 'Núcleo Habitacional 2000', '85064-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10916, 'Maringá', 'dos Gaúchos', 'Vila Emília', '87010-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10917, 'Campo Mourão', 'dos Gaúchos', 'Parque Industrial I', '87306-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10918, 'Guarapuava', 'dos Geógrafos', 'Núcleo Habitacional 2000', '85064-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10919, 'Guarapuava', 'dos Geólogos', 'Núcleo Habitacional 2000', '85064-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10920, 'Londrina', 'dos Gerânios', 'Ouro Branco', '86042-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10921, 'Maringá', 'dos Gerânios', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10922, 'Pato Branco', 'dos Gerânios', 'Novo Horizonte', '85507-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10923, 'Araucária', 'dos Gerânios', 'Campina da Barra', '83709-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10924, 'Cascavel', 'dos Gerânios', 'Guarujá', '85804-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10925, 'Campo Mourão', 'dos Gerânios', 'Jardim Santa Nilce II', '87308-197', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10926, 'Curitiba', 'dos Gerânios', 'Campo Comprido', '81210-100', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10927, 'Foz do Iguaçu', 'dos Girassóis', 'Jardim das Flores', '85855-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10928, 'Guarapuava', 'dos Girassóis', 'Trianon', '85012-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10929, 'Paranaguá', 'dos Girassóis', 'Conjunto Nilson Neves', '83215-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10930, 'Piraquara', 'dos Girassóis', 'Recreio da Serra', '83305-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10931, 'Umuarama', 'dos Girassóis', 'Parque das Jaboticabeiras', '87509-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10932, 'Sarandi', 'dos Girassóis', 'Jardim Verão', '87111-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10933, 'Telêmaco Borba', 'dos Girassóis', 'Jardim Alegre', '84268-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10934, 'Almirante Tamandaré', 'dos Girassóis', 'Loteamento Nova Morada', '83504-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10935, 'Foz do Iguaçu', 'dos Golfinhos', 'Parque Ouro Verde', '85854-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10936, 'Foz do Iguaçu', 'dos Golfinhos', 'Parque Ouro Verde', '85855-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10937, 'Cambé', 'dos Governadores Gerais', 'Jardim Vila Rica', '86192-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10938, 'Paranaguá', 'dos Guanandis', 'Jardim Samambaia', '83212-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10939, 'Paranaguá', 'dos Guapezeiros', 'Jardim Samambaia', '83212-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10940, 'Paranaguá', 'dos Guapuruvus', 'Jardim Iguaçu', '83210-007', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10941, 'Telêmaco Borba', 'dos Guararapes', 'Vila Ana Mari', '84263-090', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10942, 'Paranaguá', 'dos Guatambus', 'Jardim Iguaçu', '83210-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10943, 'Piraquara', 'dos Guimarães', 'Jardim Diguimabri', '83307-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10944, 'Guarapuava', 'dos Historiadores', 'Núcleo Habitacional 2000', '85064-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10945, 'Foz do Iguaçu', 'dos Imigrantes', 'Vila Yolanda', '85853-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10946, 'Sarandi', 'dos Imigrantes', 'Jardim Novo Mundo', '87111-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10947, 'Toledo', 'dos Imigrantes', 'Jardim Paulista', '85910-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10948, 'Cambé', 'dos Imigrantes', 'Jardim São José', '86192-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10949, 'Telêmaco Borba', 'dos Incas', 'Jardim Bonavila', '84264-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10950, 'Londrina', 'dos Inconfidentes', 'Jardim São Francisco de Assis', '86067-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10951, 'Pinhais', 'dos Ingás', 'Loteamento Alphaville Graciosa', '83327-128', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10952, 'Guarapuava', 'dos Ingazeiros', 'Morro Alto', '85067-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10953, 'Laranjeiras do Sul', 'dos Ipês', 'Cristo Rei', '85304-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10954, 'Foz do Iguaçu', 'dos Ipês', 'Imóvel Tamanduazinho', '85853-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10955, 'Paranaguá', 'dos Ipês', 'Jardim Samambaia', '83212-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10956, 'Maringá', 'dos Ipês', 'Conjunto Habitacional Inocente Vila Nova Júnior', '87060-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10957, 'Toledo', 'dos Ipês', 'Boa Esperança', '85909-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10958, 'São José dos Pinhais', 'dos Ipês', 'Rio Pequeno', '83085-547', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10959, 'Araucária', 'dos Ipês', 'Campina da Barra', '83709-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10960, 'Curitiba', 'dos Ipês', 'Barreirinha', '82700-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10961, 'Pinhais', 'dos Jaborandis', 'Loteamento Alphaville Graciosa', '83327-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10962, 'Pato Branco', 'dos Jaburus', 'Planalto', '85509-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10963, 'Paranaguá', 'dos Jaburus', 'Jardim Esperança', '83218-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10964, 'Paranaguá', 'dos Jacarandás', 'Jardim Iguaçu', '83210-008', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10965, 'São José dos Pinhais', 'dos Jacarandás', 'Rio Pequeno', '83085-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10966, 'Pinhais', 'dos Jacarandás', 'Loteamento Alphaville Graciosa', '83327-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10967, 'Toledo', 'dos Jacarandás', 'Boa Esperança', '85909-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10968, 'Londrina', 'dos Jardineiros', 'Jardim União da Vitória', '86044-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10969, 'Guarapuava', 'dos Jardineiros', 'Núcleo Habitacional 2000', '85064-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10970, 'Foz do Iguaçu', 'dos Jasmins', 'Jardim das Flores', '85855-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10971, 'Pato Branco', 'dos Jasmins', 'Novo Horizonte', '85507-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10972, 'São José dos Pinhais', 'dos Jasmins', 'Afonso Pena', '83050-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10973, 'Paranaguá', 'dos Jasmins', 'Conjunto Nilson Neves', '83215-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10974, 'Maringá', 'dos Jasmins', 'Jardim Maravilha', '87080-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10975, 'Paranaguá', 'dos Jasmins', 'Jardim Samambaia', '83212-350', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10976, 'Sarandi', 'dos Jasmins', 'Jardim Verão', '87111-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10977, 'Cascavel', 'dos Jasmins', 'Guarujá', '85804-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10978, 'Colombo', 'dos Jasmins', 'Parque Monte Castelo', '83411-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10979, 'Curitiba', 'dos Jasmins', 'Mossunguê', '81210-090', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10980, 'Paranaguá', 'dos Jatobás', 'Jardim Iguaçu', '83210-016', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10981, 'Araucária', 'dos Jatobás', 'Estação', '83705-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10982, 'Paranaguá', 'dos Jequitibás', 'Jardim Iguaçu', '83210-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10983, 'Curitiba', 'dos Jesuítas', 'Guabirotuba', '81510-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10984, 'Curitiba', 'dos Josefinos', 'Água Verde', '80620-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10985, 'Guarapuava', 'dos Juazeiros', 'Bonsucesso', '85045-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10986, 'São José dos Pinhais', 'dos Junquilhos', 'Costeira', '83015-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10987, 'Colombo', 'dos Junquilhos', 'Parque Monte Castelo', '83411-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10988, 'Campo Mourão', 'dos Lagos', 'Jardim Tropical II', '87310-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10989, 'Londrina', 'dos Lavradores', 'Newton Guimarães', '86082-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10990, 'Apucarana', 'dos Lavradores', 'Colônia dos Novos Produtores', '86801-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10991, 'Londrina', 'dos Lírios', 'Ouro Branco', '86042-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10992, 'Foz do Iguaçu', 'dos Lírios', 'Jardim Eliza II', '85854-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10993, 'Pato Branco', 'dos Lírios', 'Novo Horizonte', '85507-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10994, 'Paranaguá', 'dos Lírios', 'Conjunto Nilson Neves', '83215-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10995, 'Piraquara', 'dos Lírios', 'Planta Guarituba Pequena', '83310-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10996, 'Sarandi', 'dos Lírios', 'Jardim Verão', '87111-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10997, 'São José dos Pinhais', 'dos Lírios', 'Afonso Pena', '83050-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10998, 'Umuarama', 'dos Lírios', 'Parque das Laranjeiras', '87507-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (10999, 'Cascavel', 'dos Lírios', 'Guarujá', '85804-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11000, 'Colombo', 'dos Lírios', 'Vila Vale das Flores', '83411-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11001, 'Almirante Tamandaré', 'dos Lírios', 'Vila da Glória', '83505-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11002, 'Sarandi', 'dos Livramentos', 'Parque Residencial Santana', '87112-579', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11003, 'Umuarama', 'dos Liziantos', 'Parque das Jaboticabeiras', '87509-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11004, 'Umuarama', 'dos Lojistas', 'Parque 1º de Maio', '87509-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11005, 'Cascavel', 'dos Lusíadas', 'Interlagos', '85814-297', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11006, 'Pinhais', 'dos Luteranos', 'Vila Maria Antonieta', '83331-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11007, 'Curitiba', 'dos Maçons', 'Alto da Rua XV', '80050-090', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11008, 'Paranaguá', 'dos Macucos', 'Jardim Esperança', '83218-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11009, 'Pinhais', 'dos Mainás', 'Loteamento Alphaville Graciosa', '83327-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11010, 'Guarapuava', 'dos Marceneiros', 'Núcleo Habitacional 2000', '85064-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11011, 'Londrina', 'dos Marceneiros', 'Jardim União da Vitória', '86044-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11012, 'Umuarama', 'dos Marceneiros', 'Parque 1º de Maio', '87509-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11013, 'Almirante Tamandaré', 'dos Marceneiros', 'Jardim Dourados', '83507-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11014, 'Curitiba', 'dos Marceneiros', 'Cidade Industrial', '81310-390', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11015, 'Laranjeiras do Sul', 'dos Marfins', 'Cristo Rei', '85304-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11016, 'Guarapuava', 'dos Marmeleiros', 'Morro Alto', '85067-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11017, 'Colombo', 'dos Marmeleiros', 'Jardim Nossa Senhora das Graças', '83407-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11018, 'Londrina', 'dos Marmelos', 'Interlagos', '86035-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11019, 'Guarapuava', 'dos Matemáticos', 'Núcleo Habitacional 2000', '85064-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11020, 'Londrina', 'dos Mecânicos', 'Conjunto Vivi Xavier', '86082-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11021, 'Guarapuava', 'dos Mecânicos', 'Núcleo Habitacional 2000', '85064-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11022, 'Guarapuava', 'dos Médicos', 'Núcleo Habitacional 2000', '85064-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11023, 'Londrina', 'dos Melros', 'Vitória Régia', '86038-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11024, 'Cascavel', 'dos Metais', 'Presidente', '85818-127', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11025, 'Umuarama', 'dos Milagres', 'Jardim San Martim', '87508-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11026, 'Cascavel', 'dos Minerais', 'Presidente', '85818-126', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11027, 'Almirante Tamandaré', 'dos Minérios', 'Jardim Dona Belizaria', '83513-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11028, 'Almirante Tamandaré', 'dos Minérios', 'Jardim Dona Belizaria', '83514-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11029, 'Almirante Tamandaré', 'dos Minérios', 'Jardim Rafaela', '83512-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11030, 'Almirante Tamandaré', 'dos Minérios', 'Jardim Monterrey', '83507-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11031, 'Almirante Tamandaré', 'dos Minérios', 'Botiatuba', '83511-530', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11032, 'Curitiba', 'dos Minérios', 'Taboão', '82130-570', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11033, 'Foz do Iguaçu', 'dos Miosotis', 'Jardim Santa Cecília', '85854-496', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11034, 'Londrina', 'dos Miosótis', 'Ouro Branco', '86042-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11035, 'Piraquara', 'dos Miosótis', 'Recreio da Serra', '83305-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11036, 'Sarandi', 'dos Mognos', 'Jardim Monterey', '87112-805', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11037, 'São José dos Pinhais', 'dos Mognos', 'Rio Pequeno', '83085-536', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11038, 'São José dos Pinhais', 'dos Monges Beneditinos', 'São Sebastião', '83075-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11039, 'Pinhais', 'dos Monjoleiros', 'Loteamento Alphaville Graciosa', '83327-127', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11040, 'Campo Mourão', 'dos Monjoleiros', 'Conjunto Residencial Ilha Bela', '87309-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11041, 'Curitiba', 'dos Monjoleiros', 'Barreirinha', '82700-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11042, 'Londrina', 'dos Motoristas', 'Newton Guimarães', '86082-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11043, 'Guarapuava', 'dos Motoristas', 'Núcleo Habitacional 2000', '85064-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11044, 'Sarandi', 'dos Motoristas', 'Parque São Pedro', '87112-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11045, 'Umuarama', 'dos Motoristas', 'Parque 1º de Maio', '87509-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11046, 'Campo Mourão', 'dos Mutirantes', 'Jardim Tropical II', '87310-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11047, 'Cascavel', 'dos Narcisos', 'Guarujá', '85804-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11048, 'Araucária', 'dos Narcisos', 'Campina da Barra', '83709-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11049, 'Guarapuava', 'dos Nutricionistas', 'Núcleo Habitacional 2000', '85064-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11050, 'Londrina', 'dos Oleiros', 'Jardim União da Vitória', '86044-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11051, 'Guarapuava', 'dos Operários', 'Núcleo Habitacional 2000', '85064-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11052, 'Paranavaí', 'dos Operários', 'Vila Alta', '87708-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11053, 'Maringá', 'dos Palmares', 'Jardim América', '87045-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11054, 'Maringá', 'dos Palmares', 'Jardim Liberdade', '87047-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11055, 'Curitiba', 'dos Palmenses', 'São Miguel', '81450-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11056, 'Curitiba', 'dos Palotinos', 'Cristo Rei', '80050-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11057, 'Umuarama', 'dos Pampas', 'Jardim Europa', '87502-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11058, 'Umuarama', 'dos Pampas', 'Jardim Birigüi', '87505-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11059, 'Francisco Beltrão', 'dos Papagaios', 'Luther King', '85605-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11060, 'Guarapuava', 'dos Papagaios', 'Bonsucesso', '85045-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11061, 'Laranjeiras do Sul', 'dos Papagaios', 'Vila Industrial', '85303-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11062, 'Maringá', 'dos Papagaios', 'Parque Hortência', '87075-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11063, 'Pato Branco', 'dos Papagaios', 'Planalto', '85509-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11064, 'São José dos Pinhais', 'dos Papagaios', 'Afonso Pena', '83045-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11065, 'Campo Largo', 'dos Papagaios', 'Vila Gilcy', '83609-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11066, 'Campo Mourão', 'dos Papagaios', 'Conjunto Habitacional Milton Luiz Pereira', '87306-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11067, 'Curitiba', 'dos Papagaios', 'Novo Mundo', '81020-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11068, 'Francisco Beltrão', 'dos Pardais', 'Luther King', '85605-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11069, 'Laranjeiras do Sul', 'dos Pardais', 'Vila Industrial', '85303-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11070, 'Guarapuava', 'dos Pardais', 'Conradinho', '85045-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11071, 'Pato Branco', 'dos Pardais', 'Planalto', '85509-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11072, 'Sarandi', 'dos Pardais', 'Conjunto Floresta', '87112-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11073, 'São José dos Pinhais', 'dos Pardais', 'Afonso Pena', '83045-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11074, 'Cascavel', 'dos Pardais', 'Floresta', '85814-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11075, 'Campo Largo', 'dos Pardais', 'Vila Dona Fina', '83609-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11076, 'Campo Mourão', 'dos Pardais', 'Jardim Tropical I', '87310-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11077, 'Pinhais', 'dos Pássaros', 'Jardim Fênix', '83326-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11078, 'Curitiba', 'dos Passionistas', 'Cabral', '80035-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11079, 'Londrina', 'dos Pastores', 'Jardim União da Vitória', '86044-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11080, 'Paranavaí', 'dos Patriotas', 'Jardim Iguaçu', '87705-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11081, 'Paranavaí', 'dos Patriotas', 'Jardim Iguaçu', '87706-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11082, 'Pato Branco', 'dos Pavões', 'Planalto', '85509-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11083, 'Apucarana', 'dos Pecuaristas', 'Colônia dos Novos Produtores', '86801-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11084, 'Francisco Beltrão', 'dos Pedestres', 'São Miguel', '85602-529', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11085, 'Londrina', 'dos Pedreiros', 'Newton Guimarães', '86082-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11086, 'Guarapuava', 'dos Pedreiros', 'Núcleo Habitacional 2000', '85064-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11087, 'Umuarama', 'dos Pedreiros', 'Parque 1º de Maio', '87509-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11088, 'Guarapuava', 'dos Pelicanos', 'Batel', '85015-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11089, 'Pato Branco', 'dos Pelicanos', 'Planalto', '85509-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11090, 'Paranaguá', 'dos Pelicanos', 'Jardim Esperança', '83218-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11091, 'São José dos Pinhais', 'dos Periquitos', 'Afonso Pena', '83045-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11092, 'Campo Largo', 'dos Periquitos', 'Vila Gilcy', '83609-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11093, 'Curitiba', 'dos Periquitos', 'Novo Mundo', '81020-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11094, 'Londrina', 'dos Pescadores', 'Jardim União da Vitória', '86044-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11095, 'Ponta Grossa', 'dos Pessegueiros', 'Chapada', '84064-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11096, 'Campo Mourão', 'dos Pessegueiros', 'Jardim Araucária', '87301-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11097, 'Colombo', 'dos Pessegueiros', 'Jardim Nossa Senhora das Graças', '83407-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11098, 'Pato Branco', 'dos Pica-Paus', 'Planalto', '85509-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11099, 'Guarapuava', 'dos Pingüins', 'Santana', '85070-686', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11100, 'Francisco Beltrão', 'dos Pinhais', 'Pinheirinho', '85606-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11101, 'Campo Mourão', 'dos Pinhais', 'Jardim Lar Paraná', '87305-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11102, 'Almirante Tamandaré', 'dos Pinheirais', 'Jardim Ipanema', '83507-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11103, 'Araucária', 'dos Pinheirais', 'Estação', '83705-570', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11104, 'Campo Mourão', 'dos Pinheirais', 'Jardim Santa Nilce I', '87308-210', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11105, 'Guarapuava', 'dos Pinheiros', 'Industrial', '85053-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11106, 'Maringá', 'dos Pinheiros', 'Zona 05', '87060-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11107, 'Piraquara', 'dos Pinheiros', 'Planta Bosque Centenário', '83311-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11108, 'Piraquara', 'dos Pinheiros', 'Chácara Águas Claras', '83308-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11109, 'Pinhais', 'dos Pinheiros', 'Planta Karla', '83328-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11110, 'São José dos Pinhais', 'dos Pinheiros', 'Guatupê', '83060-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11111, 'Sarandi', 'dos Pinheiros', 'Jardim Monterey', '87112-808', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11112, 'São José dos Pinhais', 'dos Pinheiros', 'Rio Pequeno', '83085-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11113, 'Cascavel', 'dos Pinheiros', 'Recanto Tropical', '85807-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11114, 'Campo Largo', 'dos Pinheiros', 'Jardim Guairacá', '83608-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11115, 'Curitiba', 'dos Pinheiros', 'Barreirinha', '82700-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11116, 'Pinhais', 'dos Pintassilgos', 'Loteamento Alphaville Graciosa', '83327-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11117, 'Pato Branco', 'dos Pintassilgos', 'Planalto', '85509-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11118, 'Piraquara', 'dos Pintassilgos', 'Recreio da Serra', '83305-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11119, 'Telêmaco Borba', 'dos Pintassilgos', 'Jardim São Silvestre', '84270-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11120, 'São José dos Pinhais', 'dos Pintassilgos', 'Afonso Pena', '83045-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11121, 'Curitiba', 'dos Pintassilgos', 'Novo Mundo', '81020-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11122, 'Londrina', 'dos Pintores', 'Newton Guimarães', '86082-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11123, 'Guarapuava', 'dos Pintores', 'Núcleo Habitacional 2000', '85064-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11124, 'Londrina', 'dos Pintores', 'Santa Rita 1', '86071-265', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11125, 'Umuarama', 'dos Pintores', 'Parque 1º de Maio', '87509-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11126, 'Cascavel', 'dos Pinus', 'Santa Cruz', '85806-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11127, 'Londrina', 'dos Pioneiros', 'Jardim Morumbi', '86036-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11128, 'Francisco Beltrão', 'dos Pioneiros', 'São Cristóvão', '85601-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11129, 'Francisco Beltrão', 'dos Pioneiros', 'Padre Eurico', '85604-276', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11130, 'Maringá', 'dos Pioneiros', 'Jardim Itaipu', '87065-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11131, 'Paranavaí', 'dos Pioneiros', 'Jardim Ouro Branco', '87704-320', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11132, 'Toledo', 'dos Pioneiros', 'Jardim Paulista', '85910-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11133, 'Toledo', 'dos Pioneiros', 'Jardim Bressan', '85913-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11134, 'Toledo', 'dos Pioneiros', 'Fogotti', '85914-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11135, 'Toledo', 'dos Pioneiros', 'Independência', '85906-530', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11136, 'Umuarama', 'dos Pioneiros', 'Zona V', '87504-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11137, 'Campo Mourão', 'dos Pioneiros', 'Jardim Lar Paraná', '87305-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11138, 'Cambé', 'dos Pioneiros', 'Jardim Planalto Verde', '86192-390', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11139, 'Curitiba', 'dos Pioneiros', 'Sítio Cercado', '81910-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11140, 'Curitiba', 'dos Pioneiros', 'Sítio Cercado', '81900-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11141, 'Curitiba', 'dos Piriquitos', 'Cidade Industrial', '81450-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11142, 'Pinhais', 'dos Plátanos', 'Loteamento Alphaville Graciosa', '83327-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11143, 'Guarapuava', 'dos Policiais', 'Núcleo Habitacional 2000', '85064-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11144, 'Guarapuava', 'dos Pombos', 'Bonsucesso', '85035-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11145, 'Cascavel', 'dos Pracinhas', 'Região do Lago 3', '85819-766', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11146, 'Curitiba', 'dos Presbíteros', 'São Francisco', '80410-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11147, 'Apucarana', 'dos Produtores', 'Colônia dos Novos Produtores', '86801-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11148, 'Guarapuava', 'dos Professores', 'Núcleo Habitacional 2000', '85064-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11149, 'Londrina', 'dos Professores', 'Jardim União da Vitória', '86044-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11150, 'Umuarama', 'dos Professores', 'Parque 1º de Maio', '87509-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11151, 'Araucária', 'dos Professores', 'Barigui', '83707-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11152, 'Sarandi', 'dos Profissionais', 'Parque São Pedro', '87112-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11153, 'Curitiba', 'dos Provérbios', 'Santa Cândida', '82630-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11154, 'Laranjeiras do Sul', 'dos Quero-quero', 'Vila Industrial', '85303-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11155, 'Colombo', 'dos Reis', 'Vila Campo Alto', '83408-346', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11156, 'Curitiba', 'dos Rogacionistas', 'Sítio Cercado', '81920-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11157, 'Curitiba', 'dos Rouxinóis', 'Novo Mundo', '81020-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11158, 'Guarapuava', 'dos Sabiás', 'Conradinho', '85055-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11159, 'Laranjeiras do Sul', 'dos Sabiás', 'Vila Industrial', '85303-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11160, 'Piraquara', 'dos Sabiás', 'Recreio da Serra', '83305-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11161, 'São José dos Pinhais', 'dos Sabiás', 'Afonso Pena', '83045-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11162, 'Campo Largo', 'dos Sabiás', 'Jardim Lise', '83605-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11163, 'Curitiba', 'dos Sanhaços', 'Novo Mundo', '81020-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11164, 'Toledo', 'dos Santos', 'Jardim Paulista', '85909-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11165, 'Guarapuava', 'dos Sapateiros', 'Núcleo Habitacional 2000', '85064-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11166, 'Londrina', 'dos Sapateiros', 'Jardim União da Vitória', '86044-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11167, 'Maringá', 'dos Sertões', 'Zona 04', '87014-260', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11168, 'Umuarama', 'dos Servidores Públicos', 'Parque 1º de Maio', '87509-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11169, 'Paranaguá', 'dos Sombreiros', 'Jardim Samambaia', '83212-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11170, 'Umuarama', 'dos Tamoios', 'Zona VI', '87503-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11171, 'Piraquara', 'dos Tangarás', 'Recreio da Serra', '83305-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11172, 'Paranaguá', 'dos Tangarás', 'Jardim Esperança', '83218-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11173, 'Pinhais', 'dos Tangarás', 'Loteamento Alphaville Graciosa', '83327-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11174, 'Telêmaco Borba', 'dos Tapuias', 'Nossa Senhora do Perpétuo Socorro', '84265-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11175, 'Laranjeiras do Sul', 'dos Tarumãs', 'Cristo Rei', '85304-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11176, 'Umuarama', 'dos Taxistas', 'Parque 1º de Maio', '87509-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11177, 'Guarapuava', 'dos Topógrafos', 'Núcleo Habitacional 2000', '85064-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11178, 'Umuarama', 'dos Trabalhadores', 'Parque 1º de Maio', '87509-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11179, 'Apucarana', 'dos Trabalhadores', 'Vila Operária 1', '86801-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11180, 'Colombo', 'dos Trabalhadores', 'Jardim Florença', '83414-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11181, 'Cambé', 'dos Três Poderes', 'Jardim Alvorada', '86191-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11182, 'Guarapuava', 'dos Tropeiros', 'Boqueirão', '85020-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11183, 'Cascavel', 'dos Tropeiros', 'Recanto Tropical', '85807-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11184, 'Laranjeiras do Sul', 'dos Tucanos', 'Vila Industrial', '85303-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11185, 'Pato Branco', 'dos Tucanos', 'Planalto', '85509-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11186, 'Paranaguá', 'dos Tucanos', 'Jardim Esperança', '83218-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11187, 'Sarandi', 'dos Tucanos', 'Conjunto Floresta', '87112-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11188, 'Campo Mourão', 'dos Tucanos', 'Conjunto Habitacional Milton Luiz Pereira', '87306-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11189, 'Curitiba', 'dos Tucanos', 'Novo Mundo', '81020-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11190, 'Telêmaco Borba', 'dos Tupis', 'Nossa Senhora do Perpétuo Socorro', '84265-130', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11191, 'Curitiba', 'dos Uirapurus', 'Novo Mundo', '81020-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11192, 'Umuarama', 'dos Vendedores', 'Parque 1º de Maio', '87509-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11193, 'Guarapuava', 'dos Veterinários', 'Núcleo Habitacional 2000', '85064-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11194, 'Londrina', 'dos Viajantes', 'Newton Guimarães', '86082-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11195, 'Londrina', 'dos Viajantes', 'Helena', '86026-240', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11196, 'Londrina', 'dos Vigias', 'Newton Guimarães', '86082-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11197, 'Umuarama', 'dos Vigilantes', 'Parque 1º de Maio', '87509-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11198, 'Curitiba', 'dos Xaverianos', 'Bairro Alto', '82820-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11199, 'Umuarama', 'dos Xetas', 'Zona VI', '87503-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11200, 'Umuarama', 'dos Xetas', 'Zona II', '87503-270', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11201, 'Curitiba', 'Douglas Haquim', 'Vista Alegre', '80810-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11202, 'Curitiba', 'Douglas Ribeiro de Souza', 'Cidade Industrial', '81450-719', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11203, 'Curitiba', 'Douglas Victor Novitzki', 'Cidade Industrial', '81250-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11204, 'Foz do Iguaçu', 'Douradina', 'Vila Carima', '85855-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11205, 'Arapongas', 'Douradinho', 'Jardim Portal das Flores', '86701-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11206, 'Arapongas', 'Douradinho-ocre', 'Casa Família Arapongas IV', '86709-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11207, 'Foz do Iguaçu', 'Dourado', 'Profilurb I', '85855-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11208, 'Pinhais', 'Dourado', 'Loteamento Alphaville Graciosa', '83327-098', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11209, 'Ponta Grossa', 'Dourado', 'Cará-cará', '84043-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11210, 'Telêmaco Borba', 'Dourado', 'Vila São José', '84263-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11211, 'Guarapuava', 'Dourados', 'Industrial', '85045-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11212, 'Pato Branco', 'Dourados', 'Chaparral', '85507-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11213, 'Maringá', 'Dourados', 'Jardim Itaipu', '87065-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11214, 'Sarandi', 'Dourados', 'Jardim Itamaraty', '87112-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11215, 'Umuarama', 'Dourados', 'Jardim Iguaçu', '87501-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11216, 'Campo Mourão', 'Dourados', 'Jardim Lar Paraná', '87305-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11217, 'Campo Largo', 'Dourados', 'Vila Dom Pedro', '83608-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11218, 'Curitiba', 'Doutor Abel Walter Brunnquell', 'Pinheirinho', '81870-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11219, 'Ponta Grossa', 'Doutor Abrahão Federmann', 'Chapada', '84063-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11220, 'Ponta Grossa', 'Doutor Abrahão Glasser', 'Uvaranas', '84025-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11221, 'Toledo', 'Doutor Adelfino Pancotto', 'Coopagro', '85903-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11222, 'Castro', 'Doutor Afonso Celso Abrão', 'Jardim das Araucárias', '84174-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11223, 'Curitiba', 'Doutor Afonso Loyola e Silva', 'Uberaba', '81550-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11224, 'Curitiba', 'Doutor Agostinho Brenner', 'Sítio Cercado', '81920-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11225, 'Curitiba', 'Doutor Alarico Vieira de Alencar', 'Bacacheri', '82520-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11226, 'Foz do Iguaçu', 'Doutor Alastair Munro', 'Jardim Eldorado', '85853-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11227, 'Maringá', 'Doutor Alberto Byngton Júnior', 'Vila Esperança', '87020-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11228, 'Curitiba', 'Doutor Alberto Franco Ferreira da Costa', 'Jardim Botânico', '80215-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11229, 'Londrina', 'Doutor Alberto Romi', 'Jardim Alvorada', '86060-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11230, 'Curitiba', 'Doutor Albino Farracha de Castro', 'Santa Felicidade', '82010-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11231, 'Curitiba', 'Doutor Alceu Amaral Ferreira', 'Bom Retiro', '80520-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11232, 'Araucária', 'Doutor Alceu da Silva Oliveira', 'Iguaçu', '83701-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11233, 'Curitiba', 'Doutor Alcides Vieira Arcoverde', 'Guabirotuba', '81520-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11234, 'Curitiba', 'Doutor Aldivar José Bassetti', 'Boa Vista', '82540-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11235, 'Londrina', 'Doutor Aldo Abate Neto', 'Conjunto Farid Libos', '86087-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11236, 'Curitiba', 'Doutor Alexander Fleming', 'Bacacheri', '82600-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11237, 'Curitiba', 'Doutor Alexandre Gutierrez', 'Água Verde', '80240-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11238, 'Maringá', 'Doutor Alexandre Rasgulaeff', 'Jardim Dourados', '87040-550', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11239, 'Maringá', 'Doutor Alexandre Rasgulaeff', 'Jardim Real', '87083-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11240, 'Maringá', 'Doutor Alexandre Rasgulaeff', 'Parque Residencial Cidade Nova', '87023-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11241, 'Maringá', 'Doutor Alexandre Rasgulaeff', 'Jardim Alvorada', '87033-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11242, 'Curitiba', 'Doutor Alfredo Vieira Barcelos', 'Uberaba', '81530-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11243, 'Curitiba', 'Doutor Aluízio Franca', 'Bigorrilho', '80710-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11244, 'Ponta Grossa', 'Doutor Aluízio Grochoski', 'Boa Vista', '84073-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11245, 'Ponta Grossa', 'Doutor Aluízio Grochoski', 'Boa Vista', '84073-450', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11246, 'Curitiba', 'Doutor Álvaro Albuquerque', 'Bigorrilho', '80710-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11247, 'Curitiba', 'Doutor Álvaro Teixeira Pinto', 'Santa Cândida', '82720-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11248, 'Curitiba', 'Doutor Álvaro Teixeira Pinto', 'Santa Cândida', '82640-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11249, 'Ponta Grossa', 'Doutor Alves Maciel', 'Oficinas', '84035-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11250, 'Ponta Grossa', 'Doutor Alves Maciel', 'Oficinas', '84036-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11251, 'Curitiba', 'Doutor Alvim Messias', 'Cajuru', '82930-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11252, 'Apucarana', 'Doutor André Celso Szpak', 'Loteamento Sanches dos Santos', '86806-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11253, 'Campo Mourão', 'Doutor André Slomp', 'Jardim Paulino', '87306-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11254, 'Curitiba', 'Doutor Antônio Alves de Souza', 'Bigorrilho', '80710-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11255, 'Curitiba', 'Doutor Antônio Amarante', 'Boa Vista', '82650-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11256, 'Guarapuava', 'Doutor Antônio Baraúna', 'Alto Cascavel', '85031-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11257, 'Maringá', 'Doutor Antônio de Azevedo', 'Jardim Monte Carlo', '87080-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11258, 'Campo Mourão', 'Doutor Antônio F. Slomp', 'Jardim Paulino', '87306-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11259, 'Paranaguá', 'Doutor Antônio Fontes', 'João Gualberto', '83203-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11260, 'Curitiba', 'Doutor Antônio Gomes', 'Xaxim', '81830-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11261, 'Curitiba', 'Doutor Antônio Machado de Souza', 'Taboão', '82130-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11262, 'Apucarana', 'Doutor Antônio Maria Rodrigues', 'Parque Industrial Zona Oeste II', '86800-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11263, 'Umuarama', 'Doutor Antônio Morais Barros', 'Zona II', '87501-375', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11264, 'Paranaguá', 'Doutor Antônio Olímpio de Oliveira', 'Vila Paranaguá', '83221-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11265, 'Ponta Grossa', 'Doutor Antônio Russo', 'Colônia Dona Luiza', '84045-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11266, 'Ponta Grossa', 'Doutor Antônio Schwansee', 'Estrela', '84050-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11267, 'Londrina', 'Doutor Antônio Stocchero', 'Conjunto Farid Libos', '86087-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11268, 'Campo Mourão', 'Doutor Ari Geraldo Assunção', 'Jardim Nossa Senhora Aparecida', '87309-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11269, 'Curitiba', 'Doutor Arides Pinho', 'Tatuquara', '81480-247', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11270, 'Curitiba', 'Doutor Arielly Soares da Silva', 'Boqueirão', '81750-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11271, 'Maringá', 'Doutor Arion Ribeiro de Campos', 'Zona 02', '87010-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11272, 'Londrina', 'Doutor Aristeu dos Santos Ribas', 'Santa Mônica', '86079-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11273, 'Curitiba', 'Doutor Aristóteles Batista de Camargo', 'Cidade Industrial', '81350-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11274, 'Londrina', 'Doutor Arlindo Carmona', 'Tomy', '86036-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11275, 'Curitiba', 'Doutor Armando Fajardo', 'Capão Raso', '81020-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11276, 'Curitiba', 'Doutor Arnaldo Moura', 'Mossunguê', '81210-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11277, 'Curitiba', 'Doutor Arno Duarte', 'Cidade Industrial', '81450-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11278, 'Paranaguá', 'Doutor Arthur de Souza Costa', 'Raia', '83206-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11279, 'Curitiba', 'Doutor Augusto Cantergiani', 'Pinheirinho', '81820-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11280, 'Curitiba', 'Doutor Augusto Lobo de Moura', 'Fazendinha', '81330-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11281, 'Curitiba', 'Doutor Barreto Coutinho', 'Santa Cândida', '82640-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11282, 'Toledo', 'Doutor Basílio Rambo', 'Conjunto Barão do Rio Branco II', '85905-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11283, 'Ponta Grossa', 'Doutor Batista Lacerda', 'Boa Vista', '84072-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11284, 'Curitiba', 'Doutor Bayma', 'Batel', '80420-110', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11285, 'Paranaguá', 'Doutor Belmiro Saldanha da Rocha', 'Alvorada', '83206-095', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11286, 'Curitiba', 'Doutor Bemben', 'Pilarzinho', '82115-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11287, 'Curitiba', 'Doutor Benedicto Siqueira Branco', 'Alto Boqueirão', '81860-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11288, 'Curitiba', 'Doutor Benedito Amorim', 'Santa Cândida', '82640-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11289, 'Londrina', 'Doutor Benedito Rocha Campos', 'Conjunto Farid Libos', '86087-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11290, 'Castro', 'Doutor Bernardo Pusch Júnior', 'Jardim das Nações', '84172-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11291, 'Curitiba', 'Doutor Bezerra de Menezes', 'Ahú', '80540-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11292, 'Curitiba', 'Doutor Brasílio Ferreira da Luz', 'Jardim das Américas', '81540-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11293, 'Curitiba', 'Doutor Brasílio Vicente de Castro', 'Campo Comprido', '81200-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11294, 'Curitiba', 'Doutor Bronislau Ostoja Roguski', 'Jardim das Américas', '81540-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11295, 'Araucária', 'Doutor Bruno Cichon', 'Centro', '83702-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11296, 'Umuarama', 'Doutor Camargo', 'Zona III', '87502-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11297, 'Umuarama', 'Doutor Camargo', 'Zona II', '87501-378', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11298, 'Londrina', 'Doutor Camilo Castelo Branco', 'São Jorge', '86047-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11299, 'Ponta Grossa', 'Doutor Caminhoa', 'Colônia Dona Luiza', '84045-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11300, 'São José dos Pinhais', 'Doutor Canuto Maciel de Araújo', 'Cidade Jardim', '83035-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11301, 'Campo Mourão', 'Doutor Carlos Boenig', 'Conjunto Residencial Ilha Bela', '87309-087', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11302, 'Curitiba', 'Doutor Carlos Bruno Breithaupt', 'Jardim das Américas', '81540-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11469, 'Ponta Grossa', 'Doutor Joel Laroca', 'Boa Vista', '84070-610', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11303, 'São José dos Pinhais', 'Doutor Carlos de Andrade Dantas', 'Cidade Jardim', '83035-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11304, 'Curitiba', 'Doutor Carlos de Carvalho', 'Batel', '80730-201', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11305, 'Curitiba', 'Doutor Carlos de Carvalho', 'Batel', '80730-200', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11306, 'Curitiba', 'Doutor Carlos de Carvalho', 'Centro', '80430-180', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11307, 'Curitiba', 'Doutor Carlos de Carvalho', 'Centro', '80410-180', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11308, 'Curitiba', 'Doutor Carlos de Paula Soares', 'Mercês', '80710-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11309, 'Ponta Grossa', 'Doutor Carlos Deszaunet Neto', 'Oficinas', '84035-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11310, 'São José dos Pinhais', 'Doutor Carlos do Nascimento', 'Guatupê', '83060-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11311, 'Curitiba', 'Doutor Carlos Guillen', 'Atuba', '82860-120', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11312, 'Apucarana', 'Doutor Carlos Pereira', 'Núcleo Habitacional Tancredo Neves', '86807-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11313, 'Curitiba', 'Doutor Carlos Vicente Laynes de Andrade', 'Campo Comprido', '81220-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11314, 'Laranjeiras do Sul', 'Doutor Carmosino Vieira Branco', 'Cristo Rei', '85304-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11315, 'Curitiba', 'Doutor Carvalho Chaves', 'Parolin', '80220-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11316, 'Umuarama', 'Doutor Cássio Gastão Vidigal', 'Zona VII', '87503-500', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11317, 'Curitiba', 'Doutor Cerqueira Lima', 'São Braz', '82015-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11318, 'Ponta Grossa', 'Doutor César Rocha Milleo', 'Chapada', '84062-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11319, 'Curitiba', 'Doutor Cezar Luiz Teixeira', 'Fanny', '81030-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11320, 'Curitiba', 'Doutor Cezar Perneta', 'Tatuquara', '81470-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11321, 'Ponta Grossa', 'Doutor Chafic Cury', 'Jardim Carvalho', '84015-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11322, 'Ponta Grossa', 'Doutor Cid Cordeiro Prestes', 'Uvaranas', '84030-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11323, 'Toledo', 'Doutor Cid Marcondes de Albuquerque', 'Panorama', '85911-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11324, 'São José dos Pinhais', 'Doutor Claudino dos Santos', 'Carioca', '83005-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11325, 'Araucária', 'Doutor Claudino dos Santos', 'Centro', '83702-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11326, 'Curitiba', 'Doutor Claudino dos Santos', 'São Francisco', '80020-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11327, 'Londrina', 'Doutor Cleon Bueno de Oliveira', 'Conjunto Farid Libos', '86087-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11328, 'Ponta Grossa', 'Doutor Clyceu Carlos de Macedo', 'Jardim Carvalho', '84016-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11329, 'Ponta Grossa', 'Doutor Colares', 'Centro', '84010-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11330, 'Curitiba', 'Doutor Constante Coelho', 'Jardim das Américas', '81530-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11331, 'Curitiba', 'Doutor Corrêa Coelho', 'Jardim Botânico', '80210-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11332, 'Castro', 'Doutor Costa Carvalho', 'Centro', '84165-100', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11333, 'Toledo', 'Doutor Cyro Fernandes do Lago', 'Jardim Paulista', '85910-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11334, 'Castro', 'Doutor Dagoberto Pusch', 'Jardim Social Arapongas', '84174-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11335, 'Curitiba', 'Doutor Dalton Dória Pinto', 'Hauer', '81630-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11336, 'Curitiba', 'Doutor Danilo Gomes', 'Boqueirão', '81670-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11337, 'Curitiba', 'Doutor Danilo Gomes', 'Boqueirão', '81750-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11338, 'Campo Largo', 'Doutor Dante Portugal Castagnoli', 'Vila Santa Terezinha', '83602-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11339, 'Curitiba', 'Doutor Darcy Alves de Souza', 'Campo Comprido', '81210-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11340, 'Campo Mourão', 'Doutor Décio Carlos Slomp', 'Jardim Paulino', '87306-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11341, 'Curitiba', 'Doutor Décio Dossi', 'Alto Boqueirão', '81770-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11342, 'Curitiba', 'Doutor Demerval Prestes Branco', 'Cidade Industrial', '81305-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11343, 'Londrina', 'Doutor Dicésar Buquera', 'Jardim São João', '86027-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11344, 'Londrina', 'Doutor Dimas de Barros', 'Guanabara Parque Boulevard', '86050-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11345, 'Umuarama', 'Doutor Diment', 'Zona VII', '87503-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11346, 'Apucarana', 'Doutor Dinart Garcia', 'Vila Rural Nova Ukrania', '86810-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11347, 'Londrina', 'Doutor Dirceu Antunes Sampaio', 'Conjunto Farid Libos', '86087-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11348, 'Foz do Iguaçu', 'Doutor Dirceu Lopes', 'Vila Yolanda', '85853-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11349, 'Curitiba', 'Doutor Djalma Ferreira Lopes', 'Guabirotuba', '81510-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11350, 'Curitiba', 'Doutor Domício Costa', 'Xaxim', '81720-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11351, 'Londrina', 'Doutor Douglas Antônio Jozzolino', 'Conjunto Farid Libos', '86087-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11352, 'Curitiba', 'Doutor Durval Pinto Cordeiro', 'São Braz', '82315-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11353, 'Curitiba', 'Doutor Edemar Ernsen', 'Campo Comprido', '81200-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11354, 'Ponta Grossa', 'Doutor Edgar Sponholz', 'Contorno', '84052-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11355, 'Curitiba', 'Doutor Edmir Silveira d''Ávila', 'Seminário', '80310-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11356, 'Umuarama', 'Doutor Eduardo Dias Coelho', 'Parque Cidade Jardim', '87506-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11357, 'Curitiba', 'Doutor Eduardo Mendes Gonçalves', 'Bairro Alto', '82820-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11358, 'Apucarana', 'Doutor Egídio Genaro Tucci', 'Núcleo Habitacional Osmar G Freire', '86801-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11359, 'Curitiba', 'Doutor Egídio Pereira', 'Fazendinha', '81320-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11360, 'Curitiba', 'Doutor Egon Armando Krueger', 'Cidade Industrial', '81350-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11361, 'Araucária', 'Doutor Eli Volpato', 'Chapada', '83707-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11362, 'Londrina', 'Doutor Elias César', 'Caiçaras', '86015-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11363, 'Curitiba', 'Doutor Emir Roque Dória', 'Cidade Industrial', '81260-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11364, 'Curitiba', 'Doutor Enéas Marques dos Santos', 'Seminário', '80740-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11365, 'Curitiba', 'Doutor Ennio Marçal', 'Tingui', '82600-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11366, 'Curitiba', 'Doutor Ernâni Arzua Pereira', 'São Francisco', '80510-150', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11367, 'São José dos Pinhais', 'Doutor Ernâni Benghi', 'Ipê', '83055-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11368, 'Curitiba', 'Doutor Ernesto Essenfelder Traub', 'Augusta', '81260-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11369, 'Curitiba', 'Doutor Ernesto Schwartz', 'Parolin', '80220-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11370, 'Curitiba', 'Doutor Estevam Ribeiro de Souza Neto', 'Cajuru', '82900-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11371, 'Ponta Grossa', 'Doutor Estevan Ribeiro Souza Neto', 'Contorno', '84061-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11372, 'Ponta Grossa', 'Doutor Euclides Ferreira Martins', 'Estrela', '84050-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11373, 'Curitiba', 'Doutor Eugênio Bertolli', 'Santa Felicidade', '82410-530', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11374, 'Ponta Grossa', 'Doutor Eugênio José Bocchi', 'Boa Vista', '84070-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11375, 'Curitiba', 'Doutor Eurico César de Almeida', 'Bacacheri', '82510-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11376, 'Guarapuava', 'Doutor Euripio Rauen', 'Morro Alto', '85067-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11377, 'Curitiba', 'Doutor Euzébio de Oliveira', 'Uberaba', '81570-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11378, 'Maringá', 'Doutor Ewert Eugênio de A. Nogueira', 'Vila Esperança', '87020-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11379, 'Curitiba', 'Doutor Fabiano Siqueira Cunha', 'Sítio Cercado', '81900-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11380, 'Ponta Grossa', 'Doutor Fábio de Mello Bonilha', 'Boa Vista', '84073-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11381, 'Telêmaco Borba', 'Doutor Fábio Fannuchi', 'Centro', '84261-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11382, 'Curitiba', 'Doutor Fábio Rogério Bertoli Arns', 'Uberaba', '81590-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11383, 'Curitiba', 'Doutor Fábio Rogério Bertoli Arns', 'Uberaba', '81550-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11384, 'Curitiba', 'Doutor Faivre', 'Centro', '80060-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11385, 'Piraquara', 'Doutor Fajardo', 'Jardim Veneza', '83310-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14819, 'Londrina', 'Gêmeos', 'Sol', '86070-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11386, 'Paranavaí', 'Doutor Farias Bandeira', 'Jardim Santa Eugênia', '87705-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11387, 'Curitiba', 'Doutor Faruk Abrão Kalil', 'Butiatuvinha', '82400-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11388, 'Cascavel', 'Doutor Flausino Mendes', 'Maria Luiza', '85819-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11389, 'Curitiba', 'Doutor Flávio Luz', 'Juvevê', '80030-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11390, 'São José dos Pinhais', 'Doutor Flávio Zetola', 'Três Marias', '83030-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11392, 'Toledo', 'Doutor Flores', 'Centro', '85901-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11393, 'Ponta Grossa', 'Doutor Florindo Zampieri Filho', 'Chapada', '84072-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11394, 'Apucarana', 'Doutor Fouad Elias Massad Salomão', 'Vila Minas Gerais', '86808-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11395, 'Curitiba', 'Doutor Francisco Alexandre Guedes Chagas', 'Campina do Siqueira', '80740-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11396, 'Pato Branco', 'Doutor Francisco Beltrão', 'Santa Terezinha', '85501-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11397, 'Pato Branco', 'Doutor Francisco Beltrão', 'Industrial', '85506-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11398, 'Ponta Grossa', 'Doutor Francisco Burzio', 'Centro', '84010-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11399, 'Curitiba', 'Doutor Francisco de Figueiredo Condessa Filho', 'Campo Comprido', '81210-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11400, 'São José dos Pinhais', 'Doutor Francisco Fajardo', 'Afonso Pena', '83050-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11401, 'Ponta Grossa', 'Doutor Francisco Fajardo', 'Olarias', '84035-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11402, 'Londrina', 'Doutor Francisco Jozolino', 'Vânia', '86025-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11403, 'Curitiba', 'Doutor Francisco Natel de Camargo', 'Santa Cândida', '82640-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11404, 'Curitiba', 'Doutor Francisco Paula Soares', 'São Braz', '82300-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11405, 'Curitiba', 'Doutor Francisco Ribeiro Azevedo de Macedo', 'Santa Quitéria', '80310-190', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11406, 'Curitiba', 'Doutor Francisco Soares', 'Novo Mundo', '81030-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11407, 'Londrina', 'Doutor Francisco Xavier', 'Cilo 3', '86072-410', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11408, 'Curitiba', 'Doutor Gabriel Ferreira Filho', 'Uberaba', '81550-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11409, 'Curitiba', 'Doutor Galeno de Brito', 'Sítio Cercado', '81920-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11410, 'Curitiba', 'Doutor Gastão Faria', 'Fanny', '81030-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11411, 'Maringá', 'Doutor Gastão Vidigal', 'Zona 08', '87050-440', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11412, 'Maringá', 'Doutor Gastão Vidigal', 'Conjunto Residencial Cidade Alta', '87053-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11413, 'Curitiba', 'Doutor Gastão Vidigal', 'Cajuru', '82940-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11414, 'Curitiba', 'Doutor Generoso Borges', 'Batel', '80440-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11415, 'Londrina', 'Doutor Generoso Marques', 'Country Club', '86060-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11416, 'Londrina', 'Doutor Gervásio Mourão Morales', 'Conjunto Farid Libos', '86087-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11417, 'Curitiba', 'Doutor Giddalti Ferreira do Nascimento', 'Cidade Industrial', '81270-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11418, 'Londrina', 'Doutor Gilney Carneiro Leal', 'Jamile Dequech', '86048-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11419, 'Curitiba', 'Doutor Gonzaga de Campos', 'Uberaba', '81570-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11420, 'Curitiba', 'Doutor Goulin', 'Alto da Glória', '80030-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11421, 'Curitiba', 'Doutor Goulin', 'Juvevê', '80040-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11422, 'Araucária', 'Doutor Guilherme da Motta Correia', 'Centro', '83702-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11423, 'Curitiba', 'Doutor Hamilton Dybowicz', 'Uberaba', '81570-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11424, 'São José dos Pinhais', 'Doutor Hamilton Osmar Egg', 'Zaniolo', '83025-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11425, 'Curitiba', 'Doutor Hamilton Portugal Pereira', 'Cajuru', '82980-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11426, 'Curitiba', 'Doutor Heitor Baggio', 'Cidade Industrial', '81350-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11427, 'Curitiba', 'Doutor Heitor Valente', 'Tarumã', '82800-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11428, 'Curitiba', 'Doutor Heleno da Silveira', 'Boqueirão', '81750-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11429, 'Campo Largo', 'Doutor Henrique Nogueira Dorfmund', 'Bom Jesus', '83604-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11430, 'Maringá', 'Doutor Herbert Mayer', 'Conjunto Habitacional Karina', '87047-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11431, 'Londrina', 'Doutor Hermínio Marcos Reis', 'Conjunto Farid Libos', '86087-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11432, 'Curitiba', 'Doutor Homero Ravedutti', 'Atuba', '82860-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11433, 'Araucária', 'Doutor Honestalio Guimarães', 'Centro', '83702-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11434, 'Curitiba', 'Doutor Hugo Camargo', 'Cidade Industrial', '81450-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11435, 'Curitiba', 'Doutor Hugo de Barros', 'Jardim das Américas', '81530-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11436, 'Piraquara', 'Doutor Hugo Hary Marquart', 'Guarituba', '83310-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11437, 'Campo Mourão', 'Doutor Hugo Lisot', 'Jardim Paulino', '87306-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11438, 'Campo Largo', 'Doutor Ito Carias de Oliveira', 'Vila Dona Fina', '83609-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11439, 'Curitiba', 'Doutor Ivan Ferreira do Amaral', 'Cidade Industrial', '81350-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11440, 'Curitiba', 'Doutor Ivo Reck', 'Pilarzinho', '82100-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11441, 'Curitiba', 'Doutor Jair Lima Gevaerd', 'Sítio Cercado', '81925-577', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11442, 'Ponta Grossa', 'Doutor Jamil Mussi', 'Jardim Carvalho', '84015-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11443, 'Castro', 'Doutor Javert Madureira', 'Invernada do Matadouro', '84174-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11444, 'Castro', 'Doutor Javert Madureira', 'Vila Rio Branco', '84172-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11445, 'São José dos Pinhais', 'Doutor Jayme Franca', 'São Cristóvão', '83005-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11446, 'Ponta Grossa', 'Doutor Jayme Gusmann', 'Ronda', '84051-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11447, 'Ponta Grossa', 'Doutor João Alves Pereira', 'Colônia Dona Luiza', '84046-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11448, 'Curitiba', 'Doutor João Antônio Ferreira', 'Santa Cândida', '82630-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11449, 'Curitiba', 'Doutor João Carlos de Macedo Lopes', 'Cidade Industrial', '81450-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11450, 'Curitiba', 'Doutor João Carlos Hartley Gutierrez', 'Vista Alegre', '80810-190', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11451, 'Curitiba', 'Doutor João de Lima Cordeiro', 'Centro Cívico', '80030-500', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11452, 'Curitiba', 'Doutor João de Oliveira Passos', 'Bom Retiro', '80520-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11453, 'Curitiba', 'Doutor João de Paula Moura Brito', 'Uberaba', '81570-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11454, 'Guarapuava', 'Doutor João Ferreira Neves', 'Vila Bela', '85027-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11455, 'Curitiba', 'Doutor João Kracik Neto', 'Tatuquara', '81940-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11456, 'Guarapuava', 'Doutor João Lacerda Bastos', 'Boqueirão', '85023-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11457, 'Curitiba', 'Doutor João Luiz Bettega', 'Cajuru', '82960-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11458, 'Ponta Grossa', 'Doutor João Maurício Faivre', 'Contorno', '84061-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11459, 'Curitiba', 'Doutor João Motter', 'Mossunguê', '81210-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11460, 'Curitiba', 'Doutor João Nassif', 'Atuba', '82630-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11461, 'Londrina', 'Doutor João Nicolau', 'Jardim Tókio', '86063-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11462, 'Maringá', 'Doutor João Paulino', 'Jardim Alvorada', '87033-450', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11463, 'Curitiba', 'Doutor João Skalski', 'Jardim Botânico', '80210-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11464, 'Curitiba', 'Doutor João Tobias Pinto Rebelo', 'Portão', '81070-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11465, 'Curitiba', 'Doutor João Urban', 'Campo Comprido', '81230-225', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11466, 'Curitiba', 'Doutor João Visinoni', 'Cidade Industrial', '81460-199', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11467, 'Curitiba', 'Doutor Joaquim I. Silveira da Motta', 'Guabirotuba', '81520-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11468, 'Curitiba', 'Doutor Joaquim I. Silveira da Motta', 'Uberaba', '81530-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11470, 'São José dos Pinhais', 'Doutor Joel Tesserolli', 'Miringuava', '83090-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11471, 'Curitiba', 'Doutor Jofre Cabral e Silva', 'Jardim Social', '82520-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11472, 'Curitiba', 'Doutor Jonas Salomão Dequech', 'Alto Boqueirão', '81770-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11473, 'Laranjeiras do Sul', 'Doutor Jorge Barreiros', 'São Francisco', '85303-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11474, 'Curitiba', 'Doutor Jorge Mathias Júnior', 'Mercês', '80810-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11475, 'Curitiba', 'Doutor Jorge Meyer Filho', 'Jardim Botânico', '80210-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11477, 'Castro', 'Doutor Jorge Xavier da Silva', 'Centro', '84165-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11478, 'Curitiba', 'Doutor José Alexandre de Moura Negrini', 'Cajuru', '82980-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11479, 'Curitiba', 'Doutor José Andrade de Azevedo Costa', 'Sítio Cercado', '81920-016', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11480, 'Curitiba', 'Doutor José Burigo', 'Barreirinha', '82210-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11481, 'Maringá', 'Doutor José Carlos Struet', 'Vila Esperança', '87020-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11482, 'Maringá', 'Doutor José Chrisóstomo Capinan', 'Jardim Liberdade', '87045-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11483, 'Araucária', 'Doutor José Czaki', 'Thomaz Coelho', '83707-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11484, 'Curitiba', 'Doutor José Daniel Van DER Brooke Filho', 'Umbará', '81930-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11485, 'Curitiba', 'Doutor José de Almeida Pimpão', 'Sítio Cercado', '81920-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11486, 'Piraquara', 'Doutor José de Dominicis', 'Jardim Esmeralda', '83301-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11487, 'Paranavaí', 'Doutor José de Mattos Filho', 'Jardim Nossa Senhora de Fátima', '87711-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11488, 'Apucarana', 'Doutor José F. Domingues Alexandre', 'Barra Funda', '86800-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11489, 'Curitiba', 'Doutor José Giostri Sobrinho', 'Cajuru', '82980-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11490, 'Curitiba', 'Doutor José Guilherme Loyola', 'Cidade Industrial', '81250-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11491, 'Curitiba', 'Doutor José Lobato da Costa', 'Ganchinho', '81935-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11492, 'Ponta Grossa', 'Doutor José Macedo Loyola', 'Uvaranas', '84031-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11493, 'Curitiba', 'Doutor José Manoel Ribeiro dos Santos', 'Cidade Industrial', '81350-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11494, 'Londrina', 'Doutor José Nery Machado', 'Conjunto Farid Libos', '86087-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11495, 'Londrina', 'Doutor José Octaviano Figueiredo', 'Jamile Dequech', '86048-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11496, 'Sarandi', 'Doutor José Olímpio Franco', 'Parque Industrial I', '87111-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11497, 'Curitiba', 'Doutor José Pires Braga', 'Tatuquara', '81480-257', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11498, 'Curitiba', 'Doutor José Salvador Ferreira', 'Cidade Industrial', '81315-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11499, 'Ponta Grossa', 'Doutor José Theodomiro Miro Guimarães', 'Chapada', '84062-330', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11500, 'Curitiba', 'Doutor Juarez de Oliveira', 'Jardim das Américas', '81530-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11501, 'Curitiba', 'Doutor Júlio Farah', 'Uberaba', '81570-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11502, 'Arapongas', 'Doutor Júlio Junqueira', 'Centro', '86701-160', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11503, 'Ponta Grossa', 'Doutor Júlio Prestes de Albuquerque', 'Uvaranas', '84030-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11504, 'Araucária', 'Doutor Júlio Szymanski', 'Centro', '83702-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11505, 'Apucarana', 'Doutor Juvenal Cantador', 'Parque Bela Vista', '86803-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11506, 'Londrina', 'Doutor Juvenal Egger Filho', 'Conjunto Farid Libos', '86087-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11507, 'São José dos Pinhais', 'Doutor Kival Fernando Pereira', 'Três Marias', '83030-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11508, 'Guarapuava', 'Doutor Laranjeiras', 'Centro', '85010-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11509, 'Guarapuava', 'Doutor Laranjeiras', 'Batel', '85015-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11510, 'Ponta Grossa', 'Doutor Laudelino Gonçalves', 'Chapada', '84062-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11511, 'Curitiba', 'Doutor Laurindo Abelardo de Brito', 'Boqueirão', '81730-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11512, 'Curitiba', 'Doutor Lauro Gentio Portugal Tavares', 'Sítio Cercado', '81920-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11513, 'Curitiba', 'Doutor Lauro Gentio Portugal Tavares', 'Sítio Cercado', '81925-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11514, 'Curitiba', 'Doutor Lauro Nery Canto', 'Seminário', '80740-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11515, 'Curitiba', 'Doutor Lauro Wolff Valente', 'Portão', '81070-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11516, 'Curitiba', 'Doutor Leão Mocellin', 'Santa Felicidade', '82030-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11517, 'Piraquara', 'Doutor Leocadio', 'Jardim Veneza', '83310-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11518, 'Paranaguá', 'Doutor Leocádio', 'Centro Histórico', '83203-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11519, 'Curitiba', 'Doutor Leocádio Cisneiros Corrêa', 'Xaxim', '81810-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11520, 'Colombo', 'Doutor Leocádio José Corrêa', 'Roseira', '83415-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11521, 'Curitiba', 'Doutor Leocádio José Corrêa', 'Seminário', '80310-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11522, 'Curitiba', 'Doutor Leônidas do Amaral Ferreira', 'Cristo Rei', '80050-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11523, 'Guarapuava', 'Doutor Leopoldo Francisco Bischof', 'Industrial', '85053-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11524, 'Ponta Grossa', 'Doutor Leopoldo Guimarães da Cunha', 'Oficinas', '84035-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11525, 'Curitiba', 'Doutor Levi Miró Carneiro', 'Cidade Industrial', '81460-189', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11526, 'Curitiba', 'Doutor Levino Bornancin', 'Cajuru', '82950-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11527, 'Curitiba', 'Doutor Levy Buquera', 'Sítio Cercado', '81910-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11528, 'Curitiba', 'Doutor Libânio Estanislau Cardoso', 'Cidade Industrial', '81460-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11529, 'Londrina', 'Doutor Lisímaco Ferreira da Costa', 'Recreio', '86025-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11530, 'Curitiba', 'Doutor Lourival Schwansce Torres', 'Bigorrilho', '80730-340', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11531, 'Curitiba', 'Doutor Lubumir Viergbiski', 'Campo Comprido', '81220-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11532, 'Curitiba', 'Doutor Luís Carlos Vieira Ugliano', 'Atuba', '82630-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11533, 'Guarapuava', 'Doutor Luís de Souza', 'Vila Bela', '85025-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11534, 'Curitiba', 'Doutor Luisnei Rodrigues da Silva', 'Boqueirão', '81750-295', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11535, 'Londrina', 'Doutor Luiz Aranda', 'Jamile Dequech', '86048-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11536, 'Campo Mourão', 'Doutor Luiz Carlos Klank', 'Jardim Francisco Ferreira Albuquerque', '87309-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11537, 'Curitiba', 'Doutor Luiz Fernando Van DER Broocke', 'Bacacheri', '82520-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11538, 'Curitiba', 'Doutor Luiz Losso Filho', 'Novo Mundo', '81050-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11539, 'Foz do Iguaçu', 'Doutor Luiz Passos', 'Pilar Parque Campestre', '85862-270', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11540, 'Umuarama', 'Doutor Luiz Teixeira Mendes', 'Zona IV', '87504-540', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11541, 'Curitiba', 'Doutor Lysandro Santos Lima', 'Cidade Industrial', '81315-015', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11542, 'Ponta Grossa', 'Doutor Manoel Antônio Braga Ramos', 'Estrela', '84050-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11543, 'Curitiba', 'Doutor Manoel Francisco Ferreira Correia', 'Portão', '81320-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11544, 'Curitiba', 'Doutor Manoel Linhares de Lacerda', 'Capão Raso', '81110-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11545, 'Curitiba', 'Doutor Manoel Lopes de Alencar', 'São Lourenço', '82200-480', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11546, 'Curitiba', 'Doutor Manoel Macedo Loyola', 'Mercês', '80810-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11547, 'Curitiba', 'Doutor Manoel Magalhães de Abreu', 'Uberaba', '81570-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11548, 'Curitiba', 'Doutor Manoel Pedro', 'Cabral', '80035-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11549, 'São José dos Pinhais', 'Doutor Manoel Ribeiro de Campos', 'Centro', '83005-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11550, 'Curitiba', 'Doutor Marcallo Tissot', 'Santo Inácio', '82010-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11551, 'São José dos Pinhais', 'Doutor Marcelino Nogueira', 'Centro', '83005-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11552, 'Curitiba', 'Doutor Marins Alves de Camargo', 'Tingui', '82620-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11553, 'Guarapuava', 'Doutor Mário Augusto Teixeira Freitas', 'Vila Bela', '85027-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11554, 'Londrina', 'Doutor Mário Campos', 'Parigot de Souza 2', '86082-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11555, 'Maringá', 'Doutor Mário Clapier Urbinati', 'Jardim Universitário', '87020-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11556, 'Maringá', 'Doutor Mário Clapier Urbinatti', 'Jardim Canadá', '87080-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11557, 'Curitiba', 'Doutor Mário Esmanhotto', 'Santa Felicidade', '82030-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11558, 'Ponta Grossa', 'Doutor Mário Jorge', 'Uvaranas', '84030-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11559, 'São José dos Pinhais', 'Doutor Mário Jorge', 'Miringuava', '83090-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11560, 'Curitiba', 'Doutor Mário Jorge', 'Cidade Industrial', '81450-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11561, 'Ponta Grossa', 'Doutor Mário Lima Santos', 'Estrela', '84050-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11562, 'Curitiba', 'Doutor Mário Miró Filho', 'Uberaba', '81540-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11563, 'Toledo', 'Doutor Mário Totta', 'Vila Industrial', '85905-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11564, 'Curitiba', 'Doutor Mba de Ferrante', 'Santa Felicidade', '82030-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11565, 'Campo Largo', 'Doutor Medeiros', 'Vila David Antônio', '83609-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11566, 'Curitiba', 'Doutor Mendes de Araújo', 'Abranches', '82130-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11567, 'Ponta Grossa', 'Doutor Michel Namur', 'Boa Vista', '84073-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11568, 'Londrina', 'Doutor Miguel Augel Espinosa', 'Jamile Dequech', '86048-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11569, 'Guarapuava', 'Doutor Miguel Bohomoletz', 'Vila Bela', '85027-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11570, 'Ponta Grossa', 'Doutor Miguel Quadros', 'Contorno', '84062-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11571, 'Maringá', 'Doutor Miguel Vieira Ferreira', 'Vila Santo Antônio', '87020-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11572, 'Maringá', 'Doutor Miguel Zacarias', 'Vila Progresso', '87080-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11573, 'Curitiba', 'Doutor Milton Loureiro', 'Bom Retiro', '80520-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11574, 'Apucarana', 'Doutor Miyoje Kogure', 'Vila Flamboyant', '86804-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11575, 'Londrina', 'Doutor Moacir Arcoverde', 'Aquilles Sthengel', '86086-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11576, 'Foz do Iguaçu', 'Doutor Moacir Azambuja', 'Parque Imperatriz', '85862-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11577, 'Londrina', 'Doutor Moacir Martins', 'San Fernando', '86040-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11578, 'Curitiba', 'Doutor Mohty Domit', 'Jardim Social', '82520-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11579, 'Ponta Grossa', 'Doutor Moncorvo Filho', 'Oficinas', '84036-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11580, 'São José dos Pinhais', 'Doutor Motta Júnior', 'Centro', '83005-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11581, 'São José dos Pinhais', 'Doutor Motta Júnior', 'Aristocrata', '83025-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11582, 'Ponta Grossa', 'Doutor Mozart Villaca', 'Orfãs', '84015-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11583, 'Apucarana', 'Doutor Munhoz da Rocha', 'Centro', '86800-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11584, 'Guarapuava', 'Doutor Murici', 'Alto da XV', '85065-060', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11585, 'Pato Branco', 'Doutor Murici', 'Jardim Primavera', '85502-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11586, 'São José dos Pinhais', 'Doutor Murici', 'Colônia Murici', '83085-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11587, 'São José dos Pinhais', 'Doutor Murici', 'Costeira', '83015-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11588, 'Curitiba', 'Doutor Muricy', 'Centro', '80010-120', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11589, 'Curitiba', 'Doutor Muricy', 'Centro', '80020-040', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11590, 'Maringá', 'Doutor Naby Zacarias', 'Vila Progresso', '87080-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11591, 'Apucarana', 'Doutor Nagib Daher', 'Centro', '86800-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11592, 'São José dos Pinhais', 'Doutor Narciso Nogueira Machado', 'Costeira', '83015-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11593, 'Curitiba', 'Doutor Nelson Berno', 'Prado Velho', '80215-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11594, 'Curitiba', 'Doutor Nelson de Souza Pinto', 'São Lourenço', '82200-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11595, 'Curitiba', 'Doutor Nelson José Corrêa', 'Boa Vista', '82540-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11596, 'Curitiba', 'Doutor Nelson Lins d''Albuquerque', 'Bom Retiro', '80520-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11597, 'Curitiba', 'Doutor Nelson Luís Wolski Velloso', 'Cidade Industrial', '81250-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11598, 'Maringá', 'Doutor Nerico da Silva', 'Parque das Grevíleas', '87025-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11599, 'Londrina', 'Doutor Newton Leopoldo Câmara', 'Conjunto Farid Libos', '86087-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11600, 'Curitiba', 'Doutor Ney Leprevost', 'Santo Inácio', '82010-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11601, 'São José dos Pinhais', 'Doutor Nivaldo Ênio de Moura e Costa', 'Rio Pequeno', '83070-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11602, 'Curitiba', 'Doutor Norton Ramos', 'Parolin', '81030-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11603, 'Curitiba', 'Doutor Odarci Antônio Mangi', 'Sítio Cercado', '81920-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11604, 'Castro', 'Doutor Odiles Petreski', 'Núcleo Habitacional Padre Piva', '84178-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11605, 'Toledo', 'Doutor Olavo Secco Rigon', 'Panorama', '85911-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11606, 'Londrina', 'Doutor Orlando Teodoro de Freitas', 'Jamile Dequech', '86048-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11607, 'Londrina', 'Doutor Orlando Vicentini', 'Conjunto Farid Libos', '86087-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11608, 'Curitiba', 'Doutor Osvaldo Nunes Ribeiro', 'Atuba', '82630-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11609, 'Toledo', 'Doutor Osvaldo Silveira', 'Vila Industrial', '85904-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11610, 'Londrina', 'Doutor Oswaldo A. Palhares', 'Jardim Tókio', '86063-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11611, 'Apucarana', 'Doutor Oswaldo Cruz', 'Vila Vitória', '86802-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11612, 'Apucarana', 'Doutor Oswaldo Cruz', 'Centro', '86800-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11613, 'Curitiba', 'Doutor Oswaldo Vieira', 'Bacacheri', '82520-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11614, 'Castro', 'Doutor Otávio Novaes Júnior', 'Jardim Social Arapongas', '84174-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11615, 'Curitiba', 'Doutor Othon Accioly Rodrigues da Costa', 'Cajuru', '82970-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11616, 'Curitiba', 'Doutor Otto Ernesto Blume', 'Vista Alegre', '80820-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11617, 'Guarapuava', 'Doutor Otto Rickli', 'São Cristóvão', '85060-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11618, 'Curitiba', 'Doutor Ovande do Amaral', 'Jardim das Américas', '81520-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11619, 'Curitiba', 'Doutor Ozeas Saraiva de Araújo', 'Uberaba', '81590-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11620, 'Curitiba', 'Doutor Pamphilo d''Assumpção', 'Parolin', '80220-041', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11621, 'Curitiba', 'Doutor Pamphilo d''Assumpção', 'Rebouças', '80220-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11622, 'Ponta Grossa', 'Doutor Paula Xavier', 'Centro', '84010-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11623, 'Ponta Grossa', 'Doutor Paula Xavier', 'Estrela', '84040-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11624, 'Curitiba', 'Doutor Paulo Júlio F. Bittencourt', 'Tatuquara', '81480-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11625, 'Umuarama', 'Doutor Paulo Pedrosa de Alencar', 'Zona I', '87501-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11626, 'Curitiba', 'Doutor Pedro Augusto Menna Barreto Monclaro', 'Água Verde', '80250-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11627, 'Curitiba', 'Doutor Pedro Darcy de Souza', 'Sítio Cercado', '81920-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11628, 'Curitiba', 'Doutor Pedro Suarez Galvan', 'São Braz', '82015-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11629, 'Curitiba', 'Doutor Pedro Zavaski', 'Pinheirinho', '81820-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11630, 'Curitiba', 'Doutor Pedro Zavaski', 'Pinheirinho', '81825-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11632, 'Curitiba', 'Doutor Penrose Franklin', 'Capão Raso', '81130-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11633, 'Ponta Grossa', 'Doutor Penteado de Almeida', 'Centro', '84010-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11634, 'Toledo', 'Doutor Percimo Chiaretto', 'Conjunto Barão do Rio Branco II', '85905-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11635, 'Curitiba', 'Doutor Percival Loyola', 'Portão', '81320-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11636, 'Guarapuava', 'Doutor Péricles Silva Costa', 'Vila Bela', '85025-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11637, 'Ponta Grossa', 'Doutor Petrônio Fernal', 'Oficinas', '84035-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11638, 'Curitiba', 'Doutor Petrônio Romero de Souza', 'Cajuru', '82970-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11639, 'Apucarana', 'Doutor Pinheiro Machado', 'Núcleo Habitacional Parigot de Souza', '86802-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11640, 'Ponta Grossa', 'Doutor Plauto Miró Guimarães', 'Boa Vista', '84070-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11641, 'Curitiba', 'Doutor Plínio Gonçalves Marques', 'Pinheirinho', '81880-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11642, 'Curitiba', 'Doutor Polan Duszczak', 'Cidade Industrial', '81280-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11643, 'São José dos Pinhais', 'Doutor Quinzito de Quadros Souza', 'Cidade Jardim', '83035-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11644, 'Curitiba', 'Doutor Rafi Salum', 'São Braz', '82015-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11645, 'Curitiba', 'Doutor Raul Carneiro Filho', 'Água Verde', '80620-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11646, 'Paranaguá', 'Doutor Rego', 'Dom Pedro II', '83221-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11647, 'Curitiba', 'Doutor Renê Dinorah da Silveira', 'Tarumã', '82530-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11648, 'Curitiba', 'Doutor Reynaldo Machado', 'Rebouças', '80215-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11649, 'Curitiba', 'Doutor Ricardo Beltrami', 'Bom Retiro', '80520-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11650, 'Londrina', 'Doutor Ricardo Skowroneck', 'Conjunto Farid Libos', '86087-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11651, 'Paranavaí', 'Doutor Riszardo Edmundo Gluchowski', 'Jardim Santos Dumont', '87706-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11652, 'Curitiba', 'Doutor Roberto Barrozo', 'Centro Cívico', '80530-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11653, 'Curitiba', 'Doutor Roberto Barrozo', 'São Francisco', '80520-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11654, 'Curitiba', 'Doutor Roberto Barrozo', 'Vista Alegre', '80810-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11655, 'Guarapuava', 'Doutor Roberto Cunha e Silva', 'Vila Bela', '85027-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11656, 'Ponta Grossa', 'Doutor Roberto de Brito', 'Contorno', '84060-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11657, 'Ponta Grossa', 'Doutor Roberto de Jesus Portella', 'Jardim Carvalho', '84015-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11658, 'Londrina', 'Doutor Rodolfo Rizzi', 'Conjunto Farid Libos', '86087-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11659, 'Castro', 'Doutor Romário Martins', 'Centro', '84165-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11660, 'Curitiba', 'Doutor Romualdo A. Baraúna', 'Campina do Siqueira', '80740-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11661, 'Foz do Iguaçu', 'Doutor Rómulo Trevisan', 'Vila Adriana', '85854-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11662, 'Ponta Grossa', 'Doutor Ronie Cardoso', 'Jardim Carvalho', '84016-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11663, 'Curitiba', 'Doutor Roque Vernalha', 'Cristo Rei', '80050-620', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11664, 'Curitiba', 'Doutor Rubem Fleury da Rocha', 'Abranches', '82130-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11665, 'Ponta Grossa', 'Doutor Rúbens Gomes de Souza', 'Orfãs', '84015-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11666, 'Curitiba', 'Doutor Rúbens Machado Câmara', 'Jardim Social', '82520-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11667, 'Maringá', 'Doutor Rui Carnassiali', 'Conjunto Habitacional Karina', '87047-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11668, 'Umuarama', 'Doutor Rui Ferraz de Carvalho', 'Zona I', '87501-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11669, 'Curitiba', 'Doutor Salvador de Maio', 'Jardim Botânico', '80215-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11670, 'Cascavel', 'Doutor Sandino Erasmo de Amorim', 'Maria Luiza', '85819-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11671, 'Cascavel', 'Doutor Sandino Erasmo de Amorin', 'Parque São Paulo', '85803-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11672, 'Curitiba', 'Doutor Satilas do Amaral Camargo', 'Tingui', '82620-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11673, 'Maringá', 'Doutor Saulo Porto Virmond', 'Chácara Paulista', '87005-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11674, 'Curitiba', 'Doutor Sebastião Farajala Bacila', 'Cajuru', '82950-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11675, 'Curitiba', 'Doutor Sérgio Francisco de Souza Castro', 'Uberaba', '81580-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11676, 'Paranavaí', 'Doutor Sílvio Meira e Sá Bezerra', 'Jardim Progresso', '87701-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11677, 'Paranaguá', 'Doutor Simão Aisemann', 'Campo Grande', '83203-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11678, 'Curitiba', 'Doutor Simão Kossobudski', 'Uberaba', '81580-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11679, 'Curitiba', 'Doutor Simão Kossobudski', 'Boqueirão', '81730-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11680, 'Castro', 'Doutor Sizenando Bourguignon', 'Vila Santa Cruz', '84168-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11681, 'Curitiba', 'Doutor Sobral Pinto', 'Cidade Industrial', '81350-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11682, 'Paranavaí', 'Doutor Sylvio Vidal C. Leite Ribeiro', 'Centro', '87701-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11683, 'Paranavaí', 'Doutor Sylvio Vidal C. Leite Ribeiro', 'Jardim São Cristóvão', '87702-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11684, 'Curitiba', 'Doutor Tarcílio Gaziri', 'Cascatinha', '82020-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11685, 'Curitiba', 'Doutor Theodorico Bittencourt', 'Jardim Social', '82520-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11686, 'Curitiba', 'Doutor Theodorico de Oliveira Franco', 'Cajuru', '82970-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11687, 'Foz do Iguaçu', 'Doutor Toscano de Brito', 'Vila Adriana II', '85854-470', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11688, 'Almirante Tamandaré', 'Doutor Ulisses Guimarães', 'Jardim Anita Garibaldi', '83504-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11689, 'Piraquara', 'Doutor Ulysses Guimarães', 'Planta Guarituba Pequena', '83310-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11690, 'Curitiba', 'Doutor Urbano Toniolo', 'Cajuru', '82920-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11691, 'Araucária', 'Doutor Valério Sobania', 'Capela Velha', '83706-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11692, 'Londrina', 'Doutor Vicente Machado', 'Bom Retiro', '86025-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11693, 'Paranavaí', 'Doutor Vicente Machado', 'Jardim São Jorge', '87710-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11694, 'Ponta Grossa', 'Doutor Vicente Machado', 'Centro', '84010-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11695, 'Araucária', 'Doutor Vicente Machado', 'Centro', '83702-310', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11696, 'Araucária', 'Doutor Victor do Amaral', 'Centro', '83702-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11697, 'Paranavaí', 'Doutor Vieira Lins', 'Centro', '87701-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11698, 'Curitiba', 'Doutor Vilson Pienegonda', 'Cidade Industrial', '81450-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11699, 'Araucária', 'Doutor Vital Brasil', 'Estação', '83705-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11700, 'Maringá', 'Doutor Vladimir Babkov', 'Parque Industrial Mário Bulhões', '87065-665', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11701, 'Pinhais', 'Doutor Waldemar da Costa Lima', 'Planta Cláudio Mehl', '83326-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11702, 'Ponta Grossa', 'Doutor Waldemar Steudel', 'Estrela', '84050-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11703, 'Curitiba', 'Doutor Waldemiro Pereira', 'Capão Raso', '81150-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11704, 'Londrina', 'Doutor Waldiro de Campos Gouvea', 'Jardim Graziela', '86036-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11705, 'Curitiba', 'Doutor Waldyr Obayashi', 'Butiatuvinha', '82400-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11706, 'Apucarana', 'Doutor Wolfgang Wetterer', 'Vila Nova Cidade', '86811-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11707, 'Curitiba', 'Doutor Zamenhof', 'Alto da Glória', '80030-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11708, 'Curitiba', 'Doutor Zerbini', 'Santa Cândida', '82630-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11709, 'Curitiba', 'Doutora Alzira Pirath Corrêa', 'Pinheirinho', '81150-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11710, 'Curitiba', 'Doutora Cenira Ribeiro', 'Xaxim', '81830-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11711, 'Curitiba', 'Doutora Iria Correia', 'Abranches', '82130-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11712, 'Curitiba', 'Doutora Jenny Lagos Pereira de Souza', 'Santa Cândida', '82720-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11713, 'Curitiba', 'Doutora Juracy Riquelme', 'Capão da Imbuia', '82810-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11714, 'Curitiba', 'Doutora Maria Falce de Macedo', 'Ahú', '82200-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11715, 'Curitiba', 'Doutora Martha Silva Gomes', 'Portão', '81070-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11716, 'Curitiba', 'Doutora Ottília dos Santos Franca', 'Cajuru', '82950-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11717, 'Curitiba', 'Doutora Wanda de Aguiar Horta', 'Cidade Industrial', '81170-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11718, 'Londrina', 'Doutoura Anita Carvalho', 'Santa Mônica', '86079-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11719, 'Londrina', 'Doutoura Yolanda Gomes Skowroneck', 'Conjunto Farid Libos', '86087-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11720, 'Curitiba', 'Doval David', 'Cidade Industrial', '81460-306', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11721, 'Curitiba', 'Dovico Dalprá', 'Abranches', '82220-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11722, 'Ponta Grossa', 'Doze', 'Uvaranas', '84030-507', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11723, 'Ponta Grossa', 'Doze', 'Uvaranas', '84022-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11724, 'Ponta Grossa', 'Doze', 'Chapada', '84064-579', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11725, 'Ponta Grossa', 'Doze', 'Chapada', '84063-429', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11726, 'Ponta Grossa', 'Doze', 'Contorno', '84060-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11727, 'Ponta Grossa', 'Doze', 'Contorno', '84060-579', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11728, 'Ponta Grossa', 'Doze', 'Uvaranas', '84032-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11729, 'Ponta Grossa', 'Doze', 'Jardim Carvalho', '84016-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11730, 'Ponta Grossa', 'Doze', 'Boa Vista', '84072-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11731, 'Ponta Grossa', 'Doze', 'Uvaranas', '84026-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11732, 'Ponta Grossa', 'Doze', 'Uvaranas', '84030-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11733, 'Umuarama', 'Doze', 'Jardim Maria Lúcia', '87501-669', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11734, 'Campo Largo', 'Doze', 'Jardim Guarany I', '83608-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11735, 'Campo Largo', 'Doze', 'Jardim Lorenzete', '83603-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11736, 'Almirante Tamandaré', 'Doze', 'Jardim Campo Verde', '83502-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11737, 'Almirante Tamandaré', 'Doze', 'Jardim Paraíso', '83512-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11738, 'Almirante Tamandaré', 'Doze', 'Jardim Tatiana', '83513-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11739, 'Campo Largo', 'Doze', 'Jardim Keli Cristina', '83609-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11740, 'Campo Largo', 'Doze', 'Loteamento São Gerônimo', '83606-248', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11741, 'Umuarama', 'Doze de Junho', 'Mutirão Jardim Alvorada', '87506-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11742, 'Guarapuava', 'Doze de Outubro', 'Industrial', '85045-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11743, 'Ponta Grossa', 'Doze de Outubro', 'Centro', '84010-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11744, 'Toledo', 'Doze de Outubro', 'Centro', '85900-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11745, 'Umuarama', 'Doze de Outubro', 'Conjunto Residencial Vinte e Oito de Outubro', '87509-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11746, 'Telêmaco Borba', 'Doze de Outubro', 'Nossa Senhora do Perpétuo Socorro', '84265-550', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11747, 'Cambé', 'Doze de Outubro', 'Jardim União', '86185-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11748, 'Campo Mourão', 'Dozolina Rech Ferrari', 'Jardim Ana Eliza', '87303-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11749, 'Curitiba', 'Dozolina Slompo Lazarotto', 'Boa Vista', '82650-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11750, 'Araucária', 'Dozulina Furlin Buiar', 'Tindiquera', '83708-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11751, 'Foz do Iguaçu', 'Dracena', 'Jardim Canadá', '85869-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11752, 'Maringá', 'Dracena', 'Jardim Industrial', '87065-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11753, 'Umuarama', 'Dracena', 'Conjunto Residencial Córrego Longe', '87504-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11754, 'Arapongas', 'Dragão', 'Parque Industrial II', '86703-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11755, 'Londrina', 'Dragem Feld', 'Jardim Tókio', '86063-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11756, 'Londrina', 'Drongo', 'Conjunto Habitacional Violim', '86084-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11757, 'Arapongas', 'Drongo', 'Centro', '86701-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11758, 'Arapongas', 'Drongo', 'Vila São João', '86708-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11759, 'Arapongas', 'Dronte', 'Vila Edio', '86705-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11760, 'Curitiba', 'Duarte Cesino de Medeiros', 'Cajuru', '82900-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11761, 'Londrina', 'Duarte Coelho', 'Sabará I', '86066-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11762, 'Foz do Iguaçu', 'Duarte da Costa', 'Conjunto Residencial Apora', '85869-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11763, 'Londrina', 'Duarte da Costa', 'São Cristóvão', '86025-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11764, 'Ponta Grossa', 'Duarte da Costa', 'Uvaranas', '84032-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11765, 'Piraquara', 'Duarte da Costa', 'Jardim Bela Vista', '83301-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11766, 'Telêmaco Borba', 'Duarte da Costa', 'Socomim', '84261-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11767, 'Curitiba', 'Duarte da Costa', 'Guaíra', '81010-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11768, 'Foz do Iguaçu', 'Duartina', 'Jardim do Horto', '85854-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11769, 'Maringá', 'Duartina', 'Jardim Lucianópolis', '87080-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11770, 'Curitiba', 'Duílio Dias', 'Xaxim', '81710-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11771, 'Londrina', 'Dulce Loureiro de Oliveira', 'Jardim Paris', '86082-068', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11772, 'Curitiba', 'Dulce Totti Marques', 'Alto Boqueirão', '81860-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11773, 'Londrina', 'Dulce Trigueiros', 'Franciscato II', '86078-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11774, 'Curitiba', 'Dulcídia Ansay', 'Cidade Industrial', '81310-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11775, 'São José dos Pinhais', 'Dulcídio Ananias Pinto', 'Ipê', '83055-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11776, 'Colombo', 'Dulcídio Falavinha', 'Vila Vale Verde', '83406-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11777, 'Londrina', 'Dulcídio Pereira', 'Canaã', '86015-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11778, 'Curitiba', 'Dulcídio Teixeira de Lara', 'Cidade Industrial', '81230-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11779, 'Curitiba', 'Dulcília Sequinele Pinheiro', 'Boqueirão', '81670-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11780, 'Guarapuava', 'Dulcio Camargo Ribas', 'Morro Alto', '85065-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11781, 'Laranjeiras do Sul', 'Duque de Caxias', 'Centro', '85301-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11782, 'Guarapuava', 'Duque de Caxias', 'Vila Bela', '85027-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11783, 'Foz do Iguaçu', 'Duque de Caxias', 'Centro', '85851-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11784, 'Francisco Beltrão', 'Duque de Caxias', 'Marrecas', '85601-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11785, 'Londrina', 'Duque de Caxias', 'Igapó', '86015-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11786, 'Londrina', 'Duque de Caxias', 'Jardim Londrilar', '86010-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11787, 'Londrina', 'Duque de Caxias', 'Vila São Caetano', '86026-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11788, 'Londrina', 'Duque de Caxias', 'Vila São Caetano', '86025-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11789, 'Laranjeiras do Sul', 'Duque de Caxias', 'Cristo Rei', '85304-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11790, 'Maringá', 'Duque de Caxias', 'Zona 07', '87020-025', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11791, 'Maringá', 'Duque de Caxias', 'Zona 01', '87013-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11792, 'São José dos Pinhais', 'Duque de Caxias', 'Bom Jesus', '83025-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11793, 'Pato Branco', 'Duque de Caxias', 'Santo Antônio', '85507-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11794, 'Paranaguá', 'Duque de Caxias', 'Jardim Paranaguá', '83218-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11795, 'Ponta Grossa', 'Duque de Caxias', 'Centro', '84010-750', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11796, 'Paranavaí', 'Duque de Caxias', 'Jardim São Jorge', '87711-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11797, 'Paranavaí', 'Duque de Caxias', 'Jardim São Jorge', '87710-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11798, 'Piraquara', 'Duque de Caxias', 'Jardim Bela Vista', '83301-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11799, 'Umuarama', 'Duque de Caxias', 'Zona V', '87504-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11800, 'Sarandi', 'Duque de Caxias', 'Jardim Panorama', '87113-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11801, 'Sarandi', 'Duque de Caxias', 'Parque Pioneiros', '87114-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11802, 'Apucarana', 'Duque de Caxias', 'Vila São Paulo', '86802-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11803, 'Apucarana', 'Duque de Caxias', 'Vila Agari', '86808-390', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11804, 'Campo Largo', 'Duque de Caxias', 'Vila Nova', '83605-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11805, 'Araucária', 'Duque de Caxias', 'Costeira', '83708-795', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11806, 'Cascavel', 'Duque de Caxias', 'Centro', '85801-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11807, 'Castro', 'Duque de Caxias', 'Centro', '84165-090', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11808, 'Colombo', 'Duque de Caxias', 'Vila Carrano Júnior', '83409-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11809, 'Cambé', 'Duque de Caxias', 'Centro', '86181-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11810, 'Campo Mourão', 'Duque de Caxias', 'Jardim Lar Paraná', '87305-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11811, 'Curitiba', 'Duque de Caxias', 'São Francisco', '80530-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11812, 'Curitiba', 'Duque de Caxias', 'São Francisco', '80510-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11813, 'Colombo', 'Duque Estrada', 'Jardim Central', '83409-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11814, 'Curitiba', 'Durval Alves Moço', 'Boqueirão', '81750-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11815, 'Pinhais', 'Durval Bordignon', 'Jardim Las Palmas', '83325-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11816, 'São José dos Pinhais', 'Durval Borges de Almeida', 'Ipê', '83055-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11817, 'Curitiba', 'Durval Borges de Macedo', 'Capão da Imbuia', '82810-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11818, 'Colombo', 'Durval Ceccon', 'Jardim Nossa Senhora de Fátima', '83405-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11819, 'Ponta Grossa', 'Durval da Silva', 'Oficinas', '84036-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11820, 'Curitiba', 'Durval de Morais', 'Uberaba', '81530-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11821, 'Londrina', 'Durval Fernandes', 'Espírito Santo', '86073-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11822, 'Londrina', 'Durval Ferreira da Silva', 'Jatobá', '86043-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11823, 'Curitiba', 'Durval Jungles', 'Pinheirinho', '81870-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11824, 'Curitiba', 'Durval Leopoldo Landal', 'Cidade Industrial', '81260-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11825, 'Curitiba', 'Durval Leopoldo Landal', 'Cidade Industrial', '81450-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11826, 'Curitiba', 'Durval Pacheco de Carvalho', 'Fanny', '81030-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11827, 'Almirante Tamandaré', 'Durval Raimundo', 'Jardim do Norte', '83511-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11828, 'Londrina', 'Durval Rodrigues dos Santos', 'Jardim Palmas', '86081-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11829, 'Londrina', 'Durval Salto Lessi', 'Jardim Vale Verde', '86040-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11830, 'Ponta Grossa', 'Durval Wolff', 'Chapada', '84062-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11831, 'Curitiba', 'Durvalina Fernandes', 'Atuba', '82860-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11832, 'Telêmaco Borba', 'Durvalina Pupo Ribeiro', 'Vila Ana Mari', '84263-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11833, 'Curitiba', 'Durvalina Purfíria dos Santos', 'Cidade Industrial', '81305-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11834, 'Almirante Tamandaré', 'Durvalino da Silva', 'Vila Ajambi', '83504-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11835, 'Castro', 'Durvalino Kuster de Azevedo', 'Cantagalo', '84178-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11836, 'Londrina', 'Dutra e Mello', 'Jardim Santo Ângelo', '86070-095', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11837, 'Foz do Iguaçu', 'E', 'Conjunto C', '85870-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11838, 'Paranaguá', 'E', 'Itiberê', '83206-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11839, 'Ponta Grossa', 'E', 'Uvaranas', '84031-289', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11840, 'Ponta Grossa', 'E', 'Uvaranas', '84032-479', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11841, 'Ponta Grossa', 'E', 'Colônia Dona Luiza', '84043-558', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11842, 'Ponta Grossa', 'E', 'Cará-cará', '84043-437', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11843, 'Ponta Grossa', 'E', 'Colônia Dona Luiza', '84043-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11844, 'Ponta Grossa', 'E', 'Boa Vista', '84071-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11845, 'Ponta Grossa', 'E', 'Olarias', '84035-286', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11846, 'Ponta Grossa', 'E', 'Contorno', '84060-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11847, 'Umuarama', 'E', 'Parque Dom Pedro I', '87508-018', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11848, 'Campo Largo', 'E', 'Vila Nossa Senhora do Carmo', '83601-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11849, 'Campo Mourão', 'E', 'Distrito Industrial I', '87306-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11850, 'Campo Mourão', 'E', 'Jardim Nossa Senhora Aparecida', '87309-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11851, 'Almirante Tamandaré', 'E', 'Jardim São Caetano', '83507-154', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11852, 'Almirante Tamandaré', 'E', 'Jardim Marrocos', '83511-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11853, 'Campo Largo', 'E', 'Jardim Emília', '83607-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11854, 'Campo Largo', 'E', 'Jardim Tropical', '83602-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11855, 'Campo Largo', 'E', 'Vila Torres I', '83609-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11856, 'Campo Largo', 'E', 'Jardim Três Rios', '83603-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11857, 'Castro', 'E', 'Jardim Bela Vista', '84165-419', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11858, 'Castro', 'E', 'Vila do Rosário', '84168-077', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11859, 'Campo Largo', 'E', 'Popular Nova', '83602-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11860, 'Arapongas', 'E-1', 'Vila Industrial', '86706-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11861, 'Arapongas', 'E-2', 'Vila Industrial', '86706-006', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11862, 'Londrina', 'Ébano', 'Leonor', '86071-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11863, 'Maringá', 'Ébano', 'Parque Residencial Quebec', '87023-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11864, 'Cascavel', 'Ébano', 'Brasmadeira', '85814-136', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11865, 'Almirante Tamandaré', 'Ébano', 'Loteamento Chico Mendes', '83505-765', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11866, 'Foz do Iguaçu', 'Ébano Pereira', 'Jardim Aurora', '85862-249', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11867, 'Paranavaí', 'Ébano Pereira', 'Jardim Panorama', '87707-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11868, 'Curitiba', 'Ébano Pereira', 'Centro', '80410-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11869, 'Curitiba', 'Ebenézer', 'Pilarzinho', '80520-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11870, 'Londrina', 'Ébio Ferraz de Carvalho', 'Rui Barbosa', '86031-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11871, 'Telêmaco Borba', 'Ebraim Campos Santos', 'Socomim', '84266-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11872, 'Curitiba', 'Ebraim Sebastião de Castro', 'Santa Cândida', '82640-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11873, 'Campo Largo', 'Eça de Queirós', 'São Marcos', '83602-689', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11874, 'Londrina', 'Eça de Queiroz', 'Jardim Shangri-la A', '86070-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11875, 'Francisco Beltrão', 'Eça de Queiroz', 'Jardim Novo Mundo', '85602-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11876, 'Francisco Beltrão', 'Eça de Queiroz', 'São Miguel', '85602-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11877, 'Ponta Grossa', 'Eça de Queiroz', 'Colônia Dona Luiza', '84045-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11878, 'Cascavel', 'Eça de Queiroz', 'Alto Alegre', '85805-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11879, 'Curitiba', 'Eça de Queiroz', 'Ahú', '80540-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11880, 'Curitiba', 'Ecilda Melania Voluz Brum', 'Pinheirinho', '81870-065', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11881, 'Cambé', 'Eclesiastes', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11882, 'Curitiba', 'Eclídio Pedro Hecke', 'Jardim Botânico', '80215-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11883, 'Pinhais', 'Ecológica', 'Jardim Triângulo', '83329-020', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11884, 'Pinhais', 'Ecológica', 'Jardim Boa Vista', '83327-060', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11885, 'Pinhais', 'Ecológica', 'Jardim Pio XII', '83328-200', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11886, 'Cascavel', 'Economia', 'Universitário', '85819-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11887, 'Cascavel', 'Edegar Vilaça', 'Cascavel Velho', '85818-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11888, 'Curitiba', 'Edemée Dutra Calçado', 'Sítio Cercado', '81920-745', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11889, 'Londrina', 'Éden', 'Paraíso', '86078-245', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11890, 'Cascavel', 'Eden Luiz Figueiredo', 'Santa Cruz', '85806-737', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11891, 'Curitiba', 'Edenilda M. Leal', 'Sítio Cercado', '81920-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11892, 'Colombo', 'Edenilton Baggio', 'Jardim Viviane', '83407-375', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11893, 'Curitiba', 'Edenir Correia', 'Santa Cândida', '82720-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11894, 'Foz do Iguaçu', 'Edésio Carneiro de Campos', 'Jardim Panorama', '85856-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11895, 'Cambé', 'Edésio Zerberto', 'Jardim Imperatriz', '86181-337', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11896, 'Almirante Tamandaré', 'Edgar Alberto Tiemann', 'Jardim Vitória', '83508-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11897, 'São José dos Pinhais', 'Edgar Allan Poe', 'Aristocrata', '83030-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11898, 'Campo Largo', 'Edgar Basso', 'Jardim Bela Vista', '83605-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11899, 'Curitiba', 'Edgar Bruno Franke', 'Boa Vista', '82650-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11900, 'Almirante Tamandaré', 'Edgar Ferreira do Nascimento', 'Jardim Vitória', '83508-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11901, 'Campo Largo', 'Edgar Marochi', 'Conjunto Águas Claras', '83602-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11902, 'Apucarana', 'Edgar Rank Júnior', 'Núcleo Habitacional Djalma Mendes de Oliveira', '86806-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11903, 'Curitiba', 'Edgar Souza', 'Guabirotuba', '81510-310', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11904, 'Londrina', 'Edgar Távora', 'Santa Rita 3', '86072-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11905, 'Castro', 'Edgard Briski', 'Jardim Social Arapongas', '84174-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11906, 'Curitiba', 'Edgard Cavalcanti de Albuquerque', 'Sítio Cercado', '81920-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11907, 'Curitiba', 'Edgard de Alencar Guimarães', 'Cajuru', '82970-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11908, 'Curitiba', 'Edgard Degas', 'Guabirotuba', '81510-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11909, 'Curitiba', 'Edgard Frega', 'Cidade Industrial', '81460-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11910, 'Curitiba', 'Edgard Lickfeldt', 'Uberaba', '81580-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11911, 'Londrina', 'Edgard Lopes S. Franca', 'Jamile Dequech', '86048-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11912, 'Curitiba', 'Edgard M. Zandoná', 'Cidade Industrial', '81250-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11913, 'Curitiba', 'Edgard Roquete Pinto', 'Bigorrilho', '80730-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11914, 'Curitiba', 'Edgard Rose', 'Fazendinha', '81330-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11915, 'Foz do Iguaçu', 'Edgard Schimmelpfeng', 'Parque Presidente', '85863-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11916, 'Curitiba', 'Edgard Simone', 'Abranches', '82130-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11917, 'Curitiba', 'Edgard Stelfeld', 'Jardim Social', '82530-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11918, 'Cascavel', 'Edi Domingos Dallacosta', 'Pioneiros Catarinenses', '85805-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11919, 'Curitiba', 'Ediloy Helm', 'Campo Comprido', '81220-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11920, 'Curitiba', 'Edilson Alexandre Saldanha Raffo', 'Pilarzinho', '82115-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11921, 'Curitiba', 'Edilton Trevisan', 'Pilarzinho', '82100-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11922, 'Pato Branco', 'Edimo Belmiro Pastro', 'Bela Vista', '85509-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11923, 'Curitiba', 'Edinei Cezar Charneski', 'Alto Boqueirão', '81750-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11924, 'Ponta Grossa', 'Édipo Ferreira dos Santos Ribas', 'Nova Rússia', '84053-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11925, 'Curitiba', 'Edison Luiz Ferreira', 'Cidade Industrial', '81305-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11926, 'Curitiba', 'Edisson Elleni Faust', 'Tatuquara', '81480-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11927, 'Londrina', 'Edite Borela', 'Conjunto Ernani Moura Lima 1', '86037-155', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11928, 'Curitiba', 'Edith Barcelos Schramm', 'Prado Velho', '80215-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11929, 'Curitiba', 'Edith de Franca Alves', 'Santo Inácio', '82010-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11930, 'Londrina', 'Edith Saboia Franco', 'Vale das Araucárias', '86047-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11931, 'Paranaguá', 'Edival Vidal Ribeiro', 'Vila Garcia', '83218-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11932, 'Paranaguá', 'Edival Vidal Ribeiro Filho', 'Vila Garcia', '83218-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11933, 'Londrina', 'Edivaldo Contato', 'Maria Lúcia', '86072-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11934, 'Londrina', 'Edivaldo Ferreira de Lima', 'Jardim Tropical', '86087-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11935, 'Guarapuava', 'Edivino Lange', 'Conradinho', '85045-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11936, 'Campo Mourão', 'Edmar F. Caetano Pinto', 'Jardim Lopes', '87302-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11937, 'Ponta Grossa', 'Edmar Iurk', 'Contorno', '84061-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11938, 'Curitiba', 'Edmundo Alberto Mercer', 'Tingui', '82620-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11939, 'Curitiba', 'Edmundo Angely', 'Jardim das Américas', '81520-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11940, 'Ponta Grossa', 'Edmundo Bittencourt', 'Olarias', '84035-290', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11941, 'Curitiba', 'Edmundo de Amicis', 'Xaxim', '81810-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11942, 'Foz do Iguaçu', 'Edmundo de Barros', 'Centro', '85851-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11943, 'Foz do Iguaçu', 'Edmundo de Barros', 'Centro', '85852-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11944, 'Foz do Iguaçu', 'Edmundo de Barros', 'Jardim Naipi', '85853-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11945, 'Foz do Iguaçu', 'Edmundo de Barros', 'Jardim São Paulo II', '85856-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11946, 'Curitiba', 'Edmundo Eckstein', 'Cidade Industrial', '81290-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11947, 'Araucária', 'Edmundo Ferreira', 'Porto das Laranjeiras', '83703-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11948, 'Curitiba', 'Edmundo Filla', 'Mossunguê', '81200-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11949, 'Curitiba', 'Edmundo Gillung', 'Alto Boqueirão', '81750-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11950, 'Londrina', 'Edmundo Gonçalves', 'Roseira', '86041-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11951, 'Apucarana', 'Edmundo Henrique de Fauw', 'Núcleo Habitacional Marcos Freire', '86805-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11952, 'Curitiba', 'Edmundo Kaminski', 'Orleans', '81200-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11953, 'Araucária', 'Edmundo Kampa', 'Vila Nova', '83703-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11954, 'Ponta Grossa', 'Edmundo Lins', 'Nova Rússia', '84053-340', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11955, 'Campo Mourão', 'Edmundo Mercer', 'Centro', '87302-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11956, 'Campo Mourão', 'Edmundo Mercer', 'Centro', '87301-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11957, 'Pinhais', 'Edmundo Mercer Sobrinho', 'Vila Maria Antonieta', '83331-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11958, 'Foz do Iguaçu', 'Edmundo Requião', 'Jardim Esmeralda', '85856-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11959, 'São José dos Pinhais', 'Edmundo Saporski', 'São Cristóvão', '83005-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11960, 'Curitiba', 'Edmundo Saporski', 'Mercês', '80710-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11961, 'Toledo', 'Edmundo Timm', 'Conjunto Habitacional São Francisco', '85912-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11962, 'Paranaguá', 'Edmundo Werner Neto', 'Palmital', '83206-045', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11963, 'Castro', 'Edmundo Wisoski', 'Jardim Colonial', '84178-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11964, 'Londrina', 'Edna Campanini', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11965, 'Londrina', 'Edner Canezin', 'Cristal', '86044-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11966, 'Ponta Grossa', 'Edon', 'Jardim Carvalho', '84016-669', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11967, 'Curitiba', 'Edson Antônio Ramos', 'Xaxim', '81830-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11968, 'Cascavel', 'Edson Beller de Oliveira', 'Região do Lago 3', '85819-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11969, 'Curitiba', 'Edson Campos Matesich', 'Santa Felicidade', '82410-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11970, 'Londrina', 'Edson Carlos Ribeiro', 'Roseira', '86041-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11971, 'Curitiba', 'Edson Cavalcante Queiroz', 'Cidade Industrial', '81350-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11972, 'Londrina', 'Edson Esgriguero', 'Jardim São Jorge', '86082-836', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11973, 'Cambé', 'Edson Felipe de Melo', 'Jardim Vitória', '86184-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11974, 'Londrina', 'Edson Fernandes Costa', 'Residencial Portal de Piza', '86041-306', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11975, 'Londrina', 'Edson Henrique Massi', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11976, 'Londrina', 'Edson Jere Vicente', 'Casone', '86084-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11977, 'Foz do Iguaçu', 'Edson Leite', 'Vila Borges', '85858-610', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11978, 'Umuarama', 'Edson Lopes', 'Jardim Alto da Boa Vista', '87506-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11979, 'Cascavel', 'Edson Luiz Favarin', 'Universitário', '85819-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11980, 'Paranavaí', 'Edson Martins', 'Jardim Ouro Branco', '87704-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11981, 'Paranavaí', 'Edson Martins', 'Centro', '87705-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11982, 'Paranavaí', 'Edson Martins', 'Jardim Ouro Branco', '87703-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11983, 'Guarapuava', 'Edson Nobre de Lacerda', 'Santana', '85070-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11984, 'Ponta Grossa', 'Edson Nobre de Lacerda', 'Jardim Carvalho', '84015-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11985, 'Araucária', 'Edson Queiroz', 'Chapada', '83707-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11986, 'Londrina', 'Edson Ricardo de Lima', 'Luiz de Sá', '86085-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11987, 'Almirante Tamandaré', 'Edson Roberto Mangolin', 'Jardim Casa Blanca', '83513-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11988, 'Curitiba', 'Edson Roberto Oliveira', 'Uberaba', '81550-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11989, 'Londrina', 'Edson Salles Dutra', 'Pinheiros', '86063-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11990, 'Londrina', 'Edu Chaves', 'Dom Pedro', '86039-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11991, 'Apucarana', 'Eduado T. Myazaki', 'Jardim Portal do Lago', '86802-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11992, 'Apucarana', 'Eduardo A. Felipe', 'Núcleo Habitacional João Goulart', '86807-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11993, 'Curitiba', 'Eduardo Afonso Portes', 'Xaxim', '81820-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11994, 'Cascavel', 'Eduardo Agostinho', '14 de Novembro', '85804-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11995, 'Curitiba', 'Eduardo Aguirre Calabresi', 'Cristo Rei', '80050-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11996, 'Pato Branco', 'Eduardo Amadori', 'Bonatto', '85506-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11997, 'Londrina', 'Eduardo Aparecido Turetta', 'Conjunto Habitacional Champagnat', '86086-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11998, 'Toledo', 'Eduardo Becker', 'Conjunto Residencial Tocantins', '85903-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (11999, 'Londrina', 'Eduardo Benjamin Hosken', 'Conceição', '86020-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12000, 'Ponta Grossa', 'Eduardo Bonjean', 'Uvaranas', '84030-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12001, 'Curitiba', 'Eduardo Cantarelli', 'Mercês', '80710-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12002, 'Ponta Grossa', 'Eduardo Carlos Pereira', 'Boa Vista', '84073-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12003, 'Curitiba', 'Eduardo Carlos Pereira', 'Portão', '80610-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12004, 'Curitiba', 'Eduardo Carlos Pereira', 'Portão', '81020-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12005, 'Guarapuava', 'Eduardo Chaia', 'Batel', '85015-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12006, 'Curitiba', 'Eduardo Couture', 'Jardim das Américas', '81540-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12007, 'Londrina', 'Eduardo de Pinho Neto', 'Cafezal 1', '86049-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12008, 'Toledo', 'Eduardo Domaradski', 'Residencial Santa Clara', '85908-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12009, 'Londrina', 'Eduardo dos Reis Silva', 'Portal Norte', '86079-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12010, 'Araucária', 'Eduardo Dudek', 'Tindiquera', '83708-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12011, 'Curitiba', 'Eduardo Engelhardt', 'Cajuru', '82970-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12012, 'Francisco Beltrão', 'Eduardo Faust', 'Jardim Novo Mundo', '85602-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12013, 'Londrina', 'Eduardo Fernandes da Silva', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12014, 'Toledo', 'Eduardo Gatto', 'Coopagro', '85903-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12015, 'Curitiba', 'Eduardo Gerber', 'Jardim das Américas', '81520-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12016, 'Telêmaco Borba', 'Eduardo Geronasso', 'Vila Ozorio', '84268-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12017, 'Curitiba', 'Eduardo Geronasso', 'Bacacheri', '82510-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12018, 'Londrina', 'Eduardo Grandis', 'Jardim Palmeiras', '86083-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12019, 'Foz do Iguaçu', 'Eduardo Hermann Neumann', 'Loteamento Paraguaçu', '85865-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12020, 'Curitiba', 'Eduardo Jarnicki', 'São Braz', '82315-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12021, 'Castro', 'Eduardo José de Quadros', 'Jardim Social Primavera', '84174-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12022, 'Curitiba', 'Eduardo kalinowski', 'Pilarzinho', '82100-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12023, 'Curitiba', 'Eduardo Kirylla', 'Alto Boqueirão', '81770-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12024, 'Londrina', 'Eduardo Kisser', 'Coliseu', '86076-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12025, 'Curitiba', 'Eduardo Laffitte', 'Abranches', '82130-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12026, 'Piraquara', 'Eduardo Luiz Piana', 'Planta Granjas Eldorado', '83309-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12027, 'Curitiba', 'Eduardo Luiz Piana', 'Cidade Industrial', '81230-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12028, 'Londrina', 'Eduardo Lunardelli', 'Parque Residencial Alcântara', '86047-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12029, 'Campo Largo', 'Eduardo Matos Portela', 'São Marcos', '83602-687', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12030, 'Curitiba', 'Eduardo Negrelo', 'Novo Mundo', '81020-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12031, 'Ponta Grossa', 'Eduardo Novak', 'Contorno', '84062-036', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12032, 'Guarapuava', 'Eduardo Pawlina', 'Cascavel', '85025-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12033, 'Pato Branco', 'Eduardo Pedroso', 'Pinheirinho', '85506-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12034, 'Ponta Grossa', 'Eduardo Pikunas', 'Boa Vista', '84072-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12035, 'Curitiba', 'Eduardo Pinto da Rocha', 'Alto Boqueirão', '81850-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12036, 'Curitiba', 'Eduardo Pinto da Rocha', 'Umbará', '81930-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12037, 'Curitiba', 'Eduardo Pinto da Rocha', 'Sítio Cercado', '81935-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12038, 'Curitiba', 'Eduardo Polak', 'Hauer', '81610-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12039, 'Ponta Grossa', 'Eduardo Prado', 'Uvaranas', '84025-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12040, 'São José dos Pinhais', 'Eduardo Ravaglio', 'Rio Pequeno', '83070-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12041, 'Araucária', 'Eduardo Sobania', 'Thomaz Coelho', '83707-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12042, 'Castro', 'Eduardo Sommer', 'Loteamento Jardim Pandorf', '84182-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12043, 'Curitiba', 'Eduardo Sprada', 'Campo Comprido', '81220-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12044, 'Curitiba', 'Eduardo Sprada', 'Cidade Industrial', '81290-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12045, 'Curitiba', 'Eduardo Sprada', 'Campo Comprido', '81210-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12046, 'Curitiba', 'Eduardo Sprada', 'Campo Comprido', '81270-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12047, 'Francisco Beltrão', 'Eduardo Suplici', 'Centro', '85601-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12048, 'Cascavel', 'Eduardo Tadeu Melani', 'Centro', '85801-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12049, 'Cascavel', 'Eduardo Tavares Caseiro', 'Santa Cruz', '85806-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12050, 'Curitiba', 'Eduardo Vardanega', 'Parolin', '81030-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12051, 'Curitiba', 'Eduardo Victor Piechnik', 'Uberaba', '81560-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12052, 'Araucária', 'Eduardo Wagner', 'Costeira', '83709-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12053, 'Curitiba', 'Eduardo Walter Wannagat', 'Cidade Industrial', '81315-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12054, 'Londrina', 'Edval Luiz Mazzari', 'Conjunto Habitacional  Alexandre Urbanas', '86037-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12055, 'Curitiba', 'Edvald Ribas Borba', 'Sítio Cercado', '81910-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12056, 'Curitiba', 'Edviges Model', 'São Braz', '82300-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12057, 'Curitiba', 'Edvino Antônio Deboni', 'Fazendinha', '81330-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12058, 'Toledo', 'Edvino Grahl', 'Boa Esperança', '85909-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12059, 'Campo Mourão', 'Edvino Spack', 'Jardim Maia', '87301-276', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12060, 'Apucarana', 'Edward Andrade', 'Loteamento Central', '86807-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12061, 'Londrina', 'Edwiges Massagardi Baldan', 'Andes', '86076-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12062, 'Laranjeiras do Sul', 'Edwin Sobezak', 'Vila Industrial', '85303-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12063, 'Toledo', 'Edwino Frank', 'Centro Industrial Meinolfo H Heiss', '85915-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12064, 'Curitiba', 'Edwirges Grochoska Cichon', 'Pinheirinho', '81880-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12065, 'Londrina', 'Edwy Taques de Araújo', 'Jardim Burle Marx', '86047-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12066, 'Curitiba', 'Edy Helena Schutze', 'Barreirinha', '82700-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12067, 'Cambé', 'Efésios', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12068, 'São José dos Pinhais', 'Efigênia de Jesus Cordeiro', 'Guatupê', '83060-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12069, 'São José dos Pinhais', 'Efigênia Souza Cortes', 'Colônia Rio Grande', '83025-376', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12070, 'Curitiba', 'Egas Rosa Sampaio', 'Abranches', '82220-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12071, 'Curitiba', 'Egberto Acir S. Pereira', 'Pinheirinho', '81825-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12072, 'Curitiba', 'Egídio Antônio Zamilian', 'Santa Felicidade', '82030-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12073, 'Ponta Grossa', 'Egídio Brizolla da Silva', 'Contorno', '84060-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12074, 'Campo Mourão', 'Egídio Cardoso de Lima', 'Jardim Joana D''Arc', '87300-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12075, 'Colombo', 'Egídio Carrara', 'Jardim São Gabriel', '83407-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12076, 'Ponta Grossa', 'Egídio Doná', 'Orfãs', '84015-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12077, 'Cambé', 'Egídio Fadel', 'Parque Residencial Manela', '86185-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12078, 'Ponta Grossa', 'Egídio Ferreira dos Santos Ribas', 'Nova Rússia', '84053-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12079, 'Foz do Iguaçu', 'Egilio Dotto', 'Porto Belo', '85867-637', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12080, 'Francisco Beltrão', 'Egito', 'Aeroporto', '85603-841', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12081, 'Londrina', 'Egito', 'Jardim Adriana I', '86046-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12082, 'Ponta Grossa', 'Egito', 'Jardim Carvalho', '84016-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12083, 'Pinhais', 'Egito', 'Vila Palmital', '83320-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12084, 'Telêmaco Borba', 'Egito', 'Vila Cristina', '84272-130', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12085, 'Colombo', 'Egito', 'Vila Alto da Cruz III', '83405-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12086, 'Cascavel', 'Egito', 'Santos Dumont', '85804-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12087, 'Almirante Tamandaré', 'Egito', 'Jardim Natal', '83505-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12088, 'Curitiba', 'Egito', 'Cajuru', '82960-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12089, 'Piraquara', 'Egon Laschewitz', 'Planta Jardim Tarumã', '83311-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12090, 'Ponta Grossa', 'Egon Roskamp', 'Jardim Carvalho', '84016-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12091, 'Francisco Beltrão', 'Egydio Cornelius', 'Guanabara', '85604-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12092, 'Toledo', 'Egydio Geronymo Munaretto', 'Panorama', '85911-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12093, 'Toledo', 'Egydio Geronymo Munaretto', 'Panorama', '85910-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12094, 'Toledo', 'Egydio Geronymo Munaretto', 'César Park', '85915-175', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12095, 'Curitiba', 'Egydio Pilotto', 'Uberaba', '81570-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12096, 'Maringá', 'Egydio Pitarelli', 'Conjunto Habitacional Requião', '87047-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12097, 'Curitiba', 'Egydio Ricardo Pietrobelli', 'Butiatuvinha', '82400-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12098, 'Umuarama', 'Eid Abou Saad', 'Parque Cidade Jardim', '87506-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12099, 'Colombo', 'Einsten', 'Vila Guarani', '83408-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12100, 'Londrina', 'Eiti Suguimoto', 'Maria Lúcia', '86072-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12101, 'São José dos Pinhais', 'Eixo Central Norte', 'Roseira', '83070-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12102, 'Apucarana', 'El Salvador', 'Núcleo Habitacional Vale Verde', '86805-247', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12103, 'Cascavel', 'El Salvador', 'Periolo', '85817-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12104, 'Londrina', 'Eládio Yanes Peres', 'Jardim dos Alpes I', '86075-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12105, 'Pato Branco', 'Elaine Caldato Amadori', 'Trevo Patinhos', '85504-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12106, 'Foz do Iguaçu', 'Elba de Pádua Lima', 'Parque Residencial Santa Rita', '85858-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12107, 'Curitiba', 'Elba de Pádua Lima', 'Capão Raso', '81110-490', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12108, 'Curitiba', 'Elbe de Macedo', 'Sítio Cercado', '81900-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12109, 'Curitiba', 'Elbe Pospissil', 'Juvevê', '80030-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12110, 'Campo Mourão', 'Elci Slompo Iurk', 'Jardim Paulista', '87310-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12111, 'Curitiba', 'Élcio Gusso', 'Capão Raso', '81020-060', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12112, 'Curitiba', 'Élcio Luiz de Souza', 'Santo Inácio', '82300-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12113, 'Londrina', 'Elder Abussafi de Lima', 'Portal de Versalhes 1', '86057-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12114, 'Foz do Iguaçu', 'Eldorado', 'Parque Imperatriz', '85862-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12115, 'Foz do Iguaçu', 'Eldorado', 'Jardim Duarte', '85861-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12116, 'Maringá', 'Eldorado', 'Parque Residencial Eldorado', '87025-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12117, 'Toledo', 'Eldorado', 'Boa Esperança', '85909-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12118, 'Sarandi', 'Eldorado', 'Jardim Nova Independência', '87114-636', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12119, 'Sarandi', 'Eldorado', 'Parque Residencial Bela Vista', '87112-256', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12120, 'Almirante Tamandaré', 'Eldorado', 'Jardim Itamarati', '83505-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12121, 'Curitiba', 'Elem Kotsanar', 'Sítio Cercado', '81900-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12122, 'Londrina', 'Elena Sanchez Ferreira', 'Conjunto Professora Hilda Mandarino', '86080-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12123, 'Cascavel', 'Elena Sganzerla', 'Santa Felicidade', '85803-325', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12124, 'Foz do Iguaçu', 'Eleodoro Rodrigues Seixas', 'Profilurb', '85855-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12125, 'Londrina', 'Eleonor Roosevelt', 'Brasília', '86039-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12126, 'Curitiba', 'Eleonor Roosevelt', 'Bacacheri', '82620-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12127, 'Curitiba', 'Eleonora Branco Gracia', 'Taboão', '82130-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12128, 'Curitiba', 'Eleonora Brasil Pompeo', 'Tatuquara', '81470-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12129, 'Curitiba', 'Eleonora Faria Costa da Silva', 'Capão Raso', '81110-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12130, 'Curitiba', 'Eleonora Muricy Novaes', 'Jardim Botânico', '80215-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12131, 'Maringá', 'Eleotéria Cordeiro da Silva', 'Conjunto Residencial Planalto', '87015-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12132, 'Foz do Iguaçu', 'Elfrida Engel Rios', 'Beverly Falls Park', '85858-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12133, 'Foz do Iguaçu', 'Elfrida Keller', 'Cohapar III', '85858-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12134, 'Almirante Tamandaré', 'Elfrida Roessler Jacumasso', 'Planta Almirante', '83508-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12135, 'Curitiba', 'Eli Ribeiro da Silva', 'Cidade Industrial', '81305-500', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12136, 'Curitiba', 'Eli Toledo Barbosa', 'Tatuquara', '81480-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12137, 'Curitiba', 'Eli Volpato', 'Sítio Cercado', '81935-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12138, 'Foz do Iguaçu', 'Elia Mikhael Nicolas', 'Jardim Dona Leila', '85856-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12139, 'Londrina', 'Eliana Maria Tarasconi Peixe', 'Condomínio Royal Golf Residence', '86055-550', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12140, 'Londrina', 'Eliane Alvin Dias', 'Jardim Império do Sol', '86073-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12141, 'Londrina', 'Eliane de Grammont', 'Conjunto Vivi Xavier', '86082-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12142, 'Londrina', 'Eliane Massumi Makihara', 'Dom Pedro I', '86089-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12143, 'Curitiba', 'Elias Abdo Bittar', 'Água Verde', '80610-050', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12144, 'Cascavel', 'Elias Abrão', 'Santa Cruz', '85806-137', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12145, 'Piraquara', 'Elias Alves Ferreira', 'Vila São Cristóvão', '83305-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12146, 'Campo Largo', 'Elias Alves Ferreira', 'Loteamento Itaboa', '83605-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12147, 'Curitiba', 'Elias Carazzai', 'Vista Alegre', '80820-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12148, 'Curitiba', 'Elias Casseb', 'Tatuquara', '81480-236', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12149, 'Colombo', 'Elias Cavalli', 'Centro', '83414-130', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12150, 'Londrina', 'Elias Daniel Hatti', 'Aquilles Sthengel', '86086-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12151, 'Foz do Iguaçu', 'Elias Demétrio Hanagge', 'Loteamento Universitário das Américas', '85870-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12152, 'Campo Mourão', 'Elias Farhat', 'Jardim Laura', '87300-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12153, 'Curitiba', 'Elias Fialla', 'Pinheirinho', '81870-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12154, 'Apucarana', 'Elias Gantus Bassil', 'Parque Bela Vista', '86803-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12155, 'Londrina', 'Elias Gonçalves', 'Sabará III', '86066-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12156, 'Guarapuava', 'Elias Hauagge', 'Jardim das Américas', '85030-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12157, 'Curitiba', 'Elias João Zaruch', 'Pilarzinho', '80820-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12158, 'Curitiba', 'Elias Joaquim', 'Pilarzinho', '82120-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12159, 'Curitiba', 'Elias Jorge', 'Uberaba', '81550-385', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12160, 'Curitiba', 'Elias kalil Karam', 'Cidade Industrial', '81450-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12161, 'São José dos Pinhais', 'Elias Karam', 'São Sebastião', '83075-299', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12162, 'Londrina', 'Elias Kauam', 'Parigot de Souza 2', '86082-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12163, 'Colombo', 'Elias Kubis', 'Jardim Eldorado', '83402-748', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12164, 'Foz do Iguaçu', 'Elias Kuster', 'Centro', '85851-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12165, 'Cascavel', 'Elias Maximiliano', 'Nova Cidade', '85803-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12166, 'Ponta Grossa', 'Elias Miguel Maia', 'Boa Vista', '84071-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12167, 'Curitiba', 'Elias Moyses Schelela', 'Uberaba', '81570-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12168, 'São José dos Pinhais', 'Elias Pedro Saade', 'Braga', '83020-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12169, 'Londrina', 'Elias Pereira de Rocha', 'Jardim São Jorge', '86082-808', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12170, 'Francisco Beltrão', 'Elias Scalco', 'Luther King', '85605-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12171, 'Campo Mourão', 'Elias Simão', 'Jardim Modelo', '87309-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12172, 'Araucária', 'Elias Stainsack', 'Vila Nova', '83703-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12173, 'Curitiba', 'Elias Thome', 'Pilarzinho', '82120-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12174, 'Londrina', 'Elias Tosetti', 'Pérola', '86038-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12175, 'Curitiba', 'Elias Toufic Mansur', 'Santa Cândida', '82630-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12176, 'Guarapuava', 'Elias Tratz', 'Alto Cascavel', '85031-360', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12177, 'Londrina', 'Elias Vieira Gonçalves', 'Conjunto Habitacional  Alexandre Urbanas', '86037-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12178, 'Londrina', 'Elias Viscardi', 'Santa Rita 1', '86072-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12179, 'Campo Mourão', 'Elias Xavier do Rego', 'Jardim Bandeirantes', '87308-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12180, 'Guarapuava', 'Elias Zacalusny', 'Conradinho', '85035-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12181, 'Apucarana', 'Elid Budian', 'Jardim Catuaí III', '86802-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12182, 'São José dos Pinhais', 'Elídia Pasqualim Dal Negro', 'Colônia Rio Grande', '83025-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12183, 'Maringá', 'Elídio Neto Laranjeiro', 'Jardim Oásis', '87043-650', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12184, 'Apucarana', 'Elídio Stabile', 'Centro', '86800-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12185, 'Apucarana', 'Eliezer Botelho Manhas', 'Jardim Santos Dumont III', '86812-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12186, 'Curitiba', 'Eliezer Disaró Fangueiro', 'Uberaba', '81540-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12187, 'Londrina', 'Elifaz Lopes de Oliveira', 'Conjunto Habitacional José Garcia Molina', '86080-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12188, 'Curitiba', 'Eligio Lorenzon', 'Uberaba', '81560-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12189, 'Foz do Iguaçu', 'Eligius Rockembach', 'Parque Presidente II', '85863-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12190, 'Ponta Grossa', 'Elim', 'Jardim Carvalho', '84016-707', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12191, 'Ponta Grossa', 'Elio Elvio Chaves', 'Uvaranas', '84031-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12192, 'Toledo', 'Elio Gaboardi', 'Residencial Santa Clara', '85907-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12193, 'Telêmaco Borba', 'Eliomar Meira Xavier', 'Centro', '84261-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12194, 'Maringá', 'Elionildo Dena', 'Loteamento Grajaú', '87043-496', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12195, 'Guarapuava', 'Elis Regina', 'Boqueirão', '85020-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12196, 'Foz do Iguaçu', 'Elis Regina', 'Loteamento Universitário das Américas', '85870-616', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12197, 'Londrina', 'Elis Regina', 'Conjunto Vivi Xavier', '86082-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12198, 'Maringá', 'Elis Regina', 'Conjunto Habitacional Itatiaia', '87045-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12199, 'Paranavaí', 'Elis Regina', 'Jardim São Jorge', '87711-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12200, 'Cascavel', 'Elis Regina', 'Brasília', '85815-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12201, 'Cambé', 'Elis Regina', 'Jardim Josiane', '86188-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12202, 'Curitiba', 'Elis Regina', 'São Braz', '82315-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12203, 'Maringá', 'Elis Regina II', 'Zona 36', '87045-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12204, 'Londrina', 'Elisa Maria da Rocha Pontes', 'Jardim Neman Sahyun', '86041-289', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12205, 'Pato Branco', 'Elisa Rosa Colla Padoan', 'Fraron', '85503-380', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12206, 'São José dos Pinhais', 'Elisa Sandy Cordeiro', 'Afonso Pena', '83065-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12207, 'Apucarana', 'Elisa Silvério', 'Vila Amin Maia', '86800-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12208, 'São José dos Pinhais', 'Elisa Simeon Meretka', 'Planta Quississana', '83085-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12209, 'Curitiba', 'Eliseo Bittencourt de Camargo', 'Santa Felicidade', '82015-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12210, 'Cascavel', 'Eliseth Cardoso', 'Nucleo de Produção III', '85811-570', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12211, 'Cascavel', 'Eliseu Baldi', 'Universitário', '85819-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12212, 'Apucarana', 'Eliseu Cilião', 'Jardim Presidente Kennedy', '86802-345', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12213, 'Curitiba', 'Eliseu Miranda', 'Taboão', '82130-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12214, 'Curitiba', 'Elísio Gabardo', 'Xaxim', '81710-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12215, 'Francisco Beltrão', 'Elísio Vetorello', 'Pinheirinho', '85606-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12216, 'Piraquara', 'Elisira Teodora Pereira', 'Borda do Campo', '83304-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12217, 'Londrina', 'Eliza Cabral B. Macedo', 'João Paz', '86087-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12218, 'Londrina', 'Eliza Izabel da Conceição', 'Jardim São Jorge', '86082-827', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12219, 'Pinhais', 'Eliza Mendes Saraiva', 'Prive Bois de Boulogne', '83330-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12220, 'Londrina', 'Eliza Michelete Vicente', 'Jardim Nova Esperança', '86044-648', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12221, 'Curitiba', 'Eliza Nadolny Ielen', 'Santa Cândida', '82630-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12222, 'Curitiba', 'Eliza Ramos de Proença', 'Cajuru', '82950-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12223, 'São José dos Pinhais', 'Eliza Rocco Pissaia', 'Ipê', '83055-506', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12224, 'Curitiba', 'Elizabete Charlote Brand', 'Sítio Cercado', '81920-749', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12225, 'Londrina', 'Elizabete Muniz Aranda', 'Tarobá', '86042-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12226, 'Ponta Grossa', 'Elizabeth das Graças Maurer Rota', 'Cará-cará', '84032-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12227, 'Piraquara', 'Elizabeth de Souza', 'Jardim Guarituba', '83312-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12228, 'Curitiba', 'Elizabeth Isumi Morizaki Nishi', 'Santa Cândida', '82640-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12229, 'Curitiba', 'Elizabeth Jane Brown', 'Uberaba', '81550-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12230, 'Londrina', 'Elizabeth Kenny', 'Roveri', '86039-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12231, 'Curitiba', 'Elizabeth Majewski', 'Santo Inácio', '82010-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12232, 'Curitiba', 'Elizabeth Parodi', 'Tatuquara', '81470-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12233, 'Curitiba', 'Elizabeth Vicente', 'Butiatuvinha', '82320-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12234, 'Curitiba', 'Elizário da Rocha Paranhos', 'Pinheirinho', '81150-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12235, 'Curitiba', 'Elizete Cardoso', 'Tatuquara', '81470-325', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12236, 'Paranaguá', 'Elizete Matias', 'Vila São Vicente', '83209-205', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12237, 'Curitiba', 'Elizeu Américo Comim', 'Pinheirinho', '81150-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12238, 'Apucarana', 'Elizeu Cilião Moura', 'Parque Industrial Zona Norte', '86806-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12239, 'Londrina', 'Elizeu Costa', 'Ernani de Moura Lima', '86037-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12240, 'Curitiba', 'Elizeu de Souza Mendes', 'Sítio Cercado', '81925-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12241, 'Curitiba', 'Elizeu Faria', 'Xaxim', '81720-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12242, 'Curitiba', 'Elizeu Valentin de Lima', 'Campo de Santana', '81490-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12243, 'Londrina', 'Eliziário Pinto da Silva', 'Conjunto Habitacional Saltinho', '86042-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12244, 'Almirante Tamandaré', 'Elizio F. do Nascimento', 'Planta Nossa Senhora do Pilar', '83508-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12245, 'Curitiba', 'Elízio Honorato dos Santos', 'Cidade Industrial', '81170-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12246, 'Londrina', 'Elizio Turino', 'Sabará', '86066-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12247, 'Curitiba', 'Ella Ferdinanda Dorotheia Paasche', 'Butiatuvinha', '82315-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12248, 'Curitiba', 'Ellen White', 'Ahú', '80530-410', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12249, 'Londrina', 'Eller Sproger de Almeida', 'Jardim São Jorge', '86082-826', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12250, 'Piraquara', 'Elli Butzke', 'Jardim Guarani', '83311-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12251, 'Almirante Tamandaré', 'Ellis Regina', 'Jardim Kokot', '83505-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12252, 'São José dos Pinhais', 'Elógio Maurício Marchioro', 'Bom Jesus', '83025-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12253, 'Curitiba', 'Elohar Scheremetta', 'Cachoeira', '82710-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12254, 'Colombo', 'Eloi Chicora', 'Sapopema', '83407-106', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12255, 'Ponta Grossa', 'Elói de Almeida', 'Colônia Dona Luiza', '84043-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12256, 'Foz do Iguaçu', 'Elói Lohmann', 'Conjunto Libra II', '85857-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12257, 'Curitiba', 'Elói Micheleto', 'Fazendinha', '81330-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12258, 'Curitiba', 'Elói Orestes Zeglin', 'Pinheirinho', '81110-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12259, 'São José dos Pinhais', 'Eloina Ribas Bastos', 'Costeira', '83015-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12260, 'Curitiba', 'Eloir Dide Maria', 'Tatuquara', '81470-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12261, 'Umuarama', 'Eloy Baptista Lopes', 'Jardim Aratimbó', '87502-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12262, 'Curitiba', 'Eloy Carli', 'Tatuquara', '81470-236', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12263, 'Curitiba', 'Eloy de Assis Fabris', 'Novo Mundo', '81030-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12264, 'Pinhais', 'Eloy Hermann Bach', 'Moradias Perdizes', '83326-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12265, 'Campo Mourão', 'Eloy Maciel', 'Parque Industrial I', '87306-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12266, 'Londrina', 'Eloy Mello Guides', 'Conjunto Semiramis Barros Braga', '86088-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12267, 'Paranaguá', 'Eloy Pereira Marcondes de Albuquerque', 'Conjunto Residencial Prefeito Cominese', '83215-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12268, 'Maringá', 'Eloy Victor de Melo', 'Conjunto Habitacional Requião', '87047-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12269, 'Curitiba', 'Eloylia Polzin', 'Tatuquara', '81470-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12270, 'Londrina', 'Elpídio Alves', 'Conjunto Habitacional José Giordano', '86082-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12271, 'Curitiba', 'Elpídio Alves Assumpção', 'Tingui', '82600-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12272, 'Londrina', 'Elpídio Fabiani', 'Residencial Vila Romana', '86031-829', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12273, 'Foz do Iguaçu', 'Elpídio Ferreira Dias', 'Boa Esperança', '85854-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12274, 'Maringá', 'Elpídio Francisco Costa', 'Conjunto Habitacional Requião', '87047-428', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12275, 'Londrina', 'Elpídio Ignacio Simões', 'Conjunto Habitacional José Garcia Molina', '86080-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12276, 'Campo Largo', 'Elpídio José Cardoso', 'Vila Bancária', '83601-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12277, 'Londrina', 'Elpídio Lunardelli', 'Jardim Acapulco', '86045-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12278, 'Piraquara', 'Elpídio Natal', 'Jardim Veneza', '83310-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12279, 'Piraquara', 'Elpídio Scheved', 'Vila Franca', '83305-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12280, 'Londrina', 'Elpídio Trevisan', 'Nova Olinda', '86073-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12281, 'Foz do Iguaçu', 'Elpídio Veríssimo', 'Jardim N Horizonte', '85855-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12282, 'Curitiba', 'Else Schiller Otte', 'Alto da Glória', '80030-490', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12283, 'Curitiba', 'Elso Manoel Ribeiro', 'Uberaba', '81550-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12284, 'Cambé', 'Elson José da Silva', 'Jardim Vitória', '86184-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12285, 'Londrina', 'Elson Pedro dos Santos', 'Jardim União da Vitória', '86044-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12286, 'Curitiba', 'Elton Roberto de Moura Torres', 'Boqueirão', '81650-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12287, 'Curitiba', 'Elvira Annibaleto', 'Lindóia', '81010-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12288, 'Curitiba', 'Elvira B. Polak', 'Pilarzinho', '82100-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12289, 'Londrina', 'Elvira Bendacolli', 'Jardim Alphaville', '86084-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12290, 'Toledo', 'Elvira Bombonatto', 'Jardim Europa', '85907-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12291, 'Colombo', 'Elvira Busato Guarise', 'Jardim Curitiba', '83414-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12292, 'Foz do Iguaçu', 'Elvira Catarina Botolini', 'Loteamento Universitário das Américas', '85870-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12293, 'Curitiba', 'Elvira Comparin Salvador', 'Pinheirinho', '81870-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12294, 'Campo Largo', 'Elvira de Souza', 'Vila Campesi', '83604-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12295, 'Curitiba', 'Elvira dos Santos Goulart', 'Cidade Industrial', '81170-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12296, 'Cascavel', 'Elvira Faiten Franz', 'Canadá', '85813-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12297, 'Cambé', 'Elvira Gomedi Cairrão', 'Jardim Vitória', '86184-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12298, 'Curitiba', 'Elvira Harkot Ramina', 'Mossunguê', '81200-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12299, 'Colombo', 'Elvira Jordão Czocher', 'Jardim Eldorado', '83402-749', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12300, 'Piraquara', 'Elvira Lorusso do Nascimento', 'Planta Araçatuba', '83301-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12301, 'Apucarana', 'Elvira Magro Barreto', 'Loteamento Residencial Parque da Raposa II', '86812-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12302, 'Curitiba', 'Elvira Marquesini Vaz', 'Sítio Cercado', '81900-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12303, 'São José dos Pinhais', 'Elvira Moro Costa', 'Barro Preto', '83015-806', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12304, 'São José dos Pinhais', 'Elvira Pilotto Carrano', 'Guatupê', '83065-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12305, 'Araucária', 'Elvira Pizzatto Ferreira', 'Centro', '83702-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12306, 'Toledo', 'Elvira Rosa Piazza', 'Jardim Porto Alegre', '85907-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12307, 'Cascavel', 'Elvira Saraiva', 'Coqueiral', '85807-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12308, 'São José dos Pinhais', 'Elvira Schaffer Rocha', 'Afonso Pena', '83045-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12309, 'Araucária', 'Elvira Sperandio Valentini', 'Campina da Barra', '83709-825', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12310, 'Curitiba', 'Elvira Tavares Carlos', 'Campo Comprido', '81270-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12311, 'Araucária', 'Elvis Blaszczak', 'Capela Velha', '83706-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12312, 'Londrina', 'Elvis Presley', 'Conjunto Vivi Xavier', '86082-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12313, 'Curitiba', 'Elvis Presley', 'Santa Felicidade', '82410-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12314, 'Ponta Grossa', 'Elysiário Camargo de Mello', 'Olarias', '84035-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12315, 'Curitiba', 'Elysio Simões', 'Cidade Industrial', '81310-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12316, 'Curitiba', 'Elza de Lara Zanelato', 'Xaxim', '81720-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12317, 'Londrina', 'Elza Grandi Jorge', 'Conjunto Professora Hilda Mandarino', '86080-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12318, 'Curitiba', 'Elza Nogaroli de Souza', 'Cidade Industrial', '81230-397', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12319, 'Curitiba', 'Elza Ribeiro', 'Xaxim', '81830-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12320, 'Curitiba', 'Elza Soares Palazzo', 'Cidade Industrial', '81460-316', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12321, 'Curitiba', 'Elza Yuriko Takahashi', 'Cidade Industrial', '81350-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12322, 'Curitiba', 'Elzevir da Silveira Bueno', 'Cajuru', '82940-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12323, 'Londrina', 'Elzevir Menezes Ribeiro', 'Oscavo Santos', '86079-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12324, 'Curitiba', 'Elzina Franco de Macedo', 'Cajuru', '82930-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12325, 'Curitiba', 'Elzira Alves Lourenço', 'Cidade Industrial', '81230-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12326, 'Londrina', 'Elzira Bittencourt Guides', 'Conjunto Habitacional Violim', '86088-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12327, 'Curitiba', 'Elzira Harthman', 'Cidade Industrial', '81310-436', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12328, 'Foz do Iguaçu', 'Elzira K. Matte', 'Jardim do Horto', '85854-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12329, 'Ponta Grossa', 'Ema', 'Colônia Dona Luiza', '84043-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12330, 'Maringá', 'Ema', 'Jardim Olímpico', '87070-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12331, 'Maringá', 'Ema', 'Conjunto Residencial Ney Braga', '87075-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12332, 'Umuarama', 'Ema', 'Jardim Sol Nascente', '87505-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12333, 'Arapongas', 'Ema', 'Vila Araponguinha', '86705-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12334, 'Araucária', 'Ema', 'Capela Velha', '83706-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12335, 'São José dos Pinhais', 'Ema Moro', 'Braga', '83005-605', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12336, 'Guarapuava', 'Ema Silvestri', 'Boqueirão', '85020-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12337, 'Campo Largo', 'Ema Taner de Andrade', 'Loteamento São José', '83606-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12338, 'Curitiba', 'Emanoel Voluz', 'Pinheirinho', '81870-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12339, 'Piraquara', 'Emanuel', 'Jardim Veneza', '83310-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12340, 'Curitiba', 'Emanuel Kant', 'Capão Raso', '81020-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12341, 'Curitiba', 'Emanuel Klingbeil', 'Boqueirão', '81750-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12342, 'Curitiba', 'Emanuel Meira Martins', 'Cidade Industrial', '81350-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12343, 'São José dos Pinhais', 'Emanuel Swdenborg', 'Aristocrata', '83030-085', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12345, 'Curitiba', 'Embaixador Assis Chateaubriand', 'Seminário', '80740-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12346, 'Curitiba', 'Embaixador Hipólito de Araújo', 'Rebouças', '80215-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12347, 'Maringá', 'Embarcação', 'Parque das Grevíleas', '87025-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12348, 'Foz do Iguaçu', 'Embu', 'Jardim Lancaster', '85869-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12349, 'Curitiba', 'Embu', 'Uberaba', '81550-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12350, 'Londrina', 'Emerenciana Gonçalves César', 'Sabará III', '86066-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12351, 'Curitiba', 'Emerico Eduardo Singer', 'Pinheirinho', '81820-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12352, 'Curitiba', 'Emerson Aparecido Rodrigues', 'Campo de Santana', '81490-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12353, 'São José dos Pinhais', 'Emerson Greboge', 'Colônia Murici', '83085-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12354, 'Campo Largo', 'Emídio Andreassa', 'Vila Andreassa Miranda', '83605-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12355, 'Curitiba', 'Emídio Nonato da Silva', 'Cidade Industrial', '81305-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12356, 'Piraquara', 'Emídio Xavier Duarte', 'Planta Vila Nova', '83314-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12357, 'Curitiba', 'Emile Zola', 'Lindóia', '81010-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12358, 'Londrina', 'Emília Alessio', 'Nova Olinda', '86073-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12359, 'Curitiba', 'Emília Andretta', 'Xaxim', '81710-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12360, 'Cambé', 'Emília Augusta de Jesus', 'Planta São Francisco', '86182-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12361, 'Londrina', 'Emília Bortoletto', 'Santa Rita 1', '86072-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12362, 'Curitiba', 'Emília Chopacz', 'Cidade Industrial', '81270-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12363, 'Londrina', 'Emília Cravo Martins', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12364, 'Curitiba', 'Emília Erichsen', 'Cidade Industrial', '81270-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12365, 'Cascavel', 'Emília Galafassi', 'São Cristóvão', '85813-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12366, 'Curitiba', 'Emília Gomes Costa', 'Bacacheri', '82600-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12367, 'Curitiba', 'Emília M. Ubá', 'Cachoeira', '82710-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12368, 'Ponta Grossa', 'Emília Mendes Machado', 'Chapada', '84062-686', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12369, 'Guarapuava', 'Emília Pacheco Cozechem', 'Boqueirão', '85020-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12370, 'Ponta Grossa', 'Emília Schiffer', 'Boa Vista', '84072-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12371, 'Piraquara', 'Emília Stecko', 'Planta Bosque Centenário', '83311-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12372, 'Ponta Grossa', 'Emília Suzana Justus', 'Contorno', '84061-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12373, 'Cascavel', 'Emiliano Afonso da Silva', 'Região do Lago 3', '85819-768', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12374, 'São José dos Pinhais', 'Emiliano David Perneta', 'São Sebastião', '83075-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12375, 'Apucarana', 'Emiliano Francisco Xavier', 'Parque Bela Vista', '86803-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12376, 'Piraquara', 'Emiliano Gonçalves da Silva', 'Planta Deodoro', '83304-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12377, 'Campo Largo', 'Emiliano Moreira de Almeida', 'Vila Andreassa Miranda', '83605-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12378, 'Londrina', 'Emiliano Perneta', 'Conjunto Residencial Vale do Arvoredo', '86047-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12379, 'Guarapuava', 'Emiliano Perneta', 'Alto da XV', '85065-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12380, 'Pato Branco', 'Emiliano Perneta', 'Jardim Primavera', '85502-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12381, 'Ponta Grossa', 'Emiliano Perneta', 'Uvaranas', '84025-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12382, 'Maringá', 'Emiliano Perneta', 'Zona 03', '87050-070', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12383, 'Londrina', 'Emiliano Perneta', 'Paulista', '86079-095', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12384, 'Toledo', 'Emiliano Perneta', 'Vila Industrial', '85904-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12385, 'Campo Largo', 'Emiliano Perneta', 'Centro', '83601-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12386, 'Almirante Tamandaré', 'Emiliano Perneta', 'Jardim São Carlos', '83507-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12387, 'Apucarana', 'Emiliano Perneta', 'Jardim Ponta Grossa', '86805-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12388, 'Apucarana', 'Emiliano Perneta', 'Jardim América', '86807-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12389, 'Curitiba', 'Emiliano Perneta', 'Centro', '80420-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12390, 'Curitiba', 'Emiliano Perneta', 'Centro', '80010-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12391, 'Paranaguá', 'Emiliano Tomé', 'Parque São João', '83212-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12392, 'Curitiba', 'Emílio Alexandrino da Silva', 'Santa Felicidade', '82030-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12393, 'Ponta Grossa', 'Emílio Andreatta', 'Oficinas', '84035-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12394, 'Ponta Grossa', 'Emílio Andreatta', 'Jardim Carvalho', '84015-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12395, 'Sarandi', 'Emílio Ângelo Panasol', 'Boa Vista', '87111-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12396, 'Londrina', 'Emílio Aranda', 'Operária', '86038-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12397, 'Colombo', 'Emílio Arzua', 'Jardim Rio Verde', '83405-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12398, 'Cambé', 'Emílio Barizon', 'Parque Residencial Ana Rosa', '86183-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12399, 'Cascavel', 'Emílio Bautitz', 'Universitário', '85819-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12400, 'Curitiba', 'Emílio Behling Filho', 'Uberaba', '81550-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12401, 'Curitiba', 'Emílio Belloni', 'Santa Felicidade', '82020-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12402, 'Maringá', 'Emílio Beltrami Filho', 'Parque da Gávea', '87053-337', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12403, 'Curitiba', 'Emílio Bertolini', 'Cajuru', '82920-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12404, 'Curitiba', 'Emílio Bordenoski', 'Vista Alegre', '80820-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12405, 'Campo Largo', 'Emílio Busemeyer', 'Jardim Busmayer', '83606-550', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12406, 'Paranaguá', 'Emílio César Gonçalves', 'Jardim Samambaia', '83212-346', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12407, 'Curitiba', 'Emílio Cornelsen', 'Ahú', '80540-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12408, 'Araucária', 'Emílio Cunha', 'Barigui', '83707-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12409, 'Curitiba', 'Emílio de Almeida Torres', 'Campina do Siqueira', '80740-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12410, 'Apucarana', 'Emílio de Araújo Costa', 'Núcleo Habitacional João Goulart', '86807-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12411, 'Foz do Iguaçu', 'Emílio de Menezes', 'Jardim América', '85864-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12412, 'Londrina', 'Emílio de Menezes', 'Jardim Tatiani', '86070-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12413, 'Ponta Grossa', 'Emílio de Menezes', 'Estrela', '84040-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12414, 'Paranavaí', 'Emílio de Menezes', 'Jardim São Jorge', '87710-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12415, 'Maringá', 'Emílio de Menezes', 'Zona 05', '87015-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12416, 'Toledo', 'Emílio de Menezes', 'Vila Industrial', '85904-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12417, 'Colombo', 'Emílio de Menezes', 'Jardim Central', '83409-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12418, 'Apucarana', 'Emílio de Menezes', 'Jardim Ponta Grossa', '86805-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12419, 'Cascavel', 'Emílio de Menezes', 'Presidente', '85818-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12420, 'Apucarana', 'Emílio de Menezes', 'Jardim América', '86807-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12421, 'Curitiba', 'Emílio de Menezes', 'Bom Retiro', '80520-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12422, 'Curitiba', 'Emílio de Menezes', 'São Francisco', '80510-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12423, 'Pato Branco', 'Emílio de Negri', 'Amadori', '85502-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12424, 'Toledo', 'Emílio Dietrichkeit', 'Jardim Europa', '85908-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12425, 'Francisco Beltrão', 'Emílio Donati', 'Marrecas', '85601-430', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12426, 'Maringá', 'Emílio Fajardo Espejo', 'Parque Residencial Quebec', '87025-020', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12427, 'Colombo', 'Emílio Gleber', 'Vila Yara', '83408-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12428, 'Londrina', 'Emílio Gomes Fialho', 'Dom Pedro I', '86089-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12429, 'Londrina', 'Emílio Gonzalez Truríbio', 'Jardim Ilha do Mel', '86081-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12430, 'Foz do Iguaçu', 'Emílio Henrique Gomes', 'Jardim Bandeirantes', '85862-439', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12431, 'Almirante Tamandaré', 'Emílio Johnson', 'Vila Santa Terezinha', '83501-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12432, 'Londrina', 'Emílio Kisser', 'Heimtal', '86084-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12433, 'Campo Largo', 'Emílio Klentz', 'Bom Jesus', '83604-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12434, 'Apucarana', 'Emílio Kretuchi', 'Jardim Figueira', '86801-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12435, 'Castro', 'Emílio Kugler', 'Jardim Social Arapongas', '84174-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12436, 'Londrina', 'Emílio Mahler', 'Jardim Nova Esperança', '86044-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12437, 'Guarapuava', 'Emílio Médici', 'Boqueirão', '85020-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12438, 'Curitiba', 'Emílio Mercuri', 'Santo Inácio', '82010-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12439, 'Curitiba', 'Emílio Nichele', 'Cidade Industrial', '81350-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12440, 'Londrina', 'Emílio Pavan', 'Barbeta', '86078-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12441, 'Castro', 'Emílio Rebonato', 'Cantagalo', '84178-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12442, 'Curitiba', 'Emílio Romani', 'Cidade Industrial', '81460-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12443, 'Curitiba', 'Emílio Schmidt', 'Novo Mundo', '81050-627', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12444, 'Curitiba', 'Emílio Scuissiato', 'Fazendinha', '81330-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12445, 'Guarapuava', 'Emílio Serrato', 'Vila Bela', '85025-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12446, 'Colombo', 'Emílio Simioni', 'Serrinha', '83415-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12447, 'Londrina', 'Emílio Vizentin', 'Portal de Versalhes 2', '86063-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12448, 'Araucária', 'Emílio Voss', 'Thomaz Coelho', '83707-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12449, 'Guarapuava', 'Emílio Zampier', 'Industrial', '85045-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12450, 'Curitiba', 'Emílio Zattera', 'São Braz', '82300-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12451, 'Campo Largo', 'Emingo Ângelo', 'Centro', '83601-430', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12452, 'Campo Largo', 'Emingo Ângelo', 'Jardim São Vicente', '83602-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12453, 'Curitiba', 'Emir Calluf', 'Tarumã', '82530-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12454, 'Cascavel', 'Emir Sfair', 'Santa Cruz', '85806-068', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12455, 'Curitiba', 'Emirado Árabes Unidos', 'Sítio Cercado', '81900-465', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12456, 'Londrina', 'Emma Anna Oldemberg Astafieff', 'Jardim Portal de Itamaracá', '86079-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12457, 'Curitiba', 'Emma Elvira Biancolini Bini', 'Capão da Imbuia', '82810-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12458, 'Toledo', 'Emma Hubner', 'Vila Pioneiro', '85909-747', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12459, 'Curitiba', 'Emma Pschera Lass', 'Cascatinha', '82020-785', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12460, 'Pinhais', 'Emma Rohrsetzer', 'Vila Emiliano Perneta', '83324-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12461, 'Curitiba', 'Emma Siglinda da Silva', 'Cidade Industrial', '81460-276', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12462, 'São José dos Pinhais', 'Emmanuel Kant', 'Aristocrata', '83030-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12463, 'Curitiba', 'Emmi Wolf', 'Bacacheri', '82510-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12464, 'Arapongas', 'Emu', 'Jardim Aeroporto', '86702-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12465, 'Maringá', 'Emygdio de Brito', 'Jardim Imperial II', '87023-005', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12466, 'Sarandi', 'Encarnação Castilho', 'Parque Alvamar', '87113-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12467, 'Curitiba', 'Encarnação Dolores Albacete', 'Xaxim', '81720-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12468, 'Curitiba', 'Enéas Alves de Araújo', 'Orleans', '82300-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12469, 'Francisco Beltrão', 'Enéas Marques', 'Marrecas', '85601-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12470, 'São José dos Pinhais', 'Enéas Marques', 'Cidade Jardim', '83035-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12471, 'Colombo', 'Enéas Marques', 'Jardim Guaraituba', '83410-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12472, 'Pinhais', 'Enedina Irael da Rosa', 'Planta Vila Bordignon', '83325-579', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12473, 'Colombo', 'Enemésio do Rosário Júnior', 'Vila Miracema', '83408-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12474, 'Curitiba', 'Enette Dubard', 'Tatuquara', '81470-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12475, 'Ponta Grossa', 'Enfermeira Adelaide Pareta', 'Uvaranas', '84030-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12476, 'Londrina', 'Enfermeira Maria Lucília Monti Magalhães', 'Jardim Pioneiros', '86036-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12477, 'Ponta Grossa', 'Enfermeiro Paulino', 'Uvaranas', '84026-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12478, 'Cascavel', 'Engenharia', 'Universitário', '85819-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12479, 'Curitiba', 'Engenheira Enedina Alves Marques', 'Cajuru', '82950-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12480, 'Curitiba', 'Engenheiro Ademar Munhoz', 'Uberaba', '81560-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12481, 'Curitiba', 'Engenheiro Adhemar Lino de Faria', 'Cidade Industrial', '81450-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12482, 'Curitiba', 'Engenheiro Agrônomo Lauro Klas', 'Pilarzinho', '82100-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12483, 'Campo Mourão', 'Engenheiro Airton P. S. Alves', 'Jardim Santa Cruz', '87309-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12484, 'Curitiba', 'Engenheiro Alberto Monteiro de Carvalho', 'Capão da Imbuia', '82810-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12485, 'Curitiba', 'Engenheiro Alfredo Geraldo Sica Pinto', 'Uberaba', '81590-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12486, 'Curitiba', 'Engenheiro Álvaro Baptista', 'Umbará', '81930-629', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12487, 'Curitiba', 'Engenheiro Amur Raphael Grassi Mattei', 'Campina do Siqueira', '80740-150', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12488, 'Curitiba', 'Engenheiro Antônio Batista Ribas', 'Tarumã', '82800-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12489, 'Guarapuava', 'Engenheiro Antônio Rebouças', 'Santa Cruz', '85015-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12490, 'Foz do Iguaçu', 'Engenheiro Araripe', 'Parque Morumbi II', '85859-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12491, 'Curitiba', 'Engenheiro Ariel Villar Tacla', 'Cidade Industrial', '81350-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12492, 'Curitiba', 'Engenheiro Arthur Bettes', 'Portão', '80610-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12493, 'Paranaguá', 'Engenheiro Arthur Miranda Ramos', 'Jardim Araçá', '83221-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12494, 'Curitiba', 'Engenheiro Audinir Curial Gondim', 'Taboão', '82130-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12495, 'Curitiba', 'Engenheiro Augusto Grohs', 'Prado Velho', '80215-390', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12496, 'Guarapuava', 'Engenheiro Beltrão', 'Boqueirão', '85023-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12497, 'Ponta Grossa', 'Engenheiro Beltrão', 'Oficinas', '84036-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12498, 'Toledo', 'Engenheiro Beltrão', 'Boa Esperança', '85909-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12499, 'Curitiba', 'Engenheiro Benedicto Saddock de Sá', 'Atuba', '82630-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12500, 'Curitiba', 'Engenheiro Benedito Mário da Silva', 'Cajuru', '82970-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12501, 'Curitiba', 'Engenheiro Benjamin de Andrade Mourão', 'Cajuru', '82950-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12502, 'Curitiba', 'Engenheiro Bernardino d''Oliveira', 'Cajuru', '82970-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12503, 'Curitiba', 'Engenheiro Carlos Westermann', 'Jardim Social', '82530-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12504, 'Curitiba', 'Engenheiro Cezar Mattar Neto', 'Atuba', '82860-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12505, 'Curitiba', 'Engenheiro Costa Barros', 'Cajuru', '82950-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12506, 'Curitiba', 'Engenheiro Costa Barros', 'Cajuru', '82940-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12507, 'Curitiba', 'Engenheiro Daley Sun Busetti Mori', 'Sítio Cercado', '81920-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12508, 'Paranaguá', 'Engenheiro Didio Vianna', 'Alto São Sebastião', '83203-735', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12509, 'Piraquara', 'Engenheiro Djalma Maciel', 'Jardim Santa Mônica', '83302-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12510, 'Curitiba', 'Engenheiro Douglas Souza Luz', 'Seminário', '80310-585', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12511, 'Curitiba', 'Engenheiro Durval E. P. de Carvalho', 'Butiatuvinha', '82400-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12512, 'Curitiba', 'Engenheiro Edlar Silveira D''Avilla', 'Sítio Cercado', '81920-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12513, 'Curitiba', 'Engenheiro Eduardo A. Nadolny', 'Cidade Industrial', '81460-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12514, 'Curitiba', 'Engenheiro Emílio Guetter', 'Hauer', '81630-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12515, 'Curitiba', 'Engenheiro Ernesto Guaita', 'Tingui', '82620-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12516, 'Apucarana', 'Engenheiro Eugênio Ostrensky', 'Vila Rural Nova Ukrania', '86810-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12517, 'Curitiba', 'Engenheiro Farid Surugi', 'Tarumã', '82800-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12518, 'Curitiba', 'Engenheiro Francisco Beltrão', 'Jardim Social', '82520-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12519, 'Cascavel', 'Engenheiro Francisco Natel de Camargo', 'Periolo', '85817-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12520, 'Curitiba', 'Engenheiro Francisco Xavier Driesel', 'Cachoeira', '82710-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12521, 'Curitiba', 'Engenheiro Gastão Chaves', 'Santa Cândida', '82630-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12522, 'Curitiba', 'Engenheiro Gil Reinaldo Glaser', 'Xaxim', '81710-390', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12523, 'Curitiba', 'Engenheiro Gottardo Bottarelli', 'Jardim Botânico', '80210-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12524, 'Curitiba', 'Engenheiro Hans Henrique Martin Prueter', 'Abranches', '82130-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12525, 'Cascavel', 'Engenheiro Heinz Marth', 'Santa Felicidade', '85803-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12526, 'Curitiba', 'Engenheiro Heitor Soares Gomes', 'Portão', '80330-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12527, 'Foz do Iguaçu', 'Engenheiro Hildemar Leite Franca', 'Parque Morumbi I', '85858-648', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12528, 'Curitiba', 'Engenheiro Ivan Rigomero Ceccon', 'Jardim Social', '82520-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12529, 'Piraquara', 'Engenheiro Jairo Sebastião Ferrari', 'Vila Ipanema', '83301-045', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12530, 'Curitiba', 'Engenheiro Jayme Matzenbacher', 'Atuba', '82630-307', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12531, 'Curitiba', 'Engenheiro João Bley Filho', 'Pinheirinho', '81870-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12532, 'Curitiba', 'Engenheiro João Kloss', 'Tatuquara', '81470-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12533, 'Curitiba', 'Engenheiro João Vicente Portela Couto', 'Seminário', '80310-670', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12534, 'Curitiba', 'Engenheiro João Visinoni', 'Cidade Industrial', '81280-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12535, 'Curitiba', 'Engenheiro José de Freitas Saldanha', 'Guabirotuba', '81520-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12536, 'Piraquara', 'Engenheiro José Gilberto Higino da Costa', 'Borda do Campo', '83304-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12537, 'Piraquara', 'Engenheiro José Gilberto Higino da Costa', 'Vila Militar I', '83303-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12538, 'Curitiba', 'Engenheiro José Orontes Pires', 'Abranches', '82130-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12539, 'Curitiba', 'Engenheiro Júlio César de Souza Araújo', 'Cidade Industrial', '81290-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12540, 'Curitiba', 'Engenheiro Leão Sounis', 'Jardim Botânico', '80210-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12541, 'Guarapuava', 'Engenheiro Lentsch', 'Conradinho', '85055-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12542, 'Curitiba', 'Engenheiro Linneu Ratton', 'Uberaba', '81580-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12543, 'Curitiba', 'Engenheiro Lourival Maciel', 'Mossunguê', '81210-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12544, 'Curitiba', 'Engenheiro Luiz Augusto Leão Fonseca', 'Santa Cândida', '82640-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12545, 'Curitiba', 'Engenheiro Luiz Carlos de Oliveira Borges', 'Santa Quitéria', '80310-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12546, 'Curitiba', 'Engenheiro Luiz Gastão Mendes Lima', 'Cidade Industrial', '81350-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12547, 'Curitiba', 'Engenheiro Luiz Natal Bonin', 'Taboão', '82130-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12548, 'Curitiba', 'Engenheiro Marcos José Lewin', 'Cidade Industrial', '81240-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12549, 'Ponta Grossa', 'Engenheiro Mauro Pinto', 'Uvaranas', '84030-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12550, 'Campo Mourão', 'Engenheiro Mercer', 'Jardim Conrado', '87308-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12551, 'Curitiba', 'Engenheiro Niepce da Silva', 'Portão', '80610-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12552, 'Londrina', 'Engenheiro Omar Rupp', 'Jardim Londrilar', '86015-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12553, 'Curitiba', 'Engenheiro Ostoja Roguski', 'Jardim Botânico', '80210-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12554, 'Maringá', 'Engenheiro Osvaldo Pacheco de Lacerda', 'Parque Industrial', '87065-160', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12555, 'Curitiba', 'Engenheiro Oswaldo Siqueira', 'Taboão', '82130-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12556, 'Curitiba', 'Engenheiro Paulo Gabriel Passos Brandão', 'Santa Cândida', '82640-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12557, 'São José dos Pinhais', 'Engenheiro Pedro Bonk', 'Guatupê', '83065-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12558, 'Piraquara', 'Engenheiro Pontoni', 'Jardim Primavera', '83302-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12559, 'Curitiba', 'Engenheiro Químico Dirceu Correia', 'Santa Cândida', '82720-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12560, 'Curitiba', 'Engenheiro Raul Iwersen', 'Alto da Glória', '80030-520', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12561, 'Foz do Iguaçu', 'Engenheiro Rebouças', 'Centro', '85851-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12562, 'Paranavaí', 'Engenheiro Rebouças', 'Jardim São Jorge', '87710-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12563, 'Ponta Grossa', 'Engenheiro Rebouças', 'Uvaranas', '84020-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12564, 'Toledo', 'Engenheiro Rebouças', 'Walter Fontana', '85909-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12565, 'Cascavel', 'Engenheiro Rebouças', 'Centro', '85812-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12566, 'Cascavel', 'Engenheiro Rebouças', 'Centro', '85812-131', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12567, 'São José dos Pinhais', 'Engenheiro Roberto Blonkowski Júnior', 'Planta Quississana', '83085-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12568, 'Curitiba', 'Engenheiro Roberto Fischer', 'Cidade Industrial', '81250-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12569, 'Curitiba', 'Engenheiro Roberto Guilherme P. Leite', 'Vista Alegre', '80820-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12570, 'Curitiba', 'Engenheiro Romeu Gonçalves Pereira', 'Bacacheri', '82600-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12571, 'Curitiba', 'Engenheiro Rômulo Gutierrez', 'Vista Alegre', '80810-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12572, 'Curitiba', 'Engenheiro Rômulo Gutierrez', 'Vista Alegre', '80820-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12573, 'Curitiba', 'Engenheiro Ronald Machado da Luz', 'Santa Felicidade', '82410-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12574, 'Curitiba', 'Engenheiro Sady Souza', 'Cidade Industrial', '81290-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12575, 'Curitiba', 'Engenheiro Savino Folloni', 'Juvevê', '80530-270', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12576, 'Ponta Grossa', 'Engenheiro Schamber', 'Centro', '84010-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12577, 'Curitiba', 'Engenheiro Serafim Voloschen', 'Campina do Siqueira', '80740-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12578, 'Pinhais', 'Engenheiro Sílvio Teixeira Pinto', 'Conjunto Residencial Inocoop', '83326-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12579, 'Ponta Grossa', 'Engenheiro Teixeira Soares', 'Oficinas', '84040-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12580, 'Curitiba', 'Engenheiro Teodoro Sampaio', 'Guabirotuba', '81510-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12581, 'Cascavel', 'Engenheiro Theodoro Sampaio', 'Parque São Paulo', '85803-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12582, 'Campo Largo', 'Engenheiro Tourinho', 'Centro', '83601-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12583, 'Campo Largo', 'Engenheiro Tourinho', 'Vila Solene', '83607-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12584, 'Curitiba', 'Engenheiro Toyoshi Sakai', 'Cidade Industrial', '81250-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12585, 'Ponta Grossa', 'Engenheiro Virgílio Milanese', 'Boa Vista', '84073-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12586, 'Curitiba', 'Engenheiro Waldemar Schinzel', 'Sítio Cercado', '81900-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12587, 'Curitiba', 'Engenheiro Wladislau Dec', 'Xaxim', '81810-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12588, 'Maringá', 'Engenheiro Ysumi Nishikawa', 'Vila Christino', '87050-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12589, 'Curitiba', 'Engenheiros Rebouças', 'Rebouças', '80215-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12590, 'Curitiba', 'Engenheiros Rebouças', 'Rebouças', '80250-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12591, 'Curitiba', 'Engenheiros Rebouças', 'Jardim Botânico', '80210-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12592, 'Curitiba', 'Engenheiros Rebouças', 'Rebouças', '80230-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12593, 'Foz do Iguaçu', 'Engenho Novo', 'Parque Imperatriz', '85862-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12594, 'Toledo', 'Engracia Heiss', 'Jardim Pasqualli', '85905-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12595, 'Foz do Iguaçu', 'Enguias', 'Profilurb I', '85855-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12596, 'Cambé', 'Enildo Maranha', 'Jardim Ana Eliza', '86187-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12597, 'Foz do Iguaçu', 'Ênio Kuster', 'Parque Morumbi II', '85859-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12598, 'Toledo', 'Ênio Zorzo', 'Residencial Santa Clara', '85914-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12599, 'Guarapuava', 'Enir Ada Silveira', 'São Cristóvão', '85063-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12600, 'Curitiba', 'Ennio Tasso de Monção Pires', 'Xaxim', '81830-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12601, 'Curitiba', 'Enoch Araújo Ramos', 'Cidade Industrial', '81305-690', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12602, 'Londrina', 'Enoch Vieira dos Santos', 'Residencial Moradias do Cabo Frio', '86080-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12603, 'Londrina', 'Enok França Furtunato', 'Recanto Pitanguá', '86055-579', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12604, 'Maringá', 'Enrico Bruno Pardini Zamponi', 'Zona 28', '87053-288', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12605, 'Curitiba', 'Enrico Caruso', 'São Braz', '82300-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12606, 'Apucarana', 'Enseada', 'Jardim Guarujá', '86807-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12607, 'Foz do Iguaçu', 'Entre Rios', 'Vila Carima', '85855-707', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12608, 'Pato Branco', 'Entre Rios', 'Trevo Patinhos', '85504-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12609, 'Apucarana', 'Enzo Boneto', 'Parque Bela Vista', '86803-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12610, 'Londrina', 'Enzo Rufino', 'Dom Pedro', '86039-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12611, 'Campo Largo', 'Epaminondas Bulow', 'Loteamento Itaboa', '83605-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12612, 'Curitiba', 'Epaminondas Franco', 'Tarumã', '82530-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12613, 'Curitiba', 'Epaminondas Santos', 'Bairro Alto', '82820-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12614, 'Curitiba', 'Epaminondas Santos', 'Bairro Alto', '82840-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12615, 'Toledo', 'Epitácio', 'Centro', '85901-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12616, 'Londrina', 'Epitácio Pessoa', 'Hedy', '86062-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12617, 'Guarapuava', 'Epitácio Pessoa', 'Alto da XV', '85065-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12618, 'Foz do Iguaçu', 'Epitácio Pessoa', 'Parque Presidente', '85863-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12619, 'Ponta Grossa', 'Epitácio Pessoa', 'Chapada', '84064-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12620, 'Pato Branco', 'Epitácio Pessoa', 'Pinheiros', '85504-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12621, 'Pinhais', 'Epitácio Pessoa', 'Vila Amélia', '83330-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12622, 'Telêmaco Borba', 'Epitácio Pessoa', 'Alto das Oliveiras', '84266-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12623, 'Cascavel', 'Epitácio Pessoa', 'Parque São Paulo', '85803-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12624, 'Apucarana', 'Epitácio Pessoa', 'Jardim Trabalhista', '86807-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12625, 'Curitiba', 'Eponino Macuco', 'Capão Raso', '81110-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12626, 'Guarapuava', 'Equador', 'Morro Alto', '85063-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12627, 'Londrina', 'Equador', 'Vila Rodrigues', '86010-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12628, 'Francisco Beltrão', 'Equador', 'Miniguaçu', '85605-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12629, 'Foz do Iguaçu', 'Equador', 'Jardim América', '85864-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12630, 'São José dos Pinhais', 'Equador', 'Cidade Jardim', '83035-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12631, 'Paranaguá', 'Equador', 'Jardim América', '83209-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12632, 'Maringá', 'Equador', 'Jardim Alvorada', '87033-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12633, 'Toledo', 'Equador', 'Parque Residencial Gisela', '85905-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12634, 'Telêmaco Borba', 'Equador', 'Vila Siqueira', '84266-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12635, 'Apucarana', 'Equador', 'Recanto Mundo Novo', '86805-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12636, 'Colombo', 'Equador', 'Vila São Pedro', '83404-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12637, 'Cambé', 'Equador', 'Jardim Vitória', '86182-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12638, 'Curitiba', 'Equador', 'Bacacheri', '82510-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12639, 'Apucarana', 'Eráclides Morais', 'Vila Nova', '86812-130', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12640, 'Cascavel', 'Eráclito', 'Interlagos', '85814-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12641, 'Curitiba', 'Erailto Thiele', 'São Lourenço', '82200-600', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12642, 'Ponta Grossa', 'Erasmo Braga', 'Neves', '84020-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12643, 'Curitiba', 'Erasmo de Rotterdam', 'Ahú', '82200-240', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12644, 'Curitiba', 'Erasmo Maeder', 'Bairro Alto', '82820-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12645, 'Curitiba', 'Erasmo Piloto', 'Água Verde', '80240-610', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12646, 'Curitiba', 'Ercília Cândida Maltaca', 'Santa Cândida', '82640-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12647, 'Pato Branco', 'Ercília Corona', 'Menino Deus', '85502-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12648, 'Piraquara', 'Ercílio Guimarães', 'Jardim Veneza', '83310-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12649, 'Ponta Grossa', 'Ercílio Slaviero', 'Boa Vista', '84073-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12650, 'Curitiba', 'Ercílio Slaviero', 'Alto da Rua XV', '80050-610', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12651, 'Foz do Iguaçu', 'Ércules Marchesini', 'Jardim N Horizonte', '85855-738', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12652, 'Guarapuava', 'Erechim', 'Alto Cascavel', '85031-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12653, 'Foz do Iguaçu', 'Erechim', 'Jardim Lancaster I', '85869-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12654, 'Toledo', 'Erechim', 'Jardim Porto Alegre', '85906-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12655, 'Cascavel', 'Erechim', 'Centro', '85812-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12656, 'Londrina', 'Erenilda Maria de Jesus', 'Franciscato', '86043-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12657, 'Francisco Beltrão', 'Erexim', 'Guanabara', '85604-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12658, 'Curitiba', 'Érica Florentina Kureski', 'Cidade Industrial', '81170-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12659, 'Curitiba', 'Érica Siegmund', 'Pilarzinho', '82120-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12660, 'Toledo', 'Erich Poniewans', 'Independência', '85906-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12661, 'Curitiba', 'Érico Andretta', 'Xaxim', '81710-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12662, 'Londrina', 'Érico Brehmer', 'Heimtal', '86084-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12663, 'Cascavel', 'Érico Bublitz', 'Pioneiros Catarinenses', '85805-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12664, 'Curitiba', 'Érico José de Mio', 'Campina do Siqueira', '80740-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12665, 'Guarapuava', 'Érico Veríssimo', 'Vila Carli', '85040-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12666, 'Londrina', 'Érico Veríssimo', 'Palermo', '86060-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12667, 'Foz do Iguaçu', 'Érico Veríssimo', 'Jardim Jupira', '85865-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12668, 'Francisco Beltrão', 'Érico Veríssimo', 'Nossa Senhora Aparecida', '85601-795', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12669, 'Pato Branco', 'Érico Veríssimo', 'São Cristóvão', '85508-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12670, 'São José dos Pinhais', 'Érico Veríssimo', 'Colônia Rio Grande', '83025-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12671, 'Toledo', 'Érico Veríssimo', 'Vila Industrial', '85904-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12672, 'Apucarana', 'Érico Veríssimo', 'Jardim Higienópolis', '86800-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12673, 'Araucária', 'Érico Veríssimo', 'Boqueirão', '83704-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12674, 'Colombo', 'Érico Veríssimo', 'Planta Santa Úrsula', '83405-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12675, 'Cascavel', 'Érico Veríssimo', 'Alto Alegre', '85805-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12676, 'Paranaguá', 'Erivan José Tramujas', 'Vila São Vicente', '83209-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12677, 'Maringá', 'Erlon Chaves', 'Conjunto Residencial Cidade Alta', '87053-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12678, 'São José dos Pinhais', 'Ermelia Carolina Marochi', 'Águas Belas', '83010-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12679, 'Apucarana', 'Ermelinda Luizão Cattarin', 'Jardim Santos Dumont III', '86812-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12680, 'Maringá', 'Ermelindo de Leão', 'Zona 05', '87015-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12681, 'Guarapuava', 'Ermelino de Leão', 'Primavera', '85050-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12682, 'Ponta Grossa', 'Ermelino de Leão', 'Olarias', '84035-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12683, 'Cascavel', 'Ermelino de Leão', 'Brasília', '85815-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12684, 'Londrina', 'Ermelino Leão', 'Rica', '86025-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12685, 'Curitiba', 'Ermelino Mariano Ribas', 'Vista Alegre', '80820-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12686, 'Campo Largo', 'Ermelino Ribas de Ramos', 'Vila Campesi', '83604-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12687, 'Curitiba', 'Ermelino Rodrigues', 'Centro', '80420-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12688, 'Londrina', 'Ermenegildo Bertaglia', 'Residencial Loris Sahyun', '86040-606', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12689, 'Cambé', 'Ermenegildo Sabaini', 'Jardim Vitória', '86184-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12690, 'Londrina', 'Ermilino Nonino', 'Jardim Guararapes', '86038-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12691, 'Cascavel', 'Erminda Pires Bastos', 'Santa Felicidade', '85803-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12692, 'Toledo', 'Ermindo Holzbach', 'Jardim Porto Alegre', '85907-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12693, 'Pinhais', 'Ermínio de Azevedo Costa', 'Conjunto Residencial Inocoop', '83326-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12694, 'Francisco Beltrão', 'Ermínio Romani', 'Marrecas', '85601-477', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12695, 'Londrina', 'Ermiro Barbosa Lemes', 'Conjunto Professora Hilda Mandarino', '86080-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12696, 'Castro', 'Erna Anna M. Laroca', 'Vila Frei Mathias', '84165-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12697, 'Curitiba', 'Erna Kirchgassner', 'Barreirinha', '82700-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12698, 'Piraquara', 'Erna Ratke', 'Jardim Curitiba', '83308-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12699, 'Cascavel', 'Ernandes de Oliveira', 'Pioneiros Catarinenses', '85805-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12700, 'Londrina', 'Ernandes Leite Cavalcante', 'Santa Izabel', '86031-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12701, 'Curitiba', 'Ernani Benghi', 'Sítio Cercado', '81925-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12702, 'Ponta Grossa', 'Ernâni Coimbra', 'Boa Vista', '84070-630', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12703, 'Londrina', 'Ernâni Lacerda de Athayde', 'Gleba Fazenda Palhano', '86055-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12704, 'Ponta Grossa', 'Ernâni Pilatti', 'Boa Vista', '84073-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12705, 'Curitiba', 'Ernâni Santiago de Oliveira', 'Centro Cívico', '80530-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12706, 'Curitiba', 'Ernest Hemingway', 'Xaxim', '81810-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12707, 'Londrina', 'Ernesta Chimenton Tesser', 'Jardim Paris', '86082-076', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12708, 'Londrina', 'Ernesta Galvani dos Santos', 'Maira', '86035-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12709, 'Curitiba', 'Ernestina dos Santos', 'Cidade Industrial', '81230-408', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12710, 'Londrina', 'Ernestina Duque Estrada', 'Tarobá', '86042-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12711, 'São José dos Pinhais', 'Ernesto Afonso Alves', 'Colônia Rio Grande', '83025-336', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12712, 'Cambé', 'Ernesto Ângelo Guasti', 'Conjunto Residencial Roberto Conceição', '86183-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12713, 'Colombo', 'Ernesto Baptistão', 'Centro Industrial Mauá', '83413-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12714, 'Cascavel', 'Ernesto Barnabé', 'Santa Cruz', '85806-066', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12715, 'Curitiba', 'Ernesto Biscardi', 'Capão Raso', '81130-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12716, 'Londrina', 'Ernesto Bleinroth', 'Universitário', '86050-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12717, 'Curitiba', 'Ernesto Bley', 'Sítio Cercado', '81925-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12718, 'Piraquara', 'Ernesto Bueno do Nascimento', 'Jardim dos Estados 3', '83307-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12719, 'Londrina', 'Ernesto Cândido de Lara', 'Colinas', '86056-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12720, 'Curitiba', 'Ernesto Carlos Hey', 'Pilarzinho', '82110-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12721, 'Londrina', 'Ernesto Casagrande', 'São Pedro', '86036-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12722, 'Curitiba', 'Ernesto Casagrande', 'Santo Inácio', '82010-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12723, 'Colombo', 'Ernesto Cavalli', 'Walfrido do Rosário', '83413-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12724, 'Pato Branco', 'Ernesto Colla', 'Aeroporto', '85503-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12725, 'Toledo', 'Ernesto Dalla Costa', 'Conjunto Habitacional São Francisco', '85912-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12726, 'Curitiba', 'Ernesto de Araújo', 'Jardim Botânico', '80210-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12727, 'Maringá', 'Ernesto de Oliveira', 'Conjunto João de Barro Champagnat', '87043-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12728, 'Ponta Grossa', 'Ernesto Degraf', 'Chapada', '84062-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12729, 'Curitiba', 'Ernesto Durigan', 'Santa Felicidade', '82020-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12730, 'Curitiba', 'Ernesto Edmundo Weigert', 'Bacacheri', '82600-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12731, 'Guarapuava', 'Ernesto F. de Queiroz', 'Vila Carli', '85040-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12732, 'Cascavel', 'Ernesto Farina', 'Claudete', '85811-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12733, 'Sarandi', 'Ernesto Ferro', 'Vera Cruz', '87111-769', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12734, 'Foz do Iguaçu', 'Ernesto Freiertag', 'Jardim São Paulo I', '85856-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12735, 'Londrina', 'Ernesto Garcia Duarte', 'Andes', '86076-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12736, 'Foz do Iguaçu', 'Ernesto Gayer', 'Loteamento Witt', '85862-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12737, 'Toledo', 'Ernesto Geisel', 'Jardim Maria do Carmo', '85906-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12738, 'Curitiba', 'Ernesto Germano Francisco Hannemann', 'Tatuquara', '81480-196', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12739, 'Guarapuava', 'Ernesto Gomes', 'Morro Alto', '85067-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12740, 'Paranaguá', 'Ernesto Gonçalves', 'Jardim Araçá', '83221-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12741, 'Londrina', 'Ernesto Gonçalves Mendes', 'Santa Rita 2', '86072-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12742, 'Curitiba', 'Ernesto Guariza', 'Jardim das Américas', '81520-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12743, 'Araucária', 'Ernesto Hasselmann', 'Vila Nova', '83703-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12744, 'Londrina', 'Ernesto Horner', 'Portal de Versalhes 3', '86055-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12745, 'Francisco Beltrão', 'Ernesto João Rathier', 'Miniguaçu', '85605-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12746, 'São José dos Pinhais', 'Ernesto Jonas Gonçalves', 'Guatupê', '83060-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12747, 'São José dos Pinhais', 'Ernesto José de Paula', 'Miringuava', '83090-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12748, 'São José dos Pinhais', 'Ernesto Juliatto', 'Colônia Zacarias', '83020-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12749, 'Foz do Iguaçu', 'Ernesto Keller', 'Jardim Eliza II', '85854-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12750, 'Foz do Iguaçu', 'Ernesto Keller', 'Jardim Eliza I', '85853-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12751, 'Curitiba', 'Ernesto Khol', 'Pilarzinho', '82115-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12752, 'Curitiba', 'Ernesto Krainski', 'Novo Mundo', '81050-626', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12753, 'Pinhais', 'Ernesto Kugler', 'Vila Maria Antonieta', '83331-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12754, 'Londrina', 'Ernesto Lahmann', 'Aquilles Sthengel', '86086-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12755, 'Curitiba', 'Ernesto Luiz de Oliveira', 'Vila Izabel', '80240-390', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12756, 'Curitiba', 'Ernesto Luiz Pellanda', 'Ganchinho', '81935-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12757, 'Toledo', 'Ernesto Malacarne', 'Jardim Parizzotto', '85914-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12758, 'Foz do Iguaçu', 'Ernesto Mann', 'Parque Residencial Itália', '85858-670', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12759, 'Maringá', 'Ernesto Mariucci', 'Jardim Aclimação', '87050-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12760, 'Maringá', 'Ernesto Mariucci', 'Parque da Gávea', '87053-256', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12761, 'Guarapuava', 'Ernesto Martins', 'Vila Bela', '85025-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12762, 'Londrina', 'Ernesto Mazzer', 'Colúmbia', '86057-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12763, 'Londrina', 'Ernesto Melluns', 'Nova Olinda', '86073-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12764, 'São José dos Pinhais', 'Ernesto Montanarin', 'Planta Quississana', '83085-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12765, 'Cascavel', 'Ernesto Nazaréth', 'Brasília', '85815-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12766, 'Pinhais', 'Ernesto Pacheco Bello', 'Jardim Dona Joaquina II', '83325-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12767, 'Curitiba', 'Ernesto Piazzetta', 'Bacacheri', '82510-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12768, 'Maringá', 'Ernesto Pozza', 'Jardim Novo Horizonte', '87010-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12769, 'Ponta Grossa', 'Ernesto Reusing', 'Ronda', '84051-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12770, 'Foz do Iguaçu', 'Ernesto Rodrigues Fortes', 'Beverly Falls Park', '85858-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12771, 'Curitiba', 'Ernesto Ronch', 'Tatuquara', '81480-340', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12772, 'Londrina', 'Ernesto Serra', 'Jardim Tropical', '86087-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12773, 'Toledo', 'Ernesto Sperotto', 'Jardim Porto Alegre', '85906-320', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12774, 'Londrina', 'Ernesto Tonellatti', 'Espírito Santo', '86073-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12775, 'Londrina', 'Ernesto Vacario', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12776, 'Londrina', 'Ernesto Valério', 'Coimbra', '86050-415', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12777, 'Curitiba', 'Ernesto Valt', 'Mossunguê', '81200-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12778, 'Curitiba', 'Ernesto Vieira de Souza', 'Alto Boqueirão', '81770-778', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12779, 'Ponta Grossa', 'Ernesto Vilela', 'Nova Rússia', '84070-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12780, 'Ponta Grossa', 'Ernesto Vilela', 'Centro', '84010-460', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12781, 'Maringá', 'Ernesto Volpato', 'Jardim Paris', '87083-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12782, 'Pinhais', 'Ernesto Wandembruck', 'Jardim Triângulo', '83331-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12783, 'Toledo', 'Ernesto Wiezer', 'Independência', '85906-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12784, 'Londrina', 'Erondi Dutra Lot', 'Garden Park Residence', '86079-247', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12785, 'Maringá', 'Erondino Antônio Pinhata', 'Conjunto Habitacional Requião', '87047-437', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12786, 'Toledo', 'Eroni Becker', 'Jardim Parque Verde', '85906-728', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12787, 'Paranaguá', 'Eropina Campos Cominese', 'Santos Dumont', '83209-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12788, 'Francisco Beltrão', 'Eros Abdala', 'Água Branca', '85601-338', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12789, 'Curitiba', 'Eros José Alves', 'Cajuru', '82900-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12790, 'Curitiba', 'Eros Ruppel Abdalla', 'Taboão', '82130-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12791, 'Curitiba', 'Erton Coelho Queiroz', 'Alto Boqueirão', '81770-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12793, 'Curitiba', 'Erval Velho', 'Cidade Industrial', '81270-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12794, 'Telêmaco Borba', 'Erva-mate', 'Área 01', '84268-070', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12795, 'Cascavel', 'Erva-mate', 'Recanto Tropical', '85807-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12796, 'Curitiba', 'Erva-mate', 'Santa Felicidade', '82015-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12797, 'Ponta Grossa', 'Erveira', 'Contorno', '84061-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12798, 'Campo Mourão', 'Erveira', 'Conjunto Habitacional Mendes', '87306-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12799, 'Toledo', 'Ervino Hutt', 'Residencial Santa Clara', '85914-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12800, 'Curitiba', 'Ervino Ramm', 'Cidade Industrial', '81310-446', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12801, 'Londrina', 'Escócia', 'Jardim Adriana II', '86046-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12802, 'Colombo', 'Escócia', 'Jardim Bela Vista', '83404-570', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12803, 'Curitiba', 'Escola de Oficiais Especialistas', 'Bacacheri', '82515-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12804, 'Araucária', 'Escolástica Brunato Pisca', 'Estação', '83705-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12805, 'Pato Branco', 'Escolástica Tatto', 'Trevo Patinhos', '85504-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12806, 'Maringá', 'Escritor Aluísio Azevedo', 'Conjunto Habitacional Itatiaia', '87045-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12807, 'Curitiba', 'Escritor Antônio de Alcântara Machado', 'Sítio Cercado', '81920-767', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12808, 'Curitiba', 'Escritor Edwino Donato Tempski', 'Cidade Industrial', '81460-217', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12809, 'Curitiba', 'Escritor Jorge Luiz Borges', 'São Braz', '82015-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12810, 'Curitiba', 'Escritor José Pereira da Graça Aranha', 'Sítio Cercado', '81920-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12811, 'Maringá', 'Escritora Cecília Meirelles', 'Vila Esperança', '87020-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12812, 'Curitiba', 'Escultor João Zacco Paraná', 'Bacacheri', '82600-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12813, 'Araucária', 'Escumilha', 'Campina da Barra', '83709-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12814, 'Curitiba', 'Esídio Orlando Fabri', 'Santa Felicidade', '82020-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12815, 'Ponta Grossa', 'Esmair Batista de Souza', 'Estrela', '84050-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12816, 'Pinhais', 'Esmalta Isabel de Camargo', 'Loteamento Pineville', '83325-588', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12817, 'Guarapuava', 'Esmeralda', 'Santa Cruz', '85015-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12818, 'Foz do Iguaçu', 'Esmeralda', 'Parque Ouro Verde', '85854-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12819, 'Ponta Grossa', 'Esmeralda', 'Neves', '84021-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12820, 'Maringá', 'Esmeralda', 'Jardim Real', '87083-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12821, 'Piraquara', 'Esmeralda', 'Jardim Primavera', '83302-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12822, 'Telêmaco Borba', 'Esmeralda', 'Área 04', '84266-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12823, 'Umuarama', 'Esmeralda', 'Conjunto Residencial Ouro Branco', '87508-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12824, 'Cambé', 'Esmeralda', 'Conjunto Habitacional Cristal', '86182-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12825, 'Campo Mourão', 'Esmeralda', 'Jardim Tropical I', '87310-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12826, 'Apucarana', 'Esmeralda', 'Vila Agari', '86808-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12827, 'Cascavel', 'Esmeralda', 'Esmeralda', '85806-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12828, 'Arapongas', 'Esmeralda-de-cauda-azul', 'Casa Família Arapongas IV', '86709-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12829, 'Maringá', 'Esmeraldo Leandro', 'Jardim América', '87045-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12830, 'Guarapuava', 'Espanha', 'Santana', '85063-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12831, 'Francisco Beltrão', 'Espanha', 'Seminário', '85605-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12832, 'Londrina', 'Espanha', 'Igapó', '86046-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12833, 'Foz do Iguaçu', 'Espanha', 'Vila Portes', '85865-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12834, 'Ponta Grossa', 'Espanha', 'Oficinas', '84036-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12835, 'Sarandi', 'Espanha', 'Jardim Europa', '87111-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12836, 'Umuarama', 'Espanha', 'Jardim Campo Belo', '87507-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12837, 'Almirante Tamandaré', 'Espanha', 'Vila Emerentina', '83505-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12838, 'Cascavel', 'Espanha', 'Cascavel Velho', '85818-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12839, 'Cambé', 'Espanha', 'Centro', '86181-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12840, 'Arapongas', 'Espátula', 'Parque Siomara', '86705-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12841, 'Campo Mourão', 'Espedito A. dos Santos', 'Jardim Santa Nilce I', '87308-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12842, 'Curitiba', 'Esper Jorge Chueri', 'Cajuru', '82930-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12843, 'Curitiba', 'Esper Jorge Chueri', 'Cajuru', '82920-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12844, 'Foz do Iguaçu', 'Esperança', 'Jardim Duarte', '85861-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12845, 'Cambé', 'Esperança', 'Jardim do Café', '86186-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12846, 'Campo Mourão', 'Esperança', 'Conjunto Habitacional Mendes', '87306-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12847, 'Colombo', 'Esperança Andreatto Lazarotto', 'Jardim dos Eucaliptos', '83408-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12848, 'Umuarama', 'Esperança Nova', 'Conjunto Residencial Córrego Longe', '87504-618', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12849, 'Curitiba', 'Esperandio Domingos Foggiatto', 'Prado Velho', '80215-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12850, 'Curitiba', 'Esperandio Tortato', 'Cidade Industrial', '81170-287', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12851, 'Londrina', 'Esperanto', 'Cilo 2', '86067-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12852, 'Curitiba', 'Esperidião Kalluf', 'Uberaba', '81560-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12853, 'Cascavel', 'Espinelio', 'Esmeralda', '85806-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12854, 'Londrina', 'Espírito Santo', 'Centro', '86020-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12855, 'Francisco Beltrão', 'Espírito Santo', 'São Cristóvão', '85601-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12856, 'Foz do Iguaçu', 'Espírito Santo', 'Vila Bom Jesus', '85852-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12857, 'Londrina', 'Espírito Santo', 'Centro', '86010-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12858, 'Ponta Grossa', 'Espírito Santo', 'Colônia Dona Luiza', '84045-300', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12859, 'Ponta Grossa', 'Espírito Santo', 'Nova Rússia', '84070-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12860, 'Paranaguá', 'Espírito Santo', 'Vila do Povo', '83209-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12861, 'Piraquara', 'Espírito Santo', 'Jardim dos Estados 1', '83308-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12862, 'Piraquara', 'Espírito Santo', 'Jardim dos Estados 2', '83308-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12863, 'Sarandi', 'Espírito Santo', 'Parque Residencial Bom Pastor', '87114-546', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12864, 'São José dos Pinhais', 'Espírito Santo', 'Colônia Rio Grande', '83025-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12865, 'Araucária', 'Espírito Santo', 'Iguaçu', '83701-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12866, 'Campo Largo', 'Espírito Santo', 'Jardim Esmeralda', '83604-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12867, 'Apucarana', 'Espírito Santo', 'Jardim Apucarana', '86804-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12868, 'Colombo', 'Espírito Santo', 'Jardim Bandeirantes', '83408-410', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12869, 'Castro', 'Espírito Santo', 'Invernada do Matadouro', '84174-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12870, 'Curitiba', 'Espírito Santo', 'Água Verde', '80630-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12871, 'Cambé', 'Esplanada', 'Jardim Casa Grande', '86191-386', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12872, 'Guarapuava', 'Essaete', 'São Cristóvão', '85063-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12873, 'Londrina', 'Essio Orsi', 'Barbeta', '86078-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12874, 'Londrina', 'Estação Ecológia do Jari', 'Carnascialli', '86077-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12875, 'Londrina', 'Estação Ecológica Esmeralda', 'Vila A B Vicentini', '86077-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12876, 'Curitiba', 'Estácia Cândida de Almeida', 'Cidade Industrial', '81305-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12877, 'Londrina', 'Estácio de Sá', 'Sabará I', '86066-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12878, 'Piraquara', 'Estácio de Sá', 'Jardim Bela Vista', '83301-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12879, 'Maringá', 'Estácio de Sá', 'Zona 02', '87010-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12880, 'Pato Branco', 'Estácio de Sá', 'Bortot', '85504-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12881, 'Maringá', 'Estácio de Sá', 'Vila Bosque', '87005-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12882, 'Cascavel', 'Estácio de Sá', 'Pacaembu', '85816-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12883, 'Curitiba', 'Estado de Israel', 'Vila Izabel', '80240-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12884, 'Londrina', 'Estados Unidos', 'Jerumenha', '86046-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12885, 'Ponta Grossa', 'Estados Unidos', 'Centro', '84010-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12886, 'Paranaguá', 'Estados Unidos', 'Jardim América', '83209-470', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12887, 'Maringá', 'Estados Unidos', 'Jardim Internorte', '87045-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12888, 'Umuarama', 'Estados Unidos', 'Parque Bonfim', '87507-376', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12889, 'Telêmaco Borba', 'Estados Unidos', 'Alto das Oliveiras', '84266-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12890, 'Cambé', 'Estados Unidos', 'Centro', '86181-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12891, 'Almirante Tamandaré', 'Estados Unidos', 'Vila Graziela', '83505-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12892, 'Colombo', 'Estados Unidos', 'Jardim Bela Vista', '83404-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12893, 'Cascavel', 'Estados Unidos', 'Pacaembu', '85816-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12894, 'Almirante Tamandaré', 'Estados Unidos', 'Jardim São Francisco', '83501-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12895, 'Apucarana', 'Estados Unidos', 'Recanto Mundo Novo', '86805-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12896, 'Curitiba', 'Estados Unidos', 'Bacacheri', '82510-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12897, 'Curitiba', 'Estados Unidos', 'Boa Vista', '82540-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12898, 'Arapongas', 'Estalinho', 'Conjunto Ulisses Guimarães', '86706-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12899, 'Foz do Iguaçu', 'Estância Velha', 'Loteamento Lindóia', '85856-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12900, 'Apucarana', 'Estanho', 'Parque Industrial Zona Norte', '86806-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12901, 'Ponta Grossa', 'Estanislau A. Piekarski', 'Estrela', '84040-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12902, 'Cascavel', 'Estanislau Chervinski', 'Cataratas', '85818-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12903, 'Cascavel', 'Estanislau Cidral', 'Alto Alegre', '85805-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12904, 'Araucária', 'Estanislau Grebos', 'Centro', '83702-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12905, 'Araucária', 'Estanislau Haiduk', 'Boqueirão', '83704-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12906, 'Piraquara', 'Estanislau Iachinski', 'Planta Deodoro', '83304-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12907, 'Curitiba', 'Estanislau Kais', 'Capão Raso', '81110-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12908, 'Campo Largo', 'Estanislau Kellner', 'Jardim Social', '83606-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12909, 'Curitiba', 'Estanislau Kobaça', 'Cidade Industrial', '81350-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12910, 'Curitiba', 'Estanislau Krowinski', 'Novo Mundo', '81020-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12911, 'Colombo', 'Estanislau Langoviski', 'Jardim Eldorado', '83402-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12912, 'Araucária', 'Estanislau Lesniowski', 'Estação', '83705-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12913, 'Curitiba', 'Estanislau Marks', 'Mossunguê', '81200-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12914, 'Piraquara', 'Estanislau Mazepa', 'Vila Juliana', '83306-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12915, 'Curitiba', 'Estanislau Mickosz', 'Cachoeira', '82220-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12916, 'Curitiba', 'Estanislau Pampuche', 'Campina do Siqueira', '80740-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12917, 'Foz do Iguaçu', 'Estanislau Ponte Preta', 'Jardim Cristina', '85864-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12918, 'Curitiba', 'Estanislau Selenko', 'Umbará', '81940-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12919, 'Colombo', 'Estanislau Socher', 'Jardim Mediterrâneo', '83401-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12920, 'Curitiba', 'Estanislau Szarek', 'Cidade Industrial', '81315-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12921, 'Araucária', 'Estanislau Trauczynski Sobrinho', 'Tindiquera', '83708-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12922, 'Curitiba', 'Estanislau Wildner', 'Alto Boqueirão', '81770-777', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12923, 'Araucária', 'Estanislau Wojcik', 'Tindiquera', '83708-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12924, 'Ponta Grossa', 'Estanislau Zambrycki', 'Chapada', '84063-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12925, 'Londrina', 'Estefan Marotti', 'Barbeta', '86078-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12926, 'Curitiba', 'Estefânia', 'Cachoeira', '82710-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12927, 'Cascavel', 'Estefânia Luiza Villaça', 'Brasília', '85815-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12928, 'Curitiba', 'Estéfano Antônio Schrederhof', 'Tatuquara', '81470-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12929, 'Foz do Iguaçu', 'Estéfano Bernardi', 'Parque Presidente II', '85863-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12930, 'Curitiba', 'Estéfano Betezek', 'Pinheirinho', '81870-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12931, 'Londrina', 'Estéfano Campitelli', 'Jardim Alphaville', '86084-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12932, 'Guarapuava', 'Estefano Getéski', 'Morro Alto', '85070-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12933, 'Curitiba', 'Estefano Joucoski', 'Vista Alegre', '80820-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12934, 'Piraquara', 'Estefano Kavetski', 'Vila Esperança', '83307-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12935, 'Ponta Grossa', 'Estéfano Kogus', 'Uvaranas', '84031-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12936, 'Apucarana', 'Estéfano Kutianski', 'Jardim Morada do Sol', '86811-096', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12937, 'Castro', 'Estéfano Mocroski', 'Vila Rio Branco', '84172-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12938, 'Curitiba', 'Estéfano Raulik', 'Santo Inácio', '82010-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12939, 'Toledo', 'Estéfano Secchi', 'Vila Industrial', '85904-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12940, 'Curitiba', 'Estéfano Sikorski', 'Santo Inácio', '82010-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12941, 'Curitiba', 'Estéfano Tratz', 'Capão da Imbuia', '82800-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12942, 'Guarapuava', 'Estéfano Turok', 'Santa Cruz', '85015-580', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12943, 'Piraquara', 'Estéfano Uberna', 'Recreio da Serra', '83305-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12944, 'Curitiba', 'Estéfano Valeski', 'Santa Cândida', '82630-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12945, 'São José dos Pinhais', 'Estefano Woicikievfisz', 'Colônia Murici', '83085-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12946, 'Foz do Iguaçu', 'Esteio', 'Jardim Lancaster I', '85869-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12947, 'Cascavel', 'Esteio', 'Canadá', '85813-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12948, 'Guarapuava', 'Estela Carli', 'Morro Alto', '85065-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12949, 'Toledo', 'Estela Donin', 'Coopagro', '85903-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12950, 'Araucária', 'Estela Lesniowski Wzorek', 'Fazenda Velha', '83703-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12951, 'Curitiba', 'Estelita Sarraf Scorsin', 'Santa Felicidade', '82015-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12952, 'Colombo', 'Estella Andrade dos Santos', 'Jardim Eldorado', '83402-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12953, 'Curitiba', 'Estephana Pietruza', 'Capão Raso', '81110-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12954, 'Londrina', 'Estephania Michaliszyn Von Stein', 'Monte Carlo', '86073-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12955, 'Foz do Iguaçu', 'Estephano Klein', 'Loteameto Jardim Colombelli', '85862-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12956, 'Curitiba', 'Estephano Reva', 'Santa Felicidade', '82015-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12957, 'Ponta Grossa', 'Ester Kemmelmeier', 'Estrela', '84050-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12958, 'Curitiba', 'Estevam Monastier', 'Xaxim', '81810-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12959, 'Curitiba', 'Estevão Bayão', 'Batel', '80240-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12960, 'Colombo', 'Estevão Costa', 'Uvarana', '83415-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12961, 'Curitiba', 'Estevão Manika', 'Santa Cândida', '82720-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12962, 'Curitiba', 'Estevão Mussak', 'Barreirinha', '82130-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12963, 'Londrina', 'Estevão Nantes', 'Jardim Palmas', '86081-356', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12964, 'Londrina', 'Estevo Maschio', 'Residencial Portal de Piza', '86041-307', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12965, 'Curitiba', 'Esther da Silva Florenzano', 'Cidade Industrial', '81230-396', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12966, 'Curitiba', 'Esther Lacerda Pinto', 'Capão Raso', '81110-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12967, 'Cascavel', 'Estilac Leal', 'São Cristóvão', '85816-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12968, 'Telêmaco Borba', 'Estocolmo', 'Nossa Senhora do Perpétuo Socorro', '84265-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12969, 'Cascavel', 'Estocolmo', 'Cascavel Velho', '85818-555', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12970, 'Cascavel', 'Estocolmo', 'Cascavel Velho', '85818-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12971, 'Colombo', 'Estocolmo', 'Vila Alto da Cruz', '83405-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12972, 'Cambé', 'Estônia', 'Jardim Morada do Sol', '86181-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12973, 'Londrina', 'Estoril', 'Jardim São Francisco de Assis', '86067-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12974, 'Cambé', 'Estoril', 'Parque Residencial Cambé', '86191-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12975, 'Ponta Grossa', 'Estorninho', 'Colônia Dona Luiza', '84046-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12976, 'Arapongas', 'Estorninho', 'Jardim Bandeirantes', '86703-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12977, 'Curitiba', 'Estrada da Graciosa', 'Atuba', '82840-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12978, 'Laranjeiras do Sul', 'Estrada do Cortume', 'Água Verde', '85302-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12979, 'Foz do Iguaçu', 'Estreito', 'Jardim Terra e Lar', '85858-487', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12980, 'Sarandi', 'Estrela Dalva', 'Jardim Universal', '87114-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12981, 'Sarandi', 'Estrela de Belém', 'Parque Residencial Bom Pastor', '87114-544', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12982, 'Arapongas', 'Estrelinha-ametista', 'Casa Família Arapongas IV', '86709-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12983, 'Ponta Grossa', 'Eta', 'Cará-cará', '84043-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12984, 'Curitiba', 'Etelvina Cordeiro Ribas', 'Cidade Industrial', '81315-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12985, 'Paranaguá', 'Etelvina Correia', 'Vila Garcia', '83218-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12986, 'Curitiba', 'Etelvina da Luz de Barros', 'Cidade Industrial', '81270-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12987, 'Londrina', 'Etelvina de Campos Escudero', 'Residencial Moradias do Cabo Frio', '86080-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12988, 'Colombo', 'Etelvina de Souza Crozeta', 'Jardim César Augusto', '83402-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12989, 'Curitiba', 'Etelvina Maria da Silveira Coelho', 'Sítio Cercado', '81910-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12990, 'São José dos Pinhais', 'Etelvina Pimentel Rodrigues', 'Ipê', '83055-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12991, 'Apucarana', 'Etelvino Cristiano de Paula', 'Residencial Parque da Raposa', '86812-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12992, 'Londrina', 'Etienne Lenoir', 'Industrial', '86063-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12993, 'Londrina', 'Etiópia', 'Ouro Verde', '86080-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12994, 'Pinhais', 'Etiópia', 'Jardim Hipódromo', '83320-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12995, 'Curitiba', 'Etiópia', 'Cajuru', '82960-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12996, 'Almirante Tamandaré', 'Etore Buzato', 'Planta Maria Clara', '83513-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12997, 'São José dos Pinhais', 'Etore Marenda', 'Bom Jesus', '83025-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12998, 'Paranavaí', 'Ettore Giovine', 'Centro', '87701-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (12999, 'Paranavaí', 'Ettore Giovine', 'Jardim São Cristóvão', '87702-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13000, 'Londrina', 'Ettore Pistori', 'Luiz de Sá', '86086-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13001, 'Curitiba', 'Ettore Zanlorenzi', 'São Braz', '82310-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13002, 'Paranaguá', 'Etuzi Takayama', 'Parque São João', '83212-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13003, 'Ponta Grossa', 'Eucalipto', 'Contorno', '84061-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13004, 'Telêmaco Borba', 'Eucalipto', 'Área 01', '84268-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13005, 'Almirante Tamandaré', 'Eucalipto', 'Loteamento Chico Mendes', '83505-746', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13006, 'Campo Mourão', 'Eucalipto', 'Conjunto Habitacional Parigot de Souza', '87310-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13007, 'Cascavel', 'Eucalipto', 'Parque Verde', '85807-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13008, 'Londrina', 'Eucaliptos', 'Leonor', '86071-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13009, 'Pinhais', 'Euclides Bandeira', 'Núcleo Colonial de Pinhais', '83321-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13010, 'São José dos Pinhais', 'Euclides Bandeira', 'São Sebastião', '83075-288', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13011, 'Colombo', 'Euclides Bandeira', 'Jardim Quitandinha', '83409-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13012, 'Curitiba', 'Euclides Bandeira', 'Centro Cívico', '80530-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13013, 'São José dos Pinhais', 'Euclides Batista de Oliveira', 'Afonso Pena', '83065-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13014, 'São José dos Pinhais', 'Euclides Biancheti', 'Braga', '83020-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13015, 'Ponta Grossa', 'Euclides Bittencourt Camargo', 'Contorno', '84061-619', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13016, 'Telêmaco Borba', 'Euclides Bonifácio Londres', 'Nossa Senhora de Fátima', '84264-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13017, 'Ponta Grossa', 'Euclides Correia Ribas', 'Jardim Carvalho', '84016-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13018, 'Londrina', 'Euclides da Cunha', 'Jardim Tatiani', '86070-490', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13019, 'Londrina', 'Euclides da Cunha', 'Jardim Tatiani', '86070-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13020, 'Guarapuava', 'Euclides da Cunha', 'Morro Alto', '85067-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13021, 'Laranjeiras do Sul', 'Euclides da Cunha', 'Getúlio Vargas', '85304-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13022, 'Pinhais', 'Euclides da Cunha', 'Núcleo Colonial de Pinhais', '83321-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13023, 'Ponta Grossa', 'Euclides da Cunha', 'Uvaranas', '84020-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13024, 'Maringá', 'Euclides da Cunha', 'Zona 04', '87014-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13025, 'Maringá', 'Euclides da Cunha', 'Zona 05', '87015-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13026, 'Paranavaí', 'Euclides da Cunha', 'Jardim São Jorge', '87710-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13027, 'Umuarama', 'Euclides da Cunha', 'Parque Tarumã', '87508-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13028, 'Sarandi', 'Euclides da Cunha', 'Jardim Panorama', '87113-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13029, 'Sarandi', 'Euclides da Cunha', 'Parque Pioneiros', '87114-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13030, 'Cascavel', 'Euclides da Cunha', 'Parque São Paulo', '85803-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13031, 'Apucarana', 'Euclides da Cunha', 'Parque São Jorge', '86800-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13032, 'Curitiba', 'Euclides da Cunha', 'Bigorrilho', '80730-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13033, 'Curitiba', 'Euclides da Cunha', 'Bigorrilho', '80710-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13034, 'Pinhais', 'Euclides da Cunha Ribas', 'Jardim Atuba I', '83326-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13035, 'Colombo', 'Euclides da Silva', 'Jardim Eldorado', '83402-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13036, 'Curitiba', 'Euclides da Silva', 'Cidade Industrial', '81315-100', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13037, 'Campo Largo', 'Euclides de Andrade', 'Loteamento Santa Rita', '83602-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13038, 'Campo Mourão', 'Euclides de Lima', 'Jardim Alvorada', '87308-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13039, 'Curitiba', 'Euclides de Mesquita', 'Sítio Cercado', '81920-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13040, 'Londrina', 'Euclides Figueiredo', 'Sebastião de Melo César', '86084-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13041, 'Curitiba', 'Euclides Figueiredo', 'Cidade Industrial', '81170-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13042, 'Londrina', 'Euclides Garcia', 'Colinas', '86056-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13043, 'Londrina', 'Euclides Machado', 'Barbeta', '86078-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13044, 'Piraquara', 'Euclides Miguel', 'Jardim Tropical', '83314-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13045, 'Curitiba', 'Euclides Padilha dos Santos', 'Uberaba', '81560-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13046, 'São José dos Pinhais', 'Euclides Pereira Linhares Júnior', 'Braga', '83020-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13048, 'Campo Mourão', 'Euclides Slomp', 'Jardim Maia', '87301-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13049, 'Curitiba', 'Euclides Taborda Ribas', 'Cajuru', '82970-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13050, 'Londrina', 'Euclydes Henrique de Carvalho', 'Colinas', '86056-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13051, 'Londrina', 'Eudócio Antonio Ferreira', 'Jardim Strass', '86084-836', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13052, 'Curitiba', 'Eudóxia Zafiez Santos', 'Cidade Industrial', '81315-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13053, 'Cambé', 'Eufrásia Viesi Bonalumi', 'Parque Residencial Ana Rosa', '86183-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13054, 'Paranaguá', 'Eufrásio Correia', 'Centro Histórico', '83203-300', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13055, 'Curitiba', 'Eufrásio Correia', 'Centro', '80010-170', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13056, 'São José dos Pinhais', 'Eufrásio Luiz Polakowski', 'Afonso Pena', '83045-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13057, 'Campo Largo', 'Eufrates', 'Vila Dom Pedro', '83608-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13058, 'Campo Mourão', 'Eufrosina Teodoro de Oliveira', 'Jardim Cidade Nova', '87308-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13059, 'Ponta Grossa', 'Eugênia', 'Contorno', '84061-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13060, 'Laranjeiras do Sul', 'Eugênia A. Brandielli', 'Getúlio Vargas', '85304-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13061, 'Maringá', 'Eugênia Coutinho Meller', 'Conjunto Residencial Cidade Alta', '87053-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13062, 'Curitiba', 'Eugênia Maria Baptista', 'Cidade Industrial', '81315-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13063, 'Pinhais', 'Eugênia Ribas', 'Jardim Dona Joaquina II', '83325-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13064, 'São José dos Pinhais', 'Eugênia Segala Foggiatto', 'Aristocrata', '83030-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13065, 'Paranaguá', 'Eugênio Aluísio Lules', 'Vila Garcia', '83218-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13066, 'Almirante Tamandaré', 'Eugênio Antoniacomi', 'Loteamento Formoso', '83514-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13067, 'Ponta Grossa', 'Eugênio Antônio Mendes', 'Contorno', '84052-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13068, 'Ponta Grossa', 'Eugênio Antunes Mendes', 'Uvaranas', '84031-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13069, 'Londrina', 'Eugênio Bidóia', 'Parque Residencial Alcântara', '86047-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13070, 'Londrina', 'Eugênio Brizzoto', 'Conjunto Café', '86038-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13071, 'Londrina', 'Eugênio Brugin', 'Messiânico', '86065-800', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13072, 'Curitiba', 'Eugênio Caetano do Amaral', 'Jardim Social', '82520-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13073, 'Londrina', 'Eugênio Carlesso', 'Portal de Versalhes 3', '86055-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13074, 'Londrina', 'Eugênio Colozio', 'Conjunto Habitacional Saltinho', '86042-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13075, 'Toledo', 'Eugênio Comin', 'César Park', '85913-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13076, 'Curitiba', 'Eugênio Contin', 'Cajuru', '82920-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13077, 'Curitiba', 'Eugênio da Silva Lopes', 'Alto Boqueirão', '81770-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13078, 'Apucarana', 'Eugênio Dallacosta', 'Vila Nova', '86812-250', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13079, 'Cambé', 'Eugênio Dezotti', 'Jardim Riviera', '86187-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13080, 'Sarandi', 'Eugênio Dvoranen', 'Jardim Tropical', '87113-818', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13081, 'Curitiba', 'Eugênio Ferdinando Lauer', 'Vista Alegre', '80820-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13082, 'Curitiba', 'Eugênio Flor', 'Pilarzinho', '82130-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13083, 'Londrina', 'Eugênio Gayon', 'Assis', '86085-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13084, 'Londrina', 'Eugênio Gayon', 'Conjunto Café', '86038-035', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13085, 'Curitiba', 'Eugênio Gomes de Brito', 'Cajuru', '82950-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13086, 'Curitiba', 'Eugênio Guariza', 'São Lourenço', '82200-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13087, 'Toledo', 'Eugênio Gustavo Keller', 'Conjunto Habitacional Britânia', '85903-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13088, 'Paranaguá', 'Eugênio José de Souza', 'Cruzeiro', '83221-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13089, 'Curitiba', 'Eugênio José de Souza', 'Água Verde', '80610-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13090, 'Curitiba', 'Eugênio José de Souza', 'Guaíra', '80630-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13091, 'Curitiba', 'Eugênio Link', 'Fazendinha', '81330-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13092, 'Guarapuava', 'Eugênio Luiz Dolinski', 'Primavera', '85053-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13093, 'Cambé', 'Eugênio M. Fadel', 'Conjunto Residencial Roberto Conceição', '86183-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13094, 'Guarapuava', 'Eugênio Martins', 'Bonsucesso', '85045-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13095, 'Piraquara', 'Eugênio Mazzarotto', 'Planta Irmãos Michel', '83304-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13096, 'Curitiba', 'Eugênio Mocelin', 'Boa Vista', '82540-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13097, 'Colombo', 'Eugênio Modesto de Souza', 'Jardim Esplanada', '83402-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13098, 'São José dos Pinhais', 'Eugênio Moro', 'Miringuava', '83090-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13099, 'Colombo', 'Eugênio Motin', 'Jardim Monte Líbano', '83407-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13100, 'Araucária', 'Eugênio Nakonieczny', 'Tindiquera', '83708-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13101, 'Curitiba', 'Eugênio Parolin', 'Parolin', '80220-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13102, 'Pato Branco', 'Eugênio Parzianello', 'Parzianello', '85504-500', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13103, 'Curitiba', 'Eugênio Pedro Quartarolli', 'Barreirinha', '82700-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13104, 'Ponta Grossa', 'Eugênio Ricetti', 'Oficinas', '84045-000', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13105, 'Pinhais', 'Eugênio Rodrigues', 'Vale da Boa Esperança', '83320-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13106, 'Guarapuava', 'Eugênio Schleder', 'Conradinho', '85055-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13107, 'Laranjeiras do Sul', 'Eugênio Sganzerla', 'São Francisco', '85303-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13108, 'Campo Mourão', 'Eugênio Zalewski', 'Jardim Capricórnio', '87301-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13109, 'Londrina', 'Eugênio Zemuner', 'Conjunto Novo Amparo', '86087-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13110, 'Campo Mourão', 'Eulália Carneiro de Campos', 'Jardim Alvorada', '87308-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13111, 'Campo Largo', 'Eulália da Luz Silveira', 'Jardim Rondinha', '83607-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13112, 'Maringá', 'Eulália Pires Baessa', 'Conjunto Habitacional Hermann Moraes Barros', '87023-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13113, 'Apucarana', 'Eulália Xavier', 'Vila Eulália', '86807-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13114, 'Curitiba', 'Eulívio Pastre', 'Sítio Cercado', '81920-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13115, 'Foz do Iguaçu', 'Eunápio de Queiroz', 'Jardim São Miguel', '85858-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13116, 'Curitiba', 'Eunice Bettini Bartoszeck', 'Uberaba', '81550-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13117, 'Curitiba', 'Eunice Bettini Bartoszeck', 'Uberaba', '81590-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13118, 'Ponta Grossa', 'Eunice dos Reis', 'Olarias', '84026-285', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13119, 'Curitiba', 'Eunice Weaver', 'Campo Comprido', '81220-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13120, 'Londrina', 'Eunilson Bezerra da Silva', 'Gleba Fazenda Palhano', '86055-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13121, 'Guarapuava', 'Euralina', 'Santa Cruz', '85015-050', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13122, 'Maringá', 'Eurico Batista de Oliveira', 'Parque da Gávea', '87053-336', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13123, 'Curitiba', 'Eurico Bittencourt', 'Cidade Industrial', '81305-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13124, 'Castro', 'Eurico da Silva Gomes', 'Jardim Colonial', '84178-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13125, 'Apucarana', 'Eurico de Oliveira', 'Jardim Aeroporto', '86812-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13126, 'Curitiba', 'Eurico de Paiva Vidal', 'Cajuru', '82930-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13127, 'Curitiba', 'Eurico Fonseca dos Santos', 'Xaxim', '81810-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13128, 'Almirante Tamandaré', 'Eurico Gaspar Dutra', 'Vila Grécia', '83502-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13129, 'Londrina', 'Eurico Heritt', 'Milton Gavetti', '86078-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13130, 'Curitiba', 'Eurico Júlio Bettega', 'Cidade Industrial', '81290-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13131, 'Guarapuava', 'Eurico Lustosa de Siqueira', 'Industrial', '85045-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13132, 'Castro', 'Eurico Madureira Novaes', 'Jardim das Araucárias', '84174-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13133, 'Londrina', 'Eurico Magnoni', 'Jardim Vale Azul', '86041-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13134, 'São José dos Pinhais', 'Eurico Muniz', 'Cidade Jardim', '83035-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13135, 'Curitiba', 'Eurico Zytkievitz', 'Sítio Cercado', '81900-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13136, 'Almirante Tamandaré', 'Eurides C. Pinto', 'Jardim São Domingos', '83501-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13137, 'Curitiba', 'Eurides Cândido Pinheiro', 'Cidade Industrial', '81310-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13138, 'Curitiba', 'Eurides Cunha', 'Vila Izabel', '80320-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13139, 'São José dos Pinhais', 'Eurides de Souza', 'Afonso Pena', '83050-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13140, 'Curitiba', 'Eurides Dorigo', 'Sítio Cercado', '81920-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13141, 'Araucária', 'Eurides Ferreira dos Santos', 'Capela Velha', '83706-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13142, 'Curitiba', 'Eurides Gonçalves Saldanha', 'Alto Boqueirão', '81770-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13143, 'São José dos Pinhais', 'Eurides Halama', 'Ipê', '83055-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13144, 'Curitiba', 'Eurides Maciel de Almeida', 'Uberaba', '81560-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13145, 'Londrina', 'Euridice de Oliveira Gomes', 'Santa Rita 4', '86072-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13146, 'Maringá', 'Eurilemos', 'Jardim Pássaros', '87075-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13147, 'Arapongas', 'Eurilemos', 'Conjunto Padre Bernardo Merckel', '86708-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13148, 'Arapongas', 'Eurilemos', 'Centro', '86701-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13149, 'Londrina', 'Eurípedes Barsanulfo', 'San Fernando', '86040-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13150, 'Curitiba', 'Eurípedes Garcez do Nascimento', 'Ahú', '80540-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13151, 'Pinhais', 'Eurípedes Morais e Silva', 'Conjunto Residencial Áquila', '83326-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13152, 'Londrina', 'Europa', 'Parque Residencial João Piza', '86041-005', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13153, 'Londrina', 'Europa', 'Parque Residencial João Piza', '86041-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13154, 'Pinhais', 'Europa', 'Vila Irene Margarida', '83323-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13155, 'Ponta Grossa', 'Europa', 'Oficinas', '84035-690', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13156, 'Cascavel', 'Europa', 'Periolo', '85817-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13157, 'Cascavel', 'Europa', 'Brasília', '85815-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13158, 'Pinhais', 'Eutalia Maria dos Santos', 'Planta Cláudio Mehl', '83326-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13159, 'Telêmaco Borba', 'Eutálio de Castro Ribas', 'Centro', '84261-490', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13160, 'Londrina', 'Euvira Nhola Fonseca', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13161, 'Curitiba', 'Euzébio Ansai', 'Novo Mundo', '81050-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13162, 'Londrina', 'Euzébio Barbosa de Menezes', 'Santiago', '86071-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13163, 'Ponta Grossa', 'Euzébio Batista Rosas', 'Jardim Carvalho', '84015-470', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13164, 'Ponta Grossa', 'Euzébio da Motta', 'Ronda', '84051-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13165, 'Ponta Grossa', 'Euzébio da Motta', 'Ronda', '84050-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13166, 'Curitiba', 'Euzébio da Motta', 'Alto da Glória', '80530-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13167, 'Ponta Grossa', 'Euzébio de Farias', 'Jardim Carvalho', '84016-716', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13168, 'Ponta Grossa', 'Euzébio de Mattos', 'Oficinas', '84040-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13169, 'Ponta Grossa', 'Euzébio de Queiroz', 'Uvaranas', '84032-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13170, 'São José dos Pinhais', 'Euzébio Ferreira de Paula', 'Afonso Pena', '83045-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13171, 'Foz do Iguaçu', 'Euzébio Mola', 'Jardim Oriente', '85855-100', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13172, 'Toledo', 'Euzébio Roque Garcia', 'Conjunto Residencial Tocantins', '85903-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13173, 'Curitiba', 'Euzébio Sebastião Ritzmann', 'Santo Inácio', '82010-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13174, 'Colombo', 'Euzenia Alves Ribas', 'Jardim das Flores', '83402-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13175, 'Foz do Iguaçu', 'Eva Freitas Benitez', 'Jardim Porto Belo', '85867-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13176, 'Curitiba', 'Eva Friedemann Abrahan', 'Butiatuvinha', '82320-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13177, 'Curitiba', 'Eva Stanislawa Radota', 'Tatuquara', '81470-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13178, 'Araucária', 'Eva Szrajier', 'Boqueirão', '83704-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13179, 'Colombo', 'Eva Weigert de Souza', 'Jardim das Flores', '83402-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13180, 'Araucária', 'Eva Wolski', 'Tindiquera', '83708-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13181, 'Maringá', 'Evaldo Braga', 'Conjunto Residencial Cidade Alta', '87053-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13182, 'Ponta Grossa', 'Evaldo Braga', 'Ronda', '84051-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13183, 'Colombo', 'Evaldo Kabitschke', 'Vila Alto da Cruz II', '83405-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13184, 'Colombo', 'Evaldo Lazaroto', 'Sapopema', '83407-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13185, 'Toledo', 'Evaldo Schoroeder', 'Independência', '85906-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13186, 'Curitiba', 'Evaldo Wendler', 'São Lourenço', '82200-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13187, 'São José dos Pinhais', 'Evaldo Weschr', 'São Sebastião', '83075-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13188, 'Paranavaí', 'Evangélico João Dias Motta Filho', 'Jardim Campo Belo', '87711-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13189, 'Telêmaco Borba', 'Evangelina Borba Carneiro', 'Vila Ozorio', '84268-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13190, 'Castro', 'Evangelina Madureira Camargo', 'Jardim Social Arapongas', '84174-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13191, 'Guarapuava', 'Evangelista Eduardo Deniz', 'Vila Carli', '85040-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13192, 'Curitiba', 'Evangelistas', 'Cidade Industrial', '81315-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13193, 'Londrina', 'Evanildo Clóvis de Souza', 'Jardim San Diego', '86073-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13194, 'São José dos Pinhais', 'Evanira Bonin da Rocha Cruz', 'Afonso Pena', '83065-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13195, 'Londrina', 'Evantuil Romanholo', 'Jardim Alphaville', '86084-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13196, 'Curitiba', 'Evaristo Ângelo Piloto', 'Novo Mundo', '81020-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13197, 'Curitiba', 'Evaristo Berleze', 'Bacacheri', '82600-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13198, 'Guarapuava', 'Evaristo da Veiga', 'Morro Alto', '85067-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13199, 'Foz do Iguaçu', 'Evaristo da Veiga', 'Jardim Jupira', '85865-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13200, 'Ponta Grossa', 'Evaristo da Veiga', 'Jardim Carvalho', '84016-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13201, 'Maringá', 'Evaristo da Veiga', 'Jardim Alvorada', '87030-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13202, 'Maringá', 'Evaristo da Veiga', 'Jardim Alvorada', '87033-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13203, 'Colombo', 'Evaristo da Veiga', 'Vila Gorski', '83405-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13204, 'Curitiba', 'Evaristo da Veiga', 'Boqueirão', '81650-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13205, 'Curitiba', 'Evaristo da Veiga', 'Boqueirão', '81670-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13206, 'Araucária', 'Evaristo Druziak', 'Estação', '83705-195', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13207, 'Curitiba', 'Evaristo F. F. da Costa', 'Jardim das Américas', '81530-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13208, 'Paranaguá', 'Evaristo Lagoth do Nascimento', 'Leblon', '83203-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13209, 'Ponta Grossa', 'Evaristo Morais', 'Olarias', '84035-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13210, 'Umuarama', 'Evaristo Pellacani', 'Jardim São José', '87502-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13211, 'Campo Mourão', 'Everaldo Albuquerque', 'Vila Teixeira', '87300-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13212, 'Curitiba', 'Everaldo Backheuser', 'Alto Boqueirão', '81720-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13213, 'Cascavel', 'Everaldo Loures Xavier', 'Universitário', '85819-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13214, 'Foz do Iguaçu', 'Everaldo Marques da Silva', 'Parque Residencial Santa Rita', '85858-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13215, 'Maringá', 'Evereste', 'Jardim Imperial II', '87023-037', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13216, 'Colombo', 'Evidio Cardoso', 'Jardim Campo Alto', '83408-217', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13217, 'Curitiba', 'Evilásio Pinheiro', 'Cidade Industrial', '81450-738', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13218, 'São José dos Pinhais', 'Ewaldo Carneiro de Paula', 'Miringuava', '83090-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13219, 'Curitiba', 'Ewaldo Hauer', 'Santa Cândida', '82720-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13220, 'Ponta Grossa', 'Ewaldo Nack', 'Neves', '84020-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13221, 'Curitiba', 'Ewaldo Nickel', 'Uberaba', '81580-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13222, 'Paranaguá', 'Ewaldo Scheeling Filho', 'Padre Jackson', '83221-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13223, 'Ponta Grossa', 'Expedicionário Adão Buss', 'Orfãs', '84015-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13224, 'Curitiba', 'Expedicionário Adão Wojcik', 'Alto Boqueirão', '81850-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13225, 'Curitiba', 'Expedicionário Adir Jorge', 'Alto Boqueirão', '81850-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13226, 'Umuarama', 'Expedicionário Adolfo Teza', 'Zona VII', '87503-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13227, 'São José dos Pinhais', 'Expedicionário Afonso Licheski', 'Afonso Pena', '83045-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13228, 'Curitiba', 'Expedicionário Anélio da Luz', 'Alto Boqueirão', '81850-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13229, 'Curitiba', 'Expedicionário Antônio Cação', 'Alto Boqueirão', '81850-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13230, 'São José dos Pinhais', 'Expedicionário Antônio Machado', 'Afonso Pena', '83050-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13231, 'Curitiba', 'Expedicionário Antônio Schwartz', 'Abranches', '82130-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13232, 'São José dos Pinhais', 'Expedicionário Bonifácio Gonçalves de Araújo', 'Afonso Pena', '83050-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13233, 'Curitiba', 'Expedicionário Bruno Estrifica', 'Alto Boqueirão', '81850-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13234, 'Piraquara', 'Expedicionário Carlos Alberto F. Bahr', 'Vila Ipanema', '83301-057', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13235, 'Curitiba', 'Expedicionário do Cinco de Maio', 'Alto Boqueirão', '81850-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13236, 'Curitiba', 'Expedicionário Eliseu José Hipólito', 'Alto Boqueirão', '81850-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13237, 'Curitiba', 'Expedicionário Emídio Roque Rattmann', 'Cajuru', '82950-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13238, 'Curitiba', 'Expedicionário Ernesto Gonçalves', 'Xaxim', '81810-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13239, 'Curitiba', 'Expedicionário Estanislau Wojcik', 'Alto Boqueirão', '81850-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13240, 'Curitiba', 'Expedicionário Eurides Fernandes do Nascimento', 'Alto Boqueirão', '81850-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13241, 'Curitiba', 'Expedicionário Francisco Alves de Oliveira', 'Alto Boqueirão', '81850-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13242, 'Curitiba', 'Expedicionário Francisco Pereira dos Santos', 'Alto Boqueirão', '81850-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13243, 'Guarapuava', 'Expedicionário Guilherme Lange', 'Boqueirão', '85023-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13244, 'Curitiba', 'Expedicionário Gumercindo da Silva', 'Alto Boqueirão', '81850-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13245, 'Laranjeiras do Sul', 'Expedicionário João Maria', 'Centro', '85301-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13246, 'Guarapuava', 'Expedicionário João Maria Batista', 'Alto da XV', '85065-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13247, 'Guarapuava', 'Expedicionário João Maria Batista', 'Santana', '85070-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13248, 'Curitiba', 'Expedicionário João Protzek', 'Alto Boqueirão', '81850-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13249, 'Apucarana', 'Expedicionário João Rechocoski', 'Vila Nossa Senhora da Conceição', '86810-315', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13250, 'Campo Largo', 'Expedicionário João Rossa', 'Vila Gilcy', '83609-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13251, 'São José dos Pinhais', 'Expedicionário Joaquim Lima de Amorim', 'Braga', '83020-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13252, 'Guarapuava', 'Expedicionário Luiz Savio', 'Primavera', '85050-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13253, 'Curitiba', 'Expedicionário Octávio Zontta', 'Umbará', '81940-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13254, 'São José dos Pinhais', 'Expedicionário Silvestre Skodowski', 'Planta Quississana', '83085-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13255, 'Ponta Grossa', 'Expedicionário Tuffi', 'Boa Vista', '84071-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13256, 'Foz do Iguaçu', 'Extrema', 'Loteameto Jardim Colombelli', '85862-479', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13257, 'Curitiba', 'Ezequiel Gonçalves de Lara', 'Sítio Cercado', '81925-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13258, 'Curitiba', 'Ezequiel Onofrio Vialle', 'Butiatuvinha', '82400-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13259, 'Paranaguá', 'Ezequiel Pinto da Silva', '29 de Julho', '83203-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13260, 'Laranjeiras do Sul', 'Ezidio Bozza', 'Centro', '85301-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13261, 'Curitiba', 'Ezio Zanello', 'Alto Boqueirão', '81770-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13262, 'Londrina', 'Eziquiel Antônio de Moraes', 'Franciscato II', '86078-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13263, 'Piraquara', 'Eziquiel Pinto', 'Centro', '83301-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13264, 'Francisco Beltrão', 'F', 'Cristo Rei', '85602-505', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13265, 'Foz do Iguaçu', 'F', 'Conjunto C', '85870-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13266, 'Ponta Grossa', 'F', 'Boa Vista', '84072-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13267, 'Ponta Grossa', 'F', 'Ronda', '84051-165', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13268, 'Ponta Grossa', 'F', 'Chapada', '84062-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13269, 'Ponta Grossa', 'F', 'Uvaranas', '84031-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13270, 'Paranavaí', 'F', 'Vila Operária', '87708-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13271, 'Ponta Grossa', 'F', 'Colônia Dona Luiza', '84043-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13272, 'Ponta Grossa', 'F', 'Uvaranas', '84032-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13273, 'Ponta Grossa', 'F', 'Cará-cará', '84045-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13274, 'Ponta Grossa', 'F', 'Contorno', '84060-618', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13275, 'Ponta Grossa', 'F', 'Chapada', '84063-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13276, 'Umuarama', 'F', 'Parque San Marino', '87509-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13277, 'Umuarama', 'F', 'Parque Dom Pedro I', '87508-019', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13278, 'Umuarama', 'F', 'Jardim União', '87508-166', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13279, 'Campo Mourão', 'F', 'Jardim Alvorada', '87308-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13280, 'Almirante Tamandaré', 'F', 'Jardim São Caetano', '83507-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13281, 'Campo Mourão', 'F', 'Jardim Nossa Senhora Aparecida', '87309-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13282, 'Campo Largo', 'F', 'Vila Torres I', '83609-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13283, 'Campo Largo', 'F', 'Jardim Três Rios', '83603-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13284, 'Castro', 'F', 'Vila do Rosário', '84168-078', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13285, 'Almirante Tamandaré', 'F', 'Jardim Marrocos', '83511-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13286, 'Castro', 'F', 'Jardim Bela Vista', '84165-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13287, 'Almirante Tamandaré', 'F', 'Parque Timbu', '83514-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13288, 'Campo Largo', 'F', 'Popular Nova', '83602-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13289, 'Campo Largo', 'F', 'Jardim Tropical', '83602-066', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13290, 'Arapongas', 'F-1', 'Jardim Panorama', '86708-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13291, 'Arapongas', 'F-2', 'Vila São João', '86708-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13292, 'Arapongas', 'F-2', 'Jardim Império', '86709-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13293, 'Arapongas', 'F-3', 'Jardim Panorama', '86708-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13294, 'Almirante Tamandaré', 'Fabiana V. Martins', 'Jardim Colonial', '83501-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13295, 'Cambé', 'Fabiano Dias Vector', 'Chácara Santa Maria', '86189-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13296, 'Curitiba', 'Fábio Alessandro Túlio', 'Pinheirinho', '81870-095', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13297, 'Curitiba', 'Fábio Fanuchi', 'Santa Cândida', '82630-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13298, 'Apucarana', 'Fábio Henrique da Silva', 'Jardim Catuaí III', '86802-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13299, 'Londrina', 'Fábio Paludetto', 'Pinheiros', '86063-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13300, 'Curitiba', 'Fábio Pinheiro', 'Pilarzinho', '82100-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13301, 'Curitiba', 'Fábio Roger Mendes', 'Cajuru', '82950-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13302, 'Londrina', 'Fabíola', 'Nossa Senhora de Lourdes', '86039-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13303, 'Foz do Iguaçu', 'Fadel Damen', 'Parque Morumbi IV', '85858-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13304, 'Guarapuava', 'Fagundes de Souza', 'Santana', '85070-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13305, 'Guarapuava', 'Fagundes Varela', 'Vila Bela', '85025-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13306, 'Foz do Iguaçu', 'Fagundes Varela', 'Vila Portes', '85865-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13307, 'Pato Branco', 'Fagundes Varela', 'Alvorada', '85508-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13308, 'Ponta Grossa', 'Fagundes Varela', 'Uvaranas', '84020-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13309, 'Pinhais', 'Fagundes Varela', 'Núcleo Colonial de Pinhais', '83321-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13310, 'Maringá', 'Fagundes Varela', 'Zona 06', '87015-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13311, 'Cascavel', 'Fagundes Varela', 'Coqueiral', '85807-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13312, 'Colombo', 'Fagundes Varela', 'Jardim Quitandinha', '83409-480', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13313, 'Cascavel', 'Fagundes Varela', 'Alto Alegre', '85805-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13314, 'Curitiba', 'Fagundes Varela', 'Jardim Social', '82520-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13315, 'Londrina', 'Faisão', 'Paraíso', '86078-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13316, 'Maringá', 'Faisão', 'Jardim Olímpico', '87070-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13317, 'São José dos Pinhais', 'Faisão', 'Afonso Pena', '83045-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13318, 'Campo Mourão', 'Faisão', 'Jardim Tropical I', '87310-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13319, 'Arapongas', 'Faisão', 'Vila Sampaio', '86705-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13320, 'Cambé', 'Faisão', 'Conjunto Habitacional Waldomiro M Gomes', '86182-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13321, 'Araucária', 'Faisão', 'Capela Velha', '83706-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13322, 'Londrina', 'Falcão', 'Paraíso', '86078-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13323, 'Foz do Iguaçu', 'Falcão', 'Conjunto A', '85866-230', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13324, 'Maringá', 'Falcão', 'Jardim Olímpico', '87070-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13325, 'Umuarama', 'Falcão', 'Jardim Sol Nascente', '87505-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13326, 'Campo Largo', 'Falcão', 'Vila Dona Fina', '83609-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13327, 'Cascavel', 'Falcão', 'Floresta', '85814-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13328, 'Araucária', 'Falcão', 'Capela Velha', '83706-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13329, 'Arapongas', 'Falcão', 'Conjunto Padre Bernardo Merckel', '86708-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13330, 'Arapongas', 'Falcão', 'Centro', '86701-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13331, 'Campo Mourão', 'Falcão', 'Jardim Gutierres', '87300-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13332, 'Curitiba', 'Falcão', 'Pinheirinho', '81825-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13333, 'Arapongas', 'Falcão-de-coleira', 'Conjunto Del Condor', '86703-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13334, 'Arapongas', 'Falcão-mateiro', 'Jardim Portal das Flores', '86701-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13335, 'Arapongas', 'Falcão-pelegrino', 'Jardim Petrópolis', '86709-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13336, 'Curitiba', 'Fanny Hauer', 'Hauer', '81630-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13337, 'Curitiba', 'Fantinato', 'Atuba', '82840-440', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13338, 'Piraquara', 'Fany Paciornik', 'Jardim Veneza', '83310-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13339, 'Colombo', 'Faraday', 'Vila Guarani', '83408-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13340, 'Curitiba', 'Farão Akhenaton', 'Bacacheri', '82515-250', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13341, 'Colombo', 'Farao Cavalli', 'Uvarana', '83415-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13342, 'Colombo', 'Farenheit', 'Jardim Ouro Verde', '83405-710', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13343, 'Paranaguá', 'Faria Sobrinho', 'Centro Histórico', '83203-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13344, 'Curitiba', 'Farias Brito', 'Fanny', '81030-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13345, 'Ponta Grossa', 'Farias de Brito', 'Jardim Carvalho', '84016-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13346, 'Ponta Grossa', 'Farid Calil Hafiz', 'Contorno', '84061-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13347, 'Curitiba', 'Farid Rame', 'Cidade Industrial', '81450-727', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13348, 'Curitiba', 'Farid Rossi', 'Tatuquara', '81470-256', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13349, 'Maringá', 'Farmacêutico Luiz Andrade', 'Jardim Mandacaru', '87080-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13350, 'Colombo', 'Faro', 'Parque Residencial Santa Terezinha', '83408-710', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13351, 'Londrina', 'Farrapos', 'Canadá', '86020-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13352, 'Pato Branco', 'Farrapos', 'Centro', '85501-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13353, 'Umuarama', 'Farropilha', 'Jardim Tamoio', '87505-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13354, 'Londrina', 'Farroupilha', 'Jardim Tatiani', '86070-660', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13355, 'Foz do Iguaçu', 'Farroupilha', 'Jardim Ipanema', '85862-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13356, 'Maringá', 'Farroupilha', 'Jardim Alvorada', '87033-050', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13357, 'Pato Branco', 'Farroupilha', 'Cristo Rei', '85506-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13358, 'Paranavaí', 'Farroupilha', 'Jardim São Jorge', '87711-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13359, 'Paranavaí', 'Farroupilha', 'Jardim São Jorge', '87710-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13360, 'Curitiba', 'Fátima Bark', 'Capão Raso', '81130-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13361, 'Curitiba', 'Fátima Bark', 'Capão Raso', '81150-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13362, 'Curitiba', 'Fauser Abdo Calil', 'Vista Alegre', '80820-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13363, 'Colombo', 'Faustino André Johnsson', 'Centro', '83414-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13364, 'Foz do Iguaçu', 'Faustino de Oliveira', 'Cr 2', '85863-717', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13365, 'Curitiba', 'Faustino Jacob Stofella', 'Alto Boqueirão', '81770-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13366, 'Curitiba', 'Faustino Raimundo Pellanda', 'Tatuquara', '81940-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13367, 'Piraquara', 'Faustino Reggis Filho', 'Vila Esperança', '83307-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13368, 'Campo Largo', 'Faustino Rivabem', 'Vila de Lurdes', '83601-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13369, 'Curitiba', 'Faustino Sequinel', 'Cidade Industrial', '81350-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13370, 'Curitiba', 'Fausto Fressato', 'Bigorrilho', '80710-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13371, 'Curitiba', 'Fausto Nascimento Bittencourt', 'Ahú', '80540-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13372, 'Londrina', 'Fausto Nicácio Sampaio', 'Monte Carlo', '86040-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13373, 'Foz do Iguaçu', 'Fausto Palma', 'Jardim Veraneio', '85855-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13374, 'Curitiba', 'Fausto Pereira', 'Cidade Industrial', '81170-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13375, 'Apucarana', 'Fausto Pio Miranda', 'Jardim Aeroporto', '86812-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13376, 'Ponta Grossa', 'Faveiro', 'Neves', '84020-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13377, 'Foz do Iguaçu', 'Faxinal', 'Jardim Belvedere II', '85867-606', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13378, 'Guarapuava', 'Faxinal', 'Boqueirão', '85020-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13379, 'Londrina', 'Faxinal', 'Lindóia', '86031-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13380, 'Ponta Grossa', 'Faxinal', 'Uvaranas', '84025-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13381, 'Apucarana', 'Faxinal', 'Núcleo Habitacional Nossa Senhora Aparecida', '86801-397', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13382, 'Curitiba', 'Faxinal', 'Augusta', '81290-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13383, 'Laranjeiras do Sul', 'Faxinal Grande', 'Getúlio Vargas', '85304-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13384, 'São José dos Pinhais', 'Fazenda Guatupê', 'Guatupê', '83060-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13385, 'Telêmaco Borba', 'Fazenda Velha', 'Área 02', '84267-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13386, 'Curitiba', 'Fazendinha', 'Fazendinha', '81320-560', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13387, 'São José dos Pinhais', 'Fedele de Bortoli', 'Miringuava', '83090-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13388, 'Londrina', 'Fedele Mioni', 'Colúmbia', '86057-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13389, 'Foz do Iguaçu', 'Feldspato', 'Parque Ouro Verde', '85854-150', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13390, 'Francisco Beltrão', 'Felice Manfroi', 'Pinheirinho', '85606-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13391, 'Guarapuava', 'Felícia Buch', 'Bonsucesso', '85055-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13392, 'Maringá', 'Feliciano Pereira Neto', 'Vila Cleópatra', '87010-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13393, 'Curitiba', 'Feliciano Zanlorenzi', 'Campo Comprido', '81210-390', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13394, 'Curitiba', 'Felicidade Vitorina Suek', 'Campo de Santana', '81490-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13395, 'Toledo', 'Felício Callai', 'Jardim Alta Floresta', '85905-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13396, 'Colombo', 'Felício Czocher', 'Jardim João Paulo II', '83402-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13397, 'Curitiba', 'Felício da Costa Vieira', 'Água Verde', '80630-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13398, 'Colombo', 'Felício Falavinha', 'Vila Ana Maria', '83413-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13399, 'Piraquara', 'Felício Godoy Bueno', 'Planta Pontoni Filho', '83314-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13401, 'Curitiba', 'Felício Laskoski', 'Riviera', '81290-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13402, 'Londrina', 'Felício Marconi', 'Conjunto Residencial Vale do Arvoredo', '86047-537', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13403, 'Sarandi', 'Felício Turquino', 'Jardim Nova Independência', '87114-622', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13404, 'Curitiba', 'Felício Zibarth', 'Uberaba', '81580-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13405, 'Curitiba', 'Felicita Ferro Stella', 'Butiatuvinha', '82400-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13406, 'Campo Mourão', 'Felicita Maria Dolci', 'Jardim Bandeirantes', '87308-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13407, 'Curitiba', 'Feliks Golas', 'Tatuquara', '81480-176', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13408, 'São José dos Pinhais', 'Felinto Alcides Camargo', 'Ipê', '83055-496', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13409, 'Ponta Grossa', 'Felinto Alfredo Schiffer', 'Contorno', '84052-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13410, 'Curitiba', 'Felinto Bento Vianna', 'Portão', '81070-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13411, 'Guarapuava', 'Felipe Alves de Oliveira', 'São Cristóvão', '85063-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13412, 'Londrina', 'Felipe Camarão', 'Barra Vento', '86026-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13413, 'Ponta Grossa', 'Felipe Camarão', 'Uvaranas', '84025-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13414, 'Maringá', 'Felipe Camarão', 'Zona 02', '87010-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13415, 'Pato Branco', 'Felipe Camarão', 'Pinheiros', '85504-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13416, 'Toledo', 'Felipe Camarão', 'Jardim Paulista', '85910-055', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13417, 'Telêmaco Borba', 'Felipe Camarão', 'Vila Monte Belo', '84262-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13418, 'Colombo', 'Felipe Camarão', 'Jardim Planalto', '83409-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13419, 'Curitiba', 'Felipe Camarão', 'Rebouças', '80215-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13420, 'Paranavaí', 'Felipe Camargo', 'Jardim São Jorge', '87710-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13421, 'Ponta Grossa', 'Felipe Chede', 'Contorno', '84060-280', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13422, 'Paranaguá', 'Felipe Chede', 'Centro Histórico', '83203-265', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13423, 'Cambé', 'Felipe Cortez', 'Parque Residencial Ana Rosa', '86183-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13424, 'Paranavaí', 'Felipe dos Santos', 'Jardim São Jorge', '87711-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13425, 'Ponta Grossa', 'Felipe dos Santos', 'Boa Vista', '84073-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13426, 'Paranavaí', 'Felipe dos Santos', 'Jardim São Jorge', '87710-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13427, 'Curitiba', 'Felipe dos Santos Freire', 'Sítio Cercado', '81920-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13428, 'Piraquara', 'Felipe Gubert', 'Vila São Cristóvão', '83305-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13429, 'Curitiba', 'Felipe Jacob Nadolny', 'Santa Cândida', '82720-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13430, 'Campo Largo', 'Felipe Joaquim Age', 'Jardim Social', '83606-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13431, 'Ponta Grossa', 'Felipe Justus', 'Boa Vista', '84070-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13432, 'Toledo', 'Felipe Leopoldo Friedrich', 'Centro', '85901-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13433, 'Paranaguá', 'Felipe Mattar', 'Rocio', '83221-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13434, 'Campo Largo', 'Felipe Mazul', 'Conjunto Águas Claras', '83602-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13435, 'Curitiba', 'Felipe Morlotti', 'Santa Cândida', '82630-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13436, 'Curitiba', 'Felipe Muller', 'Sítio Cercado', '81920-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13437, 'Curitiba', 'Felipe Percegona', 'Fanny', '81030-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13438, 'Londrina', 'Felipe Souza Lopes', 'Conjunto Habitacional José Garcia Molina', '86080-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13439, 'Curitiba', 'Felipe Vitola', 'Santa Felicidade', '82020-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13440, 'Foz do Iguaçu', 'Felipe Wandscheer', 'Jardim Guarapuava', '85856-530', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13441, 'Foz do Iguaçu', 'Felipe Wandscheer', 'Jardim Naipi', '85853-430', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13442, 'Ponta Grossa', 'Felipenses', 'Chapada', '84062-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13443, 'Londrina', 'Felippo Foggia', 'Jardim Ilha do Mel', '86081-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13444, 'Apucarana', 'Felisberto Borges', 'Jardim Tarobá', '86813-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13445, 'Curitiba', 'Felisberto Fiore d''Orazio', 'Santa Felicidade', '82410-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13446, 'São José dos Pinhais', 'Felisberto Martins', 'Planta Quississana', '83085-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13447, 'Guarapuava', 'Felisberto R. de Souza', 'Vila Bela', '85027-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13448, 'Campo Largo', 'Felisbino Antônio', 'Vila de Lurdes', '83601-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13449, 'Castro', 'Felisbino Gonçalves Pereira Bueno', 'Cantagalo', '84178-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13450, 'Curitiba', 'Felisbino Passos', 'Tingui', '82620-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13451, 'Curitiba', 'Félix Budel', 'Uberaba', '81590-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13452, 'Londrina', 'Félix Chenso', 'Conjunto Semiramis Barros Braga', '86088-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13453, 'Londrina', 'Félix Coronado', 'Jardim dos Alpes III', '86045-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13454, 'Toledo', 'Félix da Cunha', 'Jardim Europa', '85908-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13455, 'Curitiba', 'Félix Domakoski', 'Santo Inácio', '82010-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13456, 'Curitiba', 'Félix Francisco Juglair', 'São Braz', '82315-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13457, 'Guarapuava', 'Félix Kaminski', 'Santana', '85070-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13458, 'Araucária', 'Félix Klechovicz', 'Vila Nova', '83703-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13459, 'Foz do Iguaçu', 'Félix Martins', 'Jardim Social I', '85853-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13460, 'São José dos Pinhais', 'Félix Micrute', 'Vila Jurema', '83070-260', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13461, 'Ponta Grossa', 'Félix Pacheco', 'Uvaranas', '84030-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13462, 'Pinhais', 'Félix Ribeiro', 'Moradias Palmital', '83325-606', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13463, 'São José dos Pinhais', 'Félix Ryndack', 'Colônia Murici', '83085-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13464, 'Cambé', 'Félix Sheller', 'Jardim Santo Antônio', '86182-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13465, 'Castro', 'Félix Tadeu Meyer', 'Jardim Social Primavera', '84174-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13466, 'Araucária', 'Félix Tamplim', 'Thomaz Coelho', '83706-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13467, 'Almirante Tamandaré', 'Feliz', 'Jardim Itamarati', '83505-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13468, 'Ponta Grossa', 'Fenacita', 'Neves', '84021-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13469, 'Londrina', 'Fênix', 'Lindóia', '86031-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13470, 'Guarapuava', 'Fênix', 'São Cristóvão', '85063-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13471, 'Pinhais', 'Fênix', 'Jardim Pedro Demeterco', '83324-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13472, 'Arapongas', 'Fênix', 'Vila Nova', '86707-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13473, 'Araucária', 'Fênix', 'Estação', '83705-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13474, 'Curitiba', 'Ferdinand Otto Müller', 'Tatuquara', '81470-237', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13475, 'São José dos Pinhais', 'Ferdinando Aristides Moleta', 'Afonso Pena', '83045-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13476, 'Curitiba', 'Ferdinando Darif', 'Campina do Siqueira', '80730-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13477, 'Curitiba', 'Ferdinando Fermino Franciosi', 'Umbará', '81930-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13478, 'Curitiba', 'Ferdinando Ferreira', 'Guabirotuba', '81520-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13479, 'Foz do Iguaçu', 'Ferdinando Lakus', 'Jardim Norma', '85869-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13480, 'Curitiba', 'Ferdinando Miraglia', 'Cidade Industrial', '81260-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13481, 'Londrina', 'Ferdinando Pivaro', 'São Pedro', '86036-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13482, 'Colombo', 'Feres Felipe Daher', 'Jardim Del Rey', '83402-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13483, 'Curitiba', 'Fermina Andrade da Silveira', 'Cidade Industrial', '81315-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13484, 'Apucarana', 'Fermino Alves Campos', 'Jardim Aeroporto', '86812-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13485, 'Londrina', 'Fermino Barbosa', 'Aurora', '86047-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13486, 'Londrina', 'Fermino da Silva', 'Leste Oeste', '86037-815', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13487, 'Foz do Iguaçu', 'Fermino de Oliveira', 'Jardim N Horizonte', '85855-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13488, 'Londrina', 'Fernanda Magalhães Ventura', 'Jardim Alphaville', '86084-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13489, 'Cascavel', 'Fernandes', 'Cataratas', '85818-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13490, 'Londrina', 'Fernandes Camacho', 'Petrópolis', '86015-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13491, 'Foz do Iguaçu', 'Fernandes Carlessi', 'Jardim Panorama II', '85856-565', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13576, 'Ponta Grossa', 'Ferreira Viana', 'Uvaranas', '84032-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13492, 'Piraquara', 'Fernandes Carlos Beetz', 'Planta Granjas Eldorado', '83309-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13493, 'Curitiba', 'Fernandes de Barros', 'Cristo Rei', '80050-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13494, 'Curitiba', 'Fernandes de Barros', 'Alto da Rua XV', '80040-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13495, 'Ponta Grossa', 'Fernandes Pinheiro', 'Centro', '84010-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13496, 'Ponta Grossa', 'Fernandes Vieira', 'Nova Rússia', '84053-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13497, 'Maringá', 'Fernandes Vieira', 'Zona 02', '87010-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13498, 'Toledo', 'Fernandes Vieira', 'Jardim Paulista', '85909-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13499, 'Curitiba', 'Fernandes Vieira', 'Capão Raso', '81020-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13500, 'São José dos Pinhais', 'Fernandina Marques', 'São Sebastião', '83075-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13501, 'Campo Largo', 'Fernando Aleixo', 'Jardim Boa Vista', '83609-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13502, 'Castro', 'Fernando Alvarez', 'Castroville', '84178-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13503, 'Ponta Grossa', 'Fernando Amaro', 'Colônia Dona Luiza', '84045-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13504, 'Paranaguá', 'Fernando Amaro', 'Centro Histórico', '83203-005', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13505, 'Curitiba', 'Fernando Amaro', 'Alto da Rua XV', '80050-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13506, 'Londrina', 'Fernando Antunes dos Santos', 'Franciscato II', '86078-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13507, 'Cambé', 'Fernando Bissoqui', 'Parque Residencial Ana Rosa', '86183-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13508, 'Maringá', 'Fernando Bressa', 'Residencial Ibirapuera', '87045-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13509, 'Sarandi', 'Fernando Bressa', 'Novo Panorama', '87113-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13510, 'Castro', 'Fernando Carlos Gomes', 'Cantagalo', '84178-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13511, 'São José dos Pinhais', 'Fernando Catta Preta Machado', 'Afonso Pena', '83050-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13512, 'Londrina', 'Fernando Cerqueira César Coimbra', 'Cidadela', '86072-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13513, 'Londrina', 'Fernando Ciríaco Dias', 'Conjunto Habitacional  Alexandre Urbanas', '86037-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13514, 'Curitiba', 'Fernando Corrêa de Azevedo', 'Santa Felicidade', '82410-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13515, 'Cascavel', 'Fernando Costa', 'Parque São Paulo', '85803-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13516, 'Curitiba', 'Fernando Cretella', 'Bacacheri', '82600-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13517, 'Guarapuava', 'Fernando de Noronha', 'Morro Alto', '85065-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13518, 'Londrina', 'Fernando de Noronha', 'Centro', '86020-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13519, 'Foz do Iguaçu', 'Fernando de Noronha', 'Jardim Ipê', '85869-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13520, 'Francisco Beltrão', 'Fernando de Noronha', 'Nossa Senhora Aparecida', '85601-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13521, 'Londrina', 'Fernando de Noronha', 'Centro', '86060-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13522, 'Paranaguá', 'Fernando de Noronha', 'Vila do Povo', '83209-659', 'Acesso', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13523, 'São José dos Pinhais', 'Fernando de Noronha', 'Costeira', '83015-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13524, 'Piraquara', 'Fernando de Noronha', 'Jardim dos Estados 2', '83308-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13525, 'Umuarama', 'Fernando de Noronha', 'Parque Tarumã', '87508-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13526, 'Araucária', 'Fernando de Noronha', 'Iguaçu', '83701-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13527, 'Curitiba', 'Fernando de Noronha', 'Santa Cândida', '82640-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13528, 'Curitiba', 'Fernando de Noronha', 'Santa Cândida', '82650-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13529, 'Curitiba', 'Fernando de Souza Costa', 'Fazendinha', '81330-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13530, 'São José dos Pinhais', 'Fernando Della Giustina', 'Ipê', '83055-516', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13531, 'Maringá', 'Fernando Eff Armond Khatlab', 'Conjunto João de Barro Porto Seguro II', '87055-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13532, 'Francisco Beltrão', 'Fernando Ferrari', 'Luther King', '85605-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13533, 'Pato Branco', 'Fernando Ferrari', 'Cristo Rei', '85506-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13534, 'Foz do Iguaçu', 'Fernando Gonçalves Neves', 'Jardim N Horizonte', '85855-729', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13535, 'Londrina', 'Fernando Gongôra', 'Residencial José Lázaro Gouvea', '86050-757', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13536, 'Guarapuava', 'Fernando Lisboa Júnior', 'Santa Cruz', '85015-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13537, 'Ponta Grossa', 'Fernando Machado', 'Boa Vista', '84073-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13538, 'Curitiba', 'Fernando Mansur Wekerlin', 'São Lourenço', '82200-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13539, 'Londrina', 'Fernando Mendes de Mello', 'Conjunto Habitacional Violim', '86084-675', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13540, 'Londrina', 'Fernando Monteiro Furtado', 'Residencial José Lázaro Gouvea', '86050-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13541, 'Curitiba', 'Fernando Munhoz de Souza', 'Alto Boqueirão', '81850-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13542, 'Francisco Beltrão', 'Fernando Niehurs', 'Jardim Novo Mundo', '85602-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13543, 'Apucarana', 'Fernando Pereira', 'Jardim Ponta Grossa', '86805-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13544, 'Guarapuava', 'Fernando Pessoa', 'Morro Alto', '85065-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13545, 'Pinhais', 'Fernando Pessoa', 'Planta Núcleo Colonial de Pinhais', '83321-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13546, 'Curitiba', 'Fernando Pessoa', 'Bom Retiro', '80520-410', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13547, 'São José dos Pinhais', 'Fernando Pradi', 'Costeira', '83015-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13548, 'Ponta Grossa', 'Fernando Prestes Albuquerque', 'Jardim Carvalho', '84016-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13549, 'Curitiba', 'Fernando Rodrigues de Lima', 'Campo de Santana', '81490-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13550, 'Colombo', 'Fernando Sabino', 'Planta Teixeira de Lara', '83409-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13551, 'Paranaguá', 'Fernando Simas', 'Centro Histórico', '83203-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13552, 'Curitiba', 'Fernando Simas', 'Mercês', '80430-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13553, 'Curitiba', 'Fernando Simas', 'Mercês', '80710-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13554, 'Londrina', 'Fernando Sobrinho', 'Conjunto Santa Rita 6', '86072-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13555, 'Maringá', 'Fernando Sordi Alves', 'Conjunto Habitacional Itatiaia', '87045-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13556, 'Araucária', 'Fernando Suckow', 'Centro', '83702-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13557, 'Piraquara', 'Fernando Teixeira Nogueira', 'Planta São Tiago', '83306-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13558, 'Ponta Grossa', 'Fernando Vieira', 'Nova Rússia', '84052-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13559, 'Londrina', 'Fernão de Magalhães', 'Aeroporto', '86036-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13560, 'Guarapuava', 'Fernão Dias', 'Alto Cascavel', '85031-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13561, 'Maringá', 'Fernão Dias', 'Zona 09', '87014-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13562, 'Ponta Grossa', 'Fernão Dias', 'Oficinas', '84036-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13563, 'Umuarama', 'Fernão Dias', 'Zona III', '87502-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13564, 'Telêmaco Borba', 'Fernão Dias', 'Macopa', '84263-000', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13565, 'Pato Branco', 'Fernão Dias Paes', 'Jardim América', '85502-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13566, 'Telêmaco Borba', 'Fernão Dias Paes', 'Núcleo Bandeirantes', '84269-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13567, 'Cambé', 'Fernão Dias Paes Lemes', 'Jardim Riviera', '86187-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13568, 'Curitiba', 'Fernão Dias País', 'Cajuru', '82950-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13569, 'Guarapuava', 'Feroz', 'Industrial', '85045-470', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13570, 'Curitiba', 'Ferrara', 'São João', '82030-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13571, 'Curitiba', 'Ferreira', 'Uberaba', '81570-550', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13572, 'Foz do Iguaçu', 'Ferreira Damião do Nascimento', 'Cr 3', '85863-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13573, 'Ponta Grossa', 'Ferreira de Aguiar', 'Boa Vista', '84073-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13574, 'Ponta Grossa', 'Ferreira de Araújo', 'Uvaranas', '84030-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13575, 'Curitiba', 'Ferreira do Amaral', 'Água Verde', '80620-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13577, 'Arapongas', 'Ferreiro', 'Vila Industrial', '86706-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13578, 'Apucarana', 'Ferro', 'Parque Industrial Zona Norte', '86806-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13579, 'Ponta Grossa', 'Ferroviária', 'Uvaranas', '84030-006', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13580, 'Arapongas', 'Ferroviária', 'Centro', '86701-155', 'Estação', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13581, 'Piraquara', 'Ferroviários', 'Jardim Santa Mônica', '83302-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13582, 'Curitiba', 'Ferroviários', 'Jardim Botânico', '80215-070', 'Vila', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13583, 'Londrina', 'Ferrucio Durello', 'Jardim Continental', '86081-187', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13584, 'Campo Mourão', 'Ferrucio Panessa', 'Jardim Nossa Senhora Aparecida', '87309-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13585, 'Campo Mourão', 'Ferrucio Trivelatto', 'Jardim Paulista', '87310-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13586, 'Arapongas', 'Feverreiro', 'Conjunto Ulisses Guimarães', '86706-659', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13587, 'Paranavaí', 'Fidelcino Rocha', 'Vila Operária', '87708-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13588, 'Francisco Beltrão', 'Fidelcino Zanella', 'Miniguaçu', '85605-456', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13589, 'Foz do Iguaçu', 'Fideles Alves', 'Boa Esperança', '85854-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13590, 'Curitiba', 'Fidelino Figueiredo', 'Fazendinha', '81330-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13591, 'Ponta Grossa', 'Fidélis Augusto Alves', 'Jardim Carvalho', '84016-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13592, 'Curitiba', 'Fidélis Ballin', 'Bom Retiro', '80520-700', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13593, 'Cascavel', 'Fidélis Batista de Aguiar', 'Santa Felicidade', '85803-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13594, 'Foz do Iguaçu', 'Fidélis Rangel Batista', 'Boa Esperança', '85854-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13595, 'Curitiba', 'Fidélis Reginato', 'Cidade Industrial', '81280-057', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13596, 'Ponta Grossa', 'Fidêncio Cioli', 'Cará-cará', '84043-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13597, 'Londrina', 'Fidêncio Xavier', 'Canaã', '86015-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13598, 'Londrina', 'Figueira', 'Santa Rita 1', '86072-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13599, 'Foz do Iguaçu', 'Figueira', 'Jardim Tropical', '85855-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13600, 'Maringá', 'Figueira', 'Jardim Vitória', '87023-620', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13601, 'Ponta Grossa', 'Figueira', 'Contorno', '84061-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13602, 'Telêmaco Borba', 'Figueira', 'Área 01', '84268-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13603, 'Cascavel', 'Figueira', 'Recanto Tropical', '85807-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13604, 'Almirante Tamandaré', 'Figueira', 'Vila Tefé', '83503-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13605, 'Apucarana', 'Figueira', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13606, 'Campo Largo', 'Figueiredo', 'Jardim Santa Nely', '83608-010', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13607, 'Guarapuava', 'Filadélfia', 'Santa Cruz', '85015-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13608, 'Umuarama', 'Filadélfia', 'Jardim Los Angeles', '87509-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13609, 'Curitiba', 'Filastro Nunes Pires', 'Santo Inácio', '82010-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13610, 'Apucarana', 'Fileto Alves', 'Jardim Esperança', '86810-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13611, 'Cambé', 'Filipenses', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13612, 'Francisco Beltrão', 'Filipinas', 'Pinheirinho', '85606-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13613, 'Maringá', 'Filipinas', 'Vila Morangueira', '87030-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13614, 'Umuarama', 'Filipinas', 'Parque Bonfim', '87507-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13615, 'Almirante Tamandaré', 'Filipinas', 'Vila Graziela', '83505-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13616, 'Curitiba', 'Filipinas', 'Cajuru', '82960-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13617, 'São José dos Pinhais', 'Filisbina Rosa Ordeiro', 'Ipê', '83055-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13618, 'Araucária', 'Filomena Kaiut', 'Costeira', '83709-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13619, 'Cascavel', 'Filosofia', 'Universitário', '85819-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13620, 'Curitiba', 'Filósofo Huberto Rohden', 'Sítio Cercado', '81900-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13621, 'Guarapuava', 'Finlândia', 'Industrial', '85053-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13622, 'Londrina', 'Finlândia', 'Vilas Boas', '86046-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13623, 'Umuarama', 'Finlândia', 'Parque Bonfim', '87507-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13624, 'Cambé', 'Finlândia', 'Vila Guarani', '86182-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13625, 'Apucarana', 'Finlândia', 'Vila Isabel', '86808-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13626, 'Colombo', 'Finlândia', 'Jardim Bela Vista', '83404-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13627, 'Curitiba', 'Fioravante Baggio', 'Cidade Industrial', '81230-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13628, 'Toledo', 'Fioravante Campagnolo', 'Conjunto Habitacional São Francisco', '85912-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13629, 'Toledo', 'Fioravante Cielo', 'Conjunto Habitacional Britânia', '85903-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13630, 'Curitiba', 'Fioravante Dalla Stella', 'Cristo Rei', '80050-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13631, 'Campo Mourão', 'Fioravante João Ferri', 'Jardim Alvorada', '87308-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13632, 'Londrina', 'Fioravante Pomin', 'Conjunto Habitacional José Garcia Molina', '86080-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13633, 'Curitiba', 'Fioravante Slaviero', 'Novo Mundo', '81050-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13634, 'Londrina', 'Fioravante Tomarozzi', 'João Paz', '86087-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13635, 'Maringá', 'Fioravante Zara', 'Vila Nova', '87045-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13636, 'São José dos Pinhais', 'Fioravante Zocolotti', 'Braga', '83020-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13637, 'Cascavel', 'Fiorelo Scanagatta', 'Santa Cruz', '85806-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13638, 'Pato Branco', 'Fiorelo Zandoná', 'Santa Terezinha', '85506-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13639, 'Colombo', 'Fiorino', 'Jardim Palmares', '83412-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13640, 'Foz do Iguaçu', 'Fiorino Brol', 'Vila São Sebastião', '85870-450', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13641, 'Curitiba', 'Firenze', 'Santa Felicidade', '82400-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13642, 'Cambé', 'Fireze', 'Jardim Montecatini', '86186-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13643, 'Apucarana', 'Firman Neto', 'Vila Clementina', '86808-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13644, 'Londrina', 'Firmino Almeida Tavares', 'Parigot de Souza 2', '86082-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13645, 'Londrina', 'Firmino Lemes de Oliveira', 'Indústrias', '86043-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13646, 'Umuarama', 'Firmino Rodrigues Gomes', 'Jardim Cruzeiro', '87504-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13647, 'Londrina', 'Firmino Vieira', 'Cafezal 1', '86049-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13648, 'Ponta Grossa', 'Fiscal Antônio Mariano', 'Oficinas', '84045-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13649, 'Guarapuava', 'Flamboyant', 'Conradinho', '85055-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13650, 'Londrina', 'Flamboyant', 'Leonor', '86071-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13651, 'Pinhais', 'Flamboyant', 'Planta Karla', '83328-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13652, 'Maringá', 'Flamboyant', 'Parque Palmeiras', '87023-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13653, 'Sarandi', 'Flamboyant', 'Jardim Monterey', '87112-815', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13654, 'Cascavel', 'Flamboyant', 'Coqueiral', '85807-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13655, 'Campo Mourão', 'Flamboyant', 'Jardim Paulista', '87310-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13656, 'Cascavel', 'Flamboyant', 'Alto Alegre', '85805-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13657, 'Araucária', 'Flamboyant', 'Estação', '83705-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13658, 'Apucarana', 'Flamboyant', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13659, 'Curitiba', 'Flamboyant', 'Cachoeira', '82710-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13660, 'Londrina', 'Flamengo', 'Yara', '86027-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13661, 'Maringá', 'Flamengo', 'Vila Marumby', '87005-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13662, 'Londrina', 'Flamingo', 'Vitória Régia', '86038-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13663, 'Foz do Iguaçu', 'Flamingo', 'Portal da Foz', '85859-389', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13664, 'Maringá', 'Flamingo', 'Jardim Olímpico', '87070-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13665, 'Ponta Grossa', 'Flamingo', 'Colônia Dona Luiza', '84046-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13666, 'Araucária', 'Flamingo', 'Capela Velha', '83706-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13667, 'Cascavel', 'Flamingo', 'Floresta', '85814-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13668, 'Arapongas', 'Flamingo-chileno', 'Casa Família Arapongas IV', '86709-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13669, 'Arapongas', 'Flamingos', 'Centro', '86701-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13670, 'Maringá', 'Flanklin Delano Roosevelt', 'Conjunto Habitacional Requião', '87047-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13671, 'Maringá', 'Flausina Francisca de Souza', 'Vila Santa Izabel', '87080-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13672, 'Curitiba', 'Flausina Ribeiro de Loyola', 'Guabirotuba', '81520-530', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13673, 'Paranavaí', 'Flauzino Dias Viegas', 'Jardim Campo Belo', '87711-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13674, 'Almirante Tamandaré', 'Flávia Ferreira Matozo', 'Jardim Giannini', '83511-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13675, 'Almirante Tamandaré', 'Flávia Saldanha Machado', 'Jardim Novo Horizonte da Cachoeira', '83502-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13676, 'Curitiba', 'Flávio A. Secco', 'Atuba', '82630-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13677, 'Foz do Iguaçu', 'Flávio Azambuja Mader', 'Jardim Panorama II', '85856-585', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13678, 'Curitiba', 'Flávio Bonat', 'Tatuquara', '81480-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13679, 'Londrina', 'Flávio Buranelli', 'Jardim Olga', '86087-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13680, 'Curitiba', 'Flávio Cavalcanti', 'Barreirinha', '82210-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13681, 'Guarapuava', 'Flávio Corrêa dos Santos', 'São Cristóvão', '85063-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13682, 'Curitiba', 'Flávio Dallegrave', 'Boa Vista', '82540-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13683, 'Curitiba', 'Flávio Dallegrave', 'Cristo Rei', '80050-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13684, 'Curitiba', 'Flávio Dallegrave', 'Alto da Rua XV', '80040-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13685, 'Curitiba', 'Flávio Dallegrave', 'Bacacheri', '82510-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13686, 'Curitiba', 'Flávio Dallegrave', 'São Lourenço', '82210-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13687, 'Curitiba', 'Flávio Dallegrave', 'Barreirinha', '82220-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13688, 'Toledo', 'Flávio dal''Pra', 'Residencial Santa Clara', '85907-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13689, 'Ponta Grossa', 'Flávio de Almeida Martins', 'Nova Rússia', '84053-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13690, 'Curitiba', 'Flávio de Andrade', 'Cascatinha', '82020-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13691, 'Curitiba', 'Flávio de Azevedo Macedo', 'São Lourenço', '82200-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13692, 'Campo Mourão', 'Flávio de Paula Emer', 'Jardim Maia', '87301-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13693, 'Ponta Grossa', 'Flávio Faria Carneiro', 'Uvaranas', '84030-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13694, 'Londrina', 'Flávio Ferreira dos Santos', 'Residencial José B Almeida', '86041-828', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13695, 'Cambé', 'Flávio Ferreira dos Santos', 'Jardim José Favaro', '86183-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13696, 'Guarapuava', 'Flávio Franco', 'Primavera', '85050-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13697, 'Londrina', 'Flávio Luz', 'Colonial', '86047-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13698, 'Curitiba', 'Flávio Mariano Ribas', 'Uberaba', '81570-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13699, 'São José dos Pinhais', 'Flávio Nogueira Machado', 'Afonso Pena', '83045-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13700, 'São José dos Pinhais', 'Flávio Pereira de Andrade', 'Costeira', '83015-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13701, 'Londrina', 'Flávio Ribeiro', 'São Pedro', '86036-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13702, 'Curitiba', 'Flávio Ribeiro', 'Portão', '80330-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13703, 'Foz do Iguaçu', 'Flor de Palha', 'Vila Yolanda', '85853-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13704, 'Foz do Iguaçu', 'Floraí', 'Jardim Ipê', '85869-665', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13705, 'Ponta Grossa', 'Floraí', 'Oficinas', '84036-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13706, 'Maringá', 'Floraí', 'Zona 08', '87050-680', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13707, 'Umuarama', 'Floraí', 'Jardim Paraíso', '87505-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13708, 'Umuarama', 'Floraí', 'Zona I', '87501-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13709, 'Curitiba', 'Floraí', 'Xaxim', '81820-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13710, 'Londrina', 'Floral', 'Novo Amparo', '86042-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13711, 'Pinhais', 'Floral', 'Jardim Alto Tarumã', '83325-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13712, 'Sarandi', 'Floral', 'Jardim Monterey', '87112-787', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13713, 'Cambé', 'Flor-da-esperança', 'Jardim Ana Eliza', '86188-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13714, 'Londrina', 'Flor-da-manhã', 'Água Verde', '86050-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13715, 'Londrina', 'Flor-da-primavera', 'Colina Verde Leste', '86050-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13716, 'Foz do Iguaçu', 'Flor-da-serra', 'Jardim Duarte', '85861-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13717, 'Cascavel', 'Flor-da-serra', 'Guarujá', '85804-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13718, 'Londrina', 'Flor-de-abril', 'Ricardo', '86035-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13719, 'Londrina', 'Flor-de-ipê', 'Ouro Branco', '86042-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13720, 'Paranaguá', 'Flor-de-ipê', 'Conjunto Nilson Neves', '83215-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13721, 'Telêmaco Borba', 'Flor-de-ipê', 'Jardim Alegre', '84268-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13722, 'Umuarama', 'Flor-de-ipê', 'Parque das Jaboticabeiras', '87509-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13723, 'Pinhais', 'Flor-de-jasmin', 'Planta Walde Rosi Galvão', '83328-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13724, 'Londrina', 'Flor-de-jesus', 'Ricardo', '86035-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13725, 'Telêmaco Borba', 'Flor-de-laranjeira', 'Jardim Alegre', '84268-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13726, 'Foz do Iguaçu', 'Flor-de-lis', 'Vila Adriana', '85854-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13727, 'Guarapuava', 'Flor-de-lis', 'Trianon', '85012-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13728, 'Londrina', 'Flor-de-lis', 'Ricardo', '86035-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13729, 'Araucária', 'Flor-de-lis', 'Campina da Barra', '83709-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13730, 'Cascavel', 'Flor-de-lis', 'Guarujá', '85804-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13731, 'Cambé', 'Flor-de-lis', 'Jardim Ana Eliza', '86188-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13732, 'Londrina', 'Flor-de-lotus', 'Ouro Branco', '86042-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13733, 'Pinhais', 'Flor-de-lótus', 'Planta Walde Rosi Galvão', '83328-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13734, 'Londrina', 'Flor-de-maio', 'Ricardo', '86035-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13735, 'Umuarama', 'Flor-de-maio', 'Parque das Jaboticabeiras', '87509-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13736, 'Campo Mourão', 'Flor-de-maio', 'Conjunto Residencial Novo Mundo', '87308-600', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13737, 'Londrina', 'Flor-de-natal', 'Ricardo', '86035-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13738, 'Cambé', 'Flor-de-natal', 'Jardim Ana Eliza', '86188-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13739, 'Foz do Iguaçu', 'Flor-de-palha', 'Vila Adriana', '85854-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13740, 'Londrina', 'Flor-do-campo', 'Ouro Branco', '86042-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13741, 'Pinhais', 'Flor-do-campo', 'Planta Karla', '83328-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13742, 'Telêmaco Borba', 'Flor-do-campo', 'Jardim Alegre', '84268-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13743, 'Campo Mourão', 'Flor-do-campo', 'Jardim Santa Nilce II', '87308-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13744, 'Londrina', 'Flor-do-paraíso', 'Santo Antônio', '86035-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13745, 'Londrina', 'Flor-dos-alpes', 'Ouro Branco', '86042-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13746, 'Londrina', 'Florença', 'Parque Residencial João Piza', '86041-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13747, 'Francisco Beltrão', 'Florença', 'Jardim Floresta', '85603-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13748, 'Umuarama', 'Florença', 'Conjunto Residencial Córrego Longe', '87504-619', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13749, 'Toledo', 'Florença', 'Centro', '85901-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13750, 'Cascavel', 'Florença', 'Cascavel Velho', '85818-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13751, 'Colombo', 'Florença', 'Planta Boros', '83413-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13752, 'Maringá', 'Florence Nightingale', 'Jardim Alvorada', '87035-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13753, 'Londrina', 'Florêncio Elias de Moraes', 'Jardim Nova Esperança', '86044-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13754, 'Cascavel', 'Florêncio Galafassi', 'Periolo', '85817-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13755, 'Londrina', 'Florêncio Rodrigues', 'Jardim Vale Verde', '86040-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13756, 'Curitiba', 'Florêncio Sanches', 'Santa Cândida', '82640-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13757, 'Paranaguá', 'Florêncio Viana', 'Campo Grande', '83203-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13758, 'Curitiba', 'Florentim Ançai', 'Cidade Industrial', '81350-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13759, 'Curitiba', 'Florentina Fernandes Camargo', 'Abranches', '82130-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13760, 'Colombo', 'Florentino Rocha', 'Jardim Campo Alto', '83408-216', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13761, 'São José dos Pinhais', 'Florentino Suchla', 'Guatupê', '83060-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13762, 'Castro', 'Florentino Telles', 'Jardim das Araucárias', '84172-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13763, 'Ponta Grossa', 'Florenzano', 'Colônia Dona Luiza', '84043-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13764, 'Guarapuava', 'Flores da Cunha', 'Vila Bela', '85027-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13765, 'Foz do Iguaçu', 'Flores da Cunha', 'Mata Verde', '85853-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13766, 'Francisco Beltrão', 'Floresta', 'Pinheirinho', '85603-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13767, 'Foz do Iguaçu', 'Floresta', 'Vila Carima', '85855-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13768, 'São José dos Pinhais', 'Floresta', 'Ouro Fino', '83015-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13769, 'Campo Mourão', 'Floresta', 'Conjunto Residencial Antilhas', '87308-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13770, 'Londrina', 'Floresta das Araucárias', 'Vila A B Vicentini', '86077-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13771, 'Maringá', 'Florestal dos Pioneiros', 'Zona 02', '87010-465', 'Parque', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13772, 'Foz do Iguaçu', 'Florestópolis', 'Loteameto Jardim Colombelli', '85862-478', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13773, 'Londrina', 'Florestópolis', 'Lindóia', '86031-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13774, 'Ponta Grossa', 'Florestópolis', 'Oficinas', '84036-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13775, 'Curitiba', 'Florestópolis', 'Cidade Industrial', '81250-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13776, 'Campo Largo', 'Floresval Leal', 'Jardim Florestal', '83602-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13777, 'São José dos Pinhais', 'Floresvaldo Meres de Creddo', 'Afonso Pena', '83050-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13778, 'Campo Mourão', 'Floriano', 'Jardim Flórida', '87300-096', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13779, 'Curitiba', 'Floriano Ernani Pesch', 'Sítio Cercado', '81920-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13780, 'Curitiba', 'Floriano Essenfelder', 'Alto da Glória', '80060-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13781, 'Guarapuava', 'Floriano Guine', 'Morro Alto', '85070-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13782, 'Curitiba', 'Floriano Nolasco da Silva', 'Atuba', '82860-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13783, 'Paranavaí', 'Floriano Peixoto', 'Jardim Progresso', '87701-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13784, 'Paranavaí', 'Floriano Peixoto', 'Jardim Paulista', '87709-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13785, 'Curitiba', 'Floriano Ramos Ribeiro', 'Cajuru', '82940-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13786, 'Apucarana', 'Floriano Volante', 'Núcleo Habitacional Mathias Hoffman', '86805-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13787, 'Foz do Iguaçu', 'Florianópolis', 'Conjunto C', '85870-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13788, 'Foz do Iguaçu', 'Florianópolis', 'Jardim Karla', '85868-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13789, 'Laranjeiras do Sul', 'Florianópolis', 'Água Verde', '85302-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13790, 'Foz do Iguaçu', 'Florianópolis', 'Jardim Santa Rosa', '85869-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13791, 'Guarapuava', 'Florianópolis', 'Santa Cruz', '85015-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13792, 'Londrina', 'Florianópolis', 'Pietraroia', '86020-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13793, 'Francisco Beltrão', 'Florianópolis', 'Alvorada', '85601-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13794, 'Piraquara', 'Florianópolis', 'Planta São Tiago', '83306-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13795, 'Maringá', 'Florianópolis', 'Parque Residencial Cidade Nova', '87023-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13796, 'São José dos Pinhais', 'Florianópolis', 'Ouro Fino', '83015-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13797, 'Paranavaí', 'Florianópolis', 'Jardim Belo Horizonte', '87701-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13798, 'Telêmaco Borba', 'Florianópolis', 'Macopa', '84263-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13800, 'Sarandi', 'Florianópolis', 'Jardim Escala', '87114-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13801, 'Cambé', 'Florianópolis', 'Vila Mesquita', '86182-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13802, 'Almirante Tamandaré', 'Florianópolis', 'Jardim Gramados', '83504-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13803, 'Campo Mourão', 'Florianópolis', 'Jardim Santa Nilce II', '87308-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13804, 'Curitiba', 'Florianópolis', 'Cajuru', '82940-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13805, 'Curitiba', 'Florianópolis', 'Cajuru', '82930-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13806, 'Londrina', 'Flórida', 'Flórida', '86010-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13807, 'Foz do Iguaçu', 'Flórida', 'Jardim Belvedere II', '85867-607', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13808, 'Umuarama', 'Flórida', 'Zona I', '87501-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13809, 'Curitiba', 'Flórida', 'Barreirinha', '82560-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13810, 'Paranaguá', 'Florinda Carlos Cardoso', 'Divinéia', '83212-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13811, 'São José dos Pinhais', 'Florinda Costa Stonoga', 'Zaniolo', '83025-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13812, 'Guarapuava', 'Florinda de Matos Martini', 'Cascavel', '85025-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13813, 'Curitiba', 'Florinda Gusso Bozza', 'Pilarzinho', '82120-215', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13814, 'Londrina', 'Florindo Bau', 'Parque Universidade', '86056-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13815, 'Colombo', 'Florindo Berlesi', 'Santa Rita', '83412-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13816, 'Londrina', 'Florindo Boni', 'Colinas', '86056-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13817, 'Londrina', 'Florindo Furlan', 'Araxá', '86061-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13818, 'Curitiba', 'Florindo Gusso', 'Pilarzinho', '82110-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13819, 'Curitiba', 'Florindo José Moreschi', 'Guaíra', '80630-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13820, 'Pinhais', 'Florindo Lindes', 'Prive Bois de Boulogne', '83330-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13821, 'Sarandi', 'Florindo Neves', 'Vera Cruz', '87111-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13822, 'Maringá', 'Florindo Redivo', 'Vila Esperança', '87020-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13823, 'Curitiba', 'Florindo Rinaldin', 'Xaxim', '81810-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13824, 'Londrina', 'Florindo Salvador', 'Jardim Piza', '86073-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13825, 'Colombo', 'Florindo Trevisan', 'Vila Luiz Baron', '83412-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13826, 'Almirante Tamandaré', 'Floripa Carvalho de Cristo', 'Loteamento Nova Morada', '83504-689', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13827, 'Colombo', 'Floripa Mullmann', 'Vila Yara', '83408-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13828, 'Curitiba', 'Florisval Lanconi', 'Tarumã', '82800-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13829, 'Castro', 'Florisval R. de Morais', 'Vila Rio Branco', '84172-290', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13830, 'Maringá', 'Florisval Xavier Costa', 'Conjunto Habitacional Requião', '87047-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13831, 'Curitiba', 'Florisvaldo Rufino Tosin', 'Cidade Industrial', '81170-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13832, 'Curitiba', 'Florita Wilcek Leitoles', 'Cidade Industrial', '81450-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13833, 'Curitiba', 'Florival Elvidio da Silva', 'Sítio Cercado', '81910-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13834, 'Ponta Grossa', 'Florival Fanucchi', 'Boa Vista', '84071-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13835, 'Umuarama', 'Florivaldo Ricieri Tampelini', 'Parque Industrial I', '87507-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13836, 'Maringá', 'Fluminense', 'Vila Marumby', '87005-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13837, 'Ponta Grossa', 'Flurita', 'Neves', '84021-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13838, 'Arapongas', 'Fogo-apagou', 'Jardim Primavera', '86702-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13839, 'Curitiba', 'Fonte da Vida', 'Cajuru', '82930-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13840, 'Foz do Iguaçu', 'Fonte Nova', 'Parque Morumbi II', '85859-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13841, 'Ponta Grossa', 'Fontoino Xavier Domingos de Magalhães', 'Nova Rússia', '84053-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13842, 'Londrina', 'Fontoura Xavier', 'Jardim Tatiani', '86070-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13843, 'Paranaguá', 'Ford', 'Emboguaçu', '83209-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13844, 'Ponta Grossa', 'Forel', 'Colônia Dona Luiza', '84045-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13845, 'Foz do Iguaçu', 'Formiga', 'Loteameto Jardim Colombelli', '85862-477', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13846, 'Arapongas', 'Formigueiro', 'Jardim Morumbi', '86708-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13847, 'Arapongas', 'Formigueiro-da-serra', 'Conjunto Palmares', '86706-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13848, 'Arapongas', 'Formigueiro-de-topete-vermelho', 'Jardim São Carlos', '86704-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13849, 'Arapongas', 'Formigueiro-estrelado', 'Conjunto Padre Bernardo Merckel', '86706-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13850, 'Arapongas', 'Formigueiro-pequeno', 'Conjunto Águias', '86704-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13851, 'Arapongas', 'Formigueiro-rajado', 'Jardim Nova Baroneza', '86706-689', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13852, 'Francisco Beltrão', 'Formosa', 'São Cristóvão', '85601-357', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13853, 'Foz do Iguaçu', 'Formosa', 'Jardim Curitibano', '85869-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13854, 'Paranavaí', 'Formosa', 'Jardim São Jorge', '87710-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13855, 'Pinhais', 'Formosa', 'Planta Portal da Serra', '83325-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13856, 'Toledo', 'Formosa', 'Jardim La Salle', '85903-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13857, 'Toledo', 'Formosa', 'Jardim La Salle', '85902-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13858, 'Campo Mourão', 'Formosa', 'Jardim Gutierres', '87300-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13859, 'Colombo', 'Formosa do Oeste', 'Vila São José', '83410-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13860, 'Curitiba', 'Formosa do Oeste', 'Cidade Industrial', '81250-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13861, 'Francisco Beltrão', 'Fortaleza', 'Pinheirinho', '85603-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13862, 'Laranjeiras do Sul', 'Fortaleza', 'Água Verde', '85302-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13863, 'Foz do Iguaçu', 'Fortaleza', 'Conjunto C', '85870-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13864, 'Foz do Iguaçu', 'Fortaleza', 'Jardim das Laranjeiras', '85868-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13865, 'Londrina', 'Fortaleza', 'Jardim Agari', '86020-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13866, 'Guarapuava', 'Fortaleza', 'São Cristóvão', '85060-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13867, 'São José dos Pinhais', 'Fortaleza', 'Águas Belas', '83010-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13868, 'Maringá', 'Fortaleza', 'Vila Morangueira', '87040-340', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13869, 'Pinhais', 'Fortaleza', 'Conjunto Residencial Renato Bonilauri', '83325-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13870, 'Piraquara', 'Fortaleza', 'Vila Vicente Macedo', '83303-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13871, 'Toledo', 'Fortaleza', 'Boa Esperança', '85909-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13872, 'Telêmaco Borba', 'Fortaleza', 'Nossa Senhora de Fátima', '84264-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13873, 'Umuarama', 'Fortaleza', 'Jardim América', '87502-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13874, 'Colombo', 'Fortaleza', 'Jardim Jalisco', '83404-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13875, 'Cambé', 'Fortaleza', 'Vila Salomé', '86192-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13876, 'Cambé', 'Fortaleza', 'Jardim do Lago', '86192-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13877, 'Cascavel', 'Fortaleza', 'Centro', '85810-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13878, 'Cascavel', 'Fortaleza', 'Recanto Tropical', '85807-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13879, 'Cascavel', 'Fortaleza', 'Centro', '85810-051', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13880, 'Curitiba', 'Fortaleza', 'Cajuru', '82920-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13881, 'Curitiba', 'Fortaleza', 'Cajuru', '82930-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13882, 'Cascavel', 'Fortunato Bebber', 'Gramado', '85816-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13883, 'Maringá', 'Fortunato Borin', 'Conjunto Habitacional Requião', '87047-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13884, 'Curitiba', 'Fortunato de Mio', 'Fazendinha', '81320-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13885, 'Londrina', 'Fortunato Ferreira de Oliveira', 'Conjunto Novo Amparo', '86087-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13886, 'Cambé', 'Fortunato Fregoneze', 'Jardim Riviera', '86187-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13887, 'Londrina', 'Fortunato Giroldo Massaro', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13888, 'Foz do Iguaçu', 'Fortunato Morello', 'Loteamento Residencial Lagoa Vermelha', '85862-336', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13889, 'Londrina', 'Fortunato Moro', 'Jardim Bom Pastor', '86082-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13890, 'São José dos Pinhais', 'Fortunato Moss', 'Colônia Rio Grande', '83025-337', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13891, 'Colombo', 'Fortunato Taverna', 'Centro Industrial Mauá', '83413-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13892, 'Curitiba', 'Fortunato Veleda Bermudez', 'Vista Alegre', '80820-700', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13893, 'Colombo', 'Foster', 'Jardim Iracema', '83403-640', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13894, 'Foz do Iguaçu', 'Foz do Areia', 'Loteamento Lindóia', '85856-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13895, 'Maringá', 'Foz do Areia', 'Ebenezer', '87035-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13896, 'Londrina', 'Foz do Iguaçu', 'Bancários', '86061-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13897, 'Laranjeiras do Sul', 'Foz do Iguaçu', 'Água Verde', '85302-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13898, 'Guarapuava', 'Foz do Iguaçu', 'Industrial', '85053-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13899, 'Ponta Grossa', 'Foz do Iguaçu', 'Chapada', '84062-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13900, 'Pinhais', 'Foz do Iguaçu', 'Vila Emiliano Perneta', '83324-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13901, 'São José dos Pinhais', 'Foz do Iguaçu', 'Silveira da Motta', '83030-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13902, 'Toledo', 'Foz do Iguaçu', 'Jardim Carelli', '85906-718', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13903, 'Cambé', 'Foz do Iguaçu', 'Jardim Ana Eliza', '86188-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13904, 'Colombo', 'Foz do Iguaçu', 'Jardim Guaraituba', '83410-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13905, 'Araucária', 'Foz do Iguaçu', 'Iguaçu', '83701-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13906, 'Curitiba', 'Foz do Iguaçu', 'Pinheirinho', '81880-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13907, 'Colombo', 'Foz do Jordão', 'Jardim Modelo', '83405-187', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13908, 'Curitiba', 'Frá Angélico', 'Guabirotuba', '81510-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13909, 'Londrina', 'Frade do Serra', 'Messiânico', '86065-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13910, 'Arapongas', 'Fragata', 'Vila Aparecida', '86707-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13911, 'Foz do Iguaçu', 'Fraiburgo', 'Jardim Veneza', '85870-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13912, 'Londrina', 'Franca', 'Jardim Adriana I', '86046-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13913, 'Foz do Iguaçu', 'Franca', 'Jardim Europa', '85859-318', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13914, 'Guarapuava', 'Franca', 'Industrial', '85053-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13915, 'Foz do Iguaçu', 'Franca', 'Jardim Lancaster', '85869-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13916, 'Ponta Grossa', 'Franca', 'Oficinas', '84036-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13917, 'Sarandi', 'Franca', 'Jardim Europa', '87111-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13918, 'Toledo', 'Franca', 'Jardim Bandeirantes', '85906-739', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13919, 'Almirante Tamandaré', 'Franca', 'Vila Graziela', '83505-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13920, 'Cascavel', 'Franca', 'Cascavel Velho', '85818-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13921, 'Cambé', 'Franca', 'Centro', '86181-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13922, 'Apucarana', 'Franca', 'Loteamento Fortaleza', '86802-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13923, 'Umuarama', 'França', 'Parque Bonfim', '87507-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13924, 'Arapongas', 'Francelho', 'Vila Nova', '86707-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13925, 'Colombo', 'Francelisio José de Camargo', 'Planta Boros', '83413-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13926, 'Londrina', 'Francis Bacon', 'Vera Cruz', '86036-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13927, 'Curitiba', 'Francis Bacon', 'Santa Cândida', '82720-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13928, 'Ponta Grossa', 'Francis Jammes', 'Cará-cará', '84043-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13929, 'Araucária', 'Francisca Andrade de Souza', 'Estação', '83705-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13930, 'Piraquara', 'Francisca Assis Center', 'Vila Ipanema', '83301-036', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13931, 'Curitiba', 'Francisca Azolin', 'Santa Felicidade', '82015-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13932, 'Curitiba', 'Francisca Beraldo Paolini', 'Caximba', '81490-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13933, 'Araucária', 'Francisca Bonvim', 'Costeira', '83709-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13934, 'Colombo', 'Francisca Cardoso', 'Sapopema', '83407-098', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13935, 'Curitiba', 'Francisca Chiesorin', 'Seminário', '80740-197', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13936, 'Curitiba', 'Francisca Claro Viana', 'Cajuru', '82930-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13937, 'Maringá', 'Francisca de Almeida', 'Conjunto João de Barro Cidade Canção', '87053-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13938, 'São José dos Pinhais', 'Francisca de Souza Cortes', 'Afonso Pena', '83050-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13939, 'Maringá', 'Francisca do Amaral Mello Maluf', 'Parque Avenida', '87025-570', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13940, 'Foz do Iguaçu', 'Francisca Eleotéria', 'Jardim Califórnia', '85867-506', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13941, 'Curitiba', 'Francisca Ferreira da Luz', 'Tatuquara', '81480-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13942, 'Curitiba', 'Francisca Ferreira Pontes', 'Xaxim', '81830-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13943, 'Maringá', 'Francisca Fumiko Oda dos Santos', 'Vila Esperança', '87020-690', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13944, 'Araucária', 'Francisca Grabowski', 'Fazenda Velha', '83703-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13945, 'Londrina', 'Francisca Hosken de Farias Castro', 'Conjunto Residencial Doutor Alberto João Zortea', '86042-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13946, 'Curitiba', 'Francisca Koslowski', 'Mossunguê', '81200-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13947, 'Piraquara', 'Francisca Leal de Oliveira', 'Borda do Campo', '83304-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13948, 'Curitiba', 'Francisca Luiza dos Santos', 'Campo de Santana', '81490-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13949, 'Londrina', 'Francisca Mendes', 'Jardim das Palmeiras', '86083-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13950, 'Piraquara', 'Francisca Nunes Gaio', 'Vila Ipanema', '83301-049', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13951, 'Curitiba', 'Francisca Pampuche Antoniacomi', 'Tatuquara', '81470-105', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13952, 'Londrina', 'Francisca Rodrigues do Amaral', 'Shangri-La', '86070-105', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13953, 'Campo Largo', 'Francisca Sovierzoski Guercheski', 'Jardim das Américas', '83601-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13954, 'Curitiba', 'Francisca Toni Mathias', 'Capão da Imbuia', '82810-320', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13955, 'Piraquara', 'Francisca Úrsula Simião', 'Vila Juliana', '83306-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13956, 'Curitiba', 'Francisco Ader', 'Novo Mundo', '81050-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13957, 'Curitiba', 'Francisco Affanio', 'Campina do Siqueira', '80740-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13958, 'Curitiba', 'Francisco Affonso da Costa', 'São João', '82030-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13959, 'Foz do Iguaçu', 'Francisco Almeida Brandão', 'Parque Presidente', '85863-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13960, 'Foz do Iguaçu', 'Francisco Alves', 'Jardim Naipi', '85853-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13961, 'Londrina', 'Francisco Alves', 'Hípica', '86067-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13962, 'São José dos Pinhais', 'Francisco Alves', 'Afonso Pena', '83050-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13963, 'Paranavaí', 'Francisco Alves', 'Jardim São Jorge', '87710-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13964, 'Pato Branco', 'Francisco Alves', 'Menino Deus', '85502-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13965, 'Toledo', 'Francisco Alves', 'Boa Esperança', '85909-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13966, 'Cascavel', 'Francisco Alves', 'Brasília', '85815-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13967, 'Curitiba', 'Francisco Alves', 'Xaxim', '81810-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13968, 'Pinhais', 'Francisco Alves Cordeiro', 'Jardim Guairacá', '83324-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13969, 'Cascavel', 'Francisco Alves da Rocha', 'Santa Felicidade', '85803-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13970, 'Curitiba', 'Francisco Alves da Rocha', 'Pilarzinho', '82115-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13971, 'São José dos Pinhais', 'Francisco Alves de Lima', 'Costeira', '83015-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13972, 'Piraquara', 'Francisco Alves de Oliveira', 'Centro', '83301-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13973, 'Paranavaí', 'Francisco Alves do Nascimento', 'Jardim Farropilha', '87708-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13974, 'Paranavaí', 'Francisco Alves do Nascimento', 'Jardim do Sol', '87711-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13975, 'Paranavaí', 'Francisco Alves do Nascimento', 'Jardim Aeroporto', '87707-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13976, 'Curitiba', 'Francisco Alves Guimarães', 'Cristo Rei', '80050-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13977, 'Campo Largo', 'Francisco Alves Mendes', 'Loteamento José Luiz Rivabem', '83604-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13978, 'Londrina', 'Francisco Alves Pinto', 'Nova Olinda', '86073-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13979, 'Curitiba', 'Francisco Alves Ribeiro Filho', 'Cajuru', '82930-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13980, 'Londrina', 'Francisco Alves Sobrinho', 'Portal de Versalhes 2', '86063-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13981, 'Foz do Iguaçu', 'Francisco Amadeu Santos', 'Jardim N Horizonte', '85855-737', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13982, 'Londrina', 'Francisco Américo', 'Jardim Marissol', '86030-499', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13983, 'Castro', 'Francisco Anacleto da Fonseca', 'Jardim dos Bancários', '84172-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13984, 'Curitiba', 'Francisco Antochechen', 'Butiatuvinha', '82320-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13985, 'Apucarana', 'Francisco Antônio Consolaro', 'Parque Industrial Zona Norte', '86806-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13986, 'Curitiba', 'Francisco Antônio da Costa Nogueira', 'Santa Felicidade', '82410-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13987, 'Londrina', 'Francisco Antônio Galhardi', 'Monte Belo', '86041-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13988, 'Curitiba', 'Francisco Antônio Ribeiro', 'Atuba', '82860-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13989, 'Campo Largo', 'Francisco Antunes Zanin', 'Jardim Florestal', '83602-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13990, 'Colombo', 'Francisco Appel', 'Jardim dos Eucaliptos', '83408-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13991, 'Londrina', 'Francisco Arias', 'Conjunto Semiramis Barros Braga', '86088-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13992, 'Colombo', 'Francisco Baggio', 'Jardim Nossa Senhora das Graças', '83407-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13993, 'Curitiba', 'Francisco Balchak', 'Boa Vista', '82560-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13994, 'Curitiba', 'Francisco Baptista da Silva', 'Orleans', '82300-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13995, 'Colombo', 'Francisco Barbiot', 'Jardim dos Eucaliptos', '83408-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13996, 'Londrina', 'Francisco Barbosa', 'Gleba Jacutinga', '86075-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13997, 'Curitiba', 'Francisco Barbosa', 'Pinheirinho', '81825-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13998, 'Colombo', 'Francisco Baron', 'Vila Luiz Baron', '83412-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (13999, 'Cascavel', 'Francisco Bartinik', 'Coqueiral', '85807-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14000, 'Toledo', 'Francisco Basso', 'Mônaco', '85905-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14001, 'Curitiba', 'Francisco Becker', 'Umbará', '81930-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14002, 'Guarapuava', 'Francisco Beltrão', 'Industrial', '85053-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14003, 'Ponta Grossa', 'Francisco Beltrão', 'Chapada', '84062-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14004, 'São José dos Pinhais', 'Francisco Beltrão', 'Cidade Jardim', '83035-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14005, 'Cascavel', 'Francisco Beltrão', 'Pacaembu', '85816-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14006, 'Campo Mourão', 'Francisco Beltrão', 'Jardim Santa Cruz', '87309-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14007, 'Colombo', 'Francisco Beltrão', 'Jardim Guaraituba', '83410-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14008, 'Londrina', 'Francisco Bento', 'Jardim Nova Esperança', '86044-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14009, 'Londrina', 'Francisco Bernardino Leite', 'Jardim Vale Verde', '86040-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14010, 'Colombo', 'Francisco Bernardo Lunardon', 'Colônia Faria', '83412-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14011, 'Curitiba', 'Francisco Bettinardi', 'Guabirotuba', '81520-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14012, 'Londrina', 'Francisco Bilmaia', 'Taliana', '86035-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14013, 'Curitiba', 'Francisco Biscardi', 'Capão Raso', '81130-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14014, 'Londrina', 'Francisco Boer', 'Jatobá', '86043-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14015, 'Curitiba', 'Francisco Bordenowski', 'Butiatuvinha', '82400-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14016, 'Curitiba', 'Francisco Borges Machado', 'Capão da Imbuia', '82810-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14017, 'Francisco Beltrão', 'Francisco Borghesan', 'Pinheirinho', '85606-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14018, 'Francisco Beltrão', 'Francisco Borghesan', 'Antônio de Paiva Cantelmo', '85603-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14019, 'Curitiba', 'Francisco Boscardin', 'Cascatinha', '82020-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14020, 'Castro', 'Francisco Botogoski', 'Morada do Sol', '84172-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14021, 'Curitiba', 'Francisco Bozza', 'Pilarzinho', '82120-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14022, 'Guarapuava', 'Francisco Braga', 'Conradinho', '85055-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14023, 'Foz do Iguaçu', 'Francisco Braga', 'Parque Residencial Três Bandeiras', '85862-266', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14024, 'Ponta Grossa', 'Francisco Braga', 'Jardim Carvalho', '84016-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14025, 'Curitiba', 'Francisco Braga', 'Guabirotuba', '81510-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14026, 'Curitiba', 'Francisco Braz Bertagnoli Júnior', 'Cidade Industrial', '81260-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14027, 'Guarapuava', 'Francisco Brochado da Rocha', 'Vila Carli', '85040-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14028, 'Pato Branco', 'Francisco Brochado da Rocha', 'Industrial', '85506-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14029, 'Foz do Iguaçu', 'Francisco Buba', 'Jardim Santa Rita', '85862-297', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14030, 'Curitiba', 'Francisco Bugalski Filho', 'Tatuquara', '81480-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14031, 'Maringá', 'Francisco Bulla', 'Jardim Liberdade', '87047-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14032, 'Londrina', 'Francisco Burali', 'Conjunto Habitacional Saltinho', '86042-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14033, 'Colombo', 'Francisco Busato', 'Centro', '83414-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14034, 'Almirante Tamandaré', 'Francisco Buzato', 'Planta Mosacal', '83513-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14035, 'Paranaguá', 'Francisco Cabral', 'Divinéia', '83212-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14036, 'Colombo', 'Francisco Caetano Coradin', 'Roseira', '83411-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14037, 'Colombo', 'Francisco Camargo', 'Centro', '83414-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14038, 'Ponta Grossa', 'Francisco Camerino', 'Orfãs', '84070-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14039, 'Ponta Grossa', 'Francisco Camerino', 'Orfãs', '84015-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14040, 'Almirante Tamandaré', 'Francisco Cardoso', 'Vila Palmira', '83514-265', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14041, 'Ponta Grossa', 'Francisco Carlos Voitexem Kalinoski', 'Contorno', '84060-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14042, 'Guarapuava', 'Francisco Carneiro Martins', 'Vila Carli', '85040-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14043, 'Curitiba', 'Francisco Caron', 'Pilarzinho', '82120-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14044, 'Londrina', 'Francisco Carvalho', 'Esperança', '86046-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14045, 'São José dos Pinhais', 'Francisco Carvalho de Lima', 'Braga', '83020-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14046, 'Curitiba', 'Francisco Carvalho de Oliveira', 'Santa Quitéria', '80310-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14047, 'Curitiba', 'Francisco Cascardo', 'Uberaba', '81540-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14048, 'Londrina', 'Francisco Cassapua', 'Estados', '86083-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14049, 'Francisco Beltrão', 'Francisco Cassiano', 'Jardim Novo Mundo', '85602-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14050, 'São José dos Pinhais', 'Francisco Cassiano de Miranda', 'Três Marias', '83030-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14051, 'Curitiba', 'Francisco Castelano', 'Jardim das Américas', '81540-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14052, 'Curitiba', 'Francisco Castilho Filho', 'Xaxim', '81720-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14053, 'Castro', 'Francisco Cavalin', 'Núcleo Habitacional Padre Piva', '84178-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14054, 'Curitiba', 'Francisco Cavalli da Costa', 'Pinheirinho', '81825-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14055, 'Londrina', 'Francisco Cazarim', 'Eucaliptos', '86031-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14056, 'Curitiba', 'Francisco Ceccon', 'Alto Boqueirão', '81770-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14057, 'Ponta Grossa', 'Francisco Celso Baptista Rosas', 'Jardim Carvalho', '84015-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14058, 'Curitiba', 'Francisco Cezar de Lima', 'Santa Felicidade', '82015-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14059, 'Piraquara', 'Francisco Chaunne', 'Vila Juliana', '83306-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14060, 'Campo Largo', 'Francisco Chemin', 'Centro', '83601-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14061, 'Londrina', 'Francisco Claret de Rezende', 'Alto da Boa Vista', '86083-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14062, 'Curitiba', 'Francisco Claudino Ferreira', 'Pinheirinho', '81825-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14063, 'Curitiba', 'Francisco Claudino Ferreira', 'Sítio Cercado', '81900-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14064, 'Apucarana', 'Francisco Coelho Vilela', 'Parque Residencial Milani', '86811-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14065, 'Paranaguá', 'Francisco Cominese', 'Santos Dumont', '83209-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14066, 'Curitiba', 'Francisco Comparin', 'São Braz', '82320-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14067, 'Francisco Beltrão', 'Francisco Comunello', 'Pinheirinho', '85606-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14068, 'Guarapuava', 'Francisco Contini', 'Industrial Xarquinho', '85053-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14069, 'Maringá', 'Francisco Corrêa de Campos', 'Vila Santo Antônio', '87030-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14070, 'Apucarana', 'Francisco Correia Assis', 'Vila Santa Terezinha', '86802-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14071, 'Piraquara', 'Francisco Correia Soares', 'Vila Izabel', '83305-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14072, 'Curitiba', 'Francisco Costa', 'Pilarzinho', '82100-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14073, 'Maringá', 'Francisco Cruz Martins', 'Conjunto Residencial Ney Braga', '87075-180', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14074, 'Araucária', 'Francisco da Costa Pina', 'Thomaz Coelho', '83707-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14075, 'Paranaguá', 'Francisco da Gama e Silva', 'Alvorada', '83206-096', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14076, 'Colombo', 'Francisco d''Agostin', 'Jardim Monza', '83406-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14077, 'Curitiba', 'Francisco Dallalibera', 'Santa Felicidade', '82030-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14078, 'Curitiba', 'Francisco Dallalibera', 'Santa Felicidade', '82410-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14079, 'São José dos Pinhais', 'Francisco Dal''Negro', 'Colônia Rio Grande', '83025-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14080, 'Curitiba', 'Francisco das Chagas Lopes', 'Boa Vista', '82650-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14081, 'Sarandi', 'Francisco de Almeida', 'Jardim Verão', '87111-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14082, 'Guarapuava', 'Francisco de Assis', 'Boqueirão', '85022-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14083, 'Piraquara', 'Francisco de Assis', 'Jardim Santa Mônica', '83302-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14084, 'Umuarama', 'Francisco de Assis', 'Zona V', '87504-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14085, 'Castro', 'Francisco de Assis Andrade', 'Vila Rio Branco', '84172-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14086, 'Curitiba', 'Francisco de Assis Celestino da Silva', 'Santa Felicidade', '82015-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14087, 'Londrina', 'Francisco de Assis Evangelista', 'Parigot de Souza 2', '86082-295', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14088, 'Londrina', 'Francisco de Assis F. Ruiz', 'Luiz de Sá', '86086-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14089, 'Curitiba', 'Francisco de Assis Ferreira', 'Cidade Industrial', '81460-228', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14090, 'Piraquara', 'Francisco de Assis Ricardo', 'Planta Jardim Tarumã', '83310-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14091, 'Campo Largo', 'Francisco de Azevedo Macedo', 'Vila Solene', '83607-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14092, 'Curitiba', 'Francisco de Bastos', 'Pinheirinho', '81880-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14093, 'Curitiba', 'Francisco de Camargo Pinto', 'Capão Raso', '81130-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14094, 'Curitiba', 'Francisco de Camargo Pinto', 'Capão Raso', '81150-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14095, 'Guarapuava', 'Francisco de Camargo Ribas', 'Dos Estados', '85035-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14096, 'Curitiba', 'Francisco de Freitas Saldanha', 'Boa Vista', '82560-350', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14097, 'Londrina', 'Francisco de Góes', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14098, 'Almirante Tamandaré', 'Francisco de Lara Vaz', 'Morro Azul', '83513-167', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14099, 'Londrina', 'Francisco de Melo Palheta', 'Conjunto Café', '86081-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14100, 'Apucarana', 'Francisco de Mesquita Gomes', 'Núcleo Habitacional Marcos Freire', '86805-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14101, 'Londrina', 'Francisco de Oliveira', 'Jardim dos Alpes I', '86075-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14102, 'Londrina', 'Francisco de Oliveira Leme', 'Conjunto Habitacional José Giordano', '86082-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14103, 'Cascavel', 'Francisco de Paula Alves', 'Presidente', '85818-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14104, 'Curitiba', 'Francisco de Paula Guimarães', 'Ahú', '80540-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14105, 'São José dos Pinhais', 'Francisco de Paula Lobo Araújo', 'Cidade Jardim', '83035-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14106, 'Araucária', 'Francisco de Paula Santos', 'Cachoeira', '83701-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14107, 'Curitiba', 'Francisco de Paula Sobrinho', 'Cajuru', '82970-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14108, 'Foz do Iguaçu', 'Francisco de Sá', 'Jardim Curitibano I', '85869-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14109, 'Piraquara', 'Francisco de Souza', 'Centro', '83301-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14110, 'Curitiba', 'Francisco de Souza Neto', 'Portão', '81070-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14111, 'Apucarana', 'Francisco Delgado', 'Jardim Pinheiros', '86803-386', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14112, 'Cambé', 'Francisco Delgado Sanches', 'Jardim Vitória', '86182-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14113, 'Guarapuava', 'Francisco Demario', 'Vila Bela', '85027-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14114, 'Curitiba', 'Francisco Derosso', 'Alto Boqueirão', '81770-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14115, 'Curitiba', 'Francisco Derosso', 'Xaxim', '81710-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14116, 'Curitiba', 'Francisco Derosso', 'Xaxim', '81720-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14117, 'Londrina', 'Francisco Dias Grillo Neto', 'Conjunto Habitacional Saltinho', '86042-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14118, 'São José dos Pinhais', 'Francisco Dirceu Chiuratto', 'Planta Quississana', '83085-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14119, 'Araucária', 'Francisco do Vale Joslin', 'Costeira', '83709-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14120, 'Curitiba', 'Francisco Domakoski', 'Campo Comprido', '81200-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14121, 'Curitiba', 'Francisco Domingos Juglair', 'Cidade Industrial', '81315-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14122, 'Londrina', 'Francisco Donato', 'Conjunto Professora Hilda Mandarino', '86080-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14123, 'Curitiba', 'Francisco dos Santos Lima', 'Santo Inácio', '82010-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14124, 'Araucária', 'Francisco Dranka', 'Porto das Laranjeiras', '83703-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14125, 'Curitiba', 'Francisco Dressler', 'Uberaba', '81550-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14126, 'Araucária', 'Francisco Drewniak', 'Costeira', '83708-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14127, 'Curitiba', 'Francisco Dubiella', 'Abranches', '82220-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14128, 'Colombo', 'Francisco Dugonski', 'Jardim Guarujá', '83407-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14129, 'Curitiba', 'Francisco Dzikowicz', 'Pinheirinho', '81870-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14130, 'Maringá', 'Francisco Eduardo Mira Gomes', 'Conjunto Residencial Cidade Alta', '87053-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14131, 'Telêmaco Borba', 'Francisco Espinosa', 'Núcleo Bandeirantes', '84269-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14132, 'São José dos Pinhais', 'Francisco Euclides do Nascimento', 'Afonso Pena', '83040-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14133, 'Pinhais', 'Francisco Eugênio Gomes Pereira', 'Jardim Atuba I', '83326-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14134, 'Toledo', 'Francisco Fath', 'Sachini', '85903-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14135, 'Curitiba', 'Francisco Favaro', 'Santa Cândida', '82650-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14136, 'São José dos Pinhais', 'Francisco Favoretto', 'Bom Jesus', '83025-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14137, 'Curitiba', 'Francisco Fay Neves', 'Santa Felicidade', '82410-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14138, 'Londrina', 'Francisco Feijó Sanches', 'Petrópolis', '86015-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14139, 'Sarandi', 'Francisco Fernandes Cara', 'Parque Alvamar', '87113-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14140, 'Londrina', 'Francisco Ferreira', 'Jardim dos Alpes III', '86045-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14141, 'Ponta Grossa', 'Francisco Ferreira', 'Boa Vista', '84073-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14142, 'Campo Mourão', 'Francisco Ferreira Albuquerque', 'Centro', '87301-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14143, 'Campo Mourão', 'Francisco Ferreira Albuquerque', 'Jardim P Campo', '87302-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14144, 'Campo Mourão', 'Francisco Ferreira Albuquerque', 'Jardim Laura', '87300-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14145, 'Maringá', 'Francisco Ferreira de Miranda', 'Zona 38', '87055-015', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14146, 'Curitiba', 'Francisco Ferreira Filho', 'Umbará', '81930-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14147, 'São José dos Pinhais', 'Francisco Ferreira Machado', 'Boneca do Iguaçu', '83040-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14148, 'Telêmaco Borba', 'Francisco Ferreira Prestes', 'Vila Ozorio', '84268-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14149, 'Toledo', 'Francisco Ferrer', 'Parque Residencial Pancera', '85902-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14150, 'Curitiba', 'Francisco Fido Fontana', 'Cidade Industrial', '81170-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14151, 'Toledo', 'Francisco Finler', 'Conjunto Habitacional São Francisco', '85915-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14152, 'Curitiba', 'Francisco Fiorillo', 'Campo Comprido', '81220-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14153, 'Foz do Iguaçu', 'Francisco Fogaça do Nascimento', 'Loteamento Mata Verde', '85853-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14154, 'Londrina', 'Francisco Fontes', 'Gleba Lindóia', '86031-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14155, 'Ponta Grossa', 'Francisco Francisquini', 'Oficinas', '84045-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14156, 'Curitiba', 'Francisco Frederico Leone', 'Cidade Industrial', '81450-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14157, 'Laranjeiras do Sul', 'Francisco Freitas', 'São Francisco', '85303-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14158, 'Curitiba', 'Francisco Frischmann', 'Portão', '80320-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14159, 'Curitiba', 'Francisco Fruet', 'Novo Mundo', '81050-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14160, 'Curitiba', 'Francisco Gabardo Filho', 'Umbará', '81940-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14161, 'Londrina', 'Francisco Gabriel Arruda', 'Conjunto Parigot de Souza 1', '86081-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14162, 'Londrina', 'Francisco Gabriel Couto', 'Lago Juliana', '86038-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14163, 'Pato Branco', 'Francisco Gabriel Neto', 'Baixada', '85505-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14164, 'Araucária', 'Francisco Galarda', 'Thomaz Coelho', '83706-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14165, 'Ponta Grossa', 'Francisco Galvão', 'Chapada', '84062-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14166, 'Apucarana', 'Francisco Garcia', 'Jardim Residencial Garcia', '86807-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14167, 'Londrina', 'Francisco Garcia de Campos', 'Conjunto Habitacional Champagnat', '86086-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14168, 'São José dos Pinhais', 'Francisco Geremias', 'Guatupê', '83060-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14169, 'Maringá', 'Francisco Glicério', 'Zona 07', '87030-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14170, 'Londrina', 'Francisco Goiabara Parra', 'Jardim Paraná', '86026-525', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14171, 'Paranavaí', 'Francisco Gomes de Lima', 'Jardim São Jorge', '87711-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14172, 'Araucária', 'Francisco Gondek', 'Estação', '83705-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14173, 'Curitiba', 'Francisco Gonzales Villanueva', 'Tarumã', '82530-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14174, 'Pato Branco', 'Francisco Gross', 'Pinheirinho', '85506-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14175, 'Foz do Iguaçu', 'Francisco Guaraná de Menezes', 'Vila Yolanda', '85853-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14176, 'Cascavel', 'Francisco Guaraná de Menezes', '14 de Novembro', '85804-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14177, 'Curitiba', 'Francisco Guilherme Bahr', 'Tingui', '82620-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14178, 'Ponta Grossa', 'Francisco Guilhermino', 'Jardim Carvalho', '84016-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14179, 'Curitiba', 'Francisco Gulin', 'Santa Felicidade', '82410-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14180, 'Curitiba', 'Francisco Habinovski', 'Capão Raso', '81110-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14181, 'Maringá', 'Francisco Helebland', 'Vila Esperança', '87030-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14182, 'Curitiba', 'Francisco Hernandes Bastida', 'São João', '82030-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14183, 'Londrina', 'Francisco Hernandes Leiva', 'Alto da Boa Vista', '86083-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14184, 'Cascavel', 'Francisco Ignacio Fernandes', 'Cataratas', '85818-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14185, 'Umuarama', 'Francisco Inácio Lira', 'Jardim San Martim', '87508-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14186, 'Paranavaí', 'Francisco Isidoro de Oliveira', 'Jardim Maringá', '87709-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14187, 'Curitiba', 'Francisco Jacob Zardo', 'Sítio Cercado', '81920-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14188, 'Araucária', 'Francisco Jess', 'Cachoeira', '83701-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14189, 'Paranaguá', 'Francisco Joaquim da Silva', 'Parque São João', '83212-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14190, 'Curitiba', 'Francisco José Bozza', 'Tatuquara', '81480-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14191, 'Piraquara', 'Francisco José de Souza', 'Vila São Cristóvão', '83305-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14192, 'Londrina', 'Francisco José Ferreira', 'Yara', '86087-540', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14193, 'Curitiba', 'Francisco José Gomes Ribeiro', 'Santo Inácio', '82010-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14194, 'Curitiba', 'Francisco José Lobo', 'Sítio Cercado', '81900-747', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14195, 'Curitiba', 'Francisco José Martin', 'Uberaba', '81580-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14196, 'Londrina', 'Francisco José Vidal', 'Jardim Paris', '86082-077', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14197, 'Curitiba', 'Francisco Juglair', 'Mossunguê', '81200-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14198, 'Araucária', 'Francisco Kampa', 'Cachoeira', '83701-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14199, 'Colombo', 'Francisco Kania', 'Vila Vale Verde', '83406-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14200, 'Telêmaco Borba', 'Francisco Kasek Pucci', 'Centro', '84261-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14201, 'Francisco Beltrão', 'Francisco Katto', 'Jardim Novo Mundo', '85602-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14202, 'São José dos Pinhais', 'Francisco Killian', 'Centro', '83005-320', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14203, 'Curitiba', 'Francisco Kleichevicz', 'Orleans', '82300-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14204, 'Curitiba', 'Francisco Klemtz', 'Portão', '80330-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14205, 'Curitiba', 'Francisco Klos', 'Boa Vista', '82560-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14206, 'Ponta Grossa', 'Francisco Kmita', 'Uvaranas', '84031-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14207, 'Araucária', 'Francisco Knopik', 'Thomaz Coelho', '83706-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14208, 'Curitiba', 'Francisco Kochinski', 'Sítio Cercado', '81920-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14209, 'Curitiba', 'Francisco Konfidera', 'Uberaba', '81590-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14210, 'Curitiba', 'Francisco Krainski', 'São Lourenço', '82210-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14211, 'Almirante Tamandaré', 'Francisco Krüger', 'Vila Formosa', '83504-490', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14212, 'Curitiba', 'Francisco Lachowski', 'Campina do Siqueira', '80730-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14213, 'Piraquara', 'Francisco Leal', 'Centro', '83301-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14214, 'Piraquara', 'Francisco Leal', 'Vila São Cristóvão', '83305-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14215, 'Curitiba', 'Francisco Leal', 'Bacacheri', '82520-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14216, 'Apucarana', 'Francisco Leandro de Mello', 'Residencial Parque da Raposa', '86812-588', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14217, 'Curitiba', 'Francisco Licnerski', 'Uberaba', '81590-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14218, 'Curitiba', 'Francisco Lipka', 'Mossunguê', '81200-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14219, 'Londrina', 'Francisco Lirola Sobrinho', 'Barbeta', '86078-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14220, 'Curitiba', 'Francisco Lopes de Oliveira', 'Cajuru', '82960-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14221, 'Cambé', 'Francisco Lopes Hernandes', 'Parque Residencial Ana Rosa', '86183-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14222, 'Pinhais', 'Francisco Lourenço', 'Jardim Triângulo', '83331-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14223, 'Curitiba', 'Francisco Lourenço Johnscher', 'Boqueirão', '81750-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14224, 'Londrina', 'Francisco Lucas Lopes', 'Assis', '86085-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14225, 'Colombo', 'Francisco Luzia de Jesus', 'Jardim Maria José', '83403-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14226, 'Curitiba', 'Francisco M. Albizu', 'Bacacheri', '82600-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14227, 'Paranaguá', 'Francisco Machado', 'Vila Guadalupe', '83221-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14228, 'Curitiba', 'Francisco Machado', 'Campina do Siqueira', '80740-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14229, 'Maringá', 'Francisco Machado Homem Júnior', 'Vila Esperança', '87020-655', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14230, 'Curitiba', 'Francisco Manfron', 'Santa Felicidade', '82020-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14231, 'Colombo', 'Francisco Manika', 'Vila Santa Maria', '83402-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14232, 'Ponta Grossa', 'Francisco Manoel da Silva', 'Uvaranas', '84020-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14233, 'Curitiba', 'Francisco Maravalhas', 'Jardim das Américas', '81540-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14234, 'Londrina', 'Francisco Marcelino da Silva', 'Jardim Itatiaia 2', '86047-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14235, 'Cascavel', 'Francisco Marchewicz', 'Cataratas', '85818-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14236, 'Maringá', 'Francisco Marin', 'Conjunto Habitacional Requião', '87047-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14237, 'Campo Largo', 'Francisco Marochi', 'Loteamento Itaboa', '83605-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14238, 'Curitiba', 'Francisco Marochi', 'Boa Vista', '82650-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14239, 'Londrina', 'Francisco Marques de Oliveira', 'João Paz', '86087-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14240, 'Apucarana', 'Francisco Martinez Zurano', 'Loteamento Jardim Gramados', '86801-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14241, 'Ponta Grossa', 'Francisco Martins de Araújo', 'Jardim Carvalho', '84016-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14242, 'Maringá', 'Francisco Matarazzo', 'Jardim Alvorada', '87035-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14243, 'Ponta Grossa', 'Francisco Matheus da Silva', 'Oficinas', '84035-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14244, 'Curitiba', 'Francisco Matzeck', 'Santa Felicidade', '82015-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14245, 'Curitiba', 'Francisco May', 'Vista Alegre', '80820-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14246, 'Guarapuava', 'Francisco Meira Martins', 'São Cristóvão', '85063-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14247, 'Londrina', 'Francisco Meleira Lopes', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14248, 'Guarapuava', 'Francisco Mendes', 'Conradinho', '85055-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14249, 'Londrina', 'Francisco Mendes', 'Alto da Boa Vista', '86083-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14250, 'Curitiba', 'Francisco Mendes', 'Santo Inácio', '82010-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14251, 'Londrina', 'Francisco Merighe', 'Bourbon', '86046-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14252, 'Londrina', 'Francisco Merlos', 'Jardim Primavera', '86086-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14253, 'Curitiba', 'Francisco Mildemberg', 'Cidade Industrial', '81350-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14254, 'Colombo', 'Francisco Milek', 'Jardim São Marcos', '83402-396', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14255, 'Castro', 'Francisco Miroslau de Macedo', 'Vila Farias', '84178-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14256, 'Guarapuava', 'Francisco Missino', 'Vila Bela', '85027-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14257, 'Curitiba', 'Francisco Monteiro Painhas', 'Sítio Cercado', '81900-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14258, 'Guarapuava', 'Francisco Moreira', 'Boqueirão', '85020-707', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14259, 'Araucária', 'Francisco Moreira Paes', 'Campina da Barra', '83709-846', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14260, 'Curitiba', 'Francisco Morilha', 'Boqueirão', '81770-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14261, 'Curitiba', 'Francisco Moro', 'Portão', '81070-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14262, 'Curitiba', 'Francisco Mota Machado', 'Capão da Imbuia', '82810-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14263, 'Curitiba', 'Francisco Mota Machado', 'Capão da Imbuia', '82800-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14264, 'Colombo', 'Francisco Motim Neto', 'Cercadinho', '83415-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14265, 'Curitiba', 'Francisco Nadolny', 'Campina do Siqueira', '80740-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14266, 'Curitiba', 'Francisco Negrão', 'Água Verde', '80620-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14267, 'Londrina', 'Francisco Neto Pires', 'Conjunto Habitacional Saltinho', '86042-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14268, 'Castro', 'Francisco Nitzke', 'Jardim Social Arapongas', '84174-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14269, 'Colombo', 'Francisco Nodari', 'Planta Nodari', '83414-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14270, 'Curitiba', 'Francisco Novicki', 'Sítio Cercado', '81880-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14271, 'Curitiba', 'Francisco Nowotarski', 'Fazendinha', '81320-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14272, 'Curitiba', 'Francisco Nunes', 'Rebouças', '80215-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14273, 'Colombo', 'Francisco Ogibowski', 'Jardim dos Eucaliptos', '83408-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14274, 'Cascavel', 'Francisco Oliva', 'Nova Cidade', '85803-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14275, 'São José dos Pinhais', 'Francisco Onofrio Claudino', 'Afonso Pena', '83050-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14276, 'Araucária', 'Francisco Orlikoski', 'Thomaz Coelho', '83707-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14277, 'Londrina', 'Francisco Ortega Moreno', 'Luiz de Sá', '86085-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14278, 'Ponta Grossa', 'Francisco Otaviano', 'Nova Rússia', '84070-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14279, 'Ponta Grossa', 'Francisco Otaviano', 'Nova Rússia', '84071-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14280, 'Curitiba', 'Francisco Otto', 'Boa Vista', '82650-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14281, 'Guarapuava', 'Francisco Pacheco', 'Bonsucesso', '85055-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14282, 'Telêmaco Borba', 'Francisco Pacher', 'Vila Ozorio', '84268-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14283, 'Foz do Iguaçu', 'Francisco Padilha', 'Jardim São Paulo II', '85856-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14284, 'Curitiba', 'Francisco Paganelli', 'São Braz', '82015-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14285, 'Curitiba', 'Francisco Parise', 'Santa Felicidade', '82015-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14286, 'Curitiba', 'Francisco Parolin', 'Parolin', '80220-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14287, 'Cambé', 'Francisco Parra Murilas', 'Vila Mesquita', '86182-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14288, 'Foz do Iguaçu', 'Francisco Paulino de Brito', 'Jardim N Horizonte', '85855-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14289, 'Londrina', 'Francisco Paulino de Freitas', 'Antônio M Nogueira Cafezal 4', '86089-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14290, 'Londrina', 'Francisco Paulo de Mello', 'Jardim Belo Horizonte', '86037-299', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14291, 'Colombo', 'Francisco Pavin', 'Jardim Las Palmas', '83409-157', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14292, 'Ponta Grossa', 'Francisco Peixoto', 'Jardim Carvalho', '84016-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14293, 'Piraquara', 'Francisco Pereira', 'Vila Izabel', '83305-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14294, 'Guarapuava', 'Francisco Pereira da Rocha', 'Jardim das Américas', '85030-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14295, 'Londrina', 'Francisco Pereira de Almeida Júnior', 'Portal de Versalhes 3', '86055-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14296, 'Ponta Grossa', 'Francisco Pereira de Barros', 'Estrela', '84050-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14297, 'São José dos Pinhais', 'Francisco Pereira Guimarães', 'São Sebastião', '83075-467', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14298, 'Curitiba', 'Francisco Pereira Mesquita', 'Cidade Industrial', '81315-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14299, 'Castro', 'Francisco Pianowski', 'Jardim das Nações', '84172-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14300, 'Ponta Grossa', 'Francisco Picot', 'Boa Vista', '84073-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14301, 'Ponta Grossa', 'Francisco Picote', 'Uvaranas', '84032-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14302, 'Curitiba', 'Francisco Pilatti', 'Pilarzinho', '82115-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14303, 'Laranjeiras do Sul', 'Francisco Piomontes', 'São Francisco', '85303-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14304, 'Guarapuava', 'Francisco Pires da Rocha', 'Bonsucesso', '85045-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14305, 'Guarapuava', 'Francisco Pires da Rocha', 'Bonsucesso', '85055-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14306, 'Curitiba', 'Francisco Pirkiel', 'Portão', '80610-285', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14307, 'Curitiba', 'Francisco Plantes Cordeiro', 'Umbará', '81930-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14308, 'Umuarama', 'Francisco Pontes', 'Jardim Alto da Boa Vista', '87506-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14309, 'Campo Mourão', 'Francisco Preisner', 'Jardim Santa Cruz', '87309-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14310, 'Curitiba', 'Francisco Prestes Maia', 'Boa Vista', '82560-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14311, 'Londrina', 'Francisco Pulpor', 'Jardim Bandeirantes', '86065-395', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14312, 'Curitiba', 'Francisco Querino de Lima', 'São Braz', '82015-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14313, 'Londrina', 'Francisco Quessada Ortega', 'Avelino A Vieira', '86056-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14314, 'Curitiba', 'Francisco Raitani', 'Capão Raso', '81110-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14315, 'Araucária', 'Francisco Raksa Júnior', 'Costeira', '83709-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14316, 'Ponta Grossa', 'Francisco Ribas', 'Centro', '84010-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14317, 'Ponta Grossa', 'Francisco Ribas', 'Orfãs', '84015-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14318, 'Almirante Tamandaré', 'Francisco Ribeiro de Matos', 'Jardim Benfica', '83505-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14319, 'Piraquara', 'Francisco Ribeiro de Oliveira', 'Planta Granjas Eldorado', '83309-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14320, 'Piraquara', 'Francisco Ribeiro Júnior', 'Vila Fuck', '83305-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14321, 'Toledo', 'Francisco Rigo', 'Jardim Planalto', '85904-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14322, 'Ponta Grossa', 'Francisco Rizental', 'Boa Vista', '84073-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14323, 'Foz do Iguaçu', 'Francisco Rocha', 'Loteamento Lindóia', '85856-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14324, 'Curitiba', 'Francisco Rocha', 'Batel', '80420-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14325, 'Curitiba', 'Francisco Rocha', 'Bigorrilho', '80710-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14326, 'Curitiba', 'Francisco Rocha', 'Bigorrilho', '80730-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14327, 'Londrina', 'Francisco Rodrigues', 'Colúmbia', '86057-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14328, 'Pato Branco', 'Francisco Rodrigues', 'Cristo Rei', '85506-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14329, 'Foz do Iguaçu', 'Francisco Rodrigues Alves', 'Parque Presidente', '85863-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14330, 'Telêmaco Borba', 'Francisco Rodrigues Carvalho', 'Centro', '84262-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14331, 'Curitiba', 'Francisco Rodrigues de Castro', 'Jardim das Américas', '81520-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14332, 'Maringá', 'Francisco Rodrigues de Melo', 'Jardim Império do Sol', '87083-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14333, 'Umuarama', 'Francisco Rodrigues Júnior', 'Jardim Alphavile', '87504-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14334, 'Foz do Iguaçu', 'Francisco Rosa e Silva', 'Parque Presidente', '85863-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14335, 'Ponta Grossa', 'Francisco Rosas', 'Oficinas', '84040-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14336, 'Londrina', 'Francisco Rossi Filho', 'Jacutinga', '86087-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14337, 'Campo Mourão', 'Francisco Ruiz', 'Jardim Nossa Senhora Aparecida', '87309-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14338, 'Apucarana', 'Francisco Sacchelli', 'Jardim Catuaí III', '86802-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14339, 'Toledo', 'Francisco Saffanoff', 'Residencial Santa Clara', '85907-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14340, 'Londrina', 'Francisco Salton', 'Loteamento Terra Bonita', '86047-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14341, 'Curitiba', 'Francisco Santi', 'Mossunguê', '81200-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14342, 'Curitiba', 'Francisco Santiago Soares', 'Portão', '81320-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14343, 'Curitiba', 'Francisco Sarot', 'Tatuquara', '81480-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14344, 'Curitiba', 'Francisco Saturnino de Andrade', 'Sítio Cercado', '81920-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14345, 'Piraquara', 'Francisco Sbrissia', 'Vila São Cristóvão', '83305-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14346, 'Londrina', 'Francisco Scerbo', 'Barbeta', '86078-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14347, 'Curitiba', 'Francisco Schaffer', 'Vista Alegre', '80820-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14348, 'Cascavel', 'Francisco Schelle', 'Parque São Paulo', '85803-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14349, 'Piraquara', 'Francisco Schuartz', 'Planta Araçatuba', '83301-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14350, 'Curitiba', 'Francisco Scorssatto', 'Sítio Cercado', '81925-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14351, 'Curitiba', 'Francisco Scremin', 'Ahú', '80540-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14352, 'Maringá', 'Francisco Sebriam Madrid', 'Loteamento Madrid', '87053-515', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14353, 'Colombo', 'Francisco Sgoda', 'Jardim Santa Fé', '83403-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14354, 'Curitiba', 'Francisco Sielski', 'Cidade Industrial', '81230-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14355, 'Maringá', 'Francisco Silveira da Rocha', 'Vila Esperança', '87020-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14356, 'Sarandi', 'Francisco Silveira da Rocha', 'Parque Alvamar', '87113-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14357, 'Curitiba', 'Francisco Simas', 'Uberaba', '81570-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14358, 'Araucária', 'Francisco Skraba', 'Capela Velha', '83706-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14359, 'Curitiba', 'Francisco Skrock', 'Sítio Cercado', '81920-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14360, 'Piraquara', 'Francisco Soares de Souza', 'Planta Araçatuba', '83301-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14361, 'Curitiba', 'Francisco Sobania', 'Cidade Industrial', '81460-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14362, 'Colombo', 'Francisco Sopa', 'Jardim Valdívia', '83403-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14363, 'Francisco Beltrão', 'Francisco Souza', 'Cango', '85604-265', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14364, 'Colombo', 'Francisco Spichila', 'Jardim Osasco', '83403-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14365, 'Cascavel', 'Francisco Stancker', 'Santa Felicidade', '85803-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14366, 'Curitiba', 'Francisco Starzinski', 'Água Verde', '80620-170', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14367, 'Curitiba', 'Francisco Stobbia', 'Jardim Social', '82520-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14368, 'Curitiba', 'Francisco Strobach Filho', 'Tatuquara', '81470-306', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14369, 'Almirante Tamandaré', 'Francisco Subinski', 'Vila Prosdócimo', '83506-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14370, 'Curitiba', 'Francisco Szurek', 'Cidade Industrial', '81350-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14371, 'Colombo', 'Francisco Taner', 'Vila Rosemari Galvão', '83411-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14372, 'Castro', 'Francisco Telles', 'Vila do Rosário', '84168-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14373, 'Curitiba', 'Francisco Timóteo de Simas', 'Uberaba', '81570-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14374, 'Curitiba', 'Francisco Tissot', 'Portão', '81320-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14375, 'São José dos Pinhais', 'Francisco Toczek', 'Afonso Pena', '83045-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14376, 'Curitiba', 'Francisco Torres', 'Centro', '80060-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14377, 'Ponta Grossa', 'Francisco Traleski', 'Boa Vista', '84071-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14378, 'Ponta Grossa', 'Francisco Túlio', 'Colônia Dona Luiza', '84045-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14379, 'Foz do Iguaçu', 'Francisco Valentin Trindade', 'Jardim Esmeralda', '85852-370', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14380, 'Curitiba', 'Francisco Vasco Garcia', 'Cajuru', '82960-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14381, 'Cascavel', 'Francisco Vaz de Lima', 'Brasmadeira', '85813-187', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14382, 'Londrina', 'Francisco Verpa', 'Monte Carlo', '86040-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14383, 'Londrina', 'Francisco Vicente da Silveira', 'Jardim Nova Esperança', '86044-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14384, 'Paranavaí', 'Francisco Vieira Borges', 'Jardim América', '87705-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14385, 'Piraquara', 'Francisco Vieira de Araújo', 'Planta O Recanto', '83302-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14386, 'Londrina', 'Francisco Vítor da Silva', 'Conjunto Ernani Moura Lima 1', '86037-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14387, 'Colombo', 'Francisco Vitório d''Agostin', 'Jardim Osasco', '83403-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14388, 'Curitiba', 'Francisco Walesko', 'Cajuru', '82930-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14389, 'Colombo', 'Francisco Wanke', 'Jardim Maria José', '83403-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14390, 'Colombo', 'Francisco Wanke', 'Jardim Guaíra', '83402-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14391, 'Curitiba', 'Francisco Warcheski', 'Tatuquara', '81480-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14392, 'Araucária', 'Francisco Wengynski', 'Campina da Barra', '83709-758', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14393, 'Pato Branco', 'Francisco Xavier', 'Centro', '85505-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14394, 'Araucária', 'Francisco Xavier da Silva', 'Centro', '83702-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14395, 'Cambé', 'Francisco Xavier da Silva', 'Jardim Silvino', '86188-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14396, 'Castro', 'Francisco Xavier da Silva', 'Centro', '84165-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14397, 'Campo Largo', 'Francisco Xavier de Almeida Garret', 'Centro', '83601-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14398, 'Curitiba', 'Francisco Xavier de Oliveira', 'Tatuquara', '81480-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14399, 'Colombo', 'Francisco Xavier dos Santos', 'Jardim Florença', '83414-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14400, 'Ponta Grossa', 'Francisco Xavier Scharr', 'Olarias', '84026-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14401, 'Curitiba', 'Francisco Zandoná', 'Vila Izabel', '80240-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14402, 'Curitiba', 'Francisco Zanetti', 'Parolin', '81030-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14403, 'Curitiba', 'Francisco Zanicotti Sobrinho', 'Santa Cândida', '82640-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14404, 'São José dos Pinhais', 'Francisco Zem', 'Afonso Pena', '83045-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14405, 'Curitiba', 'Francisco Zem', 'Alto Boqueirão', '81720-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14406, 'Curitiba', 'Francisco Zuneda Ferreira da Costa', 'Bairro Alto', '82840-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14407, 'São José dos Pinhais', 'Franciszek Olencewicz', 'Ipê', '83060-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14408, 'Colombo', 'Franco', 'Centro', '83414-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14409, 'Foz do Iguaçu', 'Franco da Rocha', 'Jardim Cedro', '85862-354', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14410, 'Curitiba', 'Franco Giglio', 'Santa Cândida', '82640-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14411, 'Ponta Grossa', 'Franco Grilo', 'Colônia Dona Luiza', '84045-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14412, 'Foz do Iguaçu', 'Franco Velasco', 'Parque Residencial Três Bandeiras', '85862-259', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14413, 'São José dos Pinhais', 'François Voltaire', 'Aristocrata', '83030-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14414, 'Colombo', 'Franklin', 'Planta Santa Úrsula', '83405-610', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14415, 'Maringá', 'Franklin Delano Roosevelt', 'Jardim Alvorada', '87035-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14416, 'Maringá', 'Franklin Delano Roosevelt', 'Jardim São Francisco', '87043-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14417, 'Ponta Grossa', 'Franklin Dória', 'Uvaranas', '84030-667', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14418, 'Foz do Iguaçu', 'Franklin Sá Ribas', 'Parque Presidente', '85863-210', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14419, 'Curitiba', 'Franklin Soares Gomes', 'Uberaba', '81530-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14420, 'Ponta Grossa', 'Franklin Távora', 'Boa Vista', '84073-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14421, 'Londrina', 'Franklina Neves Ribas', 'Jardim Burle Marx', '86047-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14422, 'Apucarana', 'Franko', 'Vila Franko', '86802-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14423, 'Foz do Iguaçu', 'Frans Essich', 'Vila Adriana II', '85854-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14424, 'Apucarana', 'Fransquita Lozano Honorato', 'Parque Residencial Juanda', '86812-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14425, 'Londrina', 'Franz Hesselman', 'São Pedro', '86036-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14426, 'Curitiba', 'Franz Hiebert', 'Xaxim', '81670-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14427, 'Curitiba', 'Franz Joséf Hoch', 'Bacacheri', '82510-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14428, 'Campo Mourão', 'Franz Kaizer', 'Jardim Copacabana', '87302-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14429, 'Curitiba', 'Franz Kroeker', 'Xaxim', '81830-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14430, 'Foz do Iguaçu', 'Franz Roth', 'Loteamento Roth', '85852-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14431, 'Ponta Grossa', 'Franz V. Werfel', 'Cará-cará', '84043-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14432, 'Londrina', 'Franz Wallenoffer', 'Heimtal', '86084-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14433, 'Curitiba', 'Frederic Chopin', 'Vista Alegre', '80820-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14434, 'Maringá', 'Frederich Banting', 'Jardim Alvorada', '87035-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14435, 'Curitiba', 'Fredericindo Mares de Souza', 'Jardim Social', '82520-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14436, 'Ponta Grossa', 'Frederico Bahls', 'Centro', '84010-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14437, 'Londrina', 'Frederico Balan', 'São Vicente', '86046-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14438, 'Curitiba', 'Frederico Barz', 'Santa Felicidade', '82020-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14439, 'Araucária', 'Frederico Basso', 'Centro', '83702-590', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14440, 'Foz do Iguaçu', 'Frederico Bernard Zillio', 'Parque Imperatriz', '85862-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14441, 'Curitiba', 'Frederico Cantarelli', 'Bigorrilho', '80710-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14442, 'Curitiba', 'Frederico Carlos Bobbins', 'Cidade Industrial', '81240-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14443, 'Curitiba', 'Frederico Carlos Toaldo', 'Butiatuvinha', '82320-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14444, 'Pato Branco', 'Frederico Chass', 'Pinheirinho', '85506-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14445, 'Ponta Grossa', 'Frederico Chemim', 'Cará-cará', '84043-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14446, 'Foz do Iguaçu', 'Frederico Chevallier', 'Novo Mundo', '85862-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14447, 'Ponta Grossa', 'Frederico Constante Degraf', 'Chapada', '84062-480', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14448, 'Colombo', 'Frederico d''Agostin', 'Jardim São Marcos', '83402-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14449, 'Curitiba', 'Frederico Dallabona', 'São Braz', '82320-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14450, 'Foz do Iguaçu', 'Frederico Engel', 'Vila Yolanda', '85853-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14451, 'Curitiba', 'Frederico Escorsin', 'São Braz', '82310-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14452, 'Curitiba', 'Frederico Faria de Oliveira', 'Centro', '80020-070', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14453, 'Curitiba', 'Frederico Félix Schiavon', 'Sítio Cercado', '81925-579', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14454, 'Colombo', 'Frederico Fronhols', 'Vila Yara', '83408-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14455, 'Curitiba', 'Frederico Galvão', 'Bacacheri', '82520-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14456, 'Ponta Grossa', 'Frederico Garcia Lorca', 'Contorno', '84043-629', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14457, 'Curitiba', 'Frederico Guilherme Virmond', 'Pilarzinho', '82120-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14458, 'Almirante Tamandaré', 'Frederico Gulin', 'Parque Timbu', '83514-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14459, 'Curitiba', 'Frederico Hain', 'Pilarzinho', '82115-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14460, 'Ponta Grossa', 'Frederico Hilgemberg', 'Jardim Carvalho', '84015-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14461, 'Ponta Grossa', 'Frederico Justus Sobrinho', 'Jardim Carvalho', '84016-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14462, 'Curitiba', 'Frederico Kirchgassner', 'São Francisco', '80510-270', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14463, 'Ponta Grossa', 'Frederico Kruse', 'Jardim Carvalho', '84016-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14464, 'Campo Mourão', 'Frederico L. Sefrin', 'Jardim Joana D''Arc', '87300-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14465, 'Foz do Iguaçu', 'Frederico Lakus', 'Jardim Norma', '85869-619', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14466, 'Curitiba', 'Frederico Lambertucci', 'Fazendinha', '81330-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14467, 'Curitiba', 'Frederico Lampe', 'Xaxim', '81710-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14468, 'Ponta Grossa', 'Frederico Lima', 'Contorno', '84061-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14469, 'Curitiba', 'Frederico Maurer', 'Hauer', '81630-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14470, 'Curitiba', 'Frederico Maurer', 'Boqueirão', '81670-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14471, 'Curitiba', 'Frederico Müller', 'Campo Comprido', '81220-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14472, 'Curitiba', 'Frederico Muraro', 'Butiatuvinha', '82310-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14473, 'São José dos Pinhais', 'Frederico Negosek', 'Braga', '83020-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14474, 'Curitiba', 'Frederico Ozanam', 'Campina do Siqueira', '80710-330', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14475, 'Londrina', 'Frederico Ozanan', 'Sebastião de Melo César', '86084-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14476, 'Curitiba', 'Frederico Parize', 'São Braz', '82015-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14477, 'Curitiba', 'Frederico Peter', 'Pinheirinho', '81820-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14478, 'Almirante Tamandaré', 'Frederico Rose', 'Vila Rachel', '83501-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14479, 'Londrina', 'Frederico Schultheiss', 'Progresso', '86079-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14480, 'Pato Branco', 'Frederico Sguarizzi', 'Industrial', '85506-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14481, 'Cambé', 'Frederico Simoni', 'Jardim Planalto Verde', '86192-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14482, 'Curitiba', 'Frederico Stadler Júnior', 'Capão da Imbuia', '82810-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14483, 'Curitiba', 'Frederico Trevisan', 'Butiatuvinha', '82320-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14484, 'Paranavaí', 'Frederico Virmond', 'Jardim Santos Dumont', '87706-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14485, 'Curitiba', 'Frederico Virmond', 'Jardim das Américas', '81520-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14486, 'Londrina', 'Frederico Vivan', 'Jardim Neman Sahyun', '86041-406', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14487, 'Ponta Grossa', 'Frederico Wagner', 'Olarias', '84035-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14488, 'Foz do Iguaçu', 'Frederico Weirich', 'Vila Yolanda', '85853-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14489, 'Curitiba', 'Fredolin Wolf', 'Pilarzinho', '82115-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14490, 'Curitiba', 'Fredolin Wolf', 'Santa Felicidade', '82410-330', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14491, 'Almirante Tamandaré', 'Fredolin Wolf', 'Vila Tanguá', '83508-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14492, 'Almirante Tamandaré', 'Fredolin Wolf', 'Vila Santa Terezinha', '83501-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14493, 'Guarapuava', 'Fredolin Worn', 'Vila Bela', '85025-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14494, 'Cambé', 'Freguesia do O', 'Jardim Morumbi', '86191-766', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14495, 'Curitiba', 'Frei Antônio Sinibaldi', 'Cidade Industrial', '81250-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14496, 'São José dos Pinhais', 'Frei Basílio Roewer Ofm', 'Guatupê', '83065-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14497, 'Almirante Tamandaré', 'Frei Beda de Gavello', 'Vila Dolores', '83514-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14498, 'São José dos Pinhais', 'Frei Belino Maria Treviso', 'Boneca do Iguaçu', '83040-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14499, 'Curitiba', 'Frei Bernardino Tomat', 'Pilarzinho', '82115-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14500, 'Curitiba', 'Frei Bruno de Carli', 'Ganchinho', '81935-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14501, 'Guarapuava', 'Frei Caneca', 'Santana', '85070-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14502, 'Guarapuava', 'Frei Caneca', 'Trianon', '85012-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14503, 'Laranjeiras do Sul', 'Frei Caneca', 'Centro', '85301-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14504, 'Guarapuava', 'Frei Caneca', 'Santa Cruz', '85015-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14505, 'Paranavaí', 'Frei Caneca', 'Jardim São Jorge', '87710-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14506, 'Pato Branco', 'Frei Caneca', 'Menino Deus', '85502-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14507, 'Ponta Grossa', 'Frei Caneca', 'Centro', '84010-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14508, 'Maringá', 'Frei Caneca', 'Jardim Liberdade', '87047-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14509, 'Umuarama', 'Frei Caneca', 'Zona IV', '87504-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14510, 'Sarandi', 'Frei Caneca', 'Parque Residencial Nova Aliança', '87111-716', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14511, 'Cambé', 'Frei Caneca', 'Parque Residencial Manela', '86185-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14512, 'Almirante Tamandaré', 'Frei Caneca', 'Planta Nossa Senhora do Pilar', '83508-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14513, 'Curitiba', 'Frei Caneca', 'Centro', '80010-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14514, 'Toledo', 'Frei Celso Quisini', 'Jardim Porto Alegre', '85906-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14515, 'Curitiba', 'Frei Constantino Gozzo', 'Vista Alegre', '80820-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14516, 'Ponta Grossa', 'Frei Doroteu de Padua', 'Chapada', '84063-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14517, 'Pinhais', 'Frei Egídio Carlotto', 'Planta Estância Pinhais', '83323-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14518, 'Curitiba', 'Frei Egídio Carlotto', 'Cidade Industrial', '81270-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14519, 'Ponta Grossa', 'Frei Elias Zulian', 'Oficinas', '84045-590', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14520, 'Curitiba', 'Frei Eurico de Mello', 'Cidade Industrial', '81250-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14521, 'Curitiba', 'Frei Fabiano de Cristo', 'Jardim das Américas', '81530-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14522, 'Curitiba', 'Frei Fidélis Vering', 'Barreirinha', '82700-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14523, 'Curitiba', 'Frei Francisco Mont''Alverne', 'Jardim das Américas', '81540-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14524, 'Curitiba', 'Frei Francisco Sampaio', 'Jardim das Américas', '81530-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14525, 'Curitiba', 'Frei Gaspar Madre de Deus', 'Portão', '81070-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14526, 'Curitiba', 'Frei Gaspar Madre de Deus', 'Novo Mundo', '81050-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14527, 'Ponta Grossa', 'Frei Gaspar Zonta', 'Chapada', '84062-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14528, 'Londrina', 'Frei Henrique de Coimbra', 'Nossa Senhora do Desterro', '86025-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14529, 'Cascavel', 'Frei Henrique de Coimbra', 'Pioneiros Catarinenses', '85805-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14530, 'Curitiba', 'Frei Henrique de Coimbra', 'Hauer', '81610-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14531, 'Curitiba', 'Frei Henrique de Coimbra', 'Hauer', '81630-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14532, 'Ponta Grossa', 'Frei Jacinto de Butiatuba', 'Cará-cará', '84032-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14533, 'Almirante Tamandaré', 'Frei Jacinto Govaski', 'Jardim Santa Maria', '83511-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14534, 'Ponta Grossa', 'Frei José Thomaz', 'Ronda', '84050-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14535, 'Paranaguá', 'Frei José Thomaz', 'Porto dos Padres', '83221-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14536, 'Curitiba', 'Frei Junipero Serra', 'Seminário', '80440-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14537, 'Ponta Grossa', 'Frei Leandro do Sacramento', 'Ronda', '84050-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14538, 'Ponta Grossa', 'Frei Leandro do Sacramento', 'Ronda', '84051-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14539, 'Francisco Beltrão', 'Frei Leodato', 'Centro', '85601-620', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14540, 'Curitiba', 'Frei Lívio Panizza', 'Cidade Industrial', '81270-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14541, 'Curitiba', 'Frei Ludgero Kroessman', 'Cidade Industrial', '81460-179', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14542, 'Telêmaco Borba', 'Frei Luiz de Amitille', 'Jardim Adriane', '84272-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14543, 'Ponta Grossa', 'Frei Luiz de Paula', 'Oficinas', '84036-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14544, 'Ponta Grossa', 'Frei Luiz de Souza', 'Oficinas', '84036-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14545, 'Ponta Grossa', 'Frei Madre de Deus', 'Nova Rússia', '84053-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14546, 'Toledo', 'Frei Manoel', 'Boa Esperança', '85909-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14547, 'Almirante Tamandaré', 'Frei Mauro', 'Vila Santa Terezinha', '83501-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14548, 'Cascavel', 'Frei Maximiano Kolbe', 'Pioneiros Catarinenses', '85805-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14549, 'Curitiba', 'Frei Miguel Illario Bottacin', 'Novo Mundo', '81050-670', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14550, 'Piraquara', 'Frei Nicodemus Grundhoff', 'Jardim Esmeralda', '83301-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14551, 'Curitiba', 'Frei Nicodemus Grunhoff', 'Tingui', '82600-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14552, 'Toledo', 'Frei Orlando', 'Boa Esperança', '85909-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14553, 'Curitiba', 'Frei Orlando', 'Jardim Social', '82530-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14554, 'Curitiba', 'Frei Ricardo', 'Mercês', '80430-240', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14555, 'Curitiba', 'Frei Rogério', 'Jardim das Américas', '81530-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14556, 'Colombo', 'Frei Santa Rita Durão', 'Jardim das Perdizes', '83409-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14557, 'Curitiba', 'Frei Tarcísio Mastena', 'Santa Felicidade', '82320-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14558, 'Toledo', 'Frei Teófilo', 'Boa Esperança', '85909-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14559, 'Curitiba', 'Frei Teófilo', 'Capão Raso', '81130-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14560, 'Ponta Grossa', 'Frei Thiago Lucchese', 'Chapada', '84064-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14561, 'Guarapuava', 'Frei Tiago Luchese', 'Santana', '85070-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14562, 'Telêmaco Borba', 'Frei Timóteo', 'Vila Santa Rita', '84263-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14563, 'Telêmaco Borba', 'Frei Timóteo', 'Fazenda Limeira', '84272-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14564, 'Toledo', 'Frei Timóteo', 'Boa Esperança', '85909-096', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14565, 'Curitiba', 'Frei Timóteo', 'Mercês', '80410-010', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14566, 'Curitiba', 'Frei Valentin Hella', 'Vista Alegre', '82100-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14567, 'Ponta Grossa', 'Frei Veloso', 'Oficinas', '84035-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14568, 'Curitiba', 'Frei Vicente Salvador', 'Jardim das Américas', '81530-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14569, 'Ponta Grossa', 'Freire Alemão', 'Estrela', '84040-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14570, 'Ponta Grossa', 'Freud', 'Colônia Dona Luiza', '84045-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14571, 'Curitiba', 'Freyesleben', 'Bigorrilho', '80710-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14572, 'Londrina', 'Frida Bleinroth', 'Conjunto Santa Rita 6', '86072-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14573, 'Curitiba', 'Frida Oertel', 'Mercês', '80810-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14574, 'Campo Largo', 'Fridolin Huber', 'Vila Bancária', '83601-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14575, 'Toledo', 'Fridolino Tiel', 'Conjunto Habitacional São Francisco', '85912-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14576, 'São José dos Pinhais', 'Friedrich Nietzsche', 'Aristocrata', '83030-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14577, 'Campo Largo', 'Fritz Erwin Schmidt', 'Vila Itaqui', '83604-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14578, 'Piraquara', 'Fritz Haase', 'Planta Concórdia', '83314-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14579, 'Cascavel', 'Fronteira', 'Região do Lago', '85812-240', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14580, 'Londrina', 'Frontelmo Ferreira Coutinho', 'Conjunto Ernani Moura Lima 1', '86037-165', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14581, 'Foz do Iguaçu', 'Frutal', 'Jardim das Palmeiras II', '85869-708', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14582, 'Arapongas', 'Fruteiro', 'Parque Veneza', '86701-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14583, 'Londrina', 'Frutuoso da Costa Câmara', 'Jardim Vale Azul', '86041-845', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14584, 'Toledo', 'Frutuoso Pereira dos Santos', 'Coopagro', '85903-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14585, 'Arapongas', 'Fruxu', 'Jardim do Sol', '86705-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14586, 'Arapongas', 'Fruxu-de-coroa-dourada', 'Jardim São Bento', '86706-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14587, 'Curitiba', 'Fuad Madi', 'Butiatuvinha', '82400-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14588, 'Londrina', 'Fukutaro Kobayashi', 'Jardim Planalto', '86084-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14589, 'Londrina', 'Fulgêncio Ferreira Neves', 'Coliseu', '86076-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14590, 'Foz do Iguaçu', 'Fulgêncio Pereira', 'Vila Yolanda', '85853-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14591, 'Foz do Iguaçu', 'Fúlvio Gallo', 'Vila Borges', '85858-470', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14592, 'Curitiba', 'Fúlvio José Alice', 'Bairro Alto', '82820-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14593, 'Foz do Iguaçu', 'Funchal', 'Beverly Falls Park', '85858-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14594, 'Londrina', 'Funchal', 'Parque Residencial João Piza', '86041-060', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14595, 'Londrina', 'Funcionários', 'Nikko', '86047-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14596, 'Ponta Grossa', 'Furiel', 'Colônia Dona Luiza', '84046-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14597, 'Cascavel', 'Furnas', 'Universitário', '85819-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14598, 'Arapongas', 'Furriel', 'Jardim Coroados', '86706-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14599, 'Arapongas', 'Furriel-vermelho', 'Conjunto Flamingos III', '86703-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14600, 'Maringá', 'Furtado de Mendonça', 'Zona 03', '87050-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14601, 'Arapongas', 'Fuselo', 'Conjunto Ulisses Guimarães', '86706-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14602, 'Araucária', 'Fux', 'Campina da Barra', '83709-770', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14603, 'Foz do Iguaçu', 'G', 'Conjunto C', '85870-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14604, 'Ponta Grossa', 'G', 'Uvaranas', '84032-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14605, 'Ponta Grossa', 'G', 'Contorno', '84060-619', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14606, 'Ponta Grossa', 'G', 'Uvaranas', '84031-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14607, 'Umuarama', 'G', 'Núcleo Cruzeiro', '87509-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14608, 'Umuarama', 'G', 'Parque San Marino', '87509-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14609, 'Umuarama', 'G', 'Parque Dom Pedro I', '87508-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14610, 'Umuarama', 'G', 'Parque das Jaboticabeiras', '87509-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14611, 'Almirante Tamandaré', 'G', 'Parque Timbu', '83514-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14612, 'Campo Largo', 'G', 'Vila Torres I', '83609-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14613, 'Campo Largo', 'G', 'Jardim Tropical', '83602-067', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14614, 'Campo Largo', 'G', 'Popular Nova', '83602-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14615, 'Almirante Tamandaré', 'G', 'Loteamento Recanto dos Papagaios', '83512-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14616, 'Campo Largo', 'G', 'Jardim Três Rios', '83603-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14617, 'Almirante Tamandaré', 'G', 'Jardim Marrocos', '83511-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14618, 'Almirante Tamandaré', 'G', 'Jardim Rosana', '83502-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14619, 'Campo Mourão', 'G', 'Jardim Nossa Senhora Aparecida', '87309-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14620, 'Campo Mourão', 'G', 'Distrito Industrial I', '87306-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14621, 'Castro', 'G', 'Jardim Bela Vista', '84165-426', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14622, 'Castro', 'G', 'Vila do Rosário', '84168-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14623, 'Arapongas', 'G-1', 'Jardim Bandeirantes', '86703-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14624, 'Arapongas', 'G-2', 'Jardim Caravelle', '86701-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14625, 'Curitiba', 'Gabirobas', 'Uberaba', '81560-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14626, 'Francisco Beltrão', 'Gabriel Abdala', 'Água Branca', '85601-332', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14627, 'Curitiba', 'Gabriel Arns', 'Uberaba', '81570-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14628, 'Araucária', 'Gabriel Campanholo', 'Estação', '83705-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14629, 'Araucária', 'Gabriel Cantele', 'Estação', '83705-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14630, 'Londrina', 'Gabriel Cestari', 'Conjunto Parigot de Souza 3', '86081-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14631, 'Curitiba', 'Gabriel Corisco Domingues', 'Boqueirão', '81670-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14632, 'Colombo', 'Gabriel Danuncio Strapasson', 'Sapopema', '83414-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14633, 'Paranaguá', 'Gabriel de Lara', '29 de Julho', '83221-685', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14634, 'Paranaguá', 'Gabriel de Lara', 'João Gualberto', '83203-550', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14635, 'Cambé', 'Gabriel de Lara', 'Jardim Silvino', '86188-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14636, 'Curitiba', 'Gabriel de Lara', 'Batel', '80440-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14637, 'Londrina', 'Gabriel Delanne', 'Tamandaré', '86061-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14638, 'Toledo', 'Gabriel Dellane', 'Jardim Paraná', '85902-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14639, 'Paranavaí', 'Gabriel Esperidião', 'Parque Morumbi', '87703-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14640, 'Colombo', 'Gabriel Ferreira', 'Vila Maria do Rosário', '83413-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14641, 'Curitiba', 'Gabriel Frecceiro de Miranda', 'Xaxim', '81810-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14642, 'Cambé', 'Gabriel Freceiro de Miranda', 'Jardim Santo Amaro', '86185-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14643, 'Londrina', 'Gabriel Frederico de Miranda', 'Ok', '86040-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14644, 'Curitiba', 'Gabriel Joaquim', 'Santa Cândida', '82630-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14645, 'Londrina', 'Gabriel Martins', 'Centro', '86010-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14646, 'Curitiba', 'Gabriel Mocellin', 'Sítio Cercado', '81935-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14647, 'Curitiba', 'Gabriel Nunes Pires', 'Campina do Siqueira', '80740-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14648, 'Londrina', 'Gabriel Passos', 'Sebastião de Melo César', '86084-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14649, 'Colombo', 'Gabriel Pedo', 'Vila Luiz Baron', '83412-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14650, 'Curitiba', 'Gabriel Ribeiro', 'Sítio Cercado', '81925-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14651, 'Curitiba', 'Gabriel Rodrigues de Almeida', 'Atuba', '82860-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14652, 'Francisco Beltrão', 'Gabriel Schnabli', 'Padre Ulrico', '85604-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14653, 'Londrina', 'Gabriel Tanios Iasbik', 'Residencial Loris Sahyun', '86040-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14654, 'Maringá', 'Gabriel Tavares de Araújo', 'Conjunto Habitacional Requião', '87047-468', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14655, 'Curitiba', 'Gabriel Turek', 'Tingui', '82620-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14656, 'Curitiba', 'Gabriel Vicente dos Santos', 'Guabirotuba', '81510-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14657, 'Londrina', 'Gabriela Mistral', 'Brasília', '86039-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14658, 'Curitiba', 'Gabriela Mistral', 'Ahú', '80540-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14659, 'Londrina', 'Gago Coutinho', 'Caravelle', '86039-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14660, 'Curitiba', 'Gago Coutinho', 'Bacacheri', '82510-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14661, 'Arapongas', 'Gainambé', 'Jardim Colúmbia III', '86707-817', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14662, 'Curitiba', 'Gaipava', 'Pinheirinho', '81825-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14663, 'Francisco Beltrão', 'Gaivota', 'Miniguaçu', '85605-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14664, 'Ponta Grossa', 'Gaivota', 'Colônia Dona Luiza', '84046-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14665, 'Ponta Grossa', 'Gaivota', 'Chapada', '84064-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14666, 'Maringá', 'Gaivota', 'Jardim Olímpico', '87070-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14667, 'Umuarama', 'Gaivota', 'Jardim Alphavile', '87504-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14668, 'Cambé', 'Gaivota', 'Conjunto Habitacional Waldomiro M Gomes', '86182-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14669, 'Arapongas', 'Gaivota', 'Vila São João', '86708-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14670, 'Araucária', 'Gaivota', 'Estação', '83705-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14671, 'Arapongas', 'Gaivota-alegre', 'Jardim Primavera', '86702-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14672, 'Arapongas', 'Gaivotão', 'Jardim Aeroporto', '86702-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14673, 'Foz do Iguaçu', 'Gaivotas', 'Portal da Foz', '85859-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14674, 'Ponta Grossa', 'Gálatas', 'Chapada', '84064-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14675, 'Cambé', 'Gálatas', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14676, 'Sarandi', 'Galaxia', 'Jardim Universal', '87114-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14677, 'Maringá', 'Galáxia', 'Jardim Universo', '87060-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14678, 'Foz do Iguaçu', 'Galdino Agostini', 'Jardim Califórnia', '85867-487', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14679, 'Curitiba', 'Galdino Aleixo', 'Campo Comprido', '81200-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14680, 'Curitiba', 'Galdino Bueno de Camargo', 'Pinheirinho', '81150-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14681, 'Apucarana', 'Galdino Gluck Júnior', 'Centro', '86800-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14682, 'Curitiba', 'Galdino Machado', 'Campo de Santana', '81490-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14683, 'Foz do Iguaçu', 'Galdino Moro', 'Jardim Porto Belo', '85867-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14684, 'Curitiba', 'Galdino Ronconi', 'Cidade Industrial', '81260-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14685, 'Cascavel', 'Galeão', 'Santos Dumont', '85804-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14686, 'Cascavel', 'Galibis', 'Santo Onofre', '85806-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14687, 'Sarandi', 'Galileu', 'Jardim Universal', '87114-518', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14688, 'Telêmaco Borba', 'Galileu', 'Fazenda Limeira', '84270-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14689, 'Cascavel', 'Galileu', 'Interlagos', '85814-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14690, 'Londrina', 'Galileu Galilei', 'Industrial', '86063-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14691, 'Colombo', 'Galileu Galilei', 'Planta Maracanã', '83408-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14692, 'Curitiba', 'Galileu Galilei', 'Lindóia', '81010-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14693, 'Arapongas', 'Galinhola', 'Jardim Aeroporto', '86702-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14694, 'Arapongas', 'Galito', 'Jardim Bandeirantes', '86703-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14695, 'Arapongas', 'Galo-da-campina', 'Jardim Primavera', '86702-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14696, 'Arapongas', 'Galo-da-serra', 'Jardim Primavera', '86702-006', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14697, 'Campo Mourão', 'Galo-da-serra', 'Jardim Tropical II', '87310-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14698, 'Cascavel', 'Galo-da-serra', 'Floresta', '85814-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14699, 'Francisco Beltrão', 'Galvão', 'Marrecas', '85601-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14700, 'Foz do Iguaçu', 'Gama', 'Jardim Vasco da Gama', '85862-378', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14701, 'Ponta Grossa', 'Gama', 'Centro', '84010-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14702, 'Ponta Grossa', 'Gama', 'Oficinas', '84035-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14703, 'Curitiba', 'Gamaliel Bueno Galvão', 'Guaíra', '81010-036', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14704, 'Curitiba', 'Gamaliel Pereira de Carvalho', 'Cidade Industrial', '81250-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14705, 'Telêmaco Borba', 'Gâmbia', 'Área 01', '84272-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14706, 'Telêmaco Borba', 'Gameleira', 'Área 06', '84271-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14707, 'Pinhais', 'Gana', 'Vila Esplanada', '83320-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14708, 'Cascavel', 'Gandhi', 'Brasmadeira', '85814-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14709, 'Maringá', 'Garça', 'Jardim Olímpico', '87070-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14710, 'Ponta Grossa', 'Garça', 'Colônia Dona Luiza', '84043-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14711, 'Cambé', 'Garça', 'Conjunto Habitacional Waldomiro M Gomes', '86182-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14712, 'Araucária', 'Garça', 'Capela Velha', '83706-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14713, 'Arapongas', 'Garça-azul', 'Jardim Cultura', '86707-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14714, 'Arapongas', 'Garça-branca', 'Conjunto Del Condor', '86703-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14715, 'Arapongas', 'Garça-cinza', 'Jardim São Carlos', '86704-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14716, 'Londrina', 'Garça-real', 'Conjunto Habitacional Violim', '86084-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14717, 'Arapongas', 'Garça-real', 'Conjunto Centauro', '86709-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14718, 'Foz do Iguaçu', 'Garças', 'Portal da Foz', '85859-668', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14719, 'Laranjeiras do Sul', 'Garças', 'Vila Industrial', '85303-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14720, 'Arapongas', 'Garças', 'Centro', '86701-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14721, 'Arapongas', 'Garças', 'Jardim Eldorado', '86708-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14722, 'Arapongas', 'Garça-vermelha', 'Conjunto Padre Chico', '86707-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14723, 'Ponta Grossa', 'Garcia Redondo', 'Uvaranas', '84020-570', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14724, 'Telêmaco Borba', 'Garcia Rodrigues Paes', 'Núcleo Bandeirantes', '84269-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14725, 'Cambé', 'Garcia Rodrigues Paes', 'Jardim Riviera', '86187-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14726, 'Piraquara', 'Gardênia', 'Jardim Veneza', '83310-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14727, 'Almirante Tamandaré', 'Gardênia', 'Vila da Glória', '83505-117', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14728, 'Londrina', 'Gardênias', 'Ricardo', '86035-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14729, 'Curitiba', 'Gardenio Scorzato', 'Vista Alegre', '82100-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14730, 'Foz do Iguaçu', 'Garibaldi', 'Jardim Lancaster', '85869-470', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14731, 'Foz do Iguaçu', 'Garibaldi', 'Conjunto A', '85861-550', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14732, 'Maringá', 'Garibaldi', 'Vila Nova', '87045-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14733, 'Telêmaco Borba', 'Garibaldi', 'Área 10', '84266-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14734, 'Toledo', 'Garibaldi', 'Centro', '85900-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14735, 'Toledo', 'Garibaldi', 'Conjunto Residencial Rossani', '85901-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14736, 'Toledo', 'Garibaldi', 'Boa Esperança', '85909-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14737, 'Arapongas', 'Garibaldi', 'Jardim Santo Antônio', '86705-666', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14738, 'Curitiba', 'Garibaldi', 'São Francisco', '80410-250', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14739, 'Curitiba', 'Garibaldi', 'São Francisco', '80510-210', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14740, 'Londrina', 'Garibaldi Deliberador', 'Cláudia', '86050-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14741, 'Londrina', 'Garibaldi Deliberador', 'Parque Residencial Alcântara', '86047-410', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14742, 'Foz do Iguaçu', 'Garimpeirinho', 'Conjunto A', '85866-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14743, 'Guarapuava', 'Garoto da Gaita', 'Conradinho', '85055-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14744, 'Foz do Iguaçu', 'Garoupa', 'Profilurb I', '85855-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14745, 'Arapongas', 'Garrincha', 'Conjunto Tropical', '86702-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14746, 'Arapongas', 'Garrincha-cinza', 'Conjunto Flamingos III', '86703-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14747, 'Arapongas', 'Garrincha-do-mato-grosso', 'Parque Industrial II', '86709-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14748, 'Arapongas', 'Garrinchão', 'Jardim Portal das Flores', '86701-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14749, 'Arapongas', 'Garrincho-açu', 'Jardim Monte Carlo II', '86704-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14750, 'Curitiba', 'Garuva', 'Cidade Industrial', '81240-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14751, 'São José dos Pinhais', 'Gasilda Pinto de Assis', 'Guatupê', '83060-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14752, 'Foz do Iguaçu', 'Gaspar', 'Jardim Petropólis', '85868-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14753, 'Curitiba', 'Gaspar Carrilho Júnior', 'Vista Alegre', '80810-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14754, 'Colombo', 'Gaspar Ceccon', 'Capivari', '83415-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14755, 'Foz do Iguaçu', 'Gaspar Dutra', 'Parque Presidente', '85863-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14756, 'Pinhais', 'Gaspar Dutra', 'Vila Amélia', '83330-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14757, 'Toledo', 'Gaspar Dutra', 'Jardim Filadélpia', '85902-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14758, 'Cascavel', 'Gaspar Dutra', 'Maria Luiza', '85819-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14759, 'Piraquara', 'Gaspar Gaio', 'Planta Laranjeiras', '83307-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14760, 'Colombo', 'Gaspar Kania', 'Jardim Guarujá', '83407-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14761, 'Campo Largo', 'Gaspar Pereira', 'Vila David Antônio', '83609-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14762, 'Maringá', 'Gaspar Ricardo', 'Zona 10', '87040-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14763, 'Francisco Beltrão', 'Gaspar Silveira Martins', 'Cristo Rei', '85602-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14764, 'Curitiba', 'Gaspar Valenga', 'Santa Felicidade', '82320-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14765, 'Pinhais', 'Gaspar Zeni', 'Jardim Guairacá', '83324-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14766, 'Ponta Grossa', 'Gastão Busquet', 'Ronda', '84050-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14767, 'Curitiba', 'Gastão Câmara', 'Bigorrilho', '80730-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14768, 'Curitiba', 'Gastão de Abreu Pires', 'Cidade Industrial', '81270-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14769, 'Curitiba', 'Gastão Luiz Cruls', 'Bairro Alto', '82840-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14770, 'Curitiba', 'Gastão Luiz Cruls', 'Bairro Alto', '82820-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14771, 'Londrina', 'Gastão Madeira', 'Dom Pedro', '86039-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14772, 'Castro', 'Gastão Negrão', 'Jardim Colonial', '84178-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14773, 'Curitiba', 'Gastão Poplade', 'Parolin', '80220-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14774, 'Paranaguá', 'Gastão Soares Gomes', 'Jardim Araçá', '83221-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14775, 'Ponta Grossa', 'Gastão Vidigal', 'Jardim Carvalho', '84016-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14776, 'Umuarama', 'Gastão Vidigal', 'Zona II', '87501-376', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14777, 'Apucarana', 'Gastão Vidigal', 'Centro', '86800-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14778, 'Londrina', 'Gattaz Cruy Eid', 'Residencial Loris Sahyun', '86040-608', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14779, 'Foz do Iguaçu', 'Gaturamo', 'Portal da Foz', '85859-667', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14780, 'Londrina', 'Gaturamo', 'Jacomo Violin', '86088-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14781, 'Arapongas', 'Gaturamo', 'Jardim Primavera', '86702-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14782, 'Arapongas', 'Gaturamo-bandeira', 'Parque Industrial II', '86703-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14783, 'Arapongas', 'Gaturamo-de-peito-dourado', 'Conjunto Águias', '86704-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14784, 'Arapongas', 'Gaturamo-dourado', 'Casa Família Arapongas IV', '86709-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14785, 'Arapongas', 'Gaturamo-plúmbeo', 'Jardim Colúmbia I', '86707-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14786, 'Arapongas', 'Gaturamo-rei', 'Conjunto Flamingos', '86703-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14787, 'Arapongas', 'Gaturamo-verde', 'Jardim São Bento', '86706-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14788, 'Umuarama', 'Gaúcha', 'Zona VI', '87503-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14789, 'Campo Mourão', 'Gaúcho', 'Jardim Tropical I', '87310-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14790, 'Guarapuava', 'Gaudêncio Ferlin', 'Santa Cruz', '85015-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14791, 'Londrina', 'Gaudêncio Ferracini', 'Conjunto Novo Amparo', '86087-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14792, 'Foz do Iguaçu', 'Gav', 'Parque Morumbi II', '85858-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14793, 'Foz do Iguaçu', 'Gávea', 'Parque Morumbi II', '85859-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14794, 'Londrina', 'Gávea', 'Ipanema', '86015-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14795, 'Foz do Iguaçu', 'Gavião', 'Portal da Foz', '85859-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14796, 'Londrina', 'Gavião', 'Paraíso', '86078-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14797, 'Francisco Beltrão', 'Gavião', 'Padre Ulrico', '85604-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14798, 'Arapongas', 'Gavião', 'Vila São João', '86708-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14799, 'Araucária', 'Gavião', 'Capela Velha', '83706-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14800, 'Cascavel', 'Gavião', 'Floresta', '85814-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14801, 'Apucarana', 'Gavião', 'Núcleo Habitacional Michel Soni', '86813-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14802, 'Arapongas', 'Gavião-branco', 'Jardim Morumbi', '86708-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14803, 'Arapongas', 'Gavião-cinzento', 'Jardim São Rafael', '86703-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14804, 'Arapongas', 'Gavião-da-cauda-curta', 'Parque Industrial II', '86703-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14805, 'Arapongas', 'Gavião-de-coleira', 'Jardim Caravelle', '86702-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14806, 'Arapongas', 'Gavião-do-brejo', 'Jardim Petrópolis', '86709-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14807, 'Arapongas', 'Gavião-mateiro', 'Jardim São Bento', '86706-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14808, 'Arapongas', 'Gavião-pintado', 'Conjunto Padre Bernardo Merckel', '86706-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14809, 'Arapongas', 'Gavião-preto', 'Jardim Petrópolis', '86709-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14810, 'Arapongas', 'Gavião-real', 'Conjunto Padre Chico', '86707-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14811, 'Arapongas', 'Gavião-velho', 'Conjunto Flamingos III', '86703-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14812, 'Arapongas', 'Gaviãozinho', 'Parque Industrial II', '86703-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14813, 'Colombo', 'Gavino Fernandes', 'Jardim dos Eucaliptos', '83408-528', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14814, 'Ponta Grossa', 'Gaza', 'Jardim Carvalho', '84016-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14815, 'Araucária', 'Gazania', 'Campina da Barra', '83709-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14816, 'Curitiba', 'Gebran Kalluf', 'Uberaba', '81560-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14817, 'Londrina', 'Gelcino Mortari', 'Alto da Boa Vista', '86083-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14818, 'Curitiba', 'Gelson Pilati', 'Sítio Cercado', '81900-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14821, 'Paranaguá', 'Genaro Regis', 'Costeira', '83203-520', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14822, 'Curitiba', 'Genauro Ferreira de Almeida', 'São Braz', '82015-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14823, 'Colombo', 'Genebra', 'Planta Boros', '83413-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14824, 'Londrina', 'Genebra Toneli Paglia', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14825, 'Castro', 'General Abreu', 'Água Suja', '84165-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14826, 'Castro', 'General Abreu', 'Centro', '84165-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14827, 'Curitiba', 'General Adalberto Gonçalves de Menezes', 'Tarumã', '82800-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14828, 'Curitiba', 'General Afonso Fink', 'Mercês', '80510-120', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14829, 'Paranaguá', 'General Agostinho Pereira Alves Filho', 'Padre Jackson', '83221-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14830, 'Curitiba', 'General Agostinho Pereira Alves Filho', 'Mercês', '80710-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14831, 'Toledo', 'General Alcebíades Formighieri', 'Jardim Alto Alegre', '85910-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14832, 'Toledo', 'General Alcides Etchegoyen', 'Jardim La Salle', '85903-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14833, 'Castro', 'General Almada', 'Vila Rio Branco', '84172-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14834, 'Curitiba', 'General Alvaro Braga', 'Pilarzinho', '82100-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14835, 'Paranavaí', 'General Andrade Neves', 'Jardim São Jorge', '87710-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14836, 'Curitiba', 'General Anor Pinho', 'Boa Vista', '82650-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14837, 'Ponta Grossa', 'General Argolo', 'Oficinas', '84035-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14838, 'Curitiba', 'General Aristides Athayde Júnior', 'Bigorrilho', '80730-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14839, 'Curitiba', 'General Aristides Athayde Júnior', 'Bigorrilho', '80710-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14840, 'Curitiba', 'General Ary Duarte Nunes', 'Uberaba', '81530-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14841, 'Ponta Grossa', 'General Barbedo', 'Colônia Dona Luiza', '84045-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14842, 'Ponta Grossa', 'General Barros Falcão', 'Boa Vista', '84073-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14843, 'Toledo', 'General Câmara', 'Jardim Europa', '85908-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14844, 'Castro', 'General Câmara', 'Centro', '84165-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14845, 'Toledo', 'General Canabarro', 'Jardim Europa', '85908-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14846, 'Guarapuava', 'General Cândido Rondon', 'Dos Estados', '85035-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14847, 'Ponta Grossa', 'General Cândido Rondon', 'Nova Rússia', '84070-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14848, 'Toledo', 'General Canrobert Pereira da Costa', 'Centro', '85900-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14849, 'Ponta Grossa', 'General Carlos Cavalcanti', 'Uvaranas', '84030-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14850, 'Ponta Grossa', 'General Carlos Cavalcanti', 'Uvaranas', '84025-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14851, 'Guarapuava', 'General Carneiro', 'Industrial', '85053-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14852, 'Foz do Iguaçu', 'General Carneiro', 'Jardim Belvedere I', '85867-550', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14853, 'Francisco Beltrão', 'General Carneiro', 'Cango', '85604-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14854, 'Ponta Grossa', 'General Carneiro', 'Centro', '84010-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14855, 'Paranaguá', 'General Carneiro', 'Centro Histórico', '83203-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14856, 'Toledo', 'General Carneiro', 'Vila Industrial', '85904-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14857, 'Colombo', 'General Carneiro', 'Jardim La Paloma', '83412-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14858, 'Curitiba', 'General Carneiro', 'Alto da Glória', '80060-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14859, 'São José dos Pinhais', 'General Catão Menna Barreto Monclaro', 'São Pedro', '83005-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14860, 'Curitiba', 'General Christiano da Rocha Kuster', 'Pinheirinho', '81820-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14861, 'Ponta Grossa', 'General Dácio César', 'Uvaranas', '84025-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14862, 'Toledo', 'General Daltro Filho', 'Parque Residencial Gisela', '85905-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14863, 'Toledo', 'General Daltro Filho', 'Vila Industrial', '85904-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14864, 'Curitiba', 'General Daltro Filho', 'Seminário', '80310-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14865, 'Curitiba', 'General de Brigada Carlos Castor de Menezes', 'Butiatuvinha', '82400-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14866, 'Curitiba', 'General Djalma da Rocha Lima', 'Boqueirão', '81730-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14867, 'Toledo', 'General Ducio L. Peliceti', 'Residencial Santa Clara', '85908-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14868, 'Cascavel', 'General Emílio Lúcio Esteves', '14 de Novembro', '85804-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14869, 'Laranjeiras do Sul', 'General Espírito Santo', 'Centro', '85301-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14870, 'Toledo', 'General Estilac Leal', 'Centro', '85900-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14871, 'Toledo', 'General Flores da Cunha', 'Panorama', '85911-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14872, 'Toledo', 'General Flores da Cunha', 'Jardim Europa', '85906-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14873, 'Curitiba', 'General Florimar Campelo', 'Boqueirão', '81750-490', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14874, 'Curitiba', 'General Francisco Lima e Silva', 'São Francisco', '80520-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14875, 'Curitiba', 'General Gastão Pereira Cordeiro', 'São Francisco', '80510-080', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14876, 'Curitiba', 'General Haroldo Bizerril', 'São Braz', '82300-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14877, 'Toledo', 'General Henrique Lott', 'Jardim Maria do Carmo', '85906-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14878, 'Londrina', 'General Horta Barbosa', 'Petrópolis', '86015-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14879, 'Curitiba', 'General Iberê de Mattos', 'Bacacheri', '82515-420', 'Parque', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14880, 'Curitiba', 'General Ivan Jejuhy Affonso da Costa', 'Bacacheri', '82510-530', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14881, 'Paranavaí', 'General João Batista Lopes', 'Jardim Guanabara', '87706-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14882, 'Paranaguá', 'General João da Silva Rebello', 'Conjunto Residencial Prefeito Cominese', '83215-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14883, 'Ponta Grossa', 'General João Ferreira de Oliveira', 'Orfãs', '84015-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14884, 'Curitiba', 'General João Gualberto Gomes de Sá', 'Jardim Social', '82520-240', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14885, 'Curitiba', 'General José Ferreira de Barros', 'Sítio Cercado', '81920-746', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14886, 'Curitiba', 'General Julião Müller Neiva de Lima', 'Sítio Cercado', '81925-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14887, 'Pinhais', 'General Lucas de Almeida Guimarães', 'Vila Tarumã', '83323-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14888, 'Curitiba', 'General Luiz Ferraz de Sampaio', 'Cidade Industrial', '81450-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14889, 'Castro', 'General Manoel F. do V. Aranha', 'Jardim Dona Helena', '84178-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14890, 'Paranavaí', 'General Manoel Nascimento Vargas', 'Jardim São Jorge', '87710-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14891, 'Apucarana', 'General Mário Tourinho', 'Núcleo Habitacional Parigot de Souza', '86802-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14892, 'Curitiba', 'General Mário Tourinho', 'Seminário', '80740-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14893, 'Umuarama', 'General Mascarenhas de Morais', 'Zona V', '87504-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14894, 'Foz do Iguaçu', 'General Meira', 'Parque Ouro Verde', '85855-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14895, 'Foz do Iguaçu', 'General Meira', 'Jardim Eldorado', '85853-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14896, 'Curitiba', 'General Murat Guimarães', 'Jardim Social', '82520-475', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14897, 'Francisco Beltrão', 'General Osório', 'Pinheirinho', '85603-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14898, 'Guarapuava', 'General Osório', 'Vila Carli', '85040-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14899, 'Francisco Beltrão', 'General Osório', 'Cango', '85604-240', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14900, 'Pato Branco', 'General Osório', 'Santo Antônio', '85507-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14901, 'Maringá', 'General Osório', 'Zona 05', '87015-540', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14902, 'Ponta Grossa', 'General Osório', 'Centro', '84010-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14903, 'Apucarana', 'General Osório', 'Jardim Tibagi', '86812-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14904, 'Cascavel', 'General Osório', 'Ciro Nardi', '85802-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14905, 'Cascavel', 'General Osório', 'Parque São Paulo', '85803-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14906, 'Cascavel', 'General Osório', 'Centro', '85801-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14907, 'Castro', 'General Osório', 'Centro', '84165-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14908, 'Apucarana', 'General Osório', 'Jardim Tarobá', '86813-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14909, 'Curitiba', 'General Osório', 'Centro', '80020-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14910, 'Laranjeiras do Sul', 'General Ozorio', 'Getúlio Vargas', '85304-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14911, 'Curitiba', 'General Pedro Labatut', 'Portão', '81320-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14912, 'Ponta Grossa', 'General Polidoro', 'Oficinas', '84035-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14913, 'Curitiba', 'General Polli Coelho', 'Tarumã', '82800-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14914, 'Curitiba', 'General Potiguara', 'Fazendinha', '81330-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14915, 'Curitiba', 'General Potiguara', 'Novo Mundo', '81050-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14916, 'Ponta Grossa', 'General Ramon', 'Colônia Dona Luiza', '84045-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14917, 'Curitiba', 'General Raul da Cunha Bello', 'Pinheirinho', '81150-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14918, 'Ponta Grossa', 'General Rondon', 'Nova Rússia', '84070-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14919, 'Toledo', 'General Rondon', 'Centro', '85901-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14920, 'Toledo', 'General Rondon', 'Jardim La Salle', '85902-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14921, 'Curitiba', 'General Setembrino de Carvalho', 'Jardim das Américas', '81530-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14922, 'Curitiba', 'General Severiano da Fonseca', 'Uberaba', '81560-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14923, 'Londrina', 'General Tasso Fragoso', 'Bancários', '86062-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14924, 'Curitiba', 'General Teodorico Guimarães', 'Fanny', '81030-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14925, 'Curitiba', 'General Theodorico Gonçalves Guimarães', 'Xaxim', '81720-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14926, 'Curitiba', 'General Walter da Costa Reis', 'Cidade Industrial', '81290-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14927, 'Curitiba', 'General Zenon Silva', 'Guaíra', '81030-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14928, 'Umuarama', 'Generino Delfino Coelho', 'Zona I-A', '87501-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14929, 'Curitiba', 'Generis Calvo', 'Tarumã', '82800-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14930, 'Pato Branco', 'Generoso Catiani', 'Bortot', '85504-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14931, 'Guarapuava', 'Generoso Cebulski', 'Alto da XV', '85065-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14932, 'Guarapuava', 'Generoso de Paula Bastos', 'Trianon', '85015-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14933, 'Guarapuava', 'Generoso de Paula Bastos', 'Trianon', '85012-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14934, 'Curitiba', 'Generoso do Nascimento Teixeira Filho', 'Cajuru', '82930-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14935, 'Pato Branco', 'Generoso Marques', 'Jardim Primavera', '85502-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14936, 'Campo Largo', 'Generoso Marques', 'Centro', '83601-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14937, 'Curitiba', 'Generoso Marques', 'Centro', '80020-230', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14938, 'Ponta Grossa', 'Generoso Marques dos Santos', 'Centro', '84010-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14939, 'Piraquara', 'Genésio Alves Pereira', 'Planta Cruzeiro', '83304-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14940, 'Castro', 'Genésio Araújo Barbosa', 'Jardim Social Arapongas', '84174-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14941, 'Cambé', 'Genésio Dias Pires', 'Jardim Santa Mônica', '86184-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14942, 'Cambé', 'Genésio G. dos Santos', 'Jardim Tarobá', '86191-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14943, 'Colombo', 'Genésio Moreschi', 'Jardim Guaraituba', '83410-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14944, 'Ponta Grossa', 'Genesis', 'Chapada', '84062-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14945, 'Cambé', 'Gênesis', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14946, 'Curitiba', 'Gênesis', 'Santa Cândida', '82630-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14947, 'Curitiba', 'Genipapo', 'Uberaba', '81540-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14948, 'Cascavel', 'Genipro Mendes de Queiroz', 'Cataratas', '85818-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14949, 'Londrina', 'Genivaldo Santos da Silva', 'Jamile Dequech', '86048-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14950, 'Londrina', 'Genny Ferreira Felizardo', 'Jardim Europa', '86043-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14951, 'Colombo', 'Genor da Silva Godoy', 'Serrinha', '83415-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14952, 'Curitiba', 'Genova', 'Butiatuvinha', '82320-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14953, 'Francisco Beltrão', 'Gênova', 'Jardim Floresta', '85603-796', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14954, 'Londrina', 'Gênova', 'Palermo', '86041-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14955, 'Cascavel', 'Gênova', 'Cascavel Velho', '85818-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14956, 'Colombo', 'Gênova', 'Planta Boros', '83413-270', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14957, 'São José dos Pinhais', 'Genovefa Kuboski Karpuchin', 'Afonso Pena', '83050-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14958, 'Londrina', 'Genoveva Fachinelli', 'Aquilles Sthengel', '86086-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14959, 'Pinhais', 'Genoveva Forlepa Kopka', 'Vale da Boa Esperança', '83320-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14960, 'Pinhais', 'Genoveva Ianoski Biss', 'Jardim Guairacá', '83324-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14961, 'Curitiba', 'Genoveva Simões Falcão', 'Cascatinha', '82020-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14962, 'Francisco Beltrão', 'Gentil Alberton', 'Pinheirinho', '85603-166', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14963, 'Curitiba', 'Gentil Antunes Branco', 'Santa Felicidade', '82410-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14964, 'Toledo', 'Gentila Soave', 'Jardim Porto Alegre', '85906-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14965, 'Pato Branco', 'Genuíno Piacentini', 'Santa Terezinha', '85501-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14966, 'Pato Branco', 'Genuíno Piacentini', 'Santa Terezinha', '85506-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14967, 'Ponta Grossa', 'Geny de Jesus Souza Ribas', 'Oficinas', '84035-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14968, 'Londrina', 'Geny Lima de Azevedo', 'Jardim Alto do Cafezal', '86049-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14969, 'Maringá', 'Geoffrey Wilde Diment', 'Zona 05', '87015-450', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14970, 'Londrina', 'George Graig Smith', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-375', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14971, 'Londrina', 'George Marcelino', 'Estados', '86083-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14972, 'Londrina', 'George Von Malte', 'Roseira', '86041-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14973, 'Londrina', 'Georgetown', 'Guanabara', '86050-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14974, 'Laranjeiras do Sul', 'Georgina R. de Matos Kraemer', 'São Francisco', '85303-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14975, 'Curitiba', 'Georgino Pioli Ribeiro', 'Xaxim', '81830-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14976, 'Londrina', 'Geralda de Nobre', 'Franciscato II', '86078-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14977, 'Apucarana', 'Geralda dos Santos', 'Jardim Marissol II', '86807-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14978, 'Apucarana', 'Geraldina da Silva Gonçalves Rodrigues', 'Loteamento Sol Nascente', '86801-267', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14979, 'Sarandi', 'Geraldina Izidia da Silva', 'Jardim Tropical', '87113-816', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14980, 'Foz do Iguaçu', 'Geraldino Manoel de Souza', 'Jardim São Paulo II', '85856-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14981, 'Curitiba', 'Geraldino Ramiro dos Santos', 'Cidade Industrial', '81260-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14982, 'Apucarana', 'Geraldo Alves Pereira', 'Loteamento Residencial Cazarin', '86802-417', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14983, 'Maringá', 'Geraldo Braga', 'Jardim Vila Rica', '87050-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14984, 'Almirante Tamandaré', 'Geraldo Cordeiro Santana', 'Planta São Venâncio', '83504-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14985, 'Londrina', 'Geraldo Costa Muniz', 'Santiago', '86071-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14986, 'Londrina', 'Geraldo da Silva', 'Jardim Piza', '86073-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14987, 'Cascavel', 'Geraldo de Oliveira', 'Santa Felicidade', '85803-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14988, 'Maringá', 'Geraldo de Souza', 'Jardim Paulista', '87047-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14989, 'Londrina', 'Geraldo de Souza Vieira', 'Jardim Nova Esperança', '86044-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14990, 'Colombo', 'Geraldo dos Santos', 'Jardim Esplanada', '83402-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14991, 'Londrina', 'Geraldo Euleutério de Godoy', 'Jardim Bavária', '86082-018', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14992, 'Londrina', 'Geraldo Francisco dos Santos', 'Santa Izabel', '86031-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14993, 'Curitiba', 'Geraldo Gabardo', 'Água Verde', '80620-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14994, 'Londrina', 'Geraldo Gonçalves da Costa', 'Parigot de Souza 2', '86082-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14995, 'Curitiba', 'Geraldo Gustavo Müller', 'Boa Vista', '82510-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14996, 'Foz do Iguaçu', 'Geraldo José de Almeida', 'Jardim Copacabana II', '85858-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14997, 'Londrina', 'Geraldo José de Almeida', 'Gaion', '86071-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14998, 'Londrina', 'Geraldo Júlio', 'Cafezal', '86045-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (14999, 'Almirante Tamandaré', 'Geraldo Krüger', 'Jardim Santa Rita de Cássia', '83506-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15000, 'Curitiba', 'Geraldo Lipka', 'Mossunguê', '81200-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15001, 'Londrina', 'Geraldo Luiz da Silva', 'Operária', '86038-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15002, 'Curitiba', 'Geraldo Meira Góes', 'Bacacheri', '82600-665', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15003, 'Campo Largo', 'Geraldo Melo Mourão', 'São Marcos', '83602-688', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15004, 'Londrina', 'Geraldo Moreira Chacon', 'Residencial Portal do Sol', '86082-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15005, 'Curitiba', 'Geraldo Moreira de Macedo', 'Cajuru', '82930-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15006, 'Umuarama', 'Geraldo Mulato', 'Conjunto Residencial Ouro Preto', '87504-599', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15007, 'Almirante Tamandaré', 'Geraldo Nascimento Carvalho', 'Jardim Campo Verde', '83502-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15008, 'Apucarana', 'Geraldo Navas Ferrarezi', 'Jardim Portal do Lago', '86802-066', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15009, 'Paranavaí', 'Geraldo Pereira dos Santos', 'Jardim América', '87705-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15010, 'Londrina', 'Geraldo Rodrigues', 'Cidadela', '86072-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15011, 'Londrina', 'Geraldo Sebastião dos Santos', 'Jardim dos Alpes III', '86045-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15012, 'Londrina', 'Geraldo Simões', 'Jardim das Palmeiras', '86083-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15013, 'Sarandi', 'Geraldo Teixeira Batista', 'São José I', '87114-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15014, 'Foz do Iguaçu', 'Geraldo Triedel', 'Conjunto Residencial Sol de Maio', '85862-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15015, 'Apucarana', 'Geraldo Vianna da Cunha', 'Loteamento Sanches dos Santos', '86806-587', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15016, 'Curitiba', 'Geraldo Warkentin', 'Alto Boqueirão', '81770-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15017, 'Sarandi', 'Geraldo Xavier', 'Jardim Escala', '87114-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15019, 'Telêmaco Borba', 'Gerânios', 'Jardim Alegre', '84268-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15020, 'Curitiba', 'Gerci Garcez das Neves', 'Cajuru', '82950-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15021, 'Piraquara', 'Gercindo Marins', 'Planta Amazonas', '83311-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15022, 'Paranaguá', 'Gercy Vieira da Silva', 'Vila do Caic', '83215-687', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15023, 'Curitiba', 'Gerd Claassen', 'Butiatuvinha', '82400-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15024, 'Curitiba', 'Gerda Thereza Metzentin', 'Novo Mundo', '81050-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15025, 'Piraquara', 'Gerdal Ribeiro', 'Planta Deodoro', '83304-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15026, 'Apucarana', 'Geremias Lunardelli', 'Barra Funda', '86800-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15027, 'Londrina', 'Geremias Venturini', 'Alto da Boa Vista', '86083-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15028, 'Curitiba', 'Gerhard Heinrichs', 'Xaxim', '81830-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15029, 'Piraquara', 'Gerhard Schroeder', 'Planta Parque das Andorinhas', '83311-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15030, 'Pinhais', 'Gerhard Trapp', 'Conjunto Residencial Áquila', '83326-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15031, 'Piraquara', 'Gerhard Von Scheidt', 'Guarituba', '83311-307', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15032, 'Cascavel', 'Geriva', 'Recanto Tropical', '85807-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15033, 'Curitiba', 'Germânia', 'Cajuru', '82900-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15034, 'Campo Largo', 'Germano Aleixo', 'Vila Torres I', '83609-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15035, 'Umuarama', 'Germano Bacarin', 'Jardim San Fernando', '87508-178', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15036, 'Curitiba', 'Germano Beckert', 'Bairro Alto', '82840-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15037, 'Ponta Grossa', 'Germano Clausen', 'Colônia Dona Luiza', '84045-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15038, 'Paranaguá', 'Germano Crispim de Oliveira', 'Parque São João', '83212-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15039, 'Curitiba', 'Germano Demuth', 'Campina do Siqueira', '80740-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15040, 'Ponta Grossa', 'Germano Ferreira Wiedermann', 'Chapada', '84062-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15041, 'Campo Mourão', 'Germano Francisco R. Bathke', 'Jardim Santa Cruz', '87309-590', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15042, 'Castro', 'Germano Kugler', 'Vila Frei Mathias', '84165-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15043, 'Francisco Beltrão', 'Germano Mayer', 'Marrecas', '85601-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15044, 'Curitiba', 'Germano Mehl', 'Uberaba', '81560-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15045, 'Toledo', 'Germano Pizetta', 'Boa Esperança', '85909-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15046, 'Curitiba', 'Germano Roggenbaum', 'Santa Felicidade', '82020-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15047, 'Campo Mourão', 'Germano Scheidt', 'Jardim Paulista', '87310-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15048, 'São José dos Pinhais', 'Germano Schlogel', 'São Cristóvão', '83005-240', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15049, 'São José dos Pinhais', 'Germano Schlogel', 'São Cristóvão', '83005-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15050, 'Almirante Tamandaré', 'Germano Thoaldo', 'Planta Mosacal', '83513-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15051, 'Campo Largo', 'Gernâncio Rodrigues de Moura', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-768', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15052, 'Colombo', 'Gerônimo Lazaroto Sobrinho', 'Jardim dos Eucaliptos', '83408-499', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15053, 'Londrina', 'Gerônimo Máximo', 'Ernani de Moura Lima', '86037-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15054, 'Curitiba', 'Gerônimo Muraro', 'Santa Felicidade', '82400-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15055, 'Curitiba', 'Gerônimo Muraro', 'Santa Felicidade', '82410-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15056, 'Curitiba', 'Gerônimo Rossetim', 'Campo Comprido', '81210-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15057, 'Paranaguá', 'Gerson Constantino', 'Ponta do Caju', '83203-137', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15058, 'Curitiba', 'Gérson da Graça', 'Campina do Siqueira', '80740-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15059, 'Maringá', 'Gérson Soares Costa Kuriango', 'Jardim Ipanema', '87053-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15060, 'Londrina', 'Gertrudes Bischof', 'Jardim Graziela', '86036-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15061, 'São José dos Pinhais', 'Gertrudes Camargo Claudino', 'Rio Pequeno', '83065-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15062, 'Curitiba', 'Gertrudes Cruz de Andrade', 'Pinheirinho', '81870-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15063, 'Toledo', 'Gertrudes Ringwald Pedrini', 'César Park', '85913-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15064, 'Londrina', 'Gervásio Alves Morales', 'Sabará III', '86066-365', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15065, 'Londrina', 'Gervásio Basílio Nunes', 'Jardim Continental', '86081-188', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15066, 'Francisco Beltrão', 'Gervazio Schurman', 'Vila Nova', '85605-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15067, 'Apucarana', 'Gesino de Souza', 'Jardim Marissol', '86807-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15068, 'Londrina', 'Gessi Eugênio da Silva', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15069, 'Londrina', 'Getúlio Antônio de Oliveira', 'Jardim Paris', '86082-097', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15070, 'Pato Branco', 'Getúlio Dal Pasquale', 'Industrial', '85504-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15071, 'Curitiba', 'Getúlio Pires de Arruda', 'Cidade Industrial', '81350-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15072, 'Londrina', 'Getúlio Ribeiro de Carvalho', 'Cafezal 1', '86049-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15073, 'Laranjeiras do Sul', 'Getúlio Vargas', 'Centro', '85301-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15074, 'Francisco Beltrão', 'Getúlio Vargas', 'Cristo Rei', '85602-500', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15075, 'Foz do Iguaçu', 'Getúlio Vargas', 'Parque Presidente', '85863-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15076, 'Foz do Iguaçu', 'Getúlio Vargas', 'Centro', '85851-340', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15077, 'Piraquara', 'Getúlio Vargas', 'Centro', '83301-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15078, 'Paranavaí', 'Getúlio Vargas', 'Jardim São João', '87709-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15079, 'Maringá', 'Getúlio Vargas', 'Zona 01', '87013-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15080, 'Paranavaí', 'Getúlio Vargas', 'Centro', '87702-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15081, 'Paranavaí', 'Getúlio Vargas', 'Centro', '87704-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15082, 'Pinhais', 'Getúlio Vargas', 'Vila Amélia', '83330-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15083, 'Telêmaco Borba', 'Getúlio Vargas', 'Alto das Oliveiras', '84265-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15084, 'Umuarama', 'Getúlio Vargas', 'Zona III', '87502-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15085, 'São José dos Pinhais', 'Getúlio Vargas', 'Centro', '83005-185', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15086, 'Colombo', 'Getúlio Vargas', 'Vila Alto da Cruz II', '83405-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15087, 'Campo Largo', 'Getúlio Vargas', 'Centro', '83601-025', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15088, 'Almirante Tamandaré', 'Getúlio Vargas', 'Jardim São Carlos', '83507-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15089, 'Cambé', 'Getúlio Vargas', 'Centro', '86181-290', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15090, 'Cascavel', 'Getúlio Vargas', 'Cataratas', '85818-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15091, 'Cascavel', 'Getúlio Vargas', 'Centro', '85801-220', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15092, 'Campo Mourão', 'Getúlio Vargas', 'Centro', '87301-165', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15093, 'Castro', 'Getúlio Vargas', 'Centro', '84165-490', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15094, 'Curitiba', 'Geverson Plombom', 'Cidade Industrial', '81270-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15095, 'Paranaguá', 'Ghandu', 'Itiberê', '83209-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15096, 'Curitiba', 'Ghaze Saleh', 'Tingui', '82620-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15097, 'Curitiba', 'Giacchino Rossini', 'Vista Alegre', '80820-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15098, 'Londrina', 'Giacomo Ferro', 'Califórnia', '86040-065', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15099, 'Curitiba', 'Giacomo Lafaiette Minich Bassi', 'Sítio Cercado', '81925-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15100, 'São José dos Pinhais', 'Giacomo Martinatto', 'Colônia Rio Grande', '83025-650', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15101, 'Curitiba', 'Giacomo Mylla', 'Bom Retiro', '80520-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15102, 'Curitiba', 'Gianfranco Bertoni', 'Sítio Cercado', '81920-727', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15103, 'Curitiba', 'Gibran Khalil Gibran', 'Centro Cívico', '80030-020', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15104, 'Curitiba', 'Gideão', 'São Braz', '82015-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15105, 'Telêmaco Borba', 'Gigante de Pedra', 'Área 03', '84271-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15106, 'Londrina', 'Gil de Abreu e Souza', 'Condomínio Royal Golf Residence', '86055-570', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15107, 'Guarapuava', 'Gil Vicente', 'São Cristóvão', '85060-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15108, 'Curitiba', 'Gil Vicente', 'Guaíra', '81010-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15109, 'Londrina', 'Gilberia de Souza Silva', 'Conjunto Habitacional  Alexandre Urbanas', '86037-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15110, 'Londrina', 'Gilberto Camilo de Almeida', 'Jardim Morumbi', '86035-125', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15111, 'Araucária', 'Gilberto Drewniak Surek', 'Cachoeira', '83708-595', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15112, 'Paranaguá', 'Gilberto Elias Chaiben', 'Parque São João', '83212-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15113, 'Londrina', 'Gilberto Fierli', 'Esperança', '86046-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15114, 'Maringá', 'Gilberto Freire', 'Vila Esperança', '87020-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15115, 'Cascavel', 'Gilberto Freire', 'Presidente', '85818-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15116, 'Campo Mourão', 'Gilberto Gonçalves Açafrão', 'Jardim Modelo', '87309-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15117, 'Paranaguá', 'Gilberto Gutierrez', 'Porto dos Padres', '83221-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15118, 'Toledo', 'Gilberto Gutierrez Beltrão', 'Jardim Alta Floresta', '85905-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15119, 'Araucária', 'Gilberto Haliski', 'Capela Velha', '83706-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15120, 'Curitiba', 'Gilberto Kaminski', 'Cidade Industrial', '81170-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15121, 'Curitiba', 'Gilberto Mezzomo', 'Tarumã', '82530-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15122, 'Londrina', 'Gilberto Nápoli', 'Parque Residencial Michael Licha', '86078-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15123, 'Curitiba', 'Gilberto Narcizo', 'Cidade Industrial', '81315-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15124, 'Piraquara', 'Gilberto Nascimento', 'Planta Araçatuba', '83301-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15125, 'Curitiba', 'Gilberto Pinto Mileo', 'Cidade Industrial', '81310-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15126, 'Foz do Iguaçu', 'Gilberto Rolon', 'Vila Itajubá', '85852-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15127, 'Foz do Iguaçu', 'Gilberto Romeiro', 'Jardim Santa Rita', '85862-298', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15128, 'Curitiba', 'Gilberto Tesseroli Padilha', 'Sítio Cercado', '81910-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15129, 'Curitiba', 'Gilberto Turin', 'Barreirinha', '82700-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15130, 'Foz do Iguaçu', 'Gilda de Abreu', 'Parque Residencial Três Bandeiras', '85862-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15131, 'Londrina', 'Gilda de Abreu', 'Lago Parque', '86015-375', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15132, 'Maringá', 'Gilda de Abreu', 'Conjunto Residencial Cidade Alta', '87053-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15133, 'Curitiba', 'Gilda Pitarch Forcadell', 'Uberaba', '81550-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15134, 'Maringá', 'Gildete Gomes de Castro', 'Jardim Liberdade', '87047-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15135, 'Curitiba', 'Gildo Arcari', 'Pilarzinho', '82115-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15136, 'Cambé', 'Gildo Cogo', 'Jardim José Favaro', '86183-796', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15137, 'Londrina', 'Gildo Fertonani', 'Jardim Atlântico', '86073-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15138, 'Curitiba', 'Gildo Lazzarotto', 'Cidade Industrial', '81230-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15139, 'São José dos Pinhais', 'Gildo Vieira', 'Guatupê', '83060-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15140, 'Ponta Grossa', 'Gileade', 'Jardim Carvalho', '84016-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15141, 'Curitiba', 'Gilmar Cezar Piekarski', 'Tatuquara', '81470-035', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15142, 'Curitiba', 'Gilmar José Carneiro', 'Xaxim', '81710-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15143, 'Toledo', 'Gilmar Pastre', 'Centro', '85902-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15144, 'Curitiba', 'Gilney Carneiro Leal', 'Alto Boqueirão', '81770-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15145, 'Castro', 'Gilseu Nilo de Almeida', 'Jardim Colonial', '84178-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15146, 'Sarandi', 'Gilson C. Mantelo', 'Parque Industrial IV', '87111-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15147, 'Maringá', 'Gilson Ricardo Gomes de Castro', 'Jardim Liberdade', '87047-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15148, 'Apucarana', 'Giminiano Candeu', 'Vila Brasil', '86800-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15149, 'Londrina', 'Gines Parra', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15150, 'Curitiba', 'Gino Benuzzi', 'Cidade Industrial', '81350-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15151, 'Guarapuava', 'Gino Marly Pizzano', 'Conradinho', '85055-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15152, 'Maringá', 'Gino Merigo', 'Jardim Alvorada', '87033-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15153, 'Campo Largo', 'Gino Parolin', 'Jardim Social', '83606-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15154, 'Curitiba', 'Gino Parolin', 'Parolin', '80220-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15155, 'Londrina', 'Gino Tamiozzo', 'Jardim Olga', '86087-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15156, 'Londrina', 'Giocomo Rufini', 'Parigot de Souza 2', '86082-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15157, 'São José dos Pinhais', 'Giocondo dall Stella', 'Planta Quississana', '83085-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15158, 'Francisco Beltrão', 'Giocondo Felippi', 'Vila Maria Delani', '85605-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15159, 'Colombo', 'Giovani de Abreu Bianchini', 'Centro Industrial Mauá', '83413-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15160, 'Curitiba', 'Giovanni Dalla Palma', 'São Braz', '82320-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15161, 'Curitiba', 'Giovanni Gervasoni', 'Batel', '80240-590', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15162, 'Londrina', 'Giovanni Losi', 'Jardim Graziela', '86036-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15163, 'Londrina', 'Girassol', 'Jardim Santo Antônio', '86035-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15164, 'Ponta Grossa', 'Girassol', 'Contorno', '84060-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15165, 'São José dos Pinhais', 'Girassol', 'Guatupê', '83060-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15166, 'Araucária', 'Girassol', 'Campina da Barra', '83709-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15167, 'Cambé', 'Girassol', 'Jardim Ana Eliza', '86188-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15168, 'Campo Mourão', 'Girassol', 'Jardim Ana Eliza', '87303-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15169, 'Curitiba', 'Girassol', 'Cachoeira', '82710-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15170, 'Sarandi', 'Giro Watanabe', 'Jardim Nova Independência', '87114-621', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15171, 'Foz do Iguaçu', 'Girua', 'Loteamento Witt', '85862-516', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15172, 'Maringá', 'Gisele Gomes de Castro', 'Jardim Liberdade', '87047-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15173, 'Toledo', 'Gisele Merlin Leduc', 'Parque Residencial Gisela', '85905-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15174, 'Maringá', 'Gislaine Gomes de Castro', 'Jardim Liberdade', '87047-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15175, 'Curitiba', 'Giuseppe Covacci Júnior', 'Cidade Industrial', '81460-376', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15176, 'Londrina', 'Giuseppe Dichiara', 'Dom Pedro II', '86073-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15177, 'Cambé', 'Giuseppe Fabiano Fregonesi', 'Jardim Vila Rica', '86191-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15178, 'Londrina', 'Giuseppe Montini', 'Conjunto Semiramis Barros Braga', '86088-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15179, 'Ponta Grossa', 'Giuseppe Ungaretti', 'Cará-cará', '84043-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15180, 'Londrina', 'Giuseppe Vittori', 'São Lourenço', '86043-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15181, 'Curitiba', 'Giuseppe Zanella', 'Cidade Industrial', '81305-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15182, 'Maringá', 'Giuseppina Poleg Nagarotto', 'Parque Tarumã', '87053-648', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15183, 'Toledo', 'Giustina Genari', 'Jardim Planalto', '85904-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15184, 'Foz do Iguaçu', 'Glauber Rocha', 'Jardim Comercial das Bandeiras', '85864-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15185, 'Cascavel', 'Glauber Rocha', 'Brasília', '85815-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15186, 'Curitiba', 'Glauber Rocha', 'Uberaba', '81560-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15187, 'Curitiba', 'Glaúcio Bandeira', 'Ahú', '82200-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15188, 'Umuarama', 'Glauder Marques de Abreu', 'Parque Danielle', '87506-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15189, 'Toledo', 'Glaurimar Rogério Mandardo', 'Residencial Santa Clara', '85907-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15190, 'Piraquara', 'Glória', 'Jardim Santa Mônica', '83302-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15191, 'Curitiba', 'Glória Regina Chaiber', 'São Braz', '82300-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15192, 'Curitiba', 'Glória Senna', 'Sítio Cercado', '81900-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15193, 'Curitiba', 'Gloster Meteor', 'Bacacheri', '82515-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15194, 'Londrina', 'Goa', 'Cláudia', '86050-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15195, 'Arapongas', 'Gobrião', 'Vila Brasil', '86705-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15196, 'São José dos Pinhais', 'Godofredo Machado', 'Afonso Pena', '83065-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15197, 'Curitiba', 'Goethe', 'Alto da Glória', '80030-160', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15198, 'Telêmaco Borba', 'Goiaba', 'Fazenda Limeira', '84270-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15199, 'Curitiba', 'Goiabas', 'Uberaba', '81540-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15200, 'Foz do Iguaçu', 'Goiabeira', 'Jardim Mônaco', '85862-386', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15201, 'Ponta Grossa', 'Goiabeira', 'Contorno', '84061-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15202, 'Cascavel', 'Goiabeira', 'Brasmadeira', '85814-117', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15203, 'Pato Branco', 'Goianases', 'Centro', '85501-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15204, 'Foz do Iguaçu', 'Goiânia', 'Jardim Ipê', '85869-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15205, 'Guarapuava', 'Goiânia', 'São Cristóvão', '85060-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15206, 'Foz do Iguaçu', 'Goiânia', 'Conjunto C', '85870-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15207, 'Londrina', 'Goiânia', 'Pietraroia', '86020-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15208, 'Pinhais', 'Goiânia', 'Conjunto Residencial Renato Bonilauri', '83325-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15209, 'São José dos Pinhais', 'Goiânia', 'Ouro Fino', '83015-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15210, 'Maringá', 'Goiânia', 'Parque Residencial Cidade Nova', '87023-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15211, 'Piraquara', 'Goiânia', 'Vila Vicente Macedo', '83303-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15212, 'Maringá', 'Goiânia', 'Vila Morangueira', '87040-350', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15213, 'Sarandi', 'Goiânia', 'Parque Residencial Nova Aliança', '87111-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15214, 'Umuarama', 'Goiânia', 'Zona VI', '87503-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15215, 'Colombo', 'Goiânia', 'Jardim Santa Helena', '83407-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15216, 'Cambé', 'Goiânia', 'Vila Guarani', '86182-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15217, 'Curitiba', 'Goiânia', 'Cajuru', '82940-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15218, 'Laranjeiras do Sul', 'Goiás', 'Água Verde', '85302-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15219, 'Francisco Beltrão', 'Goiás', 'Alvorada', '85601-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15220, 'Londrina', 'Goiás', 'Centro', '86010-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15221, 'Guarapuava', 'Goiás', 'Dos Estados', '85035-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15222, 'Londrina', 'Goiás', 'Centro', '86020-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15223, 'Londrina', 'Goiás', 'Vila Simões', '86060-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15224, 'Foz do Iguaçu', 'Goiás', 'Jardim Los Angeles', '85852-210', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15225, 'Paranaguá', 'Goiás', 'Vila do Povo', '83209-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15226, 'Piraquara', 'Goiás', 'Jardim dos Estados 1', '83308-380', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15227, 'São José dos Pinhais', 'Goiás', 'São Domingos', '83030-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15228, 'Piraquara', 'Goiás', 'Jardim dos Estados 2', '83308-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15229, 'Maringá', 'Goiás', 'Jardim Alvorada', '87033-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15230, 'Ponta Grossa', 'Goiás', 'Orfãs', '84010-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15231, 'Pato Branco', 'Goiás', 'Centro', '85505-005', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15232, 'Telêmaco Borba', 'Goiás', 'Macopa', '84263-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15233, 'Toledo', 'Goiás', 'Centro', '85901-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15234, 'Umuarama', 'Goiás', 'Zona II', '87502-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15235, 'Cascavel', 'Goiás', 'São Cristóvão', '85813-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15236, 'Apucarana', 'Goiás', 'Jardim Apucarana', '86804-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15237, 'Campo Largo', 'Goiás', 'Jardim Esmeralda', '83604-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15238, 'Araucária', 'Goiás', 'Iguaçu', '83701-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15239, 'Curitiba', 'Goiás', 'Água Verde', '80620-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15240, 'Curitiba', 'Goiás', 'Água Verde', '80610-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15241, 'Curitiba', 'Goiás', 'Guaíra', '80630-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15242, 'Foz do Iguaçu', 'Goiatuba', 'Jardim Curitibano IV', '85869-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15243, 'Guarapuava', 'Goioerê', 'Boqueirão', '85023-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15244, 'Foz do Iguaçu', 'Goioerê', 'Mata Verde', '85853-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15245, 'Ponta Grossa', 'Goioerê', 'Olarias', '84026-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15246, 'Umuarama', 'Goioerê', 'Zona IV', '87504-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15247, 'Campo Mourão', 'Goioerê', 'Centro', '87302-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15248, 'Cambé', 'Goioerê', 'Jardim Silvino', '86187-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15249, 'Campo Mourão', 'Goioerê', 'Centro', '87303-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15250, 'Colombo', 'Goioerê', 'Vila São José', '83410-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15251, 'Londrina', 'Goioxim', 'Castelo', '86027-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15252, 'Londrina', 'Goitacazes', 'Lago Igapó', '86026-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15253, 'Cascavel', 'Golfinho', 'Cataratas', '85817-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15254, 'Colombo', 'Gombel', 'Jardim Curitiba', '83406-430', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15255, 'Cascavel', 'Gomercindo Pompeu da Silva', 'Alto Alegre', '85805-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15256, 'Almirante Tamandaré', 'Gomes Barreto', 'Colônia Vila Prado', '83504-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15257, 'Londrina', 'Gomes Carneiro', 'Boa Vista', '86015-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15258, 'Londrina', 'Gomes de Souza', 'Jardim Tatiani', '86070-480', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15259, 'Curitiba', 'Gonçalo Mendes de Siqueira', 'Pinheirinho', '81870-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15260, 'Londrina', 'Gonçalo Monteiro', 'Sabará I', '86066-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15261, 'Paranavaí', 'Gonçalves', 'Jardim Ibirapuera', '87705-030', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15262, 'Ponta Grossa', 'Gonçalves Crespo', 'Oficinas', '84035-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15263, 'Guarapuava', 'Gonçalves de Magalhães', 'Vila Bela', '85025-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15264, 'São José dos Pinhais', 'Gonçalves de Magalhães', 'Colônia Rio Grande', '83025-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15265, 'Guarapuava', 'Gonçalves Dias', 'Boqueirão', '85023-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15266, 'Foz do Iguaçu', 'Gonçalves Dias', 'Jardim Jupira', '85865-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15267, 'Pato Branco', 'Gonçalves Dias', 'São Cristóvão', '85508-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15268, 'Ponta Grossa', 'Gonçalves Dias', 'Uvaranas', '84025-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15269, 'Telêmaco Borba', 'Gonçalves Dias', 'Jardim Bonavila', '84264-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15270, 'Toledo', 'Gonçalves Dias', 'Boa Esperança', '85909-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15271, 'Colombo', 'Gonçalves Dias', 'Jardim Curitiba', '83406-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15272, 'Apucarana', 'Gonçalves Dias', 'Vila Ivone', '86804-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15273, 'Campo Largo', 'Gonçalves Dias', 'Centro', '83601-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15274, 'Campo Largo', 'Gonçalves Dias', 'Jardim São Vicente', '83602-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15275, 'Curitiba', 'Gonçalves Dias', 'Batel', '80240-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15276, 'Londrina', 'Gonçalves Ledo', 'Mazzei', '86015-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15277, 'Foz do Iguaçu', 'Gonçalves Ledo', 'Jardim Jupira', '85865-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15278, 'Ponta Grossa', 'Gonçalves Ledo', 'Oficinas', '84040-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15279, 'Toledo', 'Gonçalves Ledo', 'Jardim Alto Alegre', '85910-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15280, 'Ponta Grossa', 'Gonçalves Magalhães', 'Oficinas', '84035-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15281, 'Telêmaco Borba', 'Gongada', 'Vila Esperança', '84272-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15282, 'Cascavel', 'Gonzaguinha', 'Interlagos', '85814-287', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15283, 'São José dos Pinhais', 'Gonzales Pecotche', 'Aristocrata', '83030-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15284, 'Londrina', 'Goro Ohya', 'Eucaliptos', '86031-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15285, 'Curitiba', 'Gotardo Boza', 'Santa Felicidade', '82400-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15286, 'Pato Branco', 'Gotardo Dagostim', 'Morro da Cruz', '85505-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15287, 'Guarapuava', 'Gótigo', 'Morro Alto', '85065-496', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15288, 'São José dos Pinhais', 'Gottfried Leibniz', 'Aristocrata', '83030-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15289, 'Curitiba', 'Gottfried Werner', 'Ganchinho', '81935-340', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15290, 'Curitiba', 'Gottlieb Müeller', 'Alto da Glória', '80030-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15291, 'Curitiba', 'Gottlieb Rosenau', 'Tarumã', '82530-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15292, 'Londrina', 'Gottlieb Schilling', 'Heimtal', '86084-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15293, 'Curitiba', 'Gouber Pinto Dionísio', 'Cidade Industrial', '81460-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15294, 'Arapongas', 'Goura', 'Vila Natal', '86708-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15295, 'Arapongas', 'Goura-vitória', 'Jardim Primavera', '86702-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15296, 'Curitiba', 'Governador Agamenon Magalhães', 'Cristo Rei', '80050-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15297, 'Curitiba', 'Governador Agamenon Magalhães', 'Tarumã', '82800-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15298, 'Araucária', 'Governador Bento Munhoz da Rocha', 'Boqueirão', '83704-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15299, 'Ponta Grossa', 'Governador Bento Munhoz da Rocha Neto', 'Jardim Carvalho', '84016-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15300, 'Telêmaco Borba', 'Governador Bento Munhoz da Rocha Neto', 'Macopa', '84261-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15301, 'Curitiba', 'Governador Carlos Lacerda', 'Cidade Industrial', '81170-460', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15302, 'Guarapuava', 'Governador Edmundo Pinto', 'Boqueirão', '85022-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15303, 'Apucarana', 'Governador Emílio Gomes', 'Jardim Morumbi', '86802-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15304, 'Laranjeiras do Sul', 'Governador Garcez', 'Centro', '85301-325', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15305, 'Toledo', 'Governador Irineu Bornhausen', 'Panorama', '85911-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15306, 'Pato Branco', 'Governador Jorge Lacerda', 'Centro', '85501-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15307, 'Ponta Grossa', 'Governador Jorge Lacerda', 'Jardim Carvalho', '84016-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15308, 'Curitiba', 'Governador Jorge Lacerda', 'Guabirotuba', '81510-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15309, 'Paranaguá', 'Governador José Lacerda', 'Porto dos Padres', '83221-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15310, 'Paranaguá', 'Governador Manoel Ribas', 'Dom Pedro II', '83221-560', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15311, 'Paranaguá', 'Governador Munhoz da Rocha', 'Jardim Paranaguá', '83218-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15312, 'Umuarama', 'Governador Ney Braga', 'Zona I', '87501-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15313, 'Francisco Beltrão', 'Governador Parigot de Souza', 'Cango', '85604-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15314, 'Londrina', 'Governador Parigot de Souza', 'Caiçaras', '86015-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15315, 'Maringá', 'Governador Parigot de Souza', 'Zona 01', '87013-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15316, 'Umuarama', 'Governador Parigot de Souza', 'Zona I', '87501-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15317, 'Umuarama', 'Governador Parigot de Souza', 'Zona VII', '87503-410', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15318, 'Araucária', 'Governador Parigot de Souza', 'Boqueirão', '83704-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15319, 'Guarapuava', 'Governador Pedro Viriato Parigot de Souza', 'Alto da XV', '85065-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15320, 'Ponta Grossa', 'Governador Pedro Viriato Parigot de Souza', 'Jardim Carvalho', '84016-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15321, 'Telêmaco Borba', 'Governador Pedro Viriato Parigot de Souza', 'Bela Vista do Paraíso', '84262-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15322, 'Apucarana', 'Governador Roberto da Silveira', 'Barra Funda', '86800-520', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15323, 'Curitiba', 'Governador Roberto Silveira', 'Cajuru', '82940-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15324, 'Laranjeiras do Sul', 'Governador Trota', 'Centro', '85301-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15325, 'Foz do Iguaçu', 'Governador Valadares', 'Parque Residencial Três Fronteiras', '85855-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15326, 'Guarapuava', 'Governador Valadares', 'Alto Cascavel', '85031-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15327, 'Londrina', 'Governador Valadares', 'Andrade', '86061-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15328, 'Piraquara', 'Governador Valadares', 'Jardim Tropical', '83314-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15329, 'Curitiba', 'Grã Nicco', 'Mossunguê', '81200-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15330, 'Londrina', 'Grã-Bretanha', 'Mister Thomas', '86046-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15331, 'Umuarama', 'Grã-Bretanha', 'Parque Bonfim', '87507-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15332, 'Ponta Grossa', 'Graça Aranha', 'Oficinas', '84045-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15333, 'Pinhais', 'Graça Aranha', 'Núcleo Colonial de Pinhais', '83321-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15334, 'Londrina', 'Gracia Castilho Pagan', 'Portal de Versalhes 1', '86057-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15335, 'Londrina', 'Graciano Benini', 'Pinheiros', '86063-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15336, 'Curitiba', 'Graciette Salmon', 'Uberaba', '81580-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15337, 'Guarapuava', 'Graciliano Ramos', 'Vila Bela', '85025-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15338, 'Londrina', 'Graciliano Ramos', 'Cilo 3', '86073-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15339, 'Francisco Beltrão', 'Graciliano Ramos', 'São Miguel', '85602-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15340, 'Foz do Iguaçu', 'Graciliano Ramos', 'Vila Brasília', '85864-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15341, 'Ponta Grossa', 'Graciliano Ramos', 'Jardim Carvalho', '84015-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15342, 'Toledo', 'Graciliano Ramos', 'Vila Industrial', '85904-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15343, 'Colombo', 'Graciliano Ramos', 'Vila Petrópolis', '83409-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15344, 'Campo Largo', 'Graciliano Ramos', 'São Marcos', '83602-678', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15345, 'Cascavel', 'Graciliano Ramos', 'Alto Alegre', '85805-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15346, 'Francisco Beltrão', 'Graciosa', 'São Cristóvão', '85601-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15347, 'Foz do Iguaçu', 'Graciosa', 'Jardim Ipê II', '85869-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15348, 'Piraquara', 'Graciosa', 'Jardim Bela Vista', '83301-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15349, 'Maringá', 'Graciosa', 'Jardim Guaporé', '87060-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15350, 'Sarandi', 'Graciosa', 'Parque Residencial Nova Aliança', '87111-728', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15351, 'Cascavel', 'Graciosa', 'Universitário', '85819-006', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15352, 'Curitiba', 'Graciosa', 'Cabral', '80035-200', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15353, 'São José dos Pinhais', 'Graciosa Betto Scolaro', 'Miringuava', '83090-427', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15354, 'Cambé', 'Graciosa Buratti', 'Parque Residencial Ana Rosa', '86183-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15355, 'Piraquara', 'Graciosa Jacomel da''Col', 'Vila Fuck', '83305-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15356, 'Londrina', 'Grafita', 'Waldemar Hauer', '86030-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15357, 'Cascavel', 'Grahm Bell', 'Interlagos', '85814-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15358, 'Londrina', 'Grajaú', 'Jacomo Violin', '86025-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15359, 'Pinhais', 'Grajaú', 'Loteamento Alphaville Graciosa', '83327-088', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15360, 'Colombo', 'Grajaú', 'Jardim Curitiba', '83406-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15361, 'Araucária', 'Grajaú', 'Estação', '83705-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15362, 'Laranjeiras do Sul', 'Gralha-azul', 'Vila Industrial', '85303-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15363, 'Guarapuava', 'Gralha-azul', 'São Cristóvão', '85060-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15364, 'Londrina', 'Gralha-azul', 'Waldemar Hauer', '86030-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15365, 'Francisco Beltrão', 'Gralha-azul', 'Miniguaçu', '85605-480', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15366, 'Maringá', 'Gralha-azul', 'Jardim Olímpico', '87070-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15367, 'Maringá', 'Gralha-azul', 'Conjunto Residencial Ney Braga', '87075-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15368, 'Ponta Grossa', 'Gralha-azul', 'Colônia Dona Luiza', '84043-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15369, 'Pato Branco', 'Gralha-azul', 'Planalto', '85509-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15370, 'São José dos Pinhais', 'Gralha-azul', 'Afonso Pena', '83045-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15371, 'Umuarama', 'Gralha-azul', 'Jardim Social', '87506-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15372, 'Sarandi', 'Gralha-azul', 'Conjunto Floresta', '87112-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15373, 'Telêmaco Borba', 'Gralha-azul', 'Vila Gomes', '84272-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15374, 'Apucarana', 'Gralha-azul', 'Recanto das Araras', '86812-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15375, 'Campo Largo', 'Gralha-azul', 'Vila Gilcy', '83609-120', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15376, 'Almirante Tamandaré', 'Gralha-azul', 'Loteamento Montparnasse', '83508-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15377, 'Colombo', 'Gralha-azul', 'Planta Santa Tereza', '83401-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15378, 'Cascavel', 'Gralha-azul', 'Guarujá', '85804-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15379, 'Arapongas', 'Gralha-azul', 'Vila Edio', '86705-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15380, 'Cambé', 'Gralha-azul', 'Conjunto Habitacional Waldomiro M Gomes', '86182-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15381, 'Araucária', 'Gralha-azul', 'Capela Velha', '83706-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15382, 'Curitiba', 'Gralha-azul', 'Cidade Industrial', '81450-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15383, 'Arapongas', 'Gralha-ca-ca', 'Conjunto Tropical', '86702-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15384, 'Arapongas', 'Gralha-de-crista-negra', 'Jardim São Bento', '86706-727', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15385, 'Arapongas', 'Gralha-de-nuca-azul', 'Gleba Arapongas', '86702-805', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15386, 'Arapongas', 'Gralha-do-campo', 'Jardim Aeroporto', '86702-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15387, 'Arapongas', 'Gralha-púrpura', 'Jardim Coroados', '86707-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15388, 'Foz do Iguaçu', 'Gralhas', 'Portal da Foz', '85859-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15389, 'Foz do Iguaçu', 'Gramado', 'Conjunto A', '85861-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15390, 'Foz do Iguaçu', 'Gramado', 'Parque Residencial Três Bandeiras', '85862-240', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15391, 'Francisco Beltrão', 'Gramado', 'Pinheirinho', '85603-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15392, 'Foz do Iguaçu', 'Gramado', 'Jardim Lancaster', '85869-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15393, 'Foz do Iguaçu', 'Gramado', 'Conjunto A', '85860-460', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15394, 'Guarapuava', 'Gramado', 'Morro Alto', '85067-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15395, 'Cascavel', 'Gramado', 'Coqueiral', '85807-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15396, 'Pinhais', 'Gramona', 'Planta Walde Rosi Galvão', '83328-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15397, 'Ponta Grossa', 'Granada', 'Neves', '84021-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15398, 'Telêmaco Borba', 'Granada', 'Vila São Francisco de Assis', '84264-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15399, 'Cascavel', 'Granada', 'Esmeralda', '85806-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15400, 'Foz do Iguaçu', 'Granadas', 'Parque Ouro Verde', '85854-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15401, 'Foz do Iguaçu', 'Grande', 'Jardim Amazonas', '85857-185', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15402, 'Apucarana', 'Grande Alexandre', 'Jardim Independência', '86811-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15403, 'Apucarana', 'Grande Alexandre', 'Vila Nova', '86812-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15404, 'Curitiba', 'Grandes Rios', 'Cidade Industrial', '81250-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15405, 'Londrina', 'Granito', 'Santa Inês', '86030-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15406, 'Foz do Iguaçu', 'Grão-Pará', 'Loteamento Menger', '85862-547', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15407, 'Curitiba', 'Grapira', 'São Braz', '82315-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15408, 'Foz do Iguaçu', 'Graúna', 'Jardim Veneza', '85870-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15409, 'Londrina', 'Graúna', 'Vitória Régia', '86038-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15410, 'Pinhais', 'Graúna', 'Jardim Fênix', '83326-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15411, 'Campo Mourão', 'Graúna', 'Jardim Lopes', '87302-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15412, 'Arapongas', 'Graúna', 'Vila São João', '86708-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15413, 'Curitiba', 'Graúna', 'São Braz', '82315-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15414, 'Foz do Iguaçu', 'Gravataí', 'Jardim Duarte', '85861-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15415, 'Francisco Beltrão', 'Gravataí', 'Pinheirinho', '85603-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15416, 'Arapongas', 'Graveteiro', 'Conjunto Ulisses Guimarães', '86706-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15417, 'Curitiba', 'Graviolas', 'Uberaba', '81550-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15418, 'Foz do Iguaçu', 'Graxaim', 'Conjunto A', '85861-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15419, 'Curitiba', 'Graziele Wolf', 'São João', '82410-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15420, 'Guarapuava', 'Grécia', 'Industrial', '85053-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15421, 'Londrina', 'Grécia', 'Igapó', '86046-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15422, 'Francisco Beltrão', 'Grécia', 'Seminário', '85605-648', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15423, 'Telêmaco Borba', 'Grécia', 'Área 01', '84272-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15424, 'Almirante Tamandaré', 'Grécia', 'Vila Grécia', '83502-430', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15425, 'Cambé', 'Grécia', 'Jardim Primavera', '86181-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15426, 'Cascavel', 'Grécia', 'Cascavel Velho', '85818-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15427, 'Almirante Tamandaré', 'Grécia', 'Vila Graziela', '83505-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15428, 'Ponta Grossa', 'Greenhalgn', 'Oficinas', '84036-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15429, 'Londrina', 'Gregória de Souza Vacário', 'Jardim Maria Celina', '86081-558', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15430, 'Colombo', 'Gregório Adada', 'Vila Esperanceta', '83403-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15431, 'Toledo', 'Gregório Barros', 'Jardim Anápolis', '85905-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15432, 'Londrina', 'Gregório Cherbaty', 'Dom Ático', '86061-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15433, 'Ponta Grossa', 'Gregório da Fonseca', 'Ronda', '84051-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15434, 'Guarapuava', 'Gregório de Matos', 'Dos Estados', '85035-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15435, 'Colombo', 'Gregório de Matos', 'Planta Vila Nova', '83404-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15436, 'Curitiba', 'Gregório de Matos', 'São Lourenço', '82200-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15437, 'Ponta Grossa', 'Gregório de Mattos', 'Jardim Carvalho', '84016-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15438, 'Curitiba', 'Gregório Dorigo', 'Bigorrilho', '80710-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15439, 'Foz do Iguaçu', 'Gregório Dotto', 'Jardim Polo Centro', '85863-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15440, 'Curitiba', 'Gregório Gomes de Oliveira', 'Uberaba', '81580-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15441, 'Apucarana', 'Gregório Holak', 'Jardim Laranjeiras', '86811-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15442, 'Curitiba', 'Gregório Kaviski', 'Campina do Siqueira', '80740-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15443, 'Curitiba', 'Gregório Regeta', 'Sítio Cercado', '81925-588', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15444, 'São José dos Pinhais', 'Gregório Santana', 'Colônia Rio Grande', '83020-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15445, 'Curitiba', 'Gregório Thomaz', 'Capão Raso', '81130-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15446, 'Cascavel', 'Grevílea', 'Parque Verde', '85807-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15447, 'Araucária', 'Grevílea', 'Campina da Barra', '83709-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15448, 'Colombo', 'Groenlândia', 'Jardim Bela Vista', '83404-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15449, 'Cascavel', 'Grota Funda', 'Cataratas', '85818-739', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15450, 'Ponta Grossa', 'Grou', 'Colônia Dona Luiza', '84046-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15451, 'Arapongas', 'Grumara', 'Parque Veneza', '86701-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15452, 'Foz do Iguaçu', 'Gruta', 'Loteamento Residencial Lagoa Vermelha', '85862-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15453, 'Foz do Iguaçu', 'Guabiroba', 'Jardim Amazonas', '85857-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15454, 'Ponta Grossa', 'Guabirobeira', 'Contorno', '84061-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15455, 'Curitiba', 'Guabirotuba', 'Prado Velho', '80215-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15456, 'Ponta Grossa', 'Guacatunga', 'Contorno', '84061-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15457, 'Foz do Iguaçu', 'Guacui', 'Loteamento Campos do Iguaçu', '85857-570', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15458, 'Curitiba', 'Guacui', 'Sítio Cercado', '81935-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15459, 'Arapongas', 'Guacuru', 'Vila Araponguinha', '86705-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15460, 'Londrina', 'Guadalajara', 'Santa Rosa', '86050-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15461, 'Maringá', 'Guadalajara', 'Vila Morangueira', '87040-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15462, 'Paranaguá', 'Guadalajara', 'Campo Grande', '83203-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15463, 'Araucária', 'Guadalajara', 'Centro', '83702-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15464, 'Foz do Iguaçu', 'Guadalupe', 'Loteamento Mata Verde', '85853-685', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15465, 'Umuarama', 'Guadiana', 'Zona I', '87501-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15466, 'Paranaguá', 'Guaianá', 'Vila Guarani', '83221-487', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15467, 'Umuarama', 'Guaianápolis', 'Conjunto Residencial Córrego Longe', '87504-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15468, 'Cambé', 'Guaianases', 'Jardim Tupi', '86183-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15469, 'Umuarama', 'Guaianazes', 'Zona IV', '87504-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15470, 'Apucarana', 'Guaianazes', 'Núcleo Habitacional Colonial', '86812-447', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15471, 'Curitiba', 'Guaianazes', 'Vila Izabel', '80320-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15472, 'Maringá', 'Guaiapó', 'Conjunto Habitacional Karina', '87047-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15473, 'Maringá', 'Guaiapó', 'Jardim Internorte', '87045-115', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15474, 'Maringá', 'Guaiapó', 'Jardim Oásis', '87043-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15475, 'Foz do Iguaçu', 'Guaiaquiça', 'Conjunto A', '85861-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15476, 'Cascavel', 'Guaias', 'Santo Onofre', '85806-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15477, 'Foz do Iguaçu', 'Guaíba', 'Loteamento Campos do Iguaçu', '85857-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15478, 'Londrina', 'Guaíba', 'Oguido', '86025-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15479, 'Paranaguá', 'Guaíba', 'Jardim Guaraituba', '83209-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15480, 'Cascavel', 'Guaíba', 'Periolo', '85817-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15481, 'Apucarana', 'Guaíba', 'Chácara Mate Amargo', '86803-645', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15482, 'Guarapuava', 'Guaiby', 'São Cristóvão', '85063-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15483, 'Guarapuava', 'Guaiciara', 'Conradinho', '85045-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15484, 'Guarapuava', 'Guaicuru', 'Vila Carli', '85040-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15485, 'Londrina', 'Guaicurus', 'Matarazzo', '86026-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15486, 'Cambé', 'Guaicurus', 'Jardim Tupi', '86183-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15487, 'Guarapuava', 'Guaíra', 'Batel', '85015-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15488, 'Londrina', 'Guaíra', 'Castelo', '86027-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15489, 'Francisco Beltrão', 'Guaíra', 'São Cristóvão', '85601-735', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15490, 'Guarapuava', 'Guaíra', 'Boqueirão', '85020-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15491, 'Guarapuava', 'Guaíra', 'Alto da XV', '85065-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15492, 'Laranjeiras do Sul', 'Guaíra', 'Água Verde', '85302-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15493, 'Foz do Iguaçu', 'Guaíra', 'Jardim Paraná', '85867-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15494, 'Guarapuava', 'Guaíra', 'Centro', '85010-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15495, 'Ponta Grossa', 'Guaíra', 'Nova Rússia', '84053-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15496, 'Pinhais', 'Guaíra', 'Jardim Dona Joaquina II', '83325-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15497, 'Maringá', 'Guaíra', 'Zona 07', '87020-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15498, 'Ponta Grossa', 'Guaíra', 'Olarias', '84026-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15499, 'Umuarama', 'Guaíra', 'Jardim Paraíso', '87505-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15500, 'São José dos Pinhais', 'Guaíra', 'Silveira da Motta', '83030-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15501, 'Toledo', 'Guaíra', 'Jardim La Salle', '85902-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15502, 'Toledo', 'Guaíra', 'Jardim La Salle', '85903-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15503, 'Telêmaco Borba', 'Guaíra', 'Bela Vista do Paraíso', '84262-260', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15504, 'Araucária', 'Guaíra', 'Iguaçu', '83701-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15505, 'Cascavel', 'Guaíra', 'Claudete', '85811-380', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15506, 'Colombo', 'Guaíra', 'Jardim São José', '83410-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15507, 'Cascavel', 'Guaíra', 'Recanto Tropical', '85807-430', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15508, 'Cambé', 'Guaíra', 'Jardim Ana Eliza', '86188-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15509, 'Curitiba', 'Guaíra', 'Sítio Cercado', '81910-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15510, 'Arapongas', 'Guairaca', 'Vila Araponguinha', '86705-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15511, 'Curitiba', 'Guairaca', 'Alto Boqueirão', '81860-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15512, 'Guarapuava', 'Guairacá', 'Conradinho', '85045-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15513, 'Foz do Iguaçu', 'Guairacá', 'Jardim Santa Rosa', '85869-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15514, 'Ponta Grossa', 'Guairacá', 'Oficinas', '84035-710', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15515, 'Arapongas', 'Guairacava', 'Jardim do Sol', '86705-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15516, 'Telêmaco Borba', 'Guaitacazes', 'Nossa Senhora do Perpétuo Socorro', '84265-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15517, 'Londrina', 'Guaiuvira', 'Leonor', '86071-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15518, 'Telêmaco Borba', 'Guajuvira', 'Área 01', '84268-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15519, 'Ponta Grossa', 'Gualachos', 'Oficinas', '84035-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15520, 'Ponta Grossa', 'Gualter Oberg', 'Contorno', '84061-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15521, 'Curitiba', 'Guamirim', 'Bairro Alto', '82840-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15522, 'Ponta Grossa', 'Guamirin', 'Uvaranas', '84033-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15523, 'Guarapuava', 'Guanabara', 'Morro Alto', '85067-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15524, 'Francisco Beltrão', 'Guanabara', 'Presidente Kennedy', '85605-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15525, 'Paranavaí', 'Guanabara', 'Parque Morumbi', '87703-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15526, 'São José dos Pinhais', 'Guanabara', 'São Domingos', '83030-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15527, 'Piraquara', 'Guanabara', 'Jardim dos Estados 3', '83307-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15528, 'Umuarama', 'Guanabara', 'Zona VII', '87503-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15529, 'Toledo', 'Guanabara', 'Jardim Santa Maria', '85903-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15530, 'Telêmaco Borba', 'Guanabara', 'Nossa Senhora de Fátima', '84264-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15531, 'Toledo', 'Guanabara', 'Jardim La Salle', '85902-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15532, 'Araucária', 'Guanabara', 'Iguaçu', '83701-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15533, 'Cascavel', 'Guanabara', 'Pioneiros Catarinenses', '85805-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15534, 'Paranaguá', 'Guape', 'Itiberê', '83209-346', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15535, 'Foz do Iguaçu', 'Guapirama', 'Vila Carima', '85855-698', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15536, 'Curitiba', 'Guapirama', 'Fazendinha', '81320-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15537, 'Londrina', 'Guaporé', 'Jardim Palmares', '86025-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15538, 'Francisco Beltrão', 'Guaporé', 'Presidente Kennedy', '85605-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15539, 'Londrina', 'Guaporé', 'Centro', '86026-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15540, 'Foz do Iguaçu', 'Guaporé', 'Loteamento Campos do Iguaçu', '85857-280', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15541, 'Paranaguá', 'Guaporé', 'Santos Dumont', '83209-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15542, 'Maringá', 'Guaporé', 'Jardim Guaporé', '87060-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15543, 'Paranavaí', 'Guaporé', 'Centro', '87705-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15544, 'Piraquara', 'Guaporé', 'Jardim dos Estados 2', '83308-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15545, 'Paranavaí', 'Guaporé', 'Centro', '87703-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15546, 'Pato Branco', 'Guaporé', 'Santo Antônio', '85507-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15547, 'São José dos Pinhais', 'Guaporé', 'Águas Belas', '83010-610', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15548, 'Paranavaí', 'Guaporé', 'Centro', '87704-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15549, 'Sarandi', 'Guaporé', 'Parque Residencial Nova Aliança', '87111-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15550, 'Umuarama', 'Guaporé', 'Zona VII', '87503-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15551, 'Arapongas', 'Guaporé', 'Aricanduva', '86706-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15552, 'Guarapuava', 'Guaporema', 'Boqueirão', '85023-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15553, 'Apucarana', 'Guapuruvu', 'Parque Bela Vista', '86803-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15554, 'Foz do Iguaçu', 'Guará', 'Conjunto A', '85866-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15555, 'Guarapuava', 'Guará', 'Bonsucesso', '85055-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15556, 'Arapongas', 'Guará', 'Jardim Primavera', '86702-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15557, 'Cascavel', 'Guaracas', 'Santo Onofre', '85806-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15558, 'Foz do Iguaçu', 'Guaraci', 'Centro', '85851-026', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15559, 'Londrina', 'Guaraci', 'Oriente', '86027-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15560, 'Ponta Grossa', 'Guaraci', 'Chapada', '84062-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15561, 'São José dos Pinhais', 'Guaraci', 'Boneca do Iguaçu', '83040-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15562, 'Curitiba', 'Guaraci', 'Boqueirão', '81750-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15563, 'Foz do Iguaçu', 'Guaraciaba', 'Jardim Ipê', '85869-677', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15564, 'Ponta Grossa', 'Guaracy Paraná Vieira', 'Boa Vista', '84073-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15565, 'Paranaguá', 'Guaraguaçu', 'Jardim Guaraituba', '83209-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15566, 'Curitiba', 'Guarajuba', 'São Braz', '82310-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15567, 'Curitiba', 'Guaraná', 'Uberaba', '81560-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15568, 'Curitiba', 'Guarandi', 'São Braz', '82015-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15569, 'Laranjeiras do Sul', 'Guarani', 'São Francisco', '85303-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15570, 'Guarapuava', 'Guarani', 'Jardim das Américas', '85031-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15571, 'Guarapuava', 'Guarani', 'Vila Carli', '85040-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15572, 'Foz do Iguaçu', 'Guarani', 'Jardim Tarobá', '85856-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15573, 'Paranavaí', 'Guarani', 'Jardim São Jorge', '87710-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15574, 'Maringá', 'Guarani', 'Zona 04', '87014-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15575, 'São José dos Pinhais', 'Guarani', 'Guatupê', '83060-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15576, 'Piraquara', 'Guarani', 'Vila Dalila', '83303-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15577, 'Pato Branco', 'Guarani', 'Centro', '85501-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15578, 'Umuarama', 'Guarani', 'Zona IV', '87504-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15579, 'Telêmaco Borba', 'Guarani', 'Nossa Senhora do Perpétuo Socorro', '84265-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15580, 'Toledo', 'Guarani', 'Jardim La Salle', '85902-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15581, 'Toledo', 'Guarani', 'Centro', '85900-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15582, 'Apucarana', 'Guarani', 'Núcleo Habitacional Colonial', '86812-417', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15583, 'Campo Mourão', 'Guarani', 'Jardim Lar Paraná', '87305-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15584, 'Campo Mourão', 'Guarani', 'Jardim Pio XII', '87306-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15585, 'Arapongas', 'Guarani', 'Aricanduva', '86706-500', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15586, 'Guarapuava', 'Guaraniacu', 'Industrial', '85053-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15587, 'Guarapuava', 'Guaraniacu', 'Morro Alto', '85067-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15588, 'Laranjeiras do Sul', 'Guaraniacu', 'Água Verde', '85302-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15589, 'Ponta Grossa', 'Guaraniacu', 'Chapada', '84062-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15590, 'Colombo', 'Guaraniacu', 'Vila São José', '83410-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15591, 'Cascavel', 'Guaraniacu', 'São Cristóvão', '85816-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15592, 'Curitiba', 'Guaraniacu', 'Cidade Industrial', '81250-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15593, 'Londrina', 'Guaranis', 'Casoni', '86026-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15594, 'Cascavel', 'Guaranis', 'Santa Cruz', '85806-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15595, 'Apucarana', 'Guaranta', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15596, 'Curitiba', 'Guaranta', 'São Braz', '82315-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15597, 'Colombo', 'Guarany', 'Vila Campo Alto', '83408-318', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15598, 'Foz do Iguaçu', 'Guarapari', 'Jardim Copacabana', '85856-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15599, 'Londrina', 'Guarapari', 'San Remo', '86062-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15600, 'Arapongas', 'Guará-plúmbeo', 'Jardim Coroados', '86707-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15601, 'Londrina', 'Guarapuava', 'Jardim Santo Antônio', '86060-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15602, 'Foz do Iguaçu', 'Guarapuava', 'Jardim Ipê II', '85869-638', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15603, 'Laranjeiras do Sul', 'Guarapuava', 'Centro', '85301-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15604, 'Piraquara', 'Guarapuava', 'Planta Araçatuba', '83301-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15605, 'São José dos Pinhais', 'Guarapuava', 'Cruzeiro', '83010-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15606, 'Toledo', 'Guarapuava', 'Jardim Bressan', '85913-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15607, 'Apucarana', 'Guarapuava', 'Centro', '86800-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15608, 'Cambé', 'Guarapuava', 'Jardim Silvino', '86187-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15609, 'Campo Mourão', 'Guarapuava', 'Centro', '87302-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15610, 'Araucária', 'Guarapuava', 'Iguaçu', '83701-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15611, 'Colombo', 'Guarapuava', 'Jardim São José', '83410-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15612, 'Campo Mourão', 'Guarapuava', 'Centro', '87301-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15613, 'Curitiba', 'Guarapuava', 'Atuba', '82860-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15614, 'Guarapuava', 'Guaraqueçaba', 'Boqueirão', '85023-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15615, 'Foz do Iguaçu', 'Guaraqueçaba', 'Jardim Belvedere I', '85867-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15616, 'Foz do Iguaçu', 'Guaraqueçaba', 'Jardim Norma', '85869-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15617, 'Ponta Grossa', 'Guaraqueçaba', 'Nova Rússia', '84053-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15618, 'São José dos Pinhais', 'Guaraqueçaba', 'Cruzeiro', '83010-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15619, 'Colombo', 'Guaraqueçaba', 'Jardim São José', '83410-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15620, 'Curitiba', 'Guaraqueçaba', 'Cidade Industrial', '81250-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15621, 'Foz do Iguaçu', 'Guararapes', 'Jardim Itamaraty', '85863-746', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15622, 'Foz do Iguaçu', 'Guararapes', 'Conjunto C', '85870-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15623, 'Londrina', 'Guararapes', 'Jardim Higienópolis', '86015-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15624, 'Maringá', 'Guararapes', 'Zona 03', '87050-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15625, 'Cascavel', 'Guararapes', 'Brasmadeira', '85814-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15626, 'Apucarana', 'Guararapes', 'Vila Vitória Régia', '86801-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15627, 'Curitiba', 'Guararapes', 'Vila Izabel', '80320-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15628, 'Telêmaco Borba', 'Guarás', 'Nossa Senhora do Perpétuo Socorro', '84265-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15629, 'Toledo', 'Guarati', 'Boa Esperança', '85909-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15630, 'Maringá', 'Guaratinga', 'Jardim Pássaros', '87075-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15631, 'Arapongas', 'Guaratinga', 'Jardim Bandeirantes', '86703-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15632, 'Francisco Beltrão', 'Guaratinguetá', 'Pinheirinho', '85603-630', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15633, 'Foz do Iguaçu', 'Guaratinguetá', 'Parque Imperatriz', '85862-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15634, 'Telêmaco Borba', 'Guaratinguetá', 'Área 06', '84271-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15635, 'Foz do Iguaçu', 'Guaratuba', 'Jardim Copacabana', '85856-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15636, 'Laranjeiras do Sul', 'Guaratuba', 'Água Verde', '85302-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15637, 'Guarapuava', 'Guaratuba', 'Morro Alto', '85065-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15638, 'Piraquara', 'Guaratuba', 'Planta Araçatuba', '83301-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15639, 'Telêmaco Borba', 'Guaratuba', 'Jardim Bom Jesus', '84262-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15640, 'Umuarama', 'Guaratuba', 'Jardim San Rafael', '87508-148', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15641, 'Colombo', 'Guaratuba', 'Jardim Guilhermina', '83410-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15642, 'Cambé', 'Guaratuba', 'Jardim Ana Eliza', '86188-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15643, 'Cascavel', 'Guaratuba', 'Periolo', '85817-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15644, 'Campo Largo', 'Guaratuba', 'Ferraria', '83609-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15645, 'Curitiba', 'Guaratuba', 'Ahú', '80540-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15646, 'Londrina', 'Guaraúna', 'Conjunto Habitacional Violim', '86084-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15647, 'Arapongas', 'Guaraúna', 'Jardim Primavera', '86702-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15648, 'São José dos Pinhais', 'Guarda da Alzira Ângela', 'Afonso Pena', '83045-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15649, 'Curitiba', 'Guarda-Marinha Greenhalgn', 'Pinheirinho', '81820-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15650, 'Curitiba', 'Guarda-Mor Lustosa', 'Juvevê', '80030-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15651, 'Foz do Iguaçu', 'Guariba', 'Jardim Lancaster II', '85869-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15652, 'Maringá', 'Guarita', 'Vila Bosque', '87005-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15653, 'Ponta Grossa', 'Guarita', 'Contorno', '84061-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15654, 'Foz do Iguaçu', 'Guaru', 'Conjunto A', '85860-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15655, 'Arapongas', 'Guaruba', 'Vila Industrial', '86706-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15656, 'Londrina', 'Guarujá', 'Flórida', '86010-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15657, 'Guarapuava', 'Guarujá', 'Boqueirão', '85020-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15658, 'Foz do Iguaçu', 'Guarujá', 'Jardim Lancaster V', '85869-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15659, 'Pato Branco', 'Guarujá', 'São Roque', '85507-160', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15660, 'Umuarama', 'Guarujá', 'Jardim Ipanema', '87508-167', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15661, 'Curitiba', 'Guarujá', 'Seminário', '80310-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15662, 'Guarapuava', 'Guarulhos', 'Boqueirão', '85020-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15663, 'Londrina', 'Guarulhos', 'Champagnat', '86062-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15664, 'Telêmaco Borba', 'Guarulhos', 'Vila São José', '84263-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15665, 'Cambé', 'Guarulhos', 'Jardim São Paulo', '86191-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15666, 'Arapongas', 'Guarundi', 'Vila São João', '86708-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15667, 'Telêmaco Borba', 'Guatacara Borba Carneiro', 'Nossa Senhora do Perpétuo Socorro', '84265-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15668, 'Apucarana', 'Guatacara Borba Carneiro', 'Núcleo Habitacional Parigot de Souza', '86802-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15669, 'Francisco Beltrão', 'Guatemala', 'Aeroporto', '85603-842', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15670, 'Pinhais', 'Guatemala', 'Vila Varginha', '83320-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15671, 'Ponta Grossa', 'Guatemala', 'Olarias', '84035-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15672, 'Maringá', 'Guatemala', 'Vila Morangueira', '87040-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15673, 'Paranaguá', 'Guatemala', 'Jardim América', '83209-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15674, 'Telêmaco Borba', 'Guatemala', 'Alto das Oliveiras', '84266-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15675, 'Cascavel', 'Guatemala', 'Alto Alegre', '85805-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15676, 'Colombo', 'Guatemala', 'Vila Marcelina', '83404-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15677, 'Apucarana', 'Guatemala', 'Parque Bela Vista', '86803-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15678, 'Cascavel', 'Guatemala', 'Periolo', '85817-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15679, 'Curitiba', 'Guatemala', 'Guaíra', '81010-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15680, 'São José dos Pinhais', 'Guatupê', 'Guatupê', '83060-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15681, 'São José dos Pinhais', 'Guatupê', 'Ipê', '83055-530', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15682, 'Arapongas', 'Guaxe', 'Vila São João', '86708-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15683, 'Foz do Iguaçu', 'Guaxupé', 'Loteameto Dona Amanda', '85853-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15684, 'Maringá', 'Guedner', 'Jardim Santa Rita', '87050-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15685, 'Maringá', 'Guedner', 'Parque da Gávea', '87053-265', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15686, 'Londrina', 'Guerido Grandi', 'Conjunto Vivi Xavier', '86082-115', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15687, 'Toledo', 'Guerino Antônio Vicari', 'Jardim Europa', '85907-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15688, 'Maringá', 'Guerino Baldo', 'Conjunto Prolar', '87055-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15689, 'Araucária', 'Guerino Basso', 'Vila Nova', '83703-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15690, 'Francisco Beltrão', 'Guerino Borba', 'São Miguel', '85602-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15691, 'Francisco Beltrão', 'Guerino Buzato', 'Pinheirinho', '85606-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15692, 'Cambé', 'Guerino Cazarotto', 'Jardim Vila Rica', '86191-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15693, 'Francisco Beltrão', 'Guerino Celuppi', 'Pinheirinho', '85603-171', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15694, 'Araucária', 'Guerino Dea', 'Boqueirão', '83704-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15695, 'Colombo', 'Guerino Fiorese', 'Fervida', '83415-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15696, 'Londrina', 'Guerino Lainetti', 'Lago Juliana', '86038-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15697, 'Toledo', 'Guerino Maschio', 'Jardim Concórdia', '85906-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15698, 'Londrina', 'Guerino Massaro', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15699, 'Londrina', 'Guerino Romagnolli', 'Jardim Alphaville', '86084-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15700, 'Campo Largo', 'Guerino Scopel', 'Bom Jesus', '83604-500', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15701, 'Londrina', 'Guerino Turci', 'Jardim Itatiaia 2', '86047-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15702, 'Ponta Grossa', 'Guerra Junqueira', 'Uvaranas', '84020-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15703, 'Londrina', 'Guerreiro José Fernandes', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15704, 'Curitiba', 'Guglielmo Marconi', 'Bairro Alto', '82820-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15705, 'Londrina', 'Guia Lopes', 'Califórnia', '86040-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15706, 'Paranavaí', 'Guia Lopes', 'Jardim São Jorge', '87711-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15707, 'Ponta Grossa', 'Guia Lopes', 'Uvaranas', '84030-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15708, 'Telêmaco Borba', 'Guiana', 'Vila Rosa', '84272-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15709, 'Apucarana', 'Guiana', 'Núcleo Habitacional Vale Verde', '86805-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15710, 'Apucarana', 'Guiana Francesa', 'Núcleo Habitacional Vale Verde', '86805-256', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15711, 'Sarandi', 'Guiapo', 'Centro', '87111-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15712, 'Londrina', 'Guido Ambrósio', 'Ponte Seca', '86042-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15713, 'Londrina', 'Guido Betoni', 'Colúmbia', '86057-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15714, 'Toledo', 'Guido Friedrich', 'Jardim Parizzotto', '85914-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15715, 'Foz do Iguaçu', 'Guido Lakus', 'Jardim Norma', '85869-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15716, 'Londrina', 'Guido Marques', 'Vila Canziani', '86010-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15717, 'Curitiba', 'Guido Scotti', 'Tingui', '82620-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15718, 'Curitiba', 'Guido Trevisan', 'Pinheirinho', '81825-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15719, 'São José dos Pinhais', 'Guido Vaccari', 'Rio Pequeno', '83070-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15720, 'Cascavel', 'Guido Viaro', 'Country', '85813-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15721, 'Curitiba', 'Guido Vicente Negrello', 'Umbará', '81940-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15722, 'Londrina', 'Guido Vizintin', 'Cambezinho', '86040-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15723, 'Foz do Iguaçu', 'Guido Welter', 'Condomínio de Lazer Helena', '85853-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15724, 'Piraquara', 'Guilherme Afonso Martins', 'Vila São Cristóvão', '83305-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15725, 'Curitiba', 'Guilherme Alberto Hellmuth Seyer', 'Vista Alegre', '82100-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15726, 'Castro', 'Guilherme Alfredo Kiel', 'Jardim dos Bancários', '84172-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15727, 'Ponta Grossa', 'Guilherme Augusto Jansen', 'Uvaranas', '84030-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15728, 'Londrina', 'Guilherme Augusto Menoncin', 'Jardim Campos Verdes', '86085-256', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15729, 'Piraquara', 'Guilherme Beetz', 'Jardim Bom Jesus dos Passos', '83301-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15730, 'Curitiba', 'Guilherme Born', 'Cristo Rei', '80050-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15731, 'São José dos Pinhais', 'Guilherme Bortolotti', 'Afonso Pena', '83045-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15732, 'Curitiba', 'Guilherme Braga de Abreu Pires', 'Pilarzinho', '82100-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15733, 'Londrina', 'Guilherme Branco Neto', 'Jardim Lago Norte', '86078-447', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15734, 'Curitiba', 'Guilherme Bruschz', 'Sítio Cercado', '81920-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15735, 'Curitiba', 'Guilherme Bueno Franco', 'Tatuquara', '81480-337', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15736, 'Guarapuava', 'Guilherme Camillo', 'Boqueirão', '85020-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15737, 'Colombo', 'Guilherme Canestraro', 'Jardim Paraná', '83412-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15738, 'Pinhais', 'Guilherme Ceolin', 'Núcleo Colonial de Pinhais', '83321-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15739, 'Londrina', 'Guilherme Chiarotti', 'Eucaliptos', '86031-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15740, 'Curitiba', 'Guilherme Chiarotti', 'Santa Cândida', '82640-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15741, 'Londrina', 'Guilherme da Mota Correia', 'Jardim Tatiani', '86070-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15742, 'São José dos Pinhais', 'Guilherme Dal Negro', 'Colônia Rio Grande', '83025-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15743, 'Londrina', 'Guilherme de Almeida', 'Indústrias', '86043-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15744, 'Londrina', 'Guilherme de Almeida', 'Ouro Branco', '86042-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15745, 'Maringá', 'Guilherme de Almeida', 'Zona 01', '87013-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15746, 'Campo Mourão', 'Guilherme de Paula Xavier', 'Jardim Alvorada', '87308-570', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15747, 'Campo Mourão', 'Guilherme de Paula Xavier', 'Centro', '87303-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15748, 'Campo Mourão', 'Guilherme de Paula Xavier', 'Centro', '87302-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15749, 'Curitiba', 'Guilherme de Souza Valente', 'Abranches', '82220-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15750, 'Curitiba', 'Guilherme do Valle Nepomuceno', 'Orleans', '82310-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15751, 'Curitiba', 'Guilherme Donatti', 'Capão da Imbuia', '82810-470', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15752, 'Londrina', 'Guilherme Farel', 'Gleba Fazenda Palhano', '86055-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15753, 'Curitiba', 'Guilherme Fugmann', 'Cidade Industrial', '81305-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15754, 'São José dos Pinhais', 'Guilherme Gasparello', 'Braga', '83020-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15755, 'Almirante Tamandaré', 'Guilherme Grabowski', 'Jardim Vitória', '83508-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15756, 'Pato Branco', 'Guilherme Granzotto', 'Centro', '85502-490', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15757, 'Guarapuava', 'Guilherme Haenich', 'Vila Bela', '85027-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15758, 'Foz do Iguaçu', 'Guilherme Hubner', 'Cohapar III', '85858-570', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15759, 'Curitiba', 'Guilherme Ihlenfeldt', 'Tingui', '82620-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15760, 'Curitiba', 'Guilherme Janz', 'Mossunguê', '81210-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15761, 'Londrina', 'Guilherme Kernkamp', 'Conjunto Parigot de Souza 1', '86081-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15762, 'Londrina', 'Guilherme Kernkamp', 'Heimtal', '86084-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15763, 'Londrina', 'Guilherme Kernkamp', 'Heimtal', '86084-035', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15764, 'Curitiba', 'Guilherme Kloss', 'Cidade Industrial', '81270-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15765, 'Curitiba', 'Guilherme Kupka', 'Cidade Industrial', '81460-277', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15766, 'Curitiba', 'Guilherme Langner', 'Pinheirinho', '81880-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15767, 'Pato Branco', 'Guilherme Lebkuchen', 'Anchieta', '85501-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15768, 'Toledo', 'Guilherme Leyser', 'Jardim Porto Alegre', '85906-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15769, 'Francisco Beltrão', 'Guilherme Lindner', 'Pinheirinho', '85606-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15770, 'Curitiba', 'Guilherme Luiz de V. Lara', 'Cidade Industrial', '81315-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15771, 'Curitiba', 'Guilherme Lunardon', 'Pilarzinho', '82110-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15772, 'Curitiba', 'Guilherme Marconcin', 'Uberaba', '81570-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15773, 'Londrina', 'Guilherme Marconi', 'Industrial', '86063-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15774, 'Curitiba', 'Guilherme Martini', 'Santa Quitéria', '80310-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15775, 'Londrina', 'Guilherme Massaro', 'Arco Íris', '86050-105', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15776, 'Curitiba', 'Guilherme Matter', 'Santa Cândida', '82640-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15777, 'Curitiba', 'Guilherme Mazeto', 'Pinheirinho', '81110-436', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15778, 'Curitiba', 'Guilherme Mehl', 'Umbará', '81930-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15779, 'Campo Mourão', 'Guilherme Naimann', 'Jardim Alvorada', '87308-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15780, 'Colombo', 'Guilherme Nass', 'Jardim Guaíra', '83402-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15781, 'Curitiba', 'Guilherme Nievola', 'Xaxim', '81720-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15782, 'Curitiba', 'Guilherme Nizer', 'Tatuquara', '81470-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15783, 'Curitiba', 'Guilherme Nunes Nogueira', 'Cajuru', '82900-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15784, 'Curitiba', 'Guilherme Otto', 'Cachoeira', '82710-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15785, 'Cascavel', 'Guilherme Piovesan', 'Brasmadeira', '85814-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15786, 'Curitiba', 'Guilherme Pugsley', 'Água Verde', '80610-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15787, 'Curitiba', 'Guilherme Pugsley', 'Água Verde', '80620-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15788, 'Piraquara', 'Guilherme Ribeiro', 'Vila São Cristóvão', '83305-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15789, 'Londrina', 'Guilherme Ribeiro Soares', 'Shangri-La', '86070-065', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15790, 'Londrina', 'Guilherme Rizzi', 'Alto da Boa Vista', '86083-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15791, 'Colombo', 'Guilherme Rodbard', 'Jardim Ouro Verde', '83405-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15792, 'Curitiba', 'Guilherme Ronconi', 'Juvevê', '80035-015', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15793, 'Ponta Grossa', 'Guilherme Scheiffer', 'Uvaranas', '84030-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15794, 'Ponta Grossa', 'Guilherme Schneder', 'Contorno', '84060-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15795, 'Ponta Grossa', 'Guilherme Schneider', 'Uvaranas', '84060-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15796, 'Curitiba', 'Guilherme Schultz', 'Campo Comprido', '81210-470', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15797, 'Curitiba', 'Guilherme Scroccaro', 'Tatuquara', '81940-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15798, 'Curitiba', 'Guilherme Seeger', 'Bom Retiro', '80520-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15799, 'Colombo', 'Guilherme Socher', 'Jardim Macaé', '83402-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15800, 'Sarandi', 'Guilherme Sônego', 'Jardim Nova Paulista', '87111-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15801, 'Curitiba', 'Guilherme Toniolo', 'Boa Vista', '82560-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15802, 'Curitiba', 'Guilherme Tragante', 'Tarumã', '82800-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15803, 'Umuarama', 'Guilherme Trindade de Souza', 'Zona VII', '87503-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15804, 'Ponta Grossa', 'Guilherme Voigt', 'Uvaranas', '84026-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15805, 'Curitiba', 'Guilherme Walter Lowry', 'Uberaba', '81590-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15806, 'Colombo', 'Guilherme Weigert', 'Jardim Guadalajara', '83402-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15807, 'Curitiba', 'Guilherme Weigert', 'Santa Cândida', '82720-000', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15808, 'Pinhais', 'Guilherme Weiss', 'Vila Tarumã', '83323-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15809, 'Curitiba', 'Guilherme Wisniewski', 'Santa Cândida', '82630-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15810, 'Curitiba', 'Guilherme Wrany', 'Atuba', '82860-560', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15811, 'Castro', 'Guilherme Zimmerman', 'Centro', '84165-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15812, 'Colombo', 'Guilhermina Alves Cordeiro', 'Jardim dos Eucaliptos', '83408-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15813, 'Curitiba', 'Guilhermina Carmen Serra', 'Alto Boqueirão', '81860-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15814, 'Piraquara', 'Guilhermina Clippel Gaio', 'Centro', '83301-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15815, 'Curitiba', 'Guilhermina Fernandes', 'Cidade Industrial', '81280-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15816, 'Colombo', 'Guilhermina Foss Fromholz', 'Walfrido do Rosário', '83413-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15817, 'Londrina', 'Guilhermina Lahmann', 'Aquilles Sthengel', '86086-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15818, 'Londrina', 'Guilhermina Maria Conceição', 'Dom Pedro II', '86073-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15819, 'Almirante Tamandaré', 'Guilhermina Ribeiro', 'Jardim Dona Luiza', '83506-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15820, 'Foz do Iguaçu', 'Guimarães Rosa', 'Jardim América', '85864-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15821, 'Londrina', 'Guimarães Rosa', 'Santa Maria', '86035-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15822, 'Foz do Iguaçu', 'Guimarães Rosa', 'Vila Portes', '85865-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15823, 'Toledo', 'Guimarães Rosa', 'Jardim Bela Vista', '85908-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15824, 'Colombo', 'Guimarães Rosa', 'Jardim das Perdizes', '83409-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15825, 'Cascavel', 'Guinard', 'Independência', '85813-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15826, 'Londrina', 'Guiné', 'Ouro Verde', '86080-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15827, 'Pinhais', 'Guiné', 'Vila Palmital', '83320-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15828, 'Telêmaco Borba', 'Guiné', 'Área 01', '84272-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15829, 'Toledo', 'Guiné', 'Vila Brasil', '85909-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15830, 'Ponta Grossa', 'Guiomar Novaes', 'Centro', '84010-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15831, 'Curitiba', 'Guiraponga', 'São Braz', '82310-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15832, 'Curitiba', 'Guiroku Gastão Ayabe', 'Uberaba', '81510-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15833, 'Curitiba', 'Guissardo Pilati', 'Uberaba', '81590-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15834, 'Londrina', 'Gulherme de Almeida', 'Parque Residencial Campos Elísios', '86044-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15835, 'Curitiba', 'Gumercindo Achilles Genol', 'Pinheirinho', '81880-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15836, 'Londrina', 'Gumercindo de Souza', 'Shangri-La', '86070-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15837, 'Campo Largo', 'Gumercindo Emeliano Vieira', 'Vila Rivabem', '83605-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15838, 'Curitiba', 'Gumercindo Marés', 'Vista Alegre', '80810-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15839, 'Araucária', 'Gumercindo Rosa Pimenta', 'Tindiquera', '83708-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15840, 'Londrina', 'Gumercindo Saraiva', 'Boa Vista', '86015-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15841, 'Londrina', 'Gungadim', 'Jardim Europa', '86015-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15842, 'Cascavel', 'Gurgel', 'Universitário', '85819-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15843, 'Londrina', 'Gurucaia', 'Leonor', '86071-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15844, 'Ponta Grossa', 'Gurucaia', 'Contorno', '84061-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15845, 'Maringá', 'Gurucaia', 'Zona 02', '87005-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15846, 'Arapongas', 'Gurundi', 'Vila Sampaio', '86705-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15847, 'Arapongas', 'Guruva', 'Jardim Primavera', '86702-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15848, 'Curitiba', 'Gustav Hermann Strobel', 'Pilarzinho', '82100-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15849, 'Ponta Grossa', 'Gustavo Adolpho Roedel', 'Jardim Carvalho', '84016-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15850, 'Curitiba', 'Gustavo Ambrus', 'Prado Velho', '80215-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15851, 'Araucária', 'Gustavo Arthur Cantelle', 'Tindiquera', '83708-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15852, 'Londrina', 'Gustavo Barroso', 'Jardim Tatiani', '86070-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15853, 'Toledo', 'Gustavo Barroso', 'Panorama', '85911-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15854, 'Curitiba', 'Gustavo Barroso', 'Barreirinha', '82220-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15855, 'Londrina', 'Gustavo Branco', 'Jardim Lago Norte', '86078-448', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15856, 'Pinhais', 'Gustavo Corção', 'Chácara Esperança', '83328-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15857, 'Foz do Iguaçu', 'Gustavo Dobrandino da Silva', 'Jardim Itamaraty', '85863-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15858, 'Ponta Grossa', 'Gustavo Emílio Jansen', 'Contorno', '84062-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15859, 'Curitiba', 'Gustavo Germano Brand', 'Sítio Cercado', '81920-756', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15860, 'Toledo', 'Gustavo Isernhagen', 'Independência', '85906-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15861, 'Campo Mourão', 'Gustavo João Quenneaen', 'Jardim Alvorada', '87308-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15862, 'Almirante Tamandaré', 'Gustavo Joppert', 'Loteamento Formoso', '83514-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15863, 'Colombo', 'Gustavo Kabitschke', 'Vila Alto da Cruz II', '83405-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15864, 'Curitiba', 'Gustavo Knorr', 'Bacacheri', '82600-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15865, 'Londrina', 'Gustavo Kruger', 'Heimtal', '86084-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15866, 'Ponta Grossa', 'Gustavo Maister', 'Uvaranas', '84025-005', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15867, 'Colombo', 'Gustavo Nass', 'Jardim Contorno', '83402-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15868, 'Curitiba', 'Gustavo Prestes Aldenucci', 'Sítio Cercado', '81910-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15869, 'Curitiba', 'Gustavo Rattman', 'Bacacheri', '82520-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15870, 'Curitiba', 'Gustavo Schier', 'Novo Mundo', '81050-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15871, 'Piraquara', 'Gustavo Wachols', 'Vila Mariana', '83311-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15872, 'Curitiba', 'Gutemberg', 'Batel', '80420-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15873, 'Piraquara', 'Guttemberg', 'Jardim Bela Vista', '83301-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15874, 'Curitiba', 'Guy de Maupassant', 'Pilarzinho', '82110-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15875, 'Foz do Iguaçu', 'H', 'Conjunto C', '85870-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15876, 'Ponta Grossa', 'H', 'Chapada', '84062-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15877, 'Ponta Grossa', 'H', 'Uvaranas', '84032-486', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15878, 'Paranavaí', 'H', 'Jardim Videira', '87711-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15879, 'Ponta Grossa', 'H', 'Contorno', '84060-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15880, 'Ponta Grossa', 'H', 'Neves', '84021-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15881, 'Umuarama', 'H', 'Conjunto Residencial Guarani III', '87509-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15882, 'Umuarama', 'H', 'Núcleo Cruzeiro', '87509-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15883, 'Umuarama', 'H', 'Jardim San Fernando', '87508-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15884, 'Umuarama', 'H', 'Parque das Jaboticabeiras', '87509-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15885, 'Umuarama', 'H', 'Parque Dom Pedro I', '87508-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15886, 'Castro', 'H', 'Vila do Rosário', '84168-086', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15887, 'Almirante Tamandaré', 'H', 'Parque Timbu', '83514-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15888, 'Campo Largo', 'H', 'Popular Nova', '83602-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15889, 'Almirante Tamandaré', 'H', 'Jardim Marrocos', '83511-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15890, 'Castro', 'H', 'Jardim Bela Vista', '84165-427', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15891, 'Almirante Tamandaré', 'H', 'Loteamento Recanto dos Papagaios', '83512-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15892, 'Campo Mourão', 'H', 'Distrito Industrial I', '87306-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15893, 'Campo Mourão', 'H', 'Jardim Nossa Senhora Aparecida', '87309-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15894, 'Campo Largo', 'H', 'Jardim Três Rios', '83603-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15895, 'Arapongas', 'H-1', 'Vila Araponguinha', '86705-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15896, 'Arapongas', 'H-2', 'Vila Araponguinha', '86705-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15897, 'Arapongas', 'H-4', 'Vila Sampaio', '86705-106', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15898, 'Arapongas', 'H-5', 'Vila Sampaio', '86705-186', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15899, 'Arapongas', 'H-6', 'Vila Sampaio', '86705-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15900, 'Arapongas', 'H-7', 'Vila Araponguinha', '86705-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15901, 'Arapongas', 'H-8', 'Vila Sampaio', '86705-107', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15902, 'São José dos Pinhais', 'Habib Sarkis', 'Afonso Pena', '83045-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15903, 'Curitiba', 'Habib Taherzadeh', 'Bairro Alto', '82840-125', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15904, 'Londrina', 'Hadock Lobo', 'Erotildes', '86015-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15905, 'Curitiba', 'Haidee Pereira do Nascimento', 'Novo Mundo', '81050-648', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15906, 'Ponta Grossa', 'Hairote', 'Jardim Carvalho', '84016-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15907, 'Londrina', 'Haiti', 'Arco Íris', '86050-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15908, 'Maringá', 'Haiti', 'Vila Morangueira', '87040-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15909, 'Pinhais', 'Haiti', 'Vila Varginha', '83320-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15910, 'Paranaguá', 'Haiti', 'Jardim América', '83209-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15911, 'Telêmaco Borba', 'Haiti', 'Vila Cristina', '84272-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15912, 'Colombo', 'Haiti', 'Jardim Rio Verde', '83405-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15913, 'Apucarana', 'Haiti', 'Parque Bela Vista', '86803-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15915, 'Cascavel', 'Haiti', 'Periolo', '85817-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15916, 'Curitiba', 'Haiti', 'Guaíra', '81010-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15917, 'Ponta Grossa', 'Haity', 'Jardim Carvalho', '84016-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15918, 'Campo Mourão', 'Hale Nasser', 'Jardim Lar Paraná', '87305-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15919, 'Curitiba', 'Halim Youssef Ghanem', 'Cidade Industrial', '81305-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15920, 'Londrina', 'Halzey Colli', 'Parigot de Souza 2', '86082-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15921, 'Curitiba', 'Hamílcar Pizzatto', 'Tatuquara', '81480-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15922, 'Curitiba', 'Hamiltom César Cognialli', 'Santa Cândida', '82640-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15923, 'Castro', 'Hamilton Corrêa', 'Jardim Colonial', '84178-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15924, 'Colombo', 'Hamilton de Lima Suss', 'Jardim Cruzeiro', '83403-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15925, 'Curitiba', 'Hamilton de Oliveira', 'Cajuru', '82930-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15926, 'São José dos Pinhais', 'Hamilton Luiz Ubá', 'Miringuava', '83090-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15927, 'Curitiba', 'Hamilton Marcon', 'Cidade Industrial', '81305-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15928, 'Curitiba', 'Hamilton Pinto Alves', 'Sítio Cercado', '81935-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15929, 'Curitiba', 'Hamilton Pospissil', 'Bairro Alto', '82820-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15930, 'Curitiba', 'Hamilton Taborda Ribas', 'Cidade Industrial', '81315-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15931, 'Ponta Grossa', 'Hamilton Volpi', 'Chapada', '84062-677', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15932, 'Curitiba', 'Hamurabi', 'Santa Cândida', '82630-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15933, 'Curitiba', 'Hans João Rogalsky', 'Xaxim', '81830-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15934, 'Curitiba', 'Hans Kelsen', 'Santa Cândida', '82720-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15935, 'Castro', 'Hans Mayer', 'Castroville', '84178-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15936, 'Londrina', 'Hans Staden', 'Novo Antares', '86036-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15937, 'Ponta Grossa', 'Hara', 'Jardim Carvalho', '84016-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15938, 'Sarandi', 'Harmonia', 'Parque Alvamar', '87113-490', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15939, 'Telêmaco Borba', 'Harmonia', 'Área 02', '84267-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15940, 'Telêmaco Borba', 'Harmonia', 'Socomim', '84266-510', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15941, 'Curitiba', 'Haroldo Correia Araújo', 'Boa Vista', '82650-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15942, 'Londrina', 'Haroldo de Freitas', 'Jardim Império do Sol', '86073-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15943, 'Curitiba', 'Haroldo Drummond de Carvalho', 'Cajuru', '82970-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15944, 'Ponta Grossa', 'Haroldo Fernando Geber', 'Neves', '84020-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15945, 'Ponta Grossa', 'Haroldo Franze', 'Uvaranas', '84030-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15946, 'Ponta Grossa', 'Haroldo Gerber', 'Contorno', '84061-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15947, 'Toledo', 'Haroldo Hamilton', 'Centro', '85905-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15948, 'Araucária', 'Haroldo Lemos', 'Costeira', '83708-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15949, 'Curitiba', 'Haroldo Maravalhas', 'Cidade Industrial', '81350-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15950, 'Apucarana', 'Haroldo Tomohiko Aki', 'Núcleo Habitacional Heitor S Pinheiro', '86806-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15951, 'Foz do Iguaçu', 'Hárpia', 'Conjunto A', '85866-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15952, 'Londrina', 'Hárpia', 'Conjunto Habitacional Violim', '86084-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15953, 'Cascavel', 'Hárpia', 'Floresta', '85814-790', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15954, 'Arapongas', 'Hárpia', 'Centro', '86701-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15955, 'Campo Mourão', 'Harrison José Borges', 'Centro', '87303-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15956, 'Campo Mourão', 'Harrison José Borges', 'Centro', '87300-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15957, 'Curitiba', 'Harry Blas Gomm', 'Seminário', '80310-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15958, 'Curitiba', 'Harry Carlos Wekerlin', 'Sítio Cercado', '81910-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15959, 'Curitiba', 'Harry Delmonte Janz', 'Mossunguê', '81210-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15960, 'São José dos Pinhais', 'Harry Feeken', 'Boneca do Iguaçu', '83040-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15961, 'Curitiba', 'Harry Grahl', 'Umbará', '81930-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15962, 'Londrina', 'Harry Prochet', 'São Jorge', '86047-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15963, 'Maringá', 'Harry Prochet', 'Zona 06', '87015-480', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15964, 'Maringá', 'Harry Prochet', 'Parque Industrial Bandeirantes', '87070-120', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15965, 'Foz do Iguaçu', 'Harry Shinkle', 'Jardim Iguaçu', '85853-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15966, 'Piraquara', 'Hartwig Müller', 'Guarituba', '83311-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15967, 'Londrina', 'Harue Tanaka', 'Residencial Veneza', '86038-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15968, 'Curitiba', 'Harvey de Barros Silva', 'Pilarzinho', '82110-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15969, 'Curitiba', 'Hasdrúbal Bellegard', 'Cidade Industrial', '81460-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15970, 'Ponta Grossa', 'Hasmona', 'Jardim Carvalho', '84016-686', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15971, 'Curitiba', 'Hassan Mohamed Raad', 'Barreirinha', '82220-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15972, 'Curitiba', 'Hassib Jezzini', 'Fanny', '81030-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15973, 'Umuarama', 'Havaí', 'Jardim Paraíso', '87505-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15974, 'Londrina', 'Havana', 'Arco Íris', '86050-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15975, 'Umuarama', 'Havana', 'Conjunto Residencial Córrego Longe', '87504-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15976, 'Colombo', 'Havana', 'Planta Cristóvão Colombo', '83404-540', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15977, 'Cascavel', 'Havana', 'Periolo', '85817-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15978, 'Maringá', 'Hawai', 'Vila Morangueira', '87040-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15979, 'Telêmaco Borba', 'Hawita', 'Jardim Bonavila', '84264-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15980, 'Curitiba', 'Hayao Washida', 'Jardim Botânico', '80210-375', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15981, 'Curitiba', 'Hayde Pacheco Faria', 'Sítio Cercado', '81900-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15982, 'Apucarana', 'Haydio Miguel de Souza', 'Parque Industrial Zona Norte', '86806-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15983, 'Curitiba', 'Hayton da Silva Pereira', 'Capão da Imbuia', '82810-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15984, 'Londrina', 'Heber Soares Vargas', 'Ilha Bela', '86036-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15985, 'Ponta Grossa', 'Hebreus', 'Chapada', '84062-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15986, 'Cambé', 'Hebreus', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15987, 'Curitiba', 'Hedwirges Nadolny', 'Santa Cândida', '82620-380', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15988, 'Curitiba', 'Hedwirges Sophia Walesco', 'Xaxim', '81830-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15989, 'Curitiba', 'Hee Wing', 'Água Verde', '80620-510', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15990, 'Paranavaí', 'Heihachiro Niekawa', 'Jardim Farropilha', '87708-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15991, 'Paranavaí', 'Heihachiro Niekawa', 'Jardim Nossa Senhora de Fátima', '87707-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15992, 'Paranavaí', 'Heihachiro Niekawa', 'Jardim do Sol', '87711-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15993, 'Curitiba', 'Heinrich Lowen', 'Xaxim', '81720-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15994, 'Curitiba', 'Heinz Pechner', 'Cidade Industrial', '81280-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15995, 'Paranavaí', 'Heitor Alencar Furtado', 'Jardim Paraíso', '87708-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15996, 'Paranavaí', 'Heitor Alencar Furtado', 'Jardim Farropilha', '87707-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15997, 'Paranavaí', 'Heitor Alencar Furtado', 'Jardim Santos Dumont', '87706-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15998, 'Paranavaí', 'Heitor Alencar Furtado', 'Jardim São Jorge', '87711-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (15999, 'Paranavaí', 'Heitor Alencar Furtado', 'Jardim São Jorge', '87710-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16000, 'Araucária', 'Heitor Alves Guimarães', 'Centro', '83702-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16001, 'Araucária', 'Heitor Alves Guimarães', 'Iguaçu', '83701-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16002, 'Curitiba', 'Heitor Baggio Vidal', 'Bairro Alto', '82840-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16003, 'Curitiba', 'Heitor Baggio Vidal', 'Bairro Alto', '82820-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16004, 'Londrina', 'Heitor Barbosa Maciel', 'Jardim Primavera', '86086-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16005, 'São José dos Pinhais', 'Heitor Berleze', 'Costeira', '83015-718', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16006, 'Colombo', 'Heitor Busato', 'Sapopema', '83407-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16007, 'Curitiba', 'Heitor Cresto', 'Santa Quitéria', '80310-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16008, 'Curitiba', 'Heitor de Andrade', 'Jardim das Américas', '81530-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16009, 'Araucária', 'Heitor do Vale Joslin', 'Campina da Barra', '83709-826', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16010, 'Maringá', 'Heitor Dutra da Silva', 'Vila Nova', '87045-710', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16011, 'Curitiba', 'Heitor Ferreira', 'Tatuquara', '81480-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16012, 'Paranaguá', 'Heitor Ferruci', 'Serraria do Rocha', '83221-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16013, 'Curitiba', 'Heitor Gurgel do Amaral Valente Netto', 'Campina do Siqueira', '80740-670', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16014, 'Castro', 'Heitor Jorge Iucksch', 'Jardim das Araucárias', '84174-639', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16015, 'Londrina', 'Heitor Lima', 'Jardim Shangri-la A', '86070-520', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16016, 'Guarapuava', 'Heitor Manente', 'Primavera', '85050-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16017, 'São José dos Pinhais', 'Heitor Moro', 'Costeira', '83015-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16018, 'Piraquara', 'Heitor Pallu', 'Guarituba', '83310-446', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16019, 'Curitiba', 'Heitor Quinteiro', 'Cajuru', '82900-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16020, 'Cascavel', 'Heitor Stockler de Franca', 'Maria Luiza', '85819-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16021, 'Curitiba', 'Heitor Stockler de Franca', 'Centro Cívico', '80030-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16022, 'Foz do Iguaçu', 'Heitor Vila-Lobos', 'Parque Residencial Três Bandeiras', '85862-248', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16023, 'Colombo', 'Heitor Vila-Lobos', 'Parque Monte Castelo', '83409-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16024, 'Apucarana', 'Heitor Vila-Lobos', 'Núcleo Habitacional Castelo Branco', '86812-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16025, 'Cascavel', 'Heitor Vila-Lobos', 'Brasília', '85815-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16026, 'Curitiba', 'Hélcio da Cunha Ajuz', 'Xaxim', '81710-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16027, 'Londrina', 'Heldo Spacini', 'Portal Norte', '86079-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16028, 'Londrina', 'Helen Keller', 'Roveri', '86039-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16029, 'Colombo', 'Helena Alves Ferreira Ribeiro', 'Jardim dos Eucaliptos', '83408-517', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16030, 'Londrina', 'Helena Androukowitch Quiles', 'Jardim Pioneiros', '86036-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16031, 'Londrina', 'Helena Anunciada Betti', 'Jardim Marissol', '86030-496', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16032, 'Londrina', 'Helena Aparecida Ridão', 'Conjunto Manoel Gonçalves', '86073-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16033, 'Guarapuava', 'Helena Aracy de Barros', 'Vila Bela', '85025-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16034, 'Pinhais', 'Helena Bachmann Muhlmann', 'Vila Irene Margarida', '83326-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16035, 'Londrina', 'Helena Borges Ruzzon', 'Jardim Bom Pastor', '86082-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16036, 'Curitiba', 'Helena C. S. Corrêa', 'Pinheirinho', '81820-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16037, 'Londrina', 'Helena Caraminan', 'Jardim Imagawa', '86080-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16038, 'Piraquara', 'Helena Cordeiro Favoretto', 'Suburbana', '83304-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16039, 'Londrina', 'Helena Cortez Giarola', 'Jardim Ilha do Mel', '86081-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16040, 'Curitiba', 'Helena de Oliveira Cunha', 'Bacacheri', '82510-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16041, 'Curitiba', 'Helena Gasparim Fiorese', 'Bairro Alto', '82820-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16042, 'Cascavel', 'Helena Gurgaz', 'Santa Cruz', '85806-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16043, 'Francisco Beltrão', 'Helena J. Zonta', 'Marrecas', '85601-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16044, 'São José dos Pinhais', 'Helena Kowalski de Paula', 'Ipê', '83055-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16045, 'Curitiba', 'Helena Moscibroski Borges', 'Capão da Imbuia', '82810-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16046, 'Ponta Grossa', 'Helena Nastas Sallum', 'Boa Vista', '84072-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16047, 'Araucária', 'Helena Piekarski Pinto', 'Boqueirão', '83704-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16048, 'Araucária', 'Helena Pietrzyk Kurletto', 'Boqueirão', '83704-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16049, 'Curitiba', 'Helena Reichmann Massignan', 'Cidade Industrial', '81450-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16050, 'Curitiba', 'Helena Ribeiro Lisboa', 'Cajuru', '82980-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16051, 'Cascavel', 'Helena Scherloski', 'Cascavel Velho', '85818-517', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16052, 'Foz do Iguaçu', 'Helena Sielski', 'Jardim N Horizonte', '85855-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16053, 'Curitiba', 'Helena Stadler de Souza', 'Batel', '80440-060', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16054, 'Almirante Tamandaré', 'Helena Vaz', 'Loteamento Maria Cláudia', '83513-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16055, 'Curitiba', 'Helena Walesko Manika', 'Santa Cândida', '82720-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16056, 'Curitiba', 'Helene Ginvert Garfunkel', 'Batel', '80240-350', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16057, 'Foz do Iguaçu', 'Heleno de Freitas', 'Parque Morumbi I', '85858-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16058, 'Foz do Iguaçu', 'Heleno de Freitas', 'Parque Morumbi II', '85859-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16059, 'Foz do Iguaçu', 'Heleno Schimmelpfeng', 'Vila Yolanda', '85853-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16060, 'Apucarana', 'Hélia Nunes Vaz Margraf', 'Loteamento Residencial Parque da Raposa II', '86812-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16061, 'Londrina', 'Hélice', 'Caravelle', '86039-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16062, 'Londrina', 'Hélio Antônio Bevenho', 'Avelino A Vieira', '86056-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16063, 'Londrina', 'Hélio Barroso', 'Jardim dos Alpes III', '86045-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16064, 'Pinhais', 'Hélio Barroso', 'Planta Cláudio Mehl', '83326-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16065, 'Apucarana', 'Hélio Boneto', 'Jardim Cidade Alta', '86803-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16066, 'Curitiba', 'Hélio Cardoso Veríssimo', 'Uberaba', '81580-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16067, 'Londrina', 'Hélio Cortez', 'Alto da Boa Vista', '86083-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16068, 'Maringá', 'Hélio Costa Curta', 'Jardim Social', '87010-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16069, 'Colombo', 'Hélio Dal''Pra', 'Jardim Viviane', '83407-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16070, 'Foz do Iguaçu', 'Hélio Dias Ferraz', 'Vila Borges', '85858-320', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16071, 'Curitiba', 'Hélio Dirceu Woitikiw', 'Pinheirinho', '81870-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16072, 'Campo Mourão', 'Hélio Germano Eickhoff', 'Parque Industrial I', '87306-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16073, 'Londrina', 'Hélio Guerino', 'Ernani de Moura Lima', '86037-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16074, 'Maringá', 'Hélio Jarreta', 'Parque Residencial Anchieta', '87005-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16075, 'Apucarana', 'Hélio Mortean', 'Loteamento Residencial Cazarin', '86802-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16076, 'Cascavel', 'Hélio Richardi', 'Claudete', '85811-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16077, 'Curitiba', 'Hélio Saldanha', 'Ahú', '82200-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16078, 'Curitiba', 'Hélio Segantini', 'Uberaba', '81550-590', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16079, 'São José dos Pinhais', 'Hélio Thomaz', 'Afonso Pena', '83050-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16080, 'Ponta Grossa', 'Helladio Vidal Correia', 'Uvaranas', '84031-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16081, 'Curitiba', 'Hellen Keller', 'Capão Raso', '81020-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16082, 'Curitiba', 'Hellena Betecek', 'Butiatuvinha', '82320-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16083, 'Curitiba', 'Helly de Macedo Souza', 'Jardim Social', '82520-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16084, 'Toledo', 'Helmuth Prienitz', 'Conjunto Residencial Tocantins', '85903-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16085, 'Londrina', 'Heloísa Helena Muniz Silva', 'Conjunto Residencial Vale do Arvoredo', '86047-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16086, 'Pinhais', 'Helvino Muhlmann', 'Vila Tebas', '83326-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16087, 'Maringá', 'Hematita', 'Jardim Real', '87083-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16088, 'Ponta Grossa', 'Hematita', 'Neves', '84021-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16089, 'Colombo', 'Hemenegildo Tosin', 'Centro', '83414-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16090, 'Umuarama', 'Hemital', 'Zona I', '87501-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16091, 'Cascavel', 'Henfil', 'Interlagos', '85814-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16092, 'Umuarama', 'Hênio Romagnoli', 'Zona I', '87501-190', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16093, 'Maringá', 'Henoch Vieira de Quental', 'Conjunto Habitacional Requião', '87047-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16094, 'Curitiba', 'Henri Dunant', 'Vista Alegre', '80810-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16095, 'Apucarana', 'Henri Hermann Robert Storm', 'Parque Industrial Zona Oeste II', '86800-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16096, 'Londrina', 'Henrich Hertz', 'Industrial', '86063-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16097, 'Foz do Iguaçu', 'Henrique Alberto Pepin', 'Jardim Panorama II', '85856-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16098, 'Sarandi', 'Henrique Augusto da Silva', 'Jardim Castelo', '87112-510', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16099, 'Foz do Iguaçu', 'Henrique Bernadelli', 'Parque Residencial Três Bandeiras', '85862-257', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16100, 'Foz do Iguaçu', 'Henrique Boiarski', 'Parque Presidente II', '85863-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16101, 'Toledo', 'Henrique Bombardelli', 'Jardim Concórdia', '85906-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16102, 'São José dos Pinhais', 'Henrique Bortolan', 'Costeira', '83015-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16103, 'Piraquara', 'Henrique Brudeck', 'Vila São Cristóvão', '83305-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16104, 'Londrina', 'Henrique Bruneli', 'Avelino A Vieira', '86056-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16105, 'Foz do Iguaçu', 'Henrique Bucoski', 'Jardim Veraneio', '85855-648', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16106, 'Araucária', 'Henrique Cantador', 'Thomaz Coelho', '83707-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16107, 'Ponta Grossa', 'Henrique Clock', 'Orfãs', '84015-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16108, 'Pinhais', 'Henrique Coelho Neto', 'Núcleo Colonial de Pinhais', '83321-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16109, 'Curitiba', 'Henrique Coelho Neto', 'São Lourenço', '82200-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16110, 'Curitiba', 'Henrique Correia', 'Bairro Alto', '82840-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16111, 'Curitiba', 'Henrique da Cunha Mello', 'Santa Felicidade', '82020-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16112, 'Londrina', 'Henrique de Oliveira Camargo', 'Recreio', '86025-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16113, 'Apucarana', 'Henrique de Paula e Silva', 'Jardim Menegazzo', '86802-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16114, 'Ponta Grossa', 'Henrique Degraf', 'Centro', '84010-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16115, 'Londrina', 'Henrique Dias', 'Nova Londres', '86015-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16116, 'Maringá', 'Henrique Dias', 'Zona 03', '87050-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16117, 'Paranavaí', 'Henrique Dias', 'Jardim São Jorge', '87710-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16118, 'Ponta Grossa', 'Henrique Dias', 'Uvaranas', '84025-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16119, 'Toledo', 'Henrique Dias', 'Jardim Paulista', '85910-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16120, 'Telêmaco Borba', 'Henrique Dias', 'Centro', '84261-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16121, 'Cambé', 'Henrique Dias', 'Parque Residencial Manela', '86185-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16122, 'Curitiba', 'Henrique Dias', 'Guabirotuba', '81520-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16123, 'Londrina', 'Henrique dos Santos', 'Jardim Higienópolis', '86015-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16124, 'Curitiba', 'Henrique Dyck', 'Boqueirão', '81750-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16125, 'Londrina', 'Henrique Félix Marconi', 'Conjunto Santa Rita 6', '86072-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16126, 'Maringá', 'Henrique Fregadolli', 'Jardim Ipanema', '87053-320', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16127, 'São José dos Pinhais', 'Henrique Gonzaga de Souza Neto', 'Guatupê', '83060-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16128, 'Curitiba', 'Henrique Gregório Machado', 'Santa Quitéria', '80310-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16129, 'Foz do Iguaçu', 'Henrique Guelere', 'Jardim Evangélico', '85870-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16130, 'Ponta Grossa', 'Henrique Hennemberg', 'Boa Vista', '84070-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16131, 'Curitiba', 'Henrique Itibere da Cunha', 'Bom Retiro', '80520-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16132, 'Umuarama', 'Henrique Iwamura Tanaka', 'Parque Bandeirantes', '87504-677', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16133, 'Colombo', 'Henrique Joaquim Ribeiro', 'Vila Atuba', '83408-317', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16134, 'Curitiba', 'Henrique Joaquim Ribeiro', 'Santa Felicidade', '82015-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16135, 'Pinhais', 'Henrique José Pojda', 'Moradias Palmital', '83325-607', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16136, 'Curitiba', 'Henrique José Sikorski', 'Seminário', '80310-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16137, 'Foz do Iguaçu', 'Henrique Kapfemberg', 'Jardim Guarapuava II', '85856-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16138, 'Curitiba', 'Henrique Knopfholz', 'Cristo Rei', '80050-130', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16139, 'Ponta Grossa', 'Henrique Lage', 'Ronda', '84051-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16140, 'Ponta Grossa', 'Henrique Luiz Wendler', 'Boa Vista', '84072-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16141, 'Toledo', 'Henrique Maas', 'Loteamento Lidia Joana Vols', '85912-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16142, 'Londrina', 'Henrique Mansano', 'Jardim dos Alpes I', '86075-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16143, 'Londrina', 'Henrique Mansano', 'Santa Mônica', '86079-450', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16144, 'Curitiba', 'Henrique Martins Torres', 'Boqueirão', '81750-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16145, 'Londrina', 'Henrique Massi', 'Portal de Versalhes 1', '86057-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16146, 'Curitiba', 'Henrique Mattioli', 'Fazendinha', '81330-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16147, 'Pinhais', 'Henrique Mehl', 'Planta Cláudio Mehl', '83326-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16148, 'Curitiba', 'Henrique Mehl', 'Uberaba', '81560-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16149, 'Curitiba', 'Henrique Morales', 'Abranches', '82130-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16150, 'Pinhais', 'Henrique Moreira da Luz', 'Jardim Marumby', '83327-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16151, 'Pinhais', 'Henrique Muhlmann', 'Jardim Cláudia', '83326-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16152, 'Maringá', 'Henrique Natal Rigoldi', 'Jardim Liberdade', '87047-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16153, 'Curitiba', 'Henrique Oliva', 'Centro', '80430-270', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16154, 'Castro', 'Henrique Pereira', 'Loteamento Jardim Pandorf', '84182-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16155, 'Curitiba', 'Henrique Pereira de Camargo', 'Pinheirinho', '81880-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16156, 'Curitiba', 'Henrique Pinto da Silva', 'Pinheirinho', '81825-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16157, 'Londrina', 'Henrique Platz', 'Leste Oeste', '86037-805', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16158, 'Ponta Grossa', 'Henrique Portela de Almeida', 'Contorno', '84061-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16159, 'Toledo', 'Henrique Ramisch', 'Vila Pioneiro', '85909-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16160, 'Ponta Grossa', 'Henrique Romanovski Grissai', 'Colônia Dona Luiza', '84045-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16161, 'Piraquara', 'Henrique Romrich', 'Planta Cruzeiro', '83304-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16162, 'Londrina', 'Henrique Rose', 'Jardim Piza', '86073-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16163, 'Toledo', 'Henrique Rossan', 'Loteamento Lidia Joana Vols', '85912-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16164, 'Castro', 'Henrique Schultz', 'Jardim Social Primavera', '84174-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16165, 'Curitiba', 'Henrique Schuta', 'Capão Raso', '81130-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16166, 'Ponta Grossa', 'Henrique Thielen', 'Jardim Carvalho', '84015-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16167, 'Piraquara', 'Henrique Toni', 'Jardim Curitiba', '83308-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16168, 'Londrina', 'Henrique Vicente', 'Jardim Nova Esperança', '86044-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16169, 'Londrina', 'Henrique Victorelli', 'Alto da Boa Vista', '86083-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16170, 'Campo Mourão', 'Henrique VIII', 'Jardim Lar Paraná', '87305-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16171, 'Cambé', 'Henrique Walz', 'Jardim Boa Vista', '86191-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16172, 'Ponta Grossa', 'Henrique Zuber', 'Estrela', '84050-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16173, 'Araucária', 'Henriqueta Borrazo', 'Costeira', '83708-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16174, 'Curitiba', 'Henriqueta Parolin Schiavon', 'Sítio Cercado', '81925-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16175, 'Londrina', 'Henriqueta Tubman', 'Nossa Senhora de Lourdes', '86039-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16176, 'Londrina', 'Henry Ford', 'Industrial', '86063-365', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16177, 'Curitiba', 'Henry Ford', 'Lindóia', '81010-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16178, 'Curitiba', 'Heraclides César de Araújo', 'Centro Cívico', '80530-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16179, 'Guarapuava', 'Heraclides Mendes de Araújo', 'São Cristóvão', '85063-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16180, 'Castro', 'Heráclio Mendes de Camargo', 'Vila Santa Cruz', '84168-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16181, 'Foz do Iguaçu', 'Herbert Barthel', 'Jardim Veraneio', '85855-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16182, 'São José dos Pinhais', 'Herbert de Souza', 'Guatupê', '83065-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16183, 'Curitiba', 'Herbert Érico Ricardo Kliem', 'Atuba', '82630-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16184, 'Londrina', 'Herbert Kurshat', 'Portal de Versalhes 3', '86055-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16185, 'Curitiba', 'Herbert Max Friedlaender', 'São Lourenço', '82200-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16186, 'Curitiba', 'Herbert Munhoz Van Erven', 'Abranches', '82220-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16187, 'Curitiba', 'Herbert Neal', 'Santa Quitéria', '80310-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16188, 'São José dos Pinhais', 'Herbert Sprencer', 'Aristocrata', '83030-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16189, 'Piraquara', 'Herbert Trap', 'Planta Guarituba Pequena', '83310-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16190, 'Piraquara', 'Herbert Trap', 'Guarituba', '83311-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16191, 'Piraquara', 'Herbert Trap', 'Guarituba', '83308-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16192, 'Piraquara', 'Herbert Trap', 'Guarituba', '83309-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16193, 'Piraquara', 'Hercília C. Rodrigues', 'Jardim Esmeralda', '83301-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16194, 'Apucarana', 'Hercília Maciel', 'Jardim Eliane', '86809-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16195, 'Apucarana', 'Hercília Maria de Jesus Mota', 'Loteamento Sol Nascente', '86801-266', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16196, 'Ponta Grossa', 'Hercílio Arnaldino Rosa', 'Olarias', '84026-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16197, 'Cascavel', 'Hercílio Barcelos', 'Nova Cidade', '85803-178', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16198, 'Curitiba', 'Hercílio Kulcheski', 'Cidade Industrial', '81315-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16199, 'Paranavaí', 'Hercílio Luz', 'Jardim São Jorge', '87710-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16200, 'Piraquara', 'Hercílio Luz', 'Planta São Tiago', '83307-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16201, 'Cascavel', 'Hercílio Luz', 'Alto Alegre', '85805-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16202, 'Curitiba', 'Hércio de Figueiredo Mello Filho', 'Pilarzinho', '82110-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16203, 'Apucarana', 'Herculano Amorim Galvão', 'Vila Operária Stabile', '86811-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16204, 'Curitiba', 'Herculano Carlos Franco de Souza', 'Água Verde', '80240-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16205, 'Londrina', 'Herculano de Araújo Castro Júnior', 'Residencial Verona', '86038-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16206, 'Curitiba', 'Herculano de Araújo Filho', 'Cidade Industrial', '81460-209', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16207, 'Ponta Grossa', 'Herculano de Freitas', 'Orfãs', '84070-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16208, 'Ponta Grossa', 'Herculano de Freitas', 'Jardim Carvalho', '84015-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16209, 'Curitiba', 'Herculano de Souza', 'Jardim das Américas', '81530-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16210, 'Castro', 'Herculano Martins de Oliveira', 'Jardim Colonial', '84178-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16211, 'Maringá', 'Herculano Ribeiro de Paiva', 'Jardim Paris', '87083-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16212, 'Paranavaí', 'Herculano Rubim Toledo', 'Vila São Vicente', '87709-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16213, 'Londrina', 'Herculano Sampaio', 'Conjunto Café', '86038-055', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16214, 'Curitiba', 'Herculano Schilipak', 'Uberaba', '81540-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16215, 'Castro', 'Herculano Silva Gomes', 'Jardim Samambaia', '84182-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16216, 'Londrina', 'Hércules', 'Sol', '86070-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16217, 'Londrina', 'Hércules Accorsi', 'Cafezal', '86045-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16218, 'São José dos Pinhais', 'Hércules Lopes', 'Afonso Pena', '83050-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16219, 'Curitiba', 'Herece Fernandes', 'Cidade Industrial', '81450-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16220, 'Foz do Iguaçu', 'Herman Friedrich', 'Boa Esperança', '85854-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16221, 'Curitiba', 'Hermelino Almeida Rocha', 'Cidade Industrial', '81450-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16222, 'Curitiba', 'Hermenegildo Bonat', 'Xaxim', '81810-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16223, 'Curitiba', 'Hermenegildo Gasparini', 'Tatuquara', '81470-155', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16224, 'Maringá', 'Hermenegildo Gomes de Castro', 'Jardim Liberdade', '87047-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16225, 'Curitiba', 'Hermenegildo Luca', 'Butiatuvinha', '82320-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16226, 'Curitiba', 'Hermenegildo Luca', 'São Braz', '82315-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16227, 'Curitiba', 'Hermenegildo Luca', 'Butiatuvinha', '82400-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16228, 'Curitiba', 'Hermenegildo Luca', 'São Braz', '82310-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16229, 'Londrina', 'Hermenegildo Marquezini', 'Conjunto Novo Amparo 2', '86056-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16230, 'Curitiba', 'Hermenegildo Ormeneze', 'Portão', '81070-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16231, 'São José dos Pinhais', 'Hermenegildo Pauletto', 'Miringuava', '83090-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16232, 'Curitiba', 'Hermenegildo Rossi Borguezani', 'Umbará', '81930-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16233, 'Paranavaí', 'Hermenegildo S. Medeiros', 'Jardim Paraíso', '87708-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16234, 'São José dos Pinhais', 'Hermenegildo Soares Machado', 'Roseira', '83070-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16235, 'Umuarama', 'Hermenegildo Stecca', 'Parque Bandeirantes', '87504-697', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16236, 'Foz do Iguaçu', 'Hermes da Fonseca', 'Parque Presidente', '85863-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16237, 'Guarapuava', 'Hermes da Fonseca', 'Boqueirão', '85020-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16238, 'Toledo', 'Hermes da Fonseca', 'Jardim Filadélpia', '85902-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16239, 'Apucarana', 'Hermes da Fonseca', 'Vila Santa Lorena', '86811-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16240, 'Apucarana', 'Hermes da Fonseca', 'Jardim Trabalhista', '86807-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16241, 'Cascavel', 'Hermes da Fonseca', 'Presidente', '85818-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16242, 'Colombo', 'Hermes da Fonseca', 'Jardim Central', '83409-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16243, 'Curitiba', 'Hermes Farias de Macedo', 'Tatuquara', '81470-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16244, 'Curitiba', 'Hermes Fontes', 'Batel', '80440-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16245, 'Curitiba', 'Hermes Marques', 'Santa Cândida', '82630-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16246, 'Curitiba', 'Hermes Reddin', 'Cidade Industrial', '81450-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16247, 'Cascavel', 'Hermes Vessaro', 'São Cristóvão', '85813-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16248, 'São José dos Pinhais', 'Herminda da Rocha Barbosa', 'Guatupê', '83060-207', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16249, 'Umuarama', 'Hermínia Ageu Conticelli', 'Parque Cidade Jardim', '87506-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16250, 'Colombo', 'Hermínia Modari d''Agostin', 'Jardim Las Palmas', '83409-156', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16251, 'Londrina', 'Hermínia Rufino Bergonse', 'Jardim das Palmeiras', '86083-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16252, 'Curitiba', 'Hermínia Zanetti', 'Xaxim', '81710-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16253, 'Ponta Grossa', 'Hermínio Baggio', 'Estrela', '84050-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16254, 'Araucária', 'Hermínio Brunato', 'Estação', '83705-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16255, 'Londrina', 'Hermínio Bruno Molinari', 'Conjunto Habitacional José Giordano', '86082-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16256, 'Curitiba', 'Hermínio Cardoso', 'Tingui', '82600-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16257, 'Maringá', 'Hermínio Girardi', 'Conjunto Habitacional Hermann Moraes Barros', '87023-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16258, 'Londrina', 'Hermínio José de Souza', 'Jardim Paracatu', '86081-446', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16259, 'Curitiba', 'Hermínio Nichele', 'Umbará', '81930-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16260, 'Toledo', 'Hermínio Nichetti', 'Pacaembu', '85910-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16261, 'Castro', 'Hermínio Rebonato Sobrinho', 'Jardim Social Primavera', '84174-290', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16262, 'Paranaguá', 'Hermínio Valinas', 'Conjunto Residencial Prefeito Cominese', '83215-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16263, 'Londrina', 'Hermínio Victorelli', 'Conjunto Café', '86038-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16264, 'Curitiba', 'Hermógenes de Oliveira', 'Guabirotuba', '81510-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16265, 'Castro', 'Hernandes Antunes', 'Centro', '84165-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16357, 'Castro', 'Homero Madureira', 'Jardim Dona Helena', '84178-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16266, 'Apucarana', 'Hernando Pombo Ricardo', 'Loteamento São Sebastião', '86808-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16267, 'Piraquara', 'Hernany Paciornik', 'Jardim Veneza', '83310-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16268, 'Londrina', 'Heródoto', 'Erotildes', '86015-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16269, 'Colombo', 'Heródoto', 'Vila São Lucas', '83404-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16270, 'Londrina', 'Heron Domingues', 'Meton', '86035-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16271, 'Umuarama', 'Heron Soares de Oliveira', 'Conjunto Residencial Porto Belo', '87506-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16272, 'Curitiba', 'Heron Wanderley', 'Tatuquara', '81470-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16273, 'Curitiba', 'Herondina de Freitas Ribeiro', 'Cidade Industrial', '81230-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16274, 'Castro', 'Herondina Grimbor de Oliveira', 'Morada do Sol', '84172-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16275, 'Maringá', 'Herval', 'Zona 07', '87020-016', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16276, 'Maringá', 'Herval', 'Zona 01', '87013-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16277, 'Curitiba', 'Herval d''Oeste', 'Cidade Industrial', '81270-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16278, 'Ponta Grossa', 'Heslon', 'Jardim Carvalho', '84016-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16279, 'Guarapuava', 'Hibisco', 'Bonsucesso', '85045-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16280, 'Ponta Grossa', 'Hibisco', 'Contorno', '84060-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16281, 'Maringá', 'Hibisco', 'Jardim Alzira', '87060-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16282, 'Campo Mourão', 'Hideji Kobayashi', 'Jardim Cidade Nova', '87308-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16283, 'Londrina', 'Hideo Gunji', 'Jardim Campos Verdes', '86085-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16284, 'Paranaguá', 'Hideto Kadota', 'Jardim Samambaia', '83212-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16285, 'Londrina', 'Hifumi Ogassawara', 'Colúmbia', '86057-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16286, 'Londrina', 'Higienópolis', 'Centro', '86020-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16287, 'Londrina', 'Higienópolis', 'Jardim Higienópolis', '86015-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16288, 'Londrina', 'Higienópolis', 'Guanabara', '86050-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16289, 'Paranaguá', 'Higienópolis', 'Jardim Paranaguá', '83218-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16290, 'Sarandi', 'Higienópolis', 'Jardim Higienópolis', '87112-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16291, 'Campo Mourão', 'Higienópolis', 'Jardim Pio XII', '87306-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16292, 'Campo Mourão', 'Higienópolis', 'Jardim Lar Paraná', '87305-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16293, 'Curitiba', 'Higino Mazzarotto', 'Vista Alegre', '80820-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16294, 'Apucarana', 'Higino Sacchelli', 'Jardim Marissol', '86807-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16295, 'Londrina', 'Hikoma Udihara', 'Jardim Kobayashi', '86040-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16296, 'Colombo', 'Hilário Alves Cordeiro', 'Jardim dos Eucaliptos', '83408-516', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16297, 'Araucária', 'Hilário Durau', 'Campina da Barra', '83709-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16298, 'Francisco Beltrão', 'Hilário Ecker', 'Pinheirinho', '85606-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16299, 'Curitiba', 'Hilário Moro', 'Tingui', '82600-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16300, 'Curitiba', 'Hilário Valle', 'Santa Felicidade', '82030-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16301, 'Toledo', 'Hilberto Peiter', 'Jardim Parizzotto', '85914-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16302, 'Curitiba', 'Hilda Amaral Visinoni', 'Alto Boqueirão', '81850-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16303, 'Curitiba', 'Hilda Cadilhe de Oliveira', 'Cidade Industrial', '81260-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16304, 'Paranavaí', 'Hilda Camargo Botelho', 'Parque Morumbi', '87703-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16305, 'Campo Mourão', 'Hilda Manin Brzezinski', 'Jardim Alvorada', '87308-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16306, 'Curitiba', 'Hilda Meirelles Leal', 'Bom Retiro', '80520-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16307, 'Curitiba', 'Hilda Monteiro Cruz', 'Cidade Industrial', '81230-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16308, 'Ponta Grossa', 'Hilda Roeldel', 'Ronda', '84051-510', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16309, 'Curitiba', 'Hildebrando Cordeiro', 'Campina do Siqueira', '80740-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16310, 'Curitiba', 'Hildebrando de Araújo', 'Jardim Botânico', '80210-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16311, 'Curitiba', 'Hildebrando Dulcio', 'Bacacheri', '82510-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16312, 'Castro', 'Hildebrando Galetto', 'Jardim Social Arapongas', '84174-320', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16313, 'Guarapuava', 'Hildegard Burjan', 'Morro Alto', '85065-740', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16314, 'Curitiba', 'Hildo da Paz', 'Santa Cândida', '82720-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16315, 'Curitiba', 'Hilton de Mattos Leão', 'Cajuru', '82980-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16316, 'Campo Mourão', 'Hilton Santin', 'Jardim Esperança', '87309-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16317, 'Curitiba', 'Himer Macorin Lombardi', 'Fazendinha', '81330-560', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16318, 'Curitiba', 'Himério Lugarini', 'Butiatuvinha', '82320-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16319, 'Maringá', 'Hipócrates', 'Jardim Alvorada', '87035-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16320, 'Curitiba', 'Hipólito César Sobrinho', 'Uberaba', '81590-337', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16321, 'Ponta Grossa', 'Hipólito da Costa', 'Uvaranas', '84032-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16322, 'Ponta Grossa', 'Hipólito da Costa', 'Boa Vista', '84073-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16323, 'Curitiba', 'Hipólito da Costa', 'Boqueirão', '81650-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16324, 'Curitiba', 'Hipólito da Costa', 'Boqueirão', '81670-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16325, 'Curitiba', 'Hipólito da Costa', 'Xaxim', '81710-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16326, 'Curitiba', 'Hipólito Dopieralski', 'Alto da Rua XV', '80050-110', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16327, 'São José dos Pinhais', 'Hipólito Ferreira de Melo', 'Rio Pequeno', '83070-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16328, 'Campo Largo', 'Hipólito Ferreira Portela', 'Loteamento Itaboa', '83605-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16329, 'Guarapuava', 'Hipólito Gomes', 'Vila Bela', '85025-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16330, 'Curitiba', 'Hipólito Rodrigues da Rocha', 'Guabirotuba', '81520-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16331, 'Castro', 'Hipólito Stori', 'Vila Rio Branco', '84172-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16332, 'Curitiba', 'Hipólito Woichoski', 'Alto Boqueirão', '81770-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16333, 'São José dos Pinhais', 'Hiram Augusto Maia', 'Afonso Pena', '83050-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16334, 'Londrina', 'Hiroko Yoshimoto', 'Araxá', '86061-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16335, 'Curitiba', 'Hiromasa Ishikawa', 'Fazendinha', '81320-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16336, 'Almirante Tamandaré', 'Hiroshi Takeda', 'Jardim São Carlos', '83507-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16337, 'Londrina', 'Hisatsugo Miyasaki', 'Jardim das Américas', '86076-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16338, 'Guarapuava', 'Holanda', 'São Cristóvão', '85063-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16339, 'Londrina', 'Holanda', 'Jardim Adriana I', '86046-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16340, 'Foz do Iguaçu', 'Holanda', 'Jardim Europa', '85859-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16341, 'Maringá', 'Holanda', 'Jardim Internorte', '87045-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16342, 'Umuarama', 'Holanda', 'Parque Bonfim', '87507-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16343, 'Cascavel', 'Holanda', 'Cascavel Velho', '85818-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16344, 'Cambé', 'Holanda', 'Centro', '86181-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16345, 'Curitiba', 'Holanda', 'Boa Vista', '82540-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16346, 'Curitiba', 'Holanda', 'Bacacheri', '82510-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16347, 'Londrina', 'Holando Caram', 'Jardim Campos Verdes', '86085-248', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16348, 'Paranaguá', 'Holliens de Oliveira', 'Parque São João', '83212-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16349, 'Apucarana', 'Homero', 'Vila Nova', '86812-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16350, 'Cascavel', 'Homero', 'Interlagos', '85814-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16351, 'Apucarana', 'Homero Alcântara', 'Recanto Estoril', '86813-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16352, 'Curitiba', 'Homero Alves da Silva', 'Alto Boqueirão', '81770-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16353, 'Maringá', 'Homero Arruda', 'Jardim Paris', '87083-696', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16354, 'Curitiba', 'Homero Camargo de Oliveira', 'São Braz', '82320-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16355, 'Londrina', 'Homero Cruz', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16356, 'Apucarana', 'Homero Ferreira dos Santos', 'Loteamento Jardim Gramados', '86801-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16358, 'Londrina', 'Homero Martins Ribas', 'Áurea', '86038-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16359, 'Curitiba', 'Homero Morinobu Oguido', 'Uberaba', '81550-445', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16360, 'Londrina', 'Honduras', 'Vila Rodrigues', '86010-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16361, 'Ponta Grossa', 'Honduras', 'Ronda', '84051-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16362, 'Pinhais', 'Honduras', 'Vila Varginha', '83320-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16363, 'Telêmaco Borba', 'Honduras', 'Alto das Oliveiras', '84266-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16364, 'Colombo', 'Honduras', 'Vila Marcelina', '83404-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16365, 'Colombo', 'Honesta Cavalli', 'Vila São Lucas', '83404-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16366, 'Colombo', 'Honesta de Souza Rausis', 'Centro Industrial Mauá', '83413-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16367, 'Londrina', 'Hong-Kong', 'Cláudia', '86050-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16368, 'Colombo', 'Honorata Baldo', 'Jardim dos Eucaliptos', '83408-507', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16369, 'São José dos Pinhais', 'Honorato da Silveira', 'Ipê', '83055-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16370, 'Apucarana', 'Honorato Rossi', 'Jardim Flamingos', '86811-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16371, 'Curitiba', 'Honory Ramos Sodré', 'Tatuquara', '81480-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16372, 'Londrina', 'Horace Wells', 'Jardim Alvorada', '86060-375', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16373, 'Ponta Grossa', 'Horácio Antunes Mendes', 'Orfãs', '84015-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16374, 'Piraquara', 'Horácio de Oliveira', 'Vila Ipanema', '83301-047', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16375, 'Cambé', 'Horácio dos Santos', 'Vila Guarani', '86182-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16376, 'Ponta Grossa', 'Horácio Droppa', 'Uvaranas', '84026-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16377, 'Apucarana', 'Horácio F. S. Carvalho', 'Parque Bela Vista', '86803-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16378, 'Telêmaco Borba', 'Horácio Klabin', 'Centro', '84261-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16379, 'Telêmaco Borba', 'Horácio Klabin', 'Socomim', '84265-590', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16380, 'Cascavel', 'Horácio Ribeiro dos Reis', 'Periolo', '85817-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16381, 'Londrina', 'Horácio Sabino Coimbra', 'Cidadela', '86072-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16382, 'Foz do Iguaçu', 'Horácio Soares Trindade', 'Vila São Sebastião', '85870-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16383, 'Ponta Grossa', 'Horácio Vilela Guimarães', 'Jardim Carvalho', '84015-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16384, 'Maringá', 'Horalino José de Moraes', 'Conjunto Habitacional Requião', '87047-488', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16385, 'Ponta Grossa', 'Horebe', 'Jardim Carvalho', '84016-659', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16386, 'Apucarana', 'Horeslau Saviski', 'Jardim Guanabara', '86809-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16387, 'Apucarana', 'Horeslau Saviski', 'Vila Santa Terezinha', '86802-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16388, 'Paranaguá', 'Horizonte', 'Correia Velho', '83206-390', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16389, 'Foz do Iguaçu', 'Horizontina', 'Jardim Veneza', '85870-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16390, 'Ponta Grossa', 'Horma', 'Jardim Carvalho', '84016-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16391, 'Londrina', 'Hortelã', 'Jardim Novo Sabará', '86066-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16392, 'Almirante Tamandaré', 'Hortência', 'Loteamento Nova Morada', '83504-697', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16393, 'Londrina', 'Hortência Luiza de Lima', 'Jardim Marízia II', '86079-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16394, 'Ponta Grossa', 'Hortencio', 'Contorno', '84060-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16395, 'Campo Mourão', 'Hortencio', 'Jardim Modelo', '87309-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16396, 'Curitiba', 'Hortêncio Marino dos Santos', 'Cidade Industrial', '81460-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16397, 'Guarapuava', 'Hortencio Silveira Scharam', 'Vila Bela', '85025-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16398, 'Apucarana', 'Hortênsia', 'Jardim das Flores III', '86810-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16399, 'Araucária', 'Hortênsia', 'Campina da Barra', '83709-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16400, 'Piraquara', 'Hostílio César de Souza', 'Chácara Águas Claras', '83308-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16401, 'Campo Mourão', 'Houssein Y. Charrouf', 'Jardim Lar Paraná', '87305-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16402, 'Londrina', 'Houston', 'Jardim Montreal', '86060-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16403, 'Curitiba', 'Howell Lewis Fry', 'Cachoeira', '82710-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16404, 'Guarapuava', 'Huberto Scorsin', 'Vila Bela', '85027-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16405, 'Colombo', 'Hudson', 'Jardim Campo Alto', '83408-200', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16406, 'Araucária', 'Hugo Alencastro Cordeiro', 'Boqueirão', '83704-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16407, 'Apucarana', 'Hugo Celso Hegeto', 'Jardim Marissol', '86807-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16408, 'Curitiba', 'Hugo Cini', 'Cajuru', '82940-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16409, 'Foz do Iguaçu', 'Hugo Freitas', 'Vila Portes', '85865-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16410, 'Curitiba', 'Hugo Gusso', 'Capão Raso', '81020-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16411, 'Curitiba', 'Hugo Kinzelmann', 'Campina do Siqueira', '80740-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16412, 'Curitiba', 'Hugo Miró', 'Cidade Industrial', '81170-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16413, 'Curitiba', 'Hugo Morgenstern', 'Pinheirinho', '81820-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16414, 'Foz do Iguaçu', 'Hugo Schineider', 'Mutirão', '85858-590', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16415, 'Londrina', 'Hugo Seben', 'Avelino A Vieira', '86056-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16416, 'Londrina', 'Hugo Tavares Yabe', 'Jamile Dequech', '86048-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16417, 'Curitiba', 'Hugo Wolf', 'Santa Felicidade', '82410-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16418, 'São José dos Pinhais', 'Hugo Zen', 'Zaniolo', '83025-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16419, 'Toledo', 'Hugo Zenni', 'Jardim La Salle', '85905-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16420, 'Londrina', 'Humaiata', 'Kennedy', '86015-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16421, 'Foz do Iguaçu', 'Humaitá', 'Jardim Itamaraty', '85863-040', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16422, 'Londrina', 'Humaitá', 'Kennedy', '86060-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16423, 'Guarapuava', 'Humaitá', 'Vila Carli', '85040-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16424, 'Paranaguá', 'Humaitá', 'Vila Guadalupe', '83221-205', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16425, 'Maringá', 'Humaitá', 'Zona 04', '87014-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16426, 'Telêmaco Borba', 'Humaitá', 'Alto das Oliveiras', '84266-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16427, 'Umuarama', 'Humaitá', 'Zona IV', '87504-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16428, 'Guarapuava', 'Humany', 'São Cristóvão', '85063-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16429, 'Campo Largo', 'Humberto Baroni', 'Loteamento Santa Rita', '83602-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16430, 'Londrina', 'Humberto Bergamini Testa', 'Residencial Portal do Sol', '86082-787', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16431, 'Curitiba', 'Humberto Bertoldi', 'Cidade Industrial', '81170-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16432, 'Curitiba', 'Humberto Bevervanso', 'Bigorrilho', '80710-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16433, 'Londrina', 'Humberto Bussadori', 'Avelino A Vieira', '86056-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16434, 'Curitiba', 'Humberto Calixto Fruet', 'Cidade Industrial', '81315-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16435, 'Francisco Beltrão', 'Humberto Campos', 'São Miguel', '85602-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16436, 'Curitiba', 'Humberto Cantarelli', 'Campo Comprido', '81220-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16437, 'Guarapuava', 'Humberto Carli', 'Vila Carli', '85040-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16438, 'Curitiba', 'Humberto Carta', 'Hugo Lange', '80040-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16439, 'Curitiba', 'Humberto Cezarino', 'Santa Cândida', '82640-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16440, 'Curitiba', 'Humberto Ciccarino', 'Boqueirão', '81670-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16441, 'Apucarana', 'Humberto Contatto', 'Jardim Paulista', '86808-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16442, 'Pinhais', 'Humberto de Alencar Castelo Branco', 'Vila Amélia', '83330-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16443, 'Almirante Tamandaré', 'Humberto de Alencar Castelo Branco', 'Jardim Marambaia', '83506-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16444, 'Londrina', 'Humberto de Campos', 'Vitória', '86060-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16445, 'Paranavaí', 'Humberto de Campos', 'Jardim Paranavaí', '87701-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16446, 'Paranavaí', 'Humberto de Campos', 'Jardim Novo Horizonte', '87711-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16447, 'Maringá', 'Humberto de Campos', 'Zona 08', '87050-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16448, 'Ponta Grossa', 'Humberto de Campos', 'Uvaranas', '84025-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16449, 'Paranaguá', 'Humberto de Campos', 'Jardim Paranaguá', '83218-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16450, 'Ponta Grossa', 'Humberto de Campos', 'Uvaranas', '84026-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16451, 'Piraquara', 'Humberto de Campos', 'Jardim Veneza', '83310-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16452, 'Toledo', 'Humberto de Campos', 'Panorama', '85911-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16453, 'Cascavel', 'Humberto de Campos', 'Coqueiral', '85807-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16454, 'Curitiba', 'Humberto de Campos', 'Pilarzinho', '82120-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16455, 'Londrina', 'Humberto Delalibera', 'Catuai', '86086-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16456, 'Curitiba', 'Humberto Geronasso', 'Barreirinha', '82560-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16457, 'Curitiba', 'Humberto Giraldi', 'Cajuru', '82920-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16458, 'Curitiba', 'Humberto Higino Parolin', 'Xaxim', '81710-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16459, 'Foz do Iguaçu', 'Humberto José dos Santos', 'Jardim São Paulo I', '85856-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16460, 'Foz do Iguaçu', 'Humberto José Soletti', 'Jardim Santa Rita', '85862-299', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16461, 'Curitiba', 'Humberto Levis', 'Barreirinha', '82220-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16462, 'Foz do Iguaçu', 'Humberto Machado', 'Loteamento Witt', '85862-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16463, 'Cambé', 'Humberto Mamprim', 'Parque Residencial Ana Rosa', '86183-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16464, 'Curitiba', 'Humberto Marchesini', 'Sítio Cercado', '81910-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16465, 'Curitiba', 'Humberto Mattana', 'Capão da Imbuia', '82810-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16466, 'Castro', 'Humberto Mendes do Prado', 'Jardim Social Arapongas', '84174-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16467, 'Cambé', 'Humberto Moreschi', 'Chácara Manela', '86186-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16468, 'São José dos Pinhais', 'Humberto Moro Nogarotto', 'Braga', '83020-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16469, 'Curitiba', 'Humberto Morona', 'Cristo Rei', '80050-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16470, 'Curitiba', 'Humberto Negrello', 'Umbará', '81930-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16471, 'Londrina', 'Humberto Nobile', 'Califórnia', '86040-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16472, 'Londrina', 'Humberto Panza', 'Jardim Acapulco', '86045-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16473, 'Londrina', 'Humberto Piccinin', 'Vila Guarujá', '86010-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16474, 'Londrina', 'Humberto Puigari Coutinho', 'Barbeta', '86078-480', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16475, 'Castro', 'Humberto Raphael Flores', 'Jardim das Araucárias', '84172-595', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16476, 'Apucarana', 'Humberto Vendramel', 'Jardim Nossa Senhora de Lourdes', '86811-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16477, 'Curitiba', 'Humberto Zanato', 'Pinheirinho', '81870-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16478, 'Londrina', 'Hungria', 'Igapó', '86046-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16479, 'Cambé', 'Hungria', 'Jardim Morada do Sol', '86181-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16480, 'Colombo', 'Huxley', 'Jardim Campo Alto', '83408-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16481, 'Cascavel', 'Hyeda Baggio Mayer', 'Vila Tolentino', '85802-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16482, 'Cascavel', 'Hyeda Baggio Mayer', 'Maria Luiza', '85819-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16483, 'Curitiba', 'Hyolando de Oliveira', 'Umbará', '81930-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16484, 'Londrina', 'Hypolicoscinio Lúcio Soares', 'Armindo Guazzi', '86037-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16485, 'Maringá', 'Hypolito Nogueira Porto', 'Conjunto Habitacional Requião', '87047-407', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16486, 'Foz do Iguaçu', 'I', 'Conjunto C', '85870-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16487, 'Ponta Grossa', 'I', 'Contorno', '84060-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16488, 'Ponta Grossa', 'I', 'Uvaranas', '84032-487', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16489, 'Umuarama', 'I', 'Jardim San Fernando', '87508-176', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16490, 'Umuarama', 'I', 'Parque das Jaboticabeiras', '87509-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16491, 'Umuarama', 'I', 'Parque Dom Pedro I', '87508-026', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16492, 'Campo Mourão', 'I', 'Jardim Nossa Senhora Aparecida', '87309-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16493, 'Campo Largo', 'I', 'Popular Nova', '83602-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16494, 'Campo Largo', 'I', 'Jardim Três Rios', '83603-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16495, 'Almirante Tamandaré', 'I', 'Loteamento Recanto dos Papagaios', '83512-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16496, 'Almirante Tamandaré', 'I', 'Jardim Marrocos', '83511-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16497, 'Almirante Tamandaré', 'I', 'Parque Timbu', '83514-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16498, 'Castro', 'I', 'Vila do Rosário', '84168-066', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16499, 'Pinhais', 'Iaçanãs', 'Loteamento Alphaville Graciosa', '83327-107', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16500, 'Foz do Iguaçu', 'Iacanga', 'Jardim das Palmeiras', '85869-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16501, 'Foz do Iguaçu', 'Iapó', 'Conjunto Libra', '85857-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16502, 'Londrina', 'Iapó', 'Mendonça', '86025-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16503, 'São José dos Pinhais', 'Iapó', 'Colônia Rio Grande', '83025-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16504, 'Pinhais', 'Iapó', 'Loteamento Alphaville Graciosa', '83327-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16505, 'Curitiba', 'Iapó', 'Rebouças', '80215-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16506, 'Londrina', 'Iara', 'Antares', '86036-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16507, 'Paranaguá', 'Iara', 'Emboguaçu', '83209-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16508, 'Telêmaco Borba', 'Iara', 'Área 03', '84271-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16509, 'Campo Largo', 'Iara', 'Centro', '83601-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16510, 'Foz do Iguaçu', 'Iaras', 'Jardim Vasco da Gama', '85862-379', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16511, 'Foz do Iguaçu', 'Ibaiti', 'Jardim Belvedere II', '85867-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16512, 'Ponta Grossa', 'Ibaiti', 'Ronda', '84051-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16513, 'Pinhais', 'Ibaiti', 'Planta Portal da Serra', '83325-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16514, 'Telêmaco Borba', 'Ibaiti', 'Bela Vista do Paraíso', '84262-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16515, 'Colombo', 'Ibaiti', 'Vila São José', '83410-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16516, 'Almirante Tamandaré', 'Ibaiti', 'Vila Tefé', '83503-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16517, 'Curitiba', 'Ibaiti', 'Sítio Cercado', '81900-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16518, 'Apucarana', 'Ibarale Cazarin', 'Loteamento Residencial Cazarin', '86802-437', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16519, 'Apucarana', 'Ibate', 'Jardim Alvorada', '86805-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16520, 'Apucarana', 'Ibate', 'Jardim Ponta Grossa', '86804-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16521, 'Foz do Iguaçu', 'Ibema', 'Jardim Vale do Sol', '85862-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16522, 'Pato Branco', 'Ibema', 'Sudoeste', '85507-455', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16523, 'Cascavel', 'Ibema', 'Brasmadeira', '85814-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16524, 'Londrina', 'Ibéris', 'São Pedro', '86036-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16525, 'Umuarama', 'Ibiai', 'Zona VII', '87503-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16526, 'Curitiba', 'Ibicare', 'Cidade Industrial', '81270-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16527, 'Foz do Iguaçu', 'Ibicui', 'Loteamento Campos do Iguaçu', '85857-750', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16528, 'Londrina', 'Ibipora', 'Aurora', '86060-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16529, 'Guarapuava', 'Ibiporã', 'Jardim das Américas', '85030-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16530, 'Foz do Iguaçu', 'Ibiporã', 'Jardim Duarte', '85861-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16531, 'Pato Branco', 'Ibiporã', 'Centro', '85501-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16532, 'Pato Branco', 'Ibiporã', 'Centro', '85504-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16533, 'Pinhais', 'Ibiporã', 'Vila Emiliano Perneta', '83324-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16534, 'Ponta Grossa', 'Ibiporã', 'Nova Rússia', '84070-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16535, 'Colombo', 'Ibiporã', 'Jardim São José', '83410-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16536, 'Curitiba', 'Ibiporã', 'Alto Boqueirão', '81860-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16537, 'Londrina', 'Ibira', 'Jardim Alvorada', '86062-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16538, 'Maringá', 'Ibira', 'Jardim Alvorada', '87033-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16539, 'Umuarama', 'Ibirapuera', 'Parque Tarumã', '87508-219', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16540, 'Cambé', 'Ibirapuera', 'Jardim Morumbi', '86191-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16541, 'Londrina', 'Íbis', 'Conjunto Habitacional Violim', '86084-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16542, 'Ponta Grossa', 'Íbis', 'Colônia Dona Luiza', '84046-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16543, 'Arapongas', 'Íbis', 'Centro', '86701-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16544, 'Apucarana', 'Ibisco', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16545, 'Foz do Iguaçu', 'Ibitinga', 'Jardim Santa Rosa', '85869-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16546, 'Curitiba', 'Ibitirati', 'Uberaba', '81590-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16547, 'Foz do Iguaçu', 'Ibiúna', 'Jardim Lancaster I', '85869-430', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16548, 'Cambé', 'Ibrahim el Haouli', 'Jardim Santa Mônica', '86184-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16549, 'Londrina', 'Ibrahim Soubhia', 'Jardim Paraty', '86081-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16550, 'Araucária', 'Ibraim Antônio Mansur', 'Centro', '83702-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16551, 'Telêmaco Borba', 'Ibucui', 'Área 06', '84271-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16552, 'Guarapuava', 'Ibyama', 'São Cristóvão', '85063-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16553, 'Foz do Iguaçu', 'Icara', 'Centro', '85851-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16554, 'Foz do Iguaçu', 'Icara', 'Loteameto Jardim Colombelli', '85862-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16555, 'São José dos Pinhais', 'Icarai', 'Afonso Pena', '83040-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16556, 'Foz do Iguaçu', 'Icaraima', 'Jardim Santa Rosa', '85869-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16557, 'Guarapuava', 'Icaraima', 'Boqueirão', '85023-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16558, 'Umuarama', 'Icaraima', 'Zona IV', '87504-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16559, 'Curitiba', 'Icaraima', 'Fazendinha', '81320-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16560, 'Londrina', 'Ícaro', 'Aeroporto', '86039-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16561, 'Cascavel', 'Ícaro', 'Santos Dumont', '85804-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16562, 'Apucarana', 'Ícaro', 'Vila Nova', '86812-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16563, 'Cambé', 'Icatú', 'Jardim do Café', '86186-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16564, 'Londrina', 'Icek Wain Berg', 'Jardim Nova Esperança', '86044-638', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16565, 'São José dos Pinhais', 'Icílio Saldanha', 'São Sebastião', '83075-358', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16566, 'Londrina', 'Icós', 'Vila São Caetano', '86026-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16567, 'Arapongas', 'Icteria', 'Vila Sampaio', '86705-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16568, 'Almirante Tamandaré', 'Ida B. Ramos', 'Vila Formosa', '83506-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16569, 'Toledo', 'Ida Becker', 'Vila Becker', '85902-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16570, 'Almirante Tamandaré', 'Ida Bonfim Alcântara', 'Jardim Bela Vista', '83506-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16571, 'Curitiba', 'Ida Leonor Mazalotti Siqueira', 'Cidade Industrial', '81460-318', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16572, 'Londrina', 'Ida Melhorato Américo', 'Jardim Marissol', '86030-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16573, 'Foz do Iguaçu', 'Ida Mertig', 'Parque Presidente II', '85863-700', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16574, 'Londrina', 'Ida Postalli Victorelli', 'Cafezal 1', '86049-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16575, 'Ponta Grossa', 'Ida Santos', 'Boa Vista', '84071-400', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16576, 'Londrina', 'Ida Tamarozzi Petrucci', 'Itapoã', '86043-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16577, 'Londrina', 'Idália Maria Barbosa Soares', 'Jardim Palmas', '86081-358', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16578, 'Foz do Iguaçu', 'Idalina Correia Gradella', 'Vila Shalon', '85853-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16579, 'Curitiba', 'Idalina de Carvalho Lima', 'Pilarzinho', '82100-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16580, 'Curitiba', 'Idalina de Lima', 'Novo Mundo', '81050-628', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16581, 'Pinhais', 'Idalina dos Anjos Santos', 'Planta Guilherme Weiss', '83322-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16582, 'Apucarana', 'Idalina Lúcia Pereira', 'Recanto Bom Retiro', '86803-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16583, 'Londrina', 'Idalino César', 'Arco Íris', '86050-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16584, 'Francisco Beltrão', 'Idalino Schmoller', 'Pinheirinho', '85606-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16585, 'Londrina', 'Idefonso dos Santos', 'Cilo 1', '86036-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16586, 'Curitiba', 'Idete Scuissiatto', 'Fazendinha', '81330-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16587, 'Paranaguá', 'Idílio Mendes', 'Jardim Araçá', '83221-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16588, 'Londrina', 'Ieda Pesarini Ferreira', 'Jardim Santa Cruz', '86084-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16589, 'São José dos Pinhais', 'Ieda Solange Ribeiro', 'Ipê', '83055-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16590, 'Maringá', 'Ierecê', 'Conjunto Residencial Parigot de Souza', '87047-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16591, 'Cascavel', 'Igapo', 'Recanto Tropical', '85807-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16592, 'Foz do Iguaçu', 'Igarapava', 'Jardim Curitibano IV', '85869-696', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16593, 'Ponta Grossa', 'Ignacio Araújo', 'Jardim Carvalho', '84016-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16594, 'Londrina', 'Ignacio Borges Arantes Neto', 'Conjunto Residencial Nova Perobal', '86043-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16595, 'São José dos Pinhais', 'Ignacio Bugno', 'São Sebastião', '83075-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16596, 'Curitiba', 'Ignacio Gbur', 'Pilarzinho', '82100-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16597, 'Londrina', 'Ignacio Gonçalves', 'São Lourenço', '86043-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16598, 'São José dos Pinhais', 'Ignacio Grossmann', 'Afonso Pena', '83050-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16599, 'Colombo', 'Ignacio Kubis', 'Jardim Osasco', '83403-046', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16600, 'Araucária', 'Ignacio Novak', 'Thomaz Coelho', '83706-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16601, 'Paranaguá', 'Ignacio Reutter Sotomaior Pedroso', 'Jardim Araçá', '83221-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16602, 'Foz do Iguaçu', 'Ignacio Sottomaior', 'Vila Yolanda', '85853-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16603, 'Apucarana', 'Ignacio Stivam', 'Loteamento Residencial Cazarin', '86802-416', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16604, 'Colombo', 'Ignacio Strapasson', 'São João', '83415-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16605, 'Campo Mourão', 'Ignacio Trombini', 'Jardim Capricórnio', '87301-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16606, 'São José dos Pinhais', 'Ignacio Valenga', 'Planta Quississana', '83085-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16607, 'Curitiba', 'Ignacio Wacheski', 'Umbará', '81940-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16608, 'Curitiba', 'Ignacio Wizbycki', 'Campo Comprido', '81210-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16609, 'Curitiba', 'Ignes Colle Munhoz', 'Cidade Industrial', '81270-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16610, 'Maringá', 'Ignes Gongora', 'Conjunto Habitacional Santa Felicidade', '87053-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16611, 'Londrina', 'Ignes Sirley Mazer Cardoso', 'Jamile Dequech', '86048-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16612, 'Piraquara', 'Ignes Zaramella Mulhenhoff', 'Vila Franca', '83305-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16613, 'Curitiba', 'Ignez de Lourdes Gomes de Macedo', 'Sítio Cercado', '81920-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16614, 'Curitiba', 'Ignez de Souza Soares', 'Tatuquara', '81940-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16615, 'Londrina', 'Ignez Gonçalves Mendes', 'Jardim Barcelona', '86073-347', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16616, 'São José dos Pinhais', 'Ignez Zen Scherner', 'Colônia Rio Grande', '83025-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16617, 'Curitiba', 'Igor Stravinski', 'Fazendinha', '81330-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16618, 'Apucarana', 'Igrécio Victor de Carvalho', 'Loteamento Sanches dos Santos', '86806-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16619, 'Francisco Beltrão', 'Iguaçu', 'Vila Nova', '85605-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16620, 'Londrina', 'Iguaçu', 'Vila Nalin', '86025-435', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16621, 'Foz do Iguaçu', 'Iguaçu', 'Jardim Itaipu', '85867-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16622, 'Londrina', 'Iguaçu', 'Vila Nalin', '86025-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16623, 'Guarapuava', 'Iguaçu', 'Conradinho', '85045-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16624, 'Laranjeiras do Sul', 'Iguaçu', 'Cristo Rei', '85304-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16625, 'Foz do Iguaçu', 'Iguaçu', 'Vila Yolanda', '85853-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16626, 'Pato Branco', 'Iguaçu', 'Centro', '85502-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16627, 'Maringá', 'Iguaçu', 'Vila Esperança', '87020-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16628, 'Pato Branco', 'Iguaçu', 'Centro', '85501-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16629, 'Pato Branco', 'Iguaçu', 'Centro', '85504-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16630, 'Umuarama', 'Iguaçu', 'Parque Presidente', '87505-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16631, 'São José dos Pinhais', 'Iguaçu', 'Ipê', '83055-370', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16632, 'Campo Largo', 'Iguaçu', 'Centro', '83601-125', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16633, 'Apucarana', 'Iguaçu', 'Centro', '86800-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16634, 'Araucária', 'Iguaçu', 'Centro', '83702-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16635, 'Curitiba', 'Iguaçu', 'Rebouças', '80250-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16636, 'Curitiba', 'Iguaçu', 'Rebouças', '80230-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16637, 'Curitiba', 'Iguaçu', 'Água Verde', '80240-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16638, 'Curitiba', 'Iguaçu', 'Água Verde', '80240-031', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16639, 'Londrina', 'Iguape', 'Jardim Agari', '86025-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16640, 'Foz do Iguaçu', 'Iguapé', 'Loteameto Jardim Colombelli', '85862-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16641, 'Guarapuava', 'Iguaracu', 'Conradinho', '85055-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16642, 'Ponta Grossa', 'Iguaracu', 'Oficinas', '84036-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16643, 'Curitiba', 'Iguaracu', 'Cidade Industrial', '81250-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16644, 'Londrina', 'Iguassuina Sottomaior Ferreira Coimbra', 'Parque Residencial Professora Marieta', '86082-766', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16645, 'Foz do Iguaçu', 'Iguatemi', 'Loteamento Campos do Iguaçu', '85857-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16646, 'Pato Branco', 'Iguatemi', 'Pinheirinho', '85506-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16647, 'Campo Mourão', 'Iguatemi', 'Conjunto Habitacional Parigot de Souza', '87310-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16648, 'Piraquara', 'Iguatu', 'Jardim Tropical', '83314-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16649, 'Colombo', 'Ihalmar de Jesus Johnsson', 'Planta Bom Jesus', '83407-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16650, 'Francisco Beltrão', 'Ijuí', 'Pinheirinho', '85603-830', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16651, 'Foz do Iguaçu', 'Ijuí', 'Loteamento Campos do Iguaçu', '85857-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16652, 'Umuarama', 'Ijuí', 'Zona VI', '87503-210', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16653, 'Toledo', 'Ijuí', 'Jardim Maria do Carmo', '85906-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16654, 'Curitiba', 'Ijuí', 'Xaxim', '81720-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16655, 'Londrina', 'Ikuo Miyamura', 'Cambezinho', '86040-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16656, 'Araucária', 'Iladia Czelusniak Furman', 'Estação', '83705-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16657, 'Foz do Iguaçu', 'Ilário Cizewki', 'Jardim Princesa Daiana', '85867-687', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16658, 'Curitiba', 'Ilda C. Manaszczuk', 'Santa Cândida', '82720-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16659, 'São José dos Pinhais', 'Ilda Gomes de Novaes', 'Guatupê', '83060-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16660, 'Colombo', 'Ilda Toniolo', 'Jardim Monza', '83406-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16661, 'Paranavaí', 'Ildefonso Alves de Lima', 'Jardim Videira', '87711-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16662, 'Curitiba', 'Ildefonso Borba Cordeiro', 'Batel', '80420-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16663, 'Curitiba', 'Ildefonso Correia Fontana', 'Cidade Industrial', '81170-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16664, 'Curitiba', 'Ildefonso Costa Pinto', 'Sítio Cercado', '81925-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16665, 'Paranaguá', 'Ildefonso Munhoz da Rocha', 'Estradinha', '83206-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16666, 'Paranaguá', 'Ildefonso Munhoz da Rocha', 'Vila Paranaguá', '83221-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16667, 'São José dos Pinhais', 'Ildefonso Pereira Cardoso', 'Planta Quississana', '83085-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16668, 'Curitiba', 'Ildefonso Stockler de Franca', 'Novo Mundo', '81020-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16669, 'Colombo', 'Ildefonso Tadeu Betinardi', 'Jardim Cristina II', '83410-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16670, 'Campo Mourão', 'Ilha Abrolhos', 'Jardim Corinthias', '87309-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16671, 'Curitiba', 'Ilha de Capri', 'São João', '82030-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16672, 'Curitiba', 'Ilha de Granada', 'Jardim Social', '82520-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16673, 'Campo Mourão', 'Ilha de Itaparica', 'Conjunto Residencial Ilha Bela', '87309-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16674, 'Londrina', 'Ilha de Malta', 'Jardim São Paulo', '86046-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16675, 'Guarapuava', 'Ilha de Marajó', 'Industrial', '85053-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16676, 'Campo Mourão', 'Ilha de Marajó', 'Conjunto Residencial Ilha Bela', '87309-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16677, 'Curitiba', 'Ilha de Marajó', 'Pinheirinho', '81825-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16678, 'Cascavel', 'Ilha de Paquetá', 'Parque Verde', '85807-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16679, 'Telêmaco Borba', 'Ilha do Mel', 'Vila Arcina', '84268-270', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16680, 'Campo Mourão', 'Ilha do Mel', 'Conjunto Residencial Ilha Bela', '87309-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16681, 'Cambé', 'Ilha do Mel', 'Chácara Santa Maria', '86189-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16682, 'Telêmaco Borba', 'Ilha do Surubi', 'Jardim Alegre', '84268-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16683, 'Foz do Iguaçu', 'Ilha Grande', 'Loteamento Menger', '85862-417', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16684, 'Maringá', 'Ilha Solteira', 'Parque das Grevíleas', '87025-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16685, 'Foz do Iguaçu', 'Ilhéus', 'Jardim das Palmeiras', '85869-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16686, 'Pato Branco', 'Ilhéus', 'La Salle', '85505-200', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16687, 'Telêmaco Borba', 'Ilhéus', 'Vila Esperança', '84272-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16688, 'Almirante Tamandaré', 'Ilhéus', 'Jardim São Vicente', '83505-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16689, 'São José dos Pinhais', 'Ilhio Pedro Gasparelo', 'Cruzeiro', '83010-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16690, 'Colombo', 'Ilídio Dal''Pra', 'Vila São Gabriel', '83406-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16691, 'Curitiba', 'Ilíria Maria Zonta Bonato', 'Umbará', '81940-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16692, 'Londrina', 'Ilma Luzia Guergoletto', 'Conjunto Professora Hilda Mandarino', '86080-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16693, 'Piraquara', 'Ilma Morona Ferreira', 'Guarituba', '83311-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16694, 'São José dos Pinhais', 'Ilo Antoninho Mozer', 'Guatupê', '83060-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16695, 'Curitiba', 'Ilor Bressiani', 'Jardim Social', '82520-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16696, 'Apucarana', 'Ilson Aparecido da Silva', 'Loteamento Residencial Cazarin', '86802-427', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16697, 'Umuarama', 'Ilton Alves da Silva', 'Jardim Cruzeiro', '87504-587', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16698, 'São José dos Pinhais', 'Ilton Leandro de Souza', 'Ipê', '83055-396', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16699, 'São José dos Pinhais', 'Ilza Machado Zaniolo', 'Zaniolo', '83025-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16700, 'Francisco Beltrão', 'Imaculada Conceição', 'Cristo Rei', '85602-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16701, 'Umuarama', 'Imaculada Conceição', 'Parque San Marino', '87509-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16702, 'Curitiba', 'Imaculada Conceição', 'Rebouças', '80215-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16703, 'Maringá', 'Imalaia', 'Jardim Imperial II', '87023-036', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16704, 'Telêmaco Borba', 'Imbaú', 'Área 02', '84267-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16705, 'Araucária', 'Imbaú', 'Iguaçu', '83701-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16706, 'Londrina', 'Imbaúba', 'Leonor', '86071-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16707, 'Ponta Grossa', 'Imbira', 'Uvaranas', '84033-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16708, 'Piraquara', 'Imbituba', 'Planta São Tiago', '83307-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16709, 'Guarapuava', 'Imbituva', 'Morro Alto', '85067-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16710, 'Paranavaí', 'Imbituva', 'Jardim Ibirapuera', '87705-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16711, 'Ponta Grossa', 'Imbituva', 'Contorno', '84043-130', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16712, 'Paranavaí', 'Imbituva', 'Jardim Ouro Branco', '87704-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16713, 'Apucarana', 'Imbituva', 'Vila Monte Castelo', '86808-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16714, 'Curitiba', 'Imbituva', 'Cajuru', '82940-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16715, 'Guarapuava', 'Imbuia', 'Industrial', '85053-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16716, 'Maringá', 'Imbuia', 'Parque Palmeiras', '87023-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16717, 'Ponta Grossa', 'Imbuia', 'Uvaranas', '84033-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16718, 'Telêmaco Borba', 'Imbuia', 'Área 01', '84268-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16719, 'Cascavel', 'Imbuia', 'Recanto Tropical', '85807-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16720, 'Almirante Tamandaré', 'Imbuia', 'Loteamento Chico Mendes', '83505-745', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16721, 'Campo Mourão', 'Imbuia', 'Jardim Santa Nilce I', '87308-266', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16722, 'Apucarana', 'Imbuia', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16723, 'Cambé', 'Imbuia', 'Vila Salomé', '86192-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16724, 'Maringá', 'Imburana', 'Zona 05', '87060-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16725, 'Maringá', 'Imburi', 'Parque Residencial Quebec', '87023-660', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16726, 'Foz do Iguaçu', 'Imenbui', 'Vila Guarani', '85862-352', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16727, 'Curitiba', 'Imer Collares Marques', 'Xaxim', '81710-510', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16728, 'Laranjeiras do Sul', 'Imigrantes', 'São Francisco', '85303-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16729, 'Campo Largo', 'Imigrantes', 'Ferraria', '83609-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16730, 'Londrina', 'Immo Vicentin', 'Portal de Versalhes 3', '86055-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16731, 'Cambé', 'Ímola', 'Jardim Montecatini', '86186-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16732, 'Sarandi', 'Imperador', 'Jaqueline', '87112-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16733, 'Umuarama', 'Imperatriz', 'Conjunto Residencial Córrego Longe', '87504-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16734, 'Sarandi', 'Imperatriz Leopoldina', 'Santa Tereza', '87112-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16735, 'Foz do Iguaçu', 'Imperatriz Maria Leopoldina', 'Jardim Cláudia', '85852-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16736, 'Foz do Iguaçu', 'Imperatriz Tereza Cristina', 'Jardim Cláudia', '85852-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16737, 'Guarapuava', 'Imperial', 'Morro Alto', '85065-486', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16738, 'Sarandi', 'Imperial', 'Jardim Imperial', '87112-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16739, 'Campo Mourão', 'Imperial', 'Jardim Lar Paraná', '87305-460', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16740, 'Maringá', 'Império do Sol', 'Cidade Jardim', '87023-108', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16741, 'Araucária', 'Iná', 'Estação', '83705-050', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16742, 'Guarapuava', 'Ina Ribas Carli', 'Morro Alto', '85065-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16743, 'Curitiba', 'Inácio Barvick', 'Mossunguê', '81210-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16744, 'Foz do Iguaçu', 'Inácio dos Santos Benitez', 'Jardim Califórnia', '85867-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16745, 'Foz do Iguaçu', 'Inácio Dotto', 'Jardim Porto Belo', '85867-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16746, 'Londrina', 'Inácio Granado de Munhoz', 'Coliseu', '86076-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16747, 'São José dos Pinhais', 'Inácio Greboge', 'Zaniolo', '83025-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16748, 'Londrina', 'Inácio Grzelak', 'Heimtal', '86084-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16749, 'Curitiba', 'Inácio José de Alvarenga Peixoto', 'Xaxim', '81810-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16750, 'Guarapuava', 'Inácio Karpinski', 'Bonsucesso', '85055-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16751, 'Guarapuava', 'Inácio Karpinski', 'Bonsucesso', '85045-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16752, 'Toledo', 'Inácio Lustosa', 'Jardim Alto Alegre', '85910-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16753, 'Curitiba', 'Inácio Lustosa', 'São Francisco', '80510-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16754, 'Guarapuava', 'Inácio Martins', 'Industrial', '85045-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16755, 'Curitiba', 'Inácio Martins', 'Xaxim', '81720-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16756, 'Curitiba', 'Inácio Maximiliano da Silva', 'Cidade Industrial', '81305-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16757, 'Foz do Iguaçu', 'Inácio Ramos', 'Vila São Sebastião', '85870-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16758, 'Foz do Iguaçu', 'Inácio Rangel Batista', 'Vila São Sebastião', '85870-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16759, 'Colombo', 'Inácio Scrok', 'Jardim Brasília', '83404-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16760, 'Curitiba', 'Inácio Slompo', 'Santa Felicidade', '82320-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16761, 'Colombo', 'Inácio Torques', 'Roseira', '83415-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16762, 'Curitiba', 'Inácio Wichnewski', 'Orleans', '82310-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16763, 'Curitiba', 'Inácio Wolski', 'Cidade Industrial', '81460-366', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16764, 'Curitiba', 'Inair da Silva Duarte', 'Pinheirinho', '81870-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16765, 'Londrina', 'Inaja', 'Antares', '86036-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16766, 'Pinhais', 'Inaja', 'Jardim Pedro Demeterco', '83324-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16767, 'Telêmaco Borba', 'Inaja', 'Área 01', '84272-320', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16768, 'Umuarama', 'Inaja', 'Zona I', '87501-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16769, 'Curitiba', 'Inaja', 'Pinheirinho', '81880-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16770, 'Londrina', 'Inaldo Guimarães', 'Jardim Lago Norte', '86078-446', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16771, 'Arapongas', 'Incas', 'Aricanduva', '86706-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16772, 'Telêmaco Borba', 'Inconfidência', 'Centro', '84261-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16773, 'Londrina', 'Indaiá', 'Vera Cruz', '86036-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16774, 'Maringá', 'Indaiá', 'Zona 06', '87080-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16775, 'Umuarama', 'Indaiá', 'Zona VI', '87503-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16776, 'Curitiba', 'Indaiá', 'Bairro Alto', '82840-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16777, 'Piraquara', 'Indaial', 'Planta São Tiago', '83307-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16778, 'São José dos Pinhais', 'Indaial', 'Guatupê', '83065-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16779, 'Almirante Tamandaré', 'Indaial', 'Jardim Apucarana', '83505-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16780, 'Cascavel', 'Indaial', 'Brasília', '85815-218', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16781, 'Francisco Beltrão', 'Indaiatuba', 'Pinheirinho', '85603-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16782, 'Castro', 'Indalécio de Macedo', 'Vila Santa Cruz', '84168-230', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16783, 'Londrina', 'Indalécio Quiles', 'Jardim Pioneiros', '86036-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16784, 'Laranjeiras do Sul', 'Independência', 'São Francisco', '85303-085', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16785, 'Londrina', 'Independência', 'Recreio', '86025-235', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16786, 'Maringá', 'Independência', 'Zona 04', '87015-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16787, 'Ponta Grossa', 'Independência', 'Centro', '84010-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16788, 'Piraquara', 'Independência', 'Jardim Bela Vista', '83301-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16789, 'Paranavaí', 'Independência', 'Jardim São Jorge', '87711-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16790, 'Paranavaí', 'Independência', 'Jardim São Jorge', '87710-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16791, 'Sarandi', 'Independência', 'Jardim Independência III', '87114-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16792, 'Toledo', 'Independência', 'Centro', '85902-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16793, 'Telêmaco Borba', 'Independência', 'Centro', '84261-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16794, 'Toledo', 'Independência', 'Centro', '85901-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16795, 'Araucária', 'Independência', 'Boqueirão', '83704-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16796, 'Campo Largo', 'Independência', 'Loteamento Yara', '83605-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16797, 'Araucária', 'Independência', 'Porto das Laranjeiras', '83703-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16798, 'Francisco Beltrão', 'Índia', 'Pinheirinho', '85606-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16799, 'Guarapuava', 'Índia', 'São Cristóvão', '85063-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16800, 'Cambé', 'Índia', 'Jardim Morada do Sol', '86181-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16801, 'Curitiba', 'Índia', 'Cajuru', '82960-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16802, 'Londrina', 'Indiana', 'Iguaçu', '86060-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16803, 'Colombo', 'Indianápolis', 'Jardim São José', '83410-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16804, 'Cascavel', 'Indianápolis', 'Interlagos', '85814-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16805, 'Curitiba', 'Indianópolis', 'Alto Boqueirão', '81860-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16806, 'Francisco Beltrão', 'Indianópolis', 'Pinheirinho', '85603-036', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16807, 'Foz do Iguaçu', 'Indianópolis', 'Vila Carima', '85855-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16808, 'Maringá', 'Indianópolis', 'Zona 08', '87050-620', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16809, 'Foz do Iguaçu', 'Índio Guairacá', 'Centro', '85851-207', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16810, 'Cascavel', 'Indira Gandhi', 'Alto Alegre', '85805-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16811, 'Foz do Iguaçu', 'Indoia', 'Loteamento Campos do Iguaçu', '85857-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16812, 'Londrina', 'Indonésia', 'Jerumenha', '86046-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16813, 'Guarapuava', 'Indonésia', 'Conradinho', '85055-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16814, 'Francisco Beltrão', 'Indonésia', 'Pinheirinho', '85606-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16815, 'Pato Branco', 'Indus', 'La Salle', '85505-025', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16816, 'Guarapuava', 'Industrial', 'Industrial', '85045-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16817, 'Guarapuava', 'Industrial', 'Industrial', '85050-050', 'Jardim', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16818, 'Pato Branco', 'Industrial', 'Industrial', '85504-620', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16819, 'Pato Branco', 'Industrial', 'Industrial', '85506-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16820, 'São José dos Pinhais', 'Industrial', 'Roseira', '83070-205', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16821, 'Umuarama', 'Industrial', 'Parque Industrial I', '87507-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16822, 'Paranavaí', 'Industrial Albino Ferracini', 'Jardim Nossa Senhora de Fátima', '87711-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16823, 'Paranavaí', 'Industrial Antônio Fachin', 'Centro', '87702-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16824, 'Paranavaí', 'Industrial Antônio Fachin', 'Centro', '87703-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16825, 'Paranavaí', 'Industrial Antônio Fachin', 'Jardim Ouro Branco', '87704-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16826, 'Paranavaí', 'Industrial Antônio Fachin', 'Vila City', '87709-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16827, 'Curitiba', 'Industrial Cidade', 'Cidade Industrial', '81315-700', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16828, 'Paranavaí', 'Industrial Valmor A. A. Rosa', 'Jardim Belo Horizonte', '87701-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16829, 'Londrina', 'Inércio Picelli', 'Jardim Pacaembu', '86079-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16830, 'Colombo', 'Inês Canha Machioski', 'Planta Cristóvão Colombo', '83403-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16831, 'Londrina', 'Inês Sanches Mendes', 'Conjunto Farid Libos', '86087-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16832, 'Curitiba', 'Inez Jacek', 'Orleans', '82310-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16833, 'Cascavel', 'Infantaria', 'Região do Lago', '85812-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16834, 'Curitiba', 'Infante Dom Henrique', 'Capão Raso', '81020-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16835, 'Paranaguá', 'Ingá', 'Vila São Vicente', '83209-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16836, 'Maringá', 'Ingá', 'Zona 05', '87060-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16837, 'Umuarama', 'Ingá', 'Zona VI', '87503-230', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16838, 'Cascavel', 'Ingá', 'Recanto Tropical', '85807-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16839, 'Curitiba', 'Ingá', 'Uberaba', '81550-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16840, 'Curitiba', 'Ingabaú', 'Bairro Alto', '82840-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16841, 'Londrina', 'Inglaterra', 'Igapó', '86046-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16842, 'Foz do Iguaçu', 'Inglaterra', 'Jardim Europa', '85859-326', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16843, 'Guarapuava', 'Inglaterra', 'Industrial', '85053-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16844, 'Sarandi', 'Inglaterra', 'Jardim Europa', '87111-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16845, 'Cambé', 'Inglaterra', 'Centro', '86181-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16846, 'Almirante Tamandaré', 'Inglaterra', 'Jardim Natal', '83505-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16847, 'Cascavel', 'Inglaterra', 'Cascavel Velho', '85818-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16848, 'Colombo', 'Inglês de Souza', 'Vila Petrópolis', '83409-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16849, 'Curitiba', 'Inglês de Souza', 'Vista Alegre', '80820-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16850, 'Apucarana', 'Ingo Kern', 'Jardim Marissol', '86807-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16851, 'Curitiba', 'Ingo Viebrantz', 'Boa Vista', '82650-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16852, 'Cascavel', 'Inhambiquaras', 'Santa Cruz', '85806-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16853, 'Foz do Iguaçu', 'Inhambu', 'Portal da Foz', '85859-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16854, 'Londrina', 'Inhambu', 'Vitória Régia', '86038-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16855, 'Ponta Grossa', 'Inhambu', 'Colônia Dona Luiza', '84043-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16856, 'Londrina', 'Inhambuxororó', 'Jacomo Violin', '86088-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16857, 'Maringá', 'Inhaúma', 'Zona 03', '87050-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16858, 'Curitiba', 'Inhumas', 'São Braz', '82015-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16859, 'Curitiba', 'Innocente Rebellato', 'Xaxim', '81710-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16860, 'Londrina', 'Inocência Antunes das Neves', 'Jardim Pacaembu', '86079-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16861, 'Curitiba', 'Inocêncio Coelho Martins', 'Capão da Imbuia', '82810-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16862, 'Curitiba', 'Inocêncio Milani', 'São Braz', '82300-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16863, 'Maringá', 'Inocente Vilanova Júnior', 'Novo Centro', '87020-036', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16864, 'Curitiba', 'Inoercio Herreira', 'Cidade Industrial', '81460-207', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16865, 'Cascavel', 'Integração', 'Nova Cidade', '85803-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16866, 'Cascavel', 'Intendência', 'Região do Lago', '85812-370', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16867, 'Cascavel', 'Interlagos', 'Interlagos', '85814-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16868, 'Apucarana', 'Interventor Manoel Ribas', 'Centro', '86800-680', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16869, 'Campo Mourão', 'Interventor Manoel Ribas', 'Centro', '87303-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16870, 'Campo Mourão', 'Interventor Manoel Ribas', 'Vila Teixeira', '87300-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16871, 'Sarandi', 'Inverno', 'Jardim Primaverão', '87111-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16872, 'Londrina', 'Iochihal Kawahisa', 'Jardim Império do Sol', '86073-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16873, 'Curitiba', 'Iolanda Maria José Frederico', 'Cajuru', '82980-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16874, 'Guarapuava', 'Iolanda Noriler Stefanes', 'Primavera', '85050-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16875, 'Pinhais', 'Iolanda Túlio Borba', 'Vila Tarumã', '83323-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16876, 'Ponta Grossa', 'Iolita', 'Neves', '84021-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16877, 'Londrina', 'Iowa', 'Quebec', '86060-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16878, 'Pato Branco', 'Ipacarai', 'Alvorada', '85508-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16879, 'Foz do Iguaçu', 'Ipanema', 'Conjunto Libra', '85857-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16880, 'Francisco Beltrão', 'Ipanema', 'Pinheirinho', '85603-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16881, 'Londrina', 'Ipanema', 'Ipanema', '86015-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16882, 'Ponta Grossa', 'Ipanema', 'Cará-cará', '84043-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16883, 'Piraquara', 'Ipanema', 'Vila Ipanema', '83301-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16884, 'Sarandi', 'Ipanema', 'Jardim Mercúrio', '87112-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16885, 'Cascavel', 'Ipanema', 'Interlagos', '85814-266', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16886, 'Cambé', 'Ipanema', 'Chácara Santa Maria', '86189-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16887, 'Cascavel', 'Ipanema', 'Periolo', '85815-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16888, 'Campo Mourão', 'Ipanema', 'Jardim Tropical II', '87310-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16889, 'Cascavel', 'Ipanema', 'Periolo', '85817-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16890, 'Foz do Iguaçu', 'Ipatinga', 'Parque Imperatriz', '85862-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16891, 'Francisco Beltrão', 'Ipê', 'Pinheirinho', '85603-840', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16892, 'Guarapuava', 'Ipê', 'Industrial', '85053-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16893, 'Londrina', 'Ipê', 'Nóbrega', '86025-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16894, 'Pinhais', 'Ipê', 'Planta Karla', '83328-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16895, 'Maringá', 'Ipê', 'Vila Bosque', '87005-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16896, 'Ponta Grossa', 'Ipê', 'Chapada', '84064-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16897, 'Ponta Grossa', 'Ipê', 'Uvaranas', '84033-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16898, 'Piraquara', 'Ipê', 'Vila Santa Maria', '83306-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16899, 'Telêmaco Borba', 'Ipê', 'Área 01', '84268-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16900, 'Umuarama', 'Ipê', 'Zona VI', '87503-240', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16901, 'Campo Mourão', 'Ipê', 'Jardim Alvorada', '87308-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16902, 'Campo Largo', 'Ipê', 'Vila Dom Pedro II', '83608-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16903, 'Apucarana', 'Ipê', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16904, 'Almirante Tamandaré', 'Ipê', 'Jardim Ipanema', '83507-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16905, 'Cascavel', 'Ipê', 'Parque Verde', '85807-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16906, 'Cambé', 'Ipê', 'Vila Salomé', '86192-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16907, 'Curitiba', 'Ipê', 'São Braz', '82015-580', 'Conjunto', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16908, 'Pinhais', 'Ipê-amarelo', 'Planta Walde Rosi Galvão', '83328-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16909, 'Arapongas', 'Ipequi', 'Jardim Eldorado', '86708-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16910, 'Foz do Iguaçu', 'Ipê-roxo', 'Jardim Colônia', '85855-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16911, 'Sarandi', 'Ipês', 'Jardim Monterey', '87112-806', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16912, 'Foz do Iguaçu', 'Ipira', 'Loteameto Jardim Colombelli', '85862-469', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16913, 'Foz do Iguaçu', 'Ipiranga', 'Vila Militar', '85857-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16914, 'Guarapuava', 'Ipiranga', 'São Cristóvão', '85060-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16915, 'São José dos Pinhais', 'Ipiranga', 'Aristocrata', '83025-050', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16916, 'Paranavaí', 'Ipiranga', 'Jardim Canadá', '87708-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16917, 'Maringá', 'Ipiranga', 'Zona 04', '87014-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16918, 'Sarandi', 'Ipiranga', 'Centro', '87111-005', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16919, 'Umuarama', 'Ipiranga', 'Zona I', '87501-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16920, 'Toledo', 'Ipiranga', 'Boa Esperança', '85909-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16921, 'Apucarana', 'Ipiranga', 'Jardim Independência', '86811-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16922, 'Curitiba', 'Ipiranga', 'Capão Raso', '81110-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16923, 'Curitiba', 'Ipiranga', 'Guaíra', '80630-140', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16924, 'Foz do Iguaçu', 'Ipora', 'Vila Carima', '85855-697', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16925, 'Londrina', 'Ipora', 'Baldan', '86060-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16926, 'Curitiba', 'Ipora', 'Alto Boqueirão', '81770-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16927, 'Londrina', 'Irã', 'Igapó', '86046-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16928, 'Umuarama', 'Irã', 'Parque Bonfim', '87507-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16929, 'Londrina', 'Iracema', 'Novo Antares', '86036-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16930, 'São José dos Pinhais', 'Iracema', 'Guatupê', '83060-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16931, 'Paranavaí', 'Iracema', 'Jardim Santos Dumont', '87706-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16932, 'Colombo', 'Iracema', 'Vila Gorski', '83405-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16933, 'Francisco Beltrão', 'Iracema da Silva', 'Jardim Santa Fé', '85602-508', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16934, 'Colombo', 'Iracema Poli Guimarães Belisário', 'Cercadinho', '83415-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16935, 'Curitiba', 'Iracy Gomes de Britto', 'Atuba', '82860-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16936, 'Londrina', 'Iracy Zuba de Oliva', 'Conjunto Novo Amparo', '86087-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16937, 'Foz do Iguaçu', 'Iraí', 'Jardim Vasco da Gama', '85862-328', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16938, 'Francisco Beltrão', 'Iraí', 'Jardim Floresta', '85603-798', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16939, 'Pinhais', 'Iraí', 'Planta Bairro Weissópolis', '83321-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16940, 'Guarapuava', 'Iran Vieira de Souza', 'Conradinho', '85055-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16941, 'São José dos Pinhais', 'Irani', 'Afonso Pena', '83040-445', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16942, 'Paranaguá', 'Iranor Norberto Jamnik', 'Oceania', '83203-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16943, 'Guarapuava', 'Irapuru', 'Conradinho', '85045-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16944, 'Umuarama', 'Iraque', 'Parque Bonfim', '87507-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16945, 'Foz do Iguaçu', 'Irara', 'Conjunto A', '85861-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16946, 'Arapongas', 'Iratauá', 'Vila Brasil', '86705-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16947, 'Arapongas', 'Iratauá', 'Vila Araponguinha', '86703-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16948, 'Toledo', 'Iratema', 'Vila Industrial', '85904-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16949, 'Laranjeiras do Sul', 'Irati', 'Água Verde', '85302-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16950, 'Foz do Iguaçu', 'Irati', 'Jardim Paraná', '85867-160', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16951, 'Londrina', 'Irati', 'Araucárias', '86060-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16952, 'Guarapuava', 'Irati', 'Bonsucesso', '85045-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16953, 'Francisco Beltrão', 'Irati', 'São Cristóvão', '85601-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16954, 'Piraquara', 'Irati', 'Planta Araçatuba', '83301-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16955, 'São José dos Pinhais', 'Irati', 'Cruzeiro', '83010-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16956, 'Ponta Grossa', 'Irati', 'Contorno', '84052-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16957, 'Paranavaí', 'Irati', 'Jardim Ouro Branco', '87704-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16958, 'Umuarama', 'Irati', 'Zona V', '87504-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16959, 'Telêmaco Borba', 'Irati', 'Centro', '84261-330', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16960, 'Colombo', 'Irati', 'Jardim Cristina II', '83410-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16961, 'Apucarana', 'Irati', 'Barra Funda', '86800-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16962, 'Cascavel', 'Irati', 'Pacaembu', '85816-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16963, 'Cambé', 'Irati', 'Jardim Ana Eliza', '86188-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16964, 'Curitiba', 'Irati', 'Portão', '80330-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16965, 'Curitiba', 'Irati', 'Santa Quitéria', '80310-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16966, 'Ponta Grossa', 'Iratuá', 'Colônia Dona Luiza', '84046-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16967, 'Foz do Iguaçu', 'Iraúna', 'Conjunto A', '85866-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16968, 'Arapongas', 'Iraúna', 'Parque Veneza', '86701-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16969, 'Londrina', 'Irene Cândida de Jesus', 'Jardim Imagawa', '86080-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16970, 'Londrina', 'Irene Carrara Nunes', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16971, 'Campo Largo', 'Irene Castagnoli Souto', 'Vila Solene', '83607-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16972, 'Almirante Tamandaré', 'Irene Colodel da Cruz', 'Jardim Paraíso', '83512-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16973, 'Curitiba', 'Irene de Oliveira Correa', 'Novo Mundo', '81050-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16974, 'Curitiba', 'Irene Dutka', 'Pinheirinho', '81150-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16975, 'São José dos Pinhais', 'Irene Magnuskei Kolakowski', 'Afonso Pena', '83045-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16976, 'Londrina', 'Irene Marin Milani', 'Jardim San Diego', '86073-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16977, 'Curitiba', 'Irene Pereira da Silva', 'Pilarzinho', '82100-185', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16978, 'Foz do Iguaçu', 'Irene Savaris', 'Jardim Niterói', '85853-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16979, 'Curitiba', 'Irene Sermann', 'Cajuru', '82950-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16980, 'Curitiba', 'Irene Túlio', 'Santa Felicidade', '82410-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16981, 'Curitiba', 'Ireno Marchesini', 'Boqueirão', '81730-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16982, 'Foz do Iguaçu', 'Irere', 'Conjunto A', '85866-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16983, 'Arapongas', 'Irere', 'Jardim Panorama', '86708-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16984, 'Curitiba', 'Irere', 'São Braz', '82310-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16985, 'Guarapuava', 'Iretama', 'Boqueirão', '85022-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16986, 'Londrina', 'Iretama', 'Lindóia', '86031-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16987, 'Curitiba', 'Iretama', 'Sítio Cercado', '81935-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16988, 'Paranaguá', 'Iria Corrêa', 'Centro Histórico', '83203-115', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16989, 'Curitiba', 'Iride Celeste de Pol Bunese', 'Cidade Industrial', '81450-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16990, 'Curitiba', 'Irineo Maksemiv', 'Tatuquara', '81470-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16991, 'Curitiba', 'Irineu Adami', 'Prado Velho', '80215-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16992, 'Curitiba', 'Irineu Antônio Borges', 'Cidade Industrial', '81450-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16993, 'Curitiba', 'Irineu Araújo', 'Santa Cândida', '82640-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16994, 'Pato Branco', 'Irineu Bertani', 'Vila Esperança', '85503-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16995, 'Umuarama', 'Irineu Fernando de Oliveira', 'Parque San Remo I', '87506-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16996, 'Curitiba', 'Irineu Gonçalves Padilha Filho', 'Cidade Industrial', '81310-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16997, 'São José dos Pinhais', 'Irineu Leite de Morais', 'São Sebastião', '83075-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16998, 'Curitiba', 'Irineu Lissa', 'Capão da Imbuia', '82810-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (16999, 'Francisco Beltrão', 'Irineu Luiz Giacobo', 'Pinheirinho', '85606-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17000, 'Curitiba', 'Irineu Prevedello Tedesco', 'Alto Boqueirão', '81770-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17001, 'Apucarana', 'Irineu Sachelli', 'Jardim Guanabara', '86809-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17002, 'Foz do Iguaçu', 'Irio Manganelli', 'Jardim Santa Rita', '85862-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17003, 'Maringá', 'Íris', 'Jardim Industrial', '87065-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17004, 'Pinhais', 'Íris', 'Jardim Pio XII', '83328-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17005, 'Curitiba', 'Íris Antônio Campos', 'Campo Comprido', '81220-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17006, 'Foz do Iguaçu', 'Irlan Kalichewski', 'Vila Yolanda', '85853-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17007, 'Londrina', 'Irlanda', 'Conjunto Oscavo Gomes Santos', '86046-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17008, 'Guarapuava', 'Irlanda', 'São Cristóvão', '85063-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17009, 'Francisco Beltrão', 'Irlanda', 'Seminário', '85605-649', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17010, 'Piraquara', 'Irlandino Pereira Benevides', 'Guarituba', '83311-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17011, 'Campo Mourão', 'Irmã Adelaide Molinari', 'Conjunto Habitacional Mendes', '87306-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17012, 'Curitiba', 'Irmã Albertina Caliari', 'Taboão', '82130-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17013, 'Curitiba', 'Irmã Anatólia', 'Cachoeira', '82220-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17014, 'Curitiba', 'Irmã Angélica Mazzarotto', 'Santa Felicidade', '82320-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17015, 'Castro', 'Irmã Apoline Trezub', 'Vila Santa Cruz', '84168-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17016, 'Curitiba', 'Irmã Beatriz Comparin', 'Cajuru', '82970-370', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17017, 'Londrina', 'Irmã Bona Dose', 'Santa Mônica', '86079-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17018, 'Curitiba', 'Irmã Carmelita Maria', 'Bacacheri', '82510-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17019, 'Cascavel', 'Irmã Dulce', 'Santa Cruz', '85806-746', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17020, 'Apucarana', 'Irmã Eleutéria', 'Centro', '86800-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17021, 'Araucária', 'Irmã Elizabeth Werka', 'Boqueirão', '83704-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17022, 'Londrina', 'Irmã Elza de Azevedo Costa', 'Lagoa Dourada', '86041-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17023, 'Curitiba', 'Irmã Flávia Borlet', 'Hauer', '81630-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17024, 'Curitiba', 'Irmã Gabriela Tinoco', 'Cidade Industrial', '81460-267', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17025, 'Laranjeiras do Sul', 'Irmã Inês Vailatti', 'São Francisco', '85303-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17026, 'Maringá', 'Irmã Isabel Padierna', 'Conjunto Habitacional Karina', '87047-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17027, 'Curitiba', 'Irmã Júlia', 'Ahú', '80540-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17028, 'Paranaguá', 'Irmã Letícia', 'Costeira', '83203-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17029, 'Londrina', 'Irmã Maria Almut', 'Jamaica', '86063-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17030, 'Curitiba', 'Irmã Maria Francisca Michel', 'Alto Boqueirão', '81850-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17031, 'Curitiba', 'Irmã Maria Francisca Paolino', 'Sítio Cercado', '81910-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17032, 'Curitiba', 'Irmã Maria Leontina de Assis', 'Cidade Industrial', '81170-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17033, 'Curitiba', 'Irmã Maria Lúcia Roland', 'Hauer', '81610-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17034, 'Curitiba', 'Irmã Maria Pinheiro Araújo', 'Boqueirão', '81730-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17035, 'Londrina', 'Irmã Maria Régis', 'Jardim do Lago', '86050-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17036, 'Guarapuava', 'Irmã Milla Marcondes', 'Primavera', '85050-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17037, 'Ponta Grossa', 'Irmã Noeli Maria da Silva', 'Nova Rússia', '84071-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17038, 'Curitiba', 'Irmã Regina', 'Água Verde', '80620-490', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17039, 'Cambé', 'Irmã Ricieri Piveta', 'Vila Atalaia', '86181-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17040, 'Paranaguá', 'Irmã Santana', 'Conjunto Residencial Prefeito Cominese', '83215-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17041, 'Curitiba', 'Irmã Sofia Riechi', 'Cidade Industrial', '81230-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17042, 'Curitiba', 'Irmã Stanislava Perz', 'São Francisco', '80510-050', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17043, 'Curitiba', 'Irmã Tecla', 'Vista Alegre', '80810-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17044, 'Curitiba', 'Irmã Tereza', 'Abranches', '82130-200', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17045, 'Londrina', 'Irmã Thanes', 'Santiago', '86073-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17046, 'Curitiba', 'Irmã Vitorina Meneghetti', 'Umbará', '81930-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17047, 'Francisco Beltrão', 'Irmão Cirilo', 'Miniguaçu', '85605-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17048, 'Londrina', 'Irmão José Valério de Souza', 'Cambezinho', '86040-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17049, 'Curitiba', 'Irmão Libério Plewnia', 'Cajuru', '82980-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17050, 'Curitiba', 'Irmão Luiz Vicente', 'Cajuru', '82900-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17051, 'Toledo', 'Irmão Nicolau', 'Jardim La Salle', '85903-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17052, 'Curitiba', 'Irmão Paulo Wodonos', 'Uberaba', '81550-600', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17053, 'Curitiba', 'Irmão Ruperto Félix', 'São Lourenço', '82200-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17054, 'Apucarana', 'Irmãos Andradas', 'Jardim Independência', '86811-285', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17055, 'Araucária', 'Irmãos do Vale', 'Costeira', '83709-155', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17056, 'Campo Mourão', 'Irmãos Pereira', 'Centro', '87301-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17057, 'Campo Mourão', 'Irmãos Pereira', 'Centro', '87300-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17058, 'Curitiba', 'Irmãs Nakadaira', 'Campo Comprido', '81230-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17059, 'Curitiba', 'Irmãs Paulinas', 'Novo Mundo', '81020-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17060, 'Curitiba', 'Irmãs Paulinas', 'Novo Mundo', '81110-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17061, 'Curitiba', 'Irmgard Wagner de França', 'Cidade Industrial', '81450-026', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17062, 'Maringá', 'Iroi', 'Jardim Alamar', '87014-470', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17063, 'Umuarama', 'Iroi', 'Zona VII', '87503-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17064, 'Curitiba', 'Irton Silveira de Almeida', 'Cidade Industrial', '81450-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17065, 'Curitiba', 'Isaac Guelmann', 'Novo Mundo', '81050-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17066, 'Curitiba', 'Isaac Lazzarotto', 'Alto da Rua XV', '80050-120', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17067, 'Curitiba', 'Isaac Milder', 'Juvevê', '80040-080', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17068, 'Londrina', 'Isaac Newton', 'Industrial', '86063-455', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17069, 'Telêmaco Borba', 'Isaac Newton', 'Fazenda Limeira', '84270-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17070, 'Pinhais', 'Isaac Victor Pereira', 'Conjunto Residencial Inocoop', '83326-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17071, 'Curitiba', 'Isaak Friesen', 'Xaxim', '81830-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17072, 'Curitiba', 'Isabel Bakker', 'Boqueirão', '81750-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17073, 'Colombo', 'Isabel de Quadros Ramos', 'Jardim Las Palmas', '83409-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17074, 'Curitiba', 'Isabel K. Gbur', 'São Braz', '82015-275', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17075, 'Curitiba', 'Isabel Maria Sikorski Moscalewski', 'Mossunguê', '81210-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17076, 'Curitiba', 'Isabel Ribeiro', 'Tatuquara', '81470-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17077, 'Curitiba', 'Isabel Withers Gomm', 'Bigorrilho', '80710-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17078, 'São José dos Pinhais', 'Isabel Zen Zagonel', 'Afonso Pena', '83045-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17079, 'Curitiba', 'Isac de Oliveira', 'Uberaba', '81570-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17080, 'Telêmaco Borba', 'Isaías Amâncio Santos', 'Nossa Senhora de Fátima', '84264-360', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17081, 'Ponta Grossa', 'Isaías da Luz', 'Boa Vista', '84073-176', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17082, 'Curitiba', 'Isaías Ferreira da Silva', 'Cajuru', '82980-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17083, 'Curitiba', 'Isaías Régis de Miranda', 'Boqueirão', '81670-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17084, 'Curitiba', 'Isaías Régis de Miranda', 'Hauer', '81630-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17085, 'Londrina', 'Isaltino Gonçalves Mendes', 'Milton Gavetti', '86078-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17086, 'Londrina', 'Isamu Sanada', 'Jacutinga', '86087-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17087, 'Londrina', 'Isao Udiahara', 'Conjunto Novo Amparo 2', '86056-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17088, 'Londrina', 'Isaura Marques Pereira', 'Jardim San Diego', '86073-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17089, 'Londrina', 'Isaura Toledo Silva', 'Parque Residencial Porto Serguro II', '86083-507', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17090, 'Curitiba', 'Isauro Trinco', 'Cajuru', '82930-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17091, 'Curitiba', 'Iseo Dizaró', 'Uberaba', '81540-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17092, 'Piraquara', 'Isídio Alves Ribeiro', 'Planta Meireles', '83304-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17093, 'Campo Largo', 'Isídio Cruzara', 'Jardim Boa Vista', '83609-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17094, 'Araucária', 'Isidoro Burkoski', 'Campina da Barra', '83709-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17095, 'Piraquara', 'Isidoro Canestraro', 'Jardim Santa Helena', '83308-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17096, 'Curitiba', 'Isidoro Canestraro', 'Bom Retiro', '80520-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17097, 'Curitiba', 'Isidoro Durigan', 'Santa Felicidade', '82400-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17098, 'Colombo', 'Isidoro Gaida', 'Jardim Guarujá', '83407-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17099, 'Toledo', 'Isidoro Vera', 'Jardim Europa', '85908-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17100, 'Ponta Grossa', 'Isidro Ferrer Alfaro', 'Oficinas', '84036-540', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17101, 'Ponta Grossa', 'Iskandar Assaad Zammar', 'Contorno', '84060-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17102, 'Londrina', 'Islândia', 'Conjunto Oscavo Gomes Santos', '86046-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17103, 'Colombo', 'Islândia', 'Jardim Bela Vista', '83404-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17104, 'Piraquara', 'Ismael Duarte Viante', 'Jardim Guarani', '83311-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17105, 'Ponta Grossa', 'Ismael Martins', 'Nova Rússia', '84053-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17106, 'Curitiba', 'Ismael Rocha Cordeiro', 'Alto Boqueirão', '81850-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17107, 'Curitiba', 'Ismênia Vieira de Alencar', 'Capão Raso', '81110-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17108, 'Toledo', 'Isolde Timm', 'Sachini', '85903-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17109, 'Curitiba', 'Isolde Torquato Tilio', 'Capão Raso', '81130-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17110, 'Piraquara', 'Isolina Cordeiro de Souza', 'Vila São Cristóvão', '83305-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17111, 'Londrina', 'Isolina Soares da Silva Peres', 'Jardim Neman Sahyun', '86041-278', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17112, 'Londrina', 'Israel', 'Vilas Boas', '86046-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17113, 'Ponta Grossa', 'Israel', 'Jardim Carvalho', '84016-695', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17114, 'Almirante Tamandaré', 'Israel', 'Vila Graziela', '83505-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17115, 'Apucarana', 'Israel Alves dos Santos', 'Núcleo Habitacional João Goulart', '86807-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17116, 'Cascavel', 'Israel da Vigo Silveira', 'Nova Cidade', '85803-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17117, 'São José dos Pinhais', 'Israel de Andrade Pereira', 'Boneca do Iguaçu', '83040-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17118, 'Campo Largo', 'Israel de França', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-786', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17119, 'Apucarana', 'Israel Silva Filho', 'Núcleo Habitacional Castelo Branco', '86812-395', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17120, 'São José dos Pinhais', 'Israelita', 'Silveira da Motta', '83030-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17121, 'Curitiba', 'Issac Kriger', 'Xaxim', '81830-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17122, 'Pato Branco', 'Ita', 'Santo Antônio', '85507-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17123, 'Maringá', 'Ita', 'Zona 06', '87080-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17124, 'Foz do Iguaçu', 'Itabaiana', 'Jardim Vasco da Gama', '85862-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17125, 'São José dos Pinhais', 'Itaberai', 'Guatupê', '83060-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17126, 'Foz do Iguaçu', 'Itabira', 'Jardim Ipê II', '85869-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17127, 'Pato Branco', 'Itabira', 'Centro', '85501-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17128, 'Pato Branco', 'Itabira', 'Jardim América', '85502-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17129, 'Pato Branco', 'Itabira', 'Centro', '85504-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17130, 'Francisco Beltrão', 'Itaboraí', 'Pinheirinho', '85603-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17131, 'Guarapuava', 'Itabuna', 'Jardim das Américas', '85030-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17132, 'Telêmaco Borba', 'Itabuna', 'Vila Esperança', '84272-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17133, 'Almirante Tamandaré', 'Itabuna', 'Jardim São Vicente', '83505-727', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17134, 'Castro', 'Itaciano Mainardes', 'Vila Farias', '84178-060', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17135, 'Curitiba', 'Itaciano Marcondes', 'Santa Cândida', '82720-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17136, 'Ponta Grossa', 'Itaciano Teixeira', 'Nova Rússia', '84053-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17137, 'Curitiba', 'Itacir Luiz Miola', 'Tatuquara', '81470-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17138, 'Pato Branco', 'Itacolomi', 'Amadori', '85502-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17139, 'Pato Branco', 'Itacolomi', 'Centro', '85501-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17140, 'Pato Branco', 'Itacolomi', 'Centro', '85505-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17141, 'Umuarama', 'Itacolomi', 'Zona VII', '87503-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17142, 'Toledo', 'Itacolomi', 'Jardim Cassandra', '85909-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17143, 'Curitiba', 'Itacolomi', 'Portão', '81070-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17144, 'Toledo', 'Itacora', 'Jardim Canaã', '85914-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17145, 'Ponta Grossa', 'Itacuras', 'Oficinas', '84035-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17146, 'Cascavel', 'Itagiba Fortunato', 'Santa Cruz', '85806-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17147, 'Ponta Grossa', 'Itaguagé', 'Oficinas', '84036-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17148, 'Londrina', 'Itaguaí', 'Tsukamoto', '86027-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17149, 'Londrina', 'Itaguaje', 'Lindóia', '86031-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17150, 'Curitiba', 'Itaguaje', 'Sítio Cercado', '81935-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17151, 'Guarapuava', 'Itaguapê', 'Vila Carli', '85045-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17152, 'Foz do Iguaçu', 'Itaguara', 'Loteameto Dona Amanda', '85853-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17153, 'Foz do Iguaçu', 'Itai', 'Loteameto Dona Amanda', '85853-727', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17154, 'Ponta Grossa', 'Itaiacoca', 'Uvaranas', '84030-007', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17155, 'Curitiba', 'Itaiópolis', 'Cidade Industrial', '81230-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17156, 'Guarapuava', 'Itaipu', 'São Cristóvão', '85060-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17157, 'Foz do Iguaçu', 'Itaipu', 'Centro', '85851-360', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17158, 'Londrina', 'Itaipu', 'São Lourenço', '86026-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17159, 'Maringá', 'Itaipu', 'Ebenezer', '87035-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17160, 'Toledo', 'Itaipu', 'Jardim Santa Maria', '85903-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17161, 'Sarandi', 'Itaipu', 'Parque Residencial Nova Aliança', '87111-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17162, 'Almirante Tamandaré', 'Itaipu', 'Vila Cachoeira', '83504-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17163, 'Cascavel', 'Itaipu', 'Universitário', '85819-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17164, 'Apucarana', 'Itaipu', 'Jardim Eldorado', '86802-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17165, 'Londrina', 'Itajaí', 'Tietê', '86025-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17166, 'Foz do Iguaçu', 'Itajaí', 'Jardim Petropólis', '85868-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17167, 'São José dos Pinhais', 'Itajaí', 'São Sebastião', '83075-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17168, 'Piraquara', 'Itajaí', 'Planta São Tiago', '83306-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17169, 'Umuarama', 'Itajaí', 'Jardim Ipanema', '87508-159', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17170, 'Cascavel', 'Itajaí', 'Universitário', '85819-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17171, 'Toledo', 'Itajubá', 'Jardim Cassandra', '85909-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17172, 'Arapongas', 'Itajubá', 'Aricanduva', '86706-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17173, 'Colombo', 'Itajubá', 'Jardim Curitiba', '83406-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17174, 'Curitiba', 'Itajubá', 'Portão', '81070-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17175, 'Guarapuava', 'Itália', 'Industrial', '85053-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17176, 'Londrina', 'Itália', 'Igapó', '86046-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17177, 'Ponta Grossa', 'Itália', 'Oficinas', '84036-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17178, 'Maringá', 'Itália', 'Jardim Guaporé', '87060-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17179, 'Umuarama', 'Itália', 'Parque Bonfim', '87507-377', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17180, 'Sarandi', 'Itália', 'Jardim Europa', '87111-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17181, 'Toledo', 'Itália', 'Jardim Bandeirantes', '85906-738', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17182, 'Umuarama', 'Itália', 'Zona II', '87501-385', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17183, 'Cambé', 'Itália', 'Jardim Morada do Sol', '86181-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17184, 'Almirante Tamandaré', 'Itália', 'Vila Emerentina', '83505-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17185, 'Cascavel', 'Itália', 'Cascavel Velho', '85818-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17186, 'Curitiba', 'Itália', 'Jardim Botânico', '80210-180', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17187, 'Curitiba', 'Itália', 'Alto da Glória', '80030-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17188, 'Londrina', 'Itália Choucino', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17189, 'Curitiba', 'Itália Giampoli Amatuzzi', 'Vista Alegre', '82100-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17190, 'São José dos Pinhais', 'Itália Manzoque Piovesan', 'São Pedro', '83020-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17191, 'Curitiba', 'Itália Maria Malucelli Trombini', 'Santa Felicidade', '82410-485', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17192, 'Toledo', 'Itália Piovesan Pasqualli', 'Jardim Pasqualli', '85905-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17193, 'Curitiba', 'Italino Peruffo', 'Boqueirão', '81650-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17194, 'Apucarana', 'Ítalo Ado Fontanini', 'Loteamento Biguaçu', '86809-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17195, 'Apucarana', 'Ítalo Ado Fontanini', 'Vila São Paulo', '86800-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17196, 'Ponta Grossa', 'Ítalo Moro', 'Estrela', '84050-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17197, 'Curitiba', 'Itamar Cortes', 'Tatuquara', '81480-345', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17198, 'Maringá', 'Itamar Garcia Pereira', 'Vila Santa Izabel', '87080-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17199, 'Paranaguá', 'Itamarandiba', 'Santos Dumont', '83209-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17200, 'Almirante Tamandaré', 'Itamarandina', 'Jardim Ipê', '83505-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17201, 'Guarapuava', 'Itamarati', 'São Cristóvão', '85060-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17202, 'Paranavaí', 'Itamarati', 'Jardim Santos Dumont', '87706-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17203, 'Paranavaí', 'Itamarati', 'Jardim Iguaçu', '87705-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17204, 'Toledo', 'Itamarati', 'Jardim Anápolis', '85905-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17205, 'Cambé', 'Itamarati', 'Jardim Alvorada', '86191-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17206, 'Curitiba', 'Itamarati', 'Guabirotuba', '81520-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17207, 'Ponta Grossa', 'Itambaraca', 'Oficinas', '84036-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17208, 'Cambé', 'Itambaracás', 'Jardim Tupi', '86183-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17209, 'Guarapuava', 'Itambé', 'Industrial', '85045-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17210, 'Foz do Iguaçu', 'Itambé', 'Vila Carima', '85855-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17211, 'Londrina', 'Itambé', 'Lindóia', '86031-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17212, 'Pinhais', 'Itambé', 'Jardim Pedro Demeterco', '83324-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17213, 'Telêmaco Borba', 'Itambé', 'Área 06', '84271-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17214, 'Umuarama', 'Itambé', 'Zona VII', '87503-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17215, 'Arapongas', 'Itambé', 'Aricanduva', '86706-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17216, 'Curitiba', 'Itambé', 'Sítio Cercado', '81935-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17217, 'São José dos Pinhais', 'Itaóca', 'Guatupê', '83060-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17218, 'Foz do Iguaçu', 'Itaparica', 'Loteamento Mata Verde', '85853-686', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17219, 'Almirante Tamandaré', 'Itaparica', 'Jardim São Vicente', '83505-728', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17220, 'Francisco Beltrão', 'Itapejara do Oeste', 'Marrecas', '85601-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17221, 'Curitiba', 'Itapejara do Oeste', 'Alto Boqueirão', '81770-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17222, 'Foz do Iguaçu', 'Itapema', 'Jardim Copacabana', '85856-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17223, 'Telêmaco Borba', 'Itapema', 'Área 01', '84268-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17224, 'Umuarama', 'Itapema', 'Jardim San Rafael', '87508-168', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17225, 'Guarapuava', 'Itapemerim', 'Boqueirão', '85022-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17226, 'Foz do Iguaçu', 'Itapemirim', 'Loteamento Campos do Iguaçu', '85857-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17227, 'Foz do Iguaçu', 'Itapemirim', 'Jardim Alice II', '85858-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17228, 'Londrina', 'Itaperuna', 'Tsukamoto', '86027-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17229, 'Toledo', 'Itaperuna', 'Boa Esperança', '85909-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17230, 'Telêmaco Borba', 'Itapetinga', 'Área 06', '84271-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17231, 'Guarapuava', 'Itapetininga', 'Santana', '85070-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17232, 'Foz do Iguaçu', 'Itapetininga', 'Jardim Karla', '85868-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17233, 'Ponta Grossa', 'Itapetininga', 'Uvaranas', '84025-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17234, 'Ponta Grossa', 'Itapetininga', 'Chapada', '84062-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17235, 'Francisco Beltrão', 'Itapeva', 'Pinheirinho', '85603-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17236, 'Guarapuava', 'Itapeva', 'Jardim das Américas', '85030-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17237, 'São José dos Pinhais', 'Itapeva', 'Guatupê', '83060-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17238, 'Londrina', 'Itapicuru', 'Aparecida', '86025-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17239, 'Foz do Iguaçu', 'Itapicuru', 'Loteamento Campos do Iguaçu', '85857-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17240, 'Foz do Iguaçu', 'Itapira', 'Jardim Ipê II', '85869-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17241, 'Londrina', 'Itápolis', 'Jardim Santo Antônio', '86060-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17242, 'Pato Branco', 'Itapuá', 'Parzianello', '85504-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17243, 'Pato Branco', 'Itapuá', 'La Salle', '85505-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17244, 'Toledo', 'Itapuá', 'Walter Fontana', '85909-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17245, 'Maringá', 'Itapuã', 'Conjunto Residencial Parigot de Souza', '87047-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17246, 'Guarapuava', 'Itapuana', 'São Cristóvão', '85063-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17247, 'Maringá', 'Itapura', 'Zona 03', '87050-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17248, 'Cascavel', 'Itaquatiaras', 'Santa Cruz', '85806-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17249, 'Guarapuava', 'Itaqui', 'Jardim das Américas', '85030-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17250, 'Cascavel', 'Itaqui', 'Canadá', '85813-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17251, 'Umuarama', 'Itaquirai', 'Zona I', '87501-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17252, 'Guarapuava', 'Itararé', 'Jardim das Américas', '85030-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17253, 'Londrina', 'Itararé', 'Canadá', '86020-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17254, 'Foz do Iguaçu', 'Itararé', 'Jardim Petropólis', '85868-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17255, 'São José dos Pinhais', 'Itararé', 'Guatupê', '83060-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17256, 'Pinhais', 'Itararé', 'Loteamento Alphaville Graciosa', '83327-077', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17257, 'Toledo', 'Itararé', 'Panorama', '85911-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17258, 'Apucarana', 'Itararé', 'Jardim Ponta Grossa', '86805-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17259, 'Araucária', 'Itararé', 'Iguaçu', '83701-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17260, 'Curitiba', 'Itararé', 'Centro', '80060-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17261, 'Foz do Iguaçu', 'Itatiaia', 'Loteamento Lindóia', '85856-629', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17262, 'Telêmaco Borba', 'Itatiaia', 'Área 06', '84271-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17263, 'Curitiba', 'Itatiaia', 'Portão', '81070-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17264, 'Cascavel', 'Itatiba do Sul', 'Santos Dumont', '85804-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17265, 'São José dos Pinhais', 'Itau', 'Guatupê', '83060-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17266, 'Cascavel', 'Itaúba', 'Parque Verde', '85807-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17267, 'Umuarama', 'Itauna', 'Jardim San Martim', '87508-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17268, 'Foz do Iguaçu', 'Itaúna', 'Conjunto Libra', '85857-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17269, 'Curitiba', 'Itaúna do Sul', 'Alto Boqueirão', '81770-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17270, 'São José dos Pinhais', 'Itazuri', 'Guatupê', '83060-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17271, 'Apucarana', 'Itemerata Gonçalves dos Santos', 'Jardim Catuaí III', '86802-639', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17272, 'Paranaguá', 'Itiberê de Lima', 'Centro Histórico', '83203-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17273, 'Sarandi', 'Itiquira', 'Jardim Esplanada', '87112-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17274, 'Guarapuava', 'Itororos', 'Vila Carli', '85040-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17275, 'Foz do Iguaçu', 'Itororos', 'Jardim Itamaraty', '85863-747', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17276, 'Maringá', 'Itororos', 'Zona 02', '87010-460', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17277, 'Sarandi', 'Itororos', 'Jardim Independência III', '87114-270', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17278, 'Foz do Iguaçu', 'Itu', 'Jardim Karla', '85868-075', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17279, 'Francisco Beltrão', 'Itu', 'Pinheirinho', '85603-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17280, 'Londrina', 'Itu', 'São Cristóvão', '86025-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17281, 'Pato Branco', 'Itu', 'São Roque', '85507-030', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17282, 'Umuarama', 'Itu', 'Jardim Primavera', '87505-270', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17283, 'Umuarama', 'Itu', 'Parque Dom Pedro I', '87508-010', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17284, 'Cambé', 'Itu', 'Jardim São Paulo', '86191-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17285, 'Cascavel', 'Itu', 'Maria Luiza', '85819-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17286, 'Foz do Iguaçu', 'Itui', 'Conjunto A', '85860-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17287, 'Londrina', 'Ituiutaba', 'San Remo', '86062-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17288, 'Curitiba', 'Itupava', 'Alto da Rua XV', '80060-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17289, 'Curitiba', 'Itupava', 'Alto da Rua XV', '80040-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17290, 'Londrina', 'Iugoslávia', 'Vilas Boas', '86046-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17291, 'Cambé', 'Iugoslávia', 'Jardim Morada do Sol', '86181-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17292, 'Foz do Iguaçu', 'Iuma', 'Conjunto A', '85866-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17293, 'Londrina', 'Iusmar Gomes Dias', 'Ernani de Moura Lima', '86037-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17294, 'Pato Branco', 'Iva', 'Santo Antônio', '85507-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17295, 'Guarapuava', 'Ivai', 'Industrial', '85045-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17296, 'Foz do Iguaçu', 'Ivai', 'Jardim Amazonas', '85857-730', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17297, 'Londrina', 'Ivai', 'Conceição', '86025-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17298, 'São José dos Pinhais', 'Ivai', 'São Pedro', '83020-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17299, 'Maringá', 'Ivai', 'Vila Marumby', '87005-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17300, 'Toledo', 'Ivai', 'Jardim Porto Alegre', '85906-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17301, 'Telêmaco Borba', 'Ivai', 'Área 01', '84272-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17302, 'Sarandi', 'Ivai', 'Parque Residencial Nova Aliança', '87111-727', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17303, 'Sarandi', 'Ivai', 'Jardim Primavera', '87111-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17304, 'Cascavel', 'Ivai', 'Presidente', '85818-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17305, 'Araucária', 'Ivai', 'Iguaçu', '83701-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17306, 'Castro', 'Ivai', 'Jardim Social Arapongas', '84174-295', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17307, 'Apucarana', 'Ivai', 'Vila Boa Vista', '86810-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17308, 'Curitiba', 'Ivai', 'Alto Boqueirão', '81770-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17309, 'Pato Branco', 'Ivaí', 'Pinheirinho', '85506-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17310, 'Piraquara', 'Ivaí', 'Jardim Primavera', '83302-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17311, 'Campo Mourão', 'Ivailândia', 'Jardim Tropical II', '87310-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17312, 'Guarapuava', 'Ivaiporã', 'Boqueirão', '85022-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17313, 'Cambé', 'Ivaiporã', 'Jardim Ana Eliza', '86187-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17314, 'Curitiba', 'Ivaiporã', 'Alto Boqueirão', '81770-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17315, 'Umuarama', 'Ivaitinga', 'Zona VII', '87503-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17316, 'Maringá', 'Ivaldir Mazzia', 'Conjunto Habitacional Requião', '87047-448', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17317, 'Maringá', 'Ivaldo Borges Horta', 'Jardim Licce', '87025-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17318, 'Toledo', 'Ivan Antes', 'Jardim Anápolis', '85905-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17319, 'Curitiba', 'Ivan Coriolano Barros Durand', 'Cidade Industrial', '81170-727', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17320, 'Curitiba', 'Ivan Ferreira do Amaral Filho', 'Jardim das Américas', '81540-310', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17321, 'Maringá', 'Ivan Pavlov', 'Jardim Alvorada', '87035-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17322, 'Curitiba', 'Ivan Romeu Teixeira Júnior', 'Pinheirinho', '81870-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17323, 'Londrina', 'Ivan Sérgio Athayde Vicente', 'Gleba Fazenda Palhano', '86050-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17324, 'Cascavel', 'Ivan Serpa', 'Country', '85813-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17325, 'Almirante Tamandaré', 'Ivanilde Brito Keppel', 'Parque Timbu', '83514-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17326, 'Almirante Tamandaré', 'Ivanir Silva da Rosa', 'Jardim Campo Verde', '83502-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17327, 'Umuarama', 'Ivaté', 'Zona IV', '87504-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17328, 'Curitiba', 'Ivatuba', 'Sítio Cercado', '81935-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17329, 'Colombo', 'Ivatuva', 'Jardim Guaraituba', '83410-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17330, 'Londrina', 'Ivete Abib', 'Parque Residencial Alcântara', '86047-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17331, 'Curitiba', 'Ivete Maria Vargas', 'São Braz', '82300-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17332, 'Paranavaí', 'Ivete Vargas', 'Jardim São Jorge', '87711-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17333, 'Curitiba', 'Ivette Puglielli Cunha', 'Mossunguê', '81210-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17334, 'Maringá', 'Ivinhema', 'Parque Avenida', '87025-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17335, 'Campo Mourão', 'Ivo Bichara', 'Jardim Nossa Senhora Aparecida', '87309-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17336, 'Curitiba', 'Ivo Bisoni', 'Sítio Cercado', '81900-729', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17337, 'Londrina', 'Ivo Braguim', 'Conjunto Habitacional  Alexandre Urbanas', '86037-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17338, 'Pato Branco', 'Ivo Cantu', 'Parzianello', '85504-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17339, 'Guarapuava', 'Ivo Eduardo Cordeiro dos Passos', 'Primavera', '85050-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17340, 'Curitiba', 'Ivo Ferro', 'Uberaba', '81540-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17341, 'Curitiba', 'Ivo Ferro', 'Uberaba', '81560-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17342, 'Curitiba', 'Ivo Flemming', 'Bacacheri', '82600-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17343, 'Toledo', 'Ivo Heiss', 'Coopagro', '85903-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17344, 'Curitiba', 'Ivo Leão', 'Alto da Glória', '80030-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17345, 'Campo Mourão', 'Ivo Mário Trombini', 'Jardim Laura', '87300-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17346, 'Ponta Grossa', 'Ivo Mendes Barreto', 'Olarias', '84026-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17347, 'Londrina', 'Ivo Moratelli', 'Conjunto Habitacional Champagnat', '86086-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17348, 'São José dos Pinhais', 'Ivo Neves', 'Costeira', '83015-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17349, 'Londrina', 'Ivo Nobre da Silva', 'Conjunto Habitacional  Alexandre Urbanas', '86037-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17350, 'Curitiba', 'Ivo Odia', 'Cidade Industrial', '81305-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17351, 'Araucária', 'Ivo Pereira', 'Boqueirão', '83704-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17352, 'Curitiba', 'Ivo Pereira de Carvalho', 'Uberaba', '81560-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17353, 'Curitiba', 'Ivo Rodrigues', 'Bairro Alto', '82820-550', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17354, 'Curitiba', 'Ivone Espírito Santo Garcia', 'Uberaba', '81550-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17355, 'Londrina', 'Ivone Freitas Lopes', 'Conjunto Habitacional Saltinho', '86042-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17356, 'Londrina', 'Ivone Leiroz', 'Parigot de Souza 2', '86082-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17357, 'Londrina', 'Ivone Orcelli de Oliveira', 'Jardim Paris', '86082-066', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17358, 'Almirante Tamandaré', 'Ivone Soares', 'Jardim Parati', '83503-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17359, 'Almirante Tamandaré', 'Ivonete Ledi de Siqueira', 'Jardim Cíntia Mara', '83513-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17360, 'Londrina', 'Iwao Nakajima', 'Jardim Strass', '86084-826', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17361, 'Curitiba', 'Iwao Namizaki', 'Uberaba', '81550-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17362, 'Curitiba', 'Izaac Ferreira da Cruz', 'Sítio Cercado', '81910-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17363, 'Curitiba', 'Izaac Ferreira da Cruz', 'Sítio Cercado', '81900-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17364, 'Curitiba', 'Izaac Ferreira da Cruz', 'Alto Boqueirão', '81830-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17365, 'Curitiba', 'Izaac Ferreira da Cruz', 'Pinheirinho', '81870-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17366, 'São José dos Pinhais', 'Izabel A Redentora', 'Centro', '83005-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17367, 'São José dos Pinhais', 'Izabel A Redentora', 'Silveira da Motta', '83030-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17368, 'Foz do Iguaçu', 'Izabel Bonini Pasa', 'Parque Morumbi I', '85858-647', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17369, 'Colombo', 'Izabel Capelari Antoniacomi', 'Jardim Adriana', '83408-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17370, 'Curitiba', 'Izabel Casagrande Lopes', 'Butiatuvinha', '82320-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17371, 'Piraquara', 'Izabel Correia Soares', 'Vila Izabel', '83305-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17372, 'Colombo', 'Izabel Costa Bontorin', 'Jardim Planalto', '83409-136', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17373, 'Foz do Iguaçu', 'Izabel Cristina Becker', 'Beverly Falls Park', '85858-205', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17374, 'Curitiba', 'Izabel Gomes Posselt', 'Alto Boqueirão', '81830-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17375, 'Curitiba', 'Izabel Greca Janz', 'Mossunguê', '81210-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17376, 'Londrina', 'Izabel Guilhen Garcia', 'Universitário', '86056-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17377, 'Londrina', 'Izabel Oliveira Lima', 'Monte Belo', '86041-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17378, 'Ponta Grossa', 'Izabel Ossowski', 'Chapada', '84064-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17379, 'Curitiba', 'Izabel Raksa Voluz', 'Pinheirinho', '81870-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17380, 'Londrina', 'Izabel Ribeiro Perine', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17381, 'Londrina', 'Izabel Romeiro Malfil', 'Cafezal 1', '86049-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17382, 'Foz do Iguaçu', 'Izabel Veríssimo', 'Jardim Princesa Daiana', '85867-678', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17383, 'Curitiba', 'Izabela Veiga Kulcheski', 'Cidade Industrial', '81460-288', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17384, 'Curitiba', 'Izac Moyses Kviatek', 'Alto Boqueirão', '81770-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17385, 'Curitiba', 'Izahia Cecin Calixto', 'Cajuru', '82970-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17386, 'Colombo', 'Izaias Barbosa', 'Jardim dos Eucaliptos', '83408-529', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17387, 'Curitiba', 'Izaias Belloni', 'Santa Felicidade', '82020-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17388, 'Londrina', 'Izaias Canette', 'Jardim Ibirapuera', '86067-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17389, 'Foz do Iguaçu', 'Izaias de Noronha', 'Parque Presidente', '85863-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17390, 'Apucarana', 'Izaías Mariano', 'Jardim Catuaí', '86802-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17391, 'Londrina', 'Izaias Nunes da Silva', 'Jardim Bandeirantes', '86065-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17392, 'Curitiba', 'Izailde Oliveira Rodrigues', 'Cidade Industrial', '81170-716', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17393, 'Curitiba', 'Izair de Anhaia', 'Capão da Imbuia', '82810-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17394, 'Londrina', 'Izaíra Garcia Dutra', 'Jardim Tarobá I', '86042-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17395, 'Pinhais', 'Izaira Monteiro', 'Jardim Pedro Demeterco', '83324-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17396, 'Curitiba', 'Izalino Buosi', 'Cidade Industrial', '81170-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17397, 'Curitiba', 'Izaltino Dias Ferraz', 'Cidade Industrial', '81270-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17398, 'Londrina', 'Izaura Amaral Alves', 'Conjunto Semiramis Barros Braga', '86088-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17399, 'Maringá', 'Izaura Gamba Vitorino', 'Jardim Nilza', '87065-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17400, 'Curitiba', 'Izaura Oliveira de Oliveira', 'Campo Comprido', '81210-135', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17401, 'Foz do Iguaçu', 'Izaura Palmieri Guiacheto', 'Jardim Califórnia', '85867-486', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17402, 'Paranavaí', 'Iziddoro Ferreira da Costa', 'Jardim Simoni I', '87711-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17403, 'São José dos Pinhais', 'Izídio Fiuza', 'Guatupê', '83065-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17404, 'Londrina', 'Izidio Frederico Brito', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17405, 'Colombo', 'Izídio Mocelin Filho', 'Jardim Belo Rincão', '83412-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17406, 'Curitiba', 'Izidoro Chanoski', 'Vista Alegre', '80820-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17407, 'Londrina', 'Izidoro Chimenton', 'Residencial Portal do Sol', '86082-778', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17408, 'Almirante Tamandaré', 'Izidoro da Silva', 'São Miguel', '83511-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17409, 'Londrina', 'Izidoro Dias Lopes', 'Sebastião de Melo César', '86084-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17410, 'Araucária', 'Izidoro Klichovicz', 'Tindiquera', '83708-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17411, 'Araucária', 'Izidoro Ksiazkiewicz', 'Costeira', '83708-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17412, 'Curitiba', 'Izidoro Langa', 'Orleans', '82300-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17413, 'Curitiba', 'Izidoro Mário Paul', 'Santa Cândida', '82630-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17414, 'Foz do Iguaçu', 'Izidoro Pastorello', 'Jardim Guarapuava II', '85853-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17415, 'Foz do Iguaçu', 'Izidoro Pastorelo', 'Jardim Guarapuava II', '85856-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17416, 'Curitiba', 'Izidoro Sanzovo', 'Santa Felicidade', '82400-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17417, 'Curitiba', 'Izidoro Siedeliski', 'Novo Mundo', '81020-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17418, 'Curitiba', 'Izidoro Stavitzki', 'Pinheirinho', '81820-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17419, 'Curitiba', 'Izidoro Wosch', 'Santa Cândida', '82650-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17420, 'Foz do Iguaçu', 'Izidro de Souza', 'Cr 4', '85863-718', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17421, 'Foz do Iguaçu', 'Izidro Pires', 'Jardim Santa Rita', '85862-327', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17422, 'Londrina', 'Izilda Heringer Azevedo', 'Parque Residencial Elizabeth', '86077-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17423, 'Londrina', 'Iziquel Castaldi', 'Presidente Vargas', '86083-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17424, 'Londrina', 'Izolina da Silva Barroso', 'Del Rey', '86045-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17425, 'Curitiba', 'Izolina Moletta Maurer', 'Cidade Industrial', '81230-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17426, 'Foz do Iguaçu', 'J', 'Conjunto C', '85870-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17427, 'Ponta Grossa', 'J', 'Contorno', '84060-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17428, 'Umuarama', 'J', 'Parque Dom Pedro I', '87508-027', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17429, 'Campo Largo', 'J', 'Vila Torres I', '83609-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17430, 'Almirante Tamandaré', 'J', 'Loteamento Recanto dos Papagaios', '83512-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17431, 'Campo Largo', 'J', 'Jardim Três Rios', '83603-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17432, 'Castro', 'J', 'Vila do Rosário', '84168-087', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17433, 'Campo Largo', 'J', 'Popular Nova', '83602-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17434, 'Arapongas', 'J-1', 'Conjunto Del Condor', '86703-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17435, 'Arapongas', 'J-10', 'Conjunto Del Condor', '86703-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17436, 'Arapongas', 'J-2', 'Conjunto Del Condor', '86703-386', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17437, 'Arapongas', 'J-3', 'Conjunto Del Condor', '86703-387', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17438, 'Arapongas', 'J-4', 'Conjunto Del Condor', '86703-388', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17439, 'Arapongas', 'J-5', 'Conjunto Del Condor', '86703-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17440, 'Arapongas', 'J-6', 'Conjunto Del Condor', '86703-376', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17441, 'Arapongas', 'J-7', 'Conjunto Del Condor', '86703-377', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17442, 'Arapongas', 'J-8', 'Conjunto Del Condor', '86703-378', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17443, 'Arapongas', 'J-9', 'Conjunto Del Condor', '86703-379', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17444, 'Sarandi', 'Jabaquara', 'Jardim Nova Paulista', '87111-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17445, 'Foz do Iguaçu', 'Jaboti', 'Jardim Vasco da Gama', '85862-406', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17446, 'Ponta Grossa', 'Jaboti', 'Contorno', '84052-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17447, 'Apucarana', 'Jaboti', 'Jardim Menegazzo', '86802-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17448, 'Curitiba', 'Jaboti', 'Alto Boqueirão', '81770-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17449, 'Maringá', 'Jaboticaba', 'Jardim Tropical', '87080-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17450, 'Laranjeiras do Sul', 'Jaboticabal', 'Centro', '85301-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17451, 'Curitiba', 'Jaboticabas', 'Uberaba', '81560-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17452, 'Ponta Grossa', 'Jaboticabeira', 'Contorno', '84061-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17453, 'Guarapuava', 'Jaburu', 'Conradinho', '85045-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17454, 'Maringá', 'Jaburu', 'Parque Hortência', '87075-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17455, 'Ponta Grossa', 'Jaburu', 'Colônia Dona Luiza', '84046-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17456, 'Campo Mourão', 'Jaburu', 'Jardim Aeroporto', '87310-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17457, 'Araucária', 'Jaburu', 'Capela Velha', '83706-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17458, 'Arapongas', 'Jaburu', 'Vila Natal', '86707-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17459, 'Cambé', 'Jaburu', 'Conjunto Habitacional Waldomiro M Gomes', '86182-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17460, 'Apucarana', 'Jaburu', 'Núcleo Habitacional Michel Soni', '86813-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17461, 'Foz do Iguaçu', 'Jabuticabeira', 'Jardim Mônaco', '85862-387', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17462, 'Londrina', 'Jaca', 'Glória', '86035-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17463, 'Paranaguá', 'Jaca', 'Vila São Vicente', '83209-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17464, 'Arapongas', 'Jacamim', 'Vila São João', '86708-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17465, 'Londrina', 'Jaçanã', 'Yara', '86027-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17466, 'Foz do Iguaçu', 'Jaçanã', 'Portal da Foz', '85859-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17467, 'Guarapuava', 'Jaçanã', 'Conradinho', '85045-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17468, 'Maringá', 'Jaçanã', 'Parque Hortência', '87075-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17469, 'Paranaguá', 'Jaçanã', 'Jardim Esperança', '83218-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17470, 'Umuarama', 'Jaçanã', 'Jardim Alphavile', '87504-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17471, 'Sarandi', 'Jaçanã', 'Centro', '87111-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17472, 'Arapongas', 'Jaçanã', 'Vila São João', '86708-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17473, 'Campo Mourão', 'Jaçanã', 'Jardim Tropical I', '87310-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17474, 'Curitiba', 'Jaçanã', 'São Braz', '82315-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17476, 'Pinhais', 'Jacarandá', 'Jardim Pio XII', '83328-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17477, 'Maringá', 'Jacarandá', 'Parque Palmeiras', '87023-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17478, 'Ponta Grossa', 'Jacarandá', 'Uvaranas', '84033-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17479, 'Piraquara', 'Jacarandá', 'Planta Bosque Centenário', '83311-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17480, 'Sarandi', 'Jacarandá', 'Jardim Monterey', '87112-285', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17481, 'Telêmaco Borba', 'Jacarandá', 'Área 01', '84268-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17482, 'Campo Largo', 'Jacarandá', 'Jardim Guarany I', '83608-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17483, 'Apucarana', 'Jacarandá', 'Jardim Recanto dos Palmares', '86803-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17484, 'Cascavel', 'Jacarandá', 'Parque Verde', '85807-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17485, 'Almirante Tamandaré', 'Jacarandá', 'Loteamento Chico Mendes', '83505-747', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17486, 'Araucária', 'Jacarandá', 'Estação', '83705-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17487, 'Cambé', 'Jacarandá', 'Vila Salomé', '86192-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17488, 'Foz do Iguaçu', 'Jacareí', 'Jardim Ipê II', '85869-648', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17489, 'Umuarama', 'Jacareí', 'Zona V', '87504-270', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17490, 'Cascavel', 'Jacarepaguá', 'Interlagos', '85814-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17491, 'Londrina', 'Jacareúba', 'Santa Rita 1', '86071-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17492, 'Londrina', 'Jacarezinho', 'Indústrias', '86043-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17493, 'Pinhais', 'Jacarezinho', 'Jardim Alto Tarumã', '83325-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17494, 'Paranaguá', 'Jacarezinho', 'Emboguaçu', '83209-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17495, 'Ponta Grossa', 'Jacarezinho', 'Contorno', '84052-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17496, 'São José dos Pinhais', 'Jacarezinho', 'São Cristóvão', '83040-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17497, 'Araucária', 'Jacarezinho', 'Iguaçu', '83701-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17498, 'Cambé', 'Jacarezinho', 'Jardim Silvino', '86187-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17499, 'Colombo', 'Jacarezinho', 'Jardim Guilhermina', '83410-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17500, 'Cascavel', 'Jacarezinho', 'São Cristóvão', '85816-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17501, 'Curitiba', 'Jacarezinho', 'Mercês', '80710-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17502, 'Curitiba', 'Jacarezinho', 'Mercês', '80810-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17503, 'Curitiba', 'Jacas', 'Uberaba', '81560-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17504, 'Campo Mourão', 'Jaci Brandão', 'Jardim Copacabana', '87302-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17505, 'Ponta Grossa', 'Jaci Monteiro', 'Boa Vista', '84073-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17506, 'Colombo', 'Jaci Rodrigues', 'Vila Miracema', '83408-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17507, 'Curitiba', 'Jacintho Pereira de Carvalho', 'Augusta', '81260-546', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17508, 'Curitiba', 'Jacintho Torres', 'Cajuru', '82900-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17509, 'Curitiba', 'Jacintho Vanelli', 'São Lourenço', '82210-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17510, 'Ponta Grossa', 'Jacinto', 'Neves', '84021-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17511, 'Curitiba', 'Jacinto Antunes da Silva', 'Água Verde', '80620-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17512, 'Curitiba', 'Jacinto Cunha', 'Cidade Industrial', '81260-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17513, 'Toledo', 'Jacinto João Sartori', 'Jardim Porto Alegre', '85906-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17514, 'Ponta Grossa', 'Jacinto Lozza', 'Estrela', '84050-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17515, 'Curitiba', 'Jacir José Ferreira', 'Cidade Industrial', '81305-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17516, 'Londrina', 'Jacira Messias Leama', 'Jardim Vale Azul', '86041-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17517, 'Foz do Iguaçu', 'Jacira Morello', 'Loteamento Residencial Lagoa Vermelha', '85862-339', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17518, 'Pato Branco', 'Jacireta', 'Centro', '85504-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17519, 'Castro', 'Jack Fadel', 'Jardim Social Arapongas', '84174-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17520, 'Curitiba', 'Jackson Figueiredo', 'Parolin', '81030-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17521, 'Maringá', 'Jacó do Bandolin', 'Jardim América', '87045-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17522, 'Pato Branco', 'Jacó Morelatto', 'Vila Esperança', '85503-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17523, 'Curitiba', 'Jacob Andreatta', 'Pinheirinho', '81880-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17524, 'Londrina', 'Jacob Barolomeu Minatti', 'Centro', '86026-715', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17525, 'Londrina', 'Jacob Bartolomeu Minatti', 'Centro', '86010-355', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17526, 'Londrina', 'Jacob Bartolomeu Minatti', 'Centro', '86010-715', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17527, 'Curitiba', 'Jacob Basso', 'Santa Felicidade', '82030-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17528, 'Colombo', 'Jacob Berlezi', 'Jardim Panorama', '83412-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17529, 'Curitiba', 'Jacob Bertinato', 'Tarumã', '82530-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17530, 'Colombo', 'Jacob Bertolin', 'Itajacuru', '83407-835', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17531, 'Curitiba', 'Jacob Biron', 'São Lourenço', '82210-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17532, 'Ponta Grossa', 'Jacob Biscarra', 'Chapada', '84062-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17533, 'Colombo', 'Jacob Bonatto', 'Sapopema', '83414-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17534, 'Curitiba', 'Jacob Boryca', 'Tatuquara', '81480-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17535, 'Curitiba', 'Jacob Brandalise', 'Uberaba', '81560-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17536, 'Curitiba', 'Jacob Breda', 'São Braz', '82015-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17537, 'Almirante Tamandaré', 'Jacob C. Benato', 'Planta São João', '83514-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17538, 'Curitiba', 'Jacob de Rosso', 'Xaxim', '81810-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17539, 'Ponta Grossa', 'Jacob Ditzel Júnior', 'Nova Rússia', '84070-600', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17540, 'Cascavel', 'Jacob do Bandolin', 'Brasília', '85815-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17541, 'Araucária', 'Jacob Dranka', 'Centro', '83702-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17542, 'Londrina', 'Jacob Elias Issa', 'Jardim Acapulco', '86045-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17543, 'Ponta Grossa', 'Jacob Faintych', 'Olarias', '84026-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17544, 'Pinhais', 'Jacob Fedalto', 'Vila Tarumã', '83323-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17545, 'Curitiba', 'Jacob Foltran', 'Bigorrilho', '80710-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17546, 'Almirante Tamandaré', 'Jacob Gubava', 'Jardim Ipanema', '83507-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17547, 'Colombo', 'Jacob Gueno', 'Jardim Belo Rincão', '83412-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17548, 'Ponta Grossa', 'Jacob Holzmann', 'Olarias', '84035-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17549, 'Foz do Iguaçu', 'Jacob Horn', 'Jardim Norma', '85869-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17550, 'Colombo', 'Jacob Kulik', 'Jardim Cruzeiro', '83403-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17551, 'Pinhais', 'Jacob Macanhan', 'Jardim Guairacá', '83324-510', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17552, 'Pinhais', 'Jacob Macanhan', 'Jardim Dona Joaquina I', '83325-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17553, 'Pinhais', 'Jacob Macanhan', 'Jardim Cláudia', '83326-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17554, 'Pinhais', 'Jacob Mehl', 'Planta Cláudio Mehl', '83326-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17555, 'Colombo', 'Jacob Mehl', 'Jardim Central', '83409-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17556, 'Foz do Iguaçu', 'Jacob Munhack', 'Conjunto Habitacional Fernanda', '85862-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17557, 'Ponta Grossa', 'Jacob Nadal', 'Jardim Carvalho', '84016-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17558, 'Curitiba', 'Jacob P. Bittencourt', 'Vista Alegre', '80820-170', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17559, 'Curitiba', 'Jacob Paykala', 'Atuba', '82630-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17560, 'Curitiba', 'Jacob Romanichen', 'Xaxim', '81710-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17561, 'Laranjeiras do Sul', 'Jacob Roths', 'São Francisco', '85303-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17562, 'Ponta Grossa', 'Jacob Schell', 'Boa Vista', '84073-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17563, 'Curitiba', 'Jacob Scuissiatto', 'Fazendinha', '81330-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17564, 'Curitiba', 'Jacob Stofella Filho', 'Água Verde', '80620-350', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17565, 'Curitiba', 'Jacob Teides Sobrinho', 'Novo Mundo', '81020-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17566, 'Piraquara', 'Jacob Valenga', 'Vila Franca', '83305-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17567, 'Ponta Grossa', 'Jacob Vuitik', 'Uvaranas', '84031-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17568, 'Curitiba', 'Jacob Wellner', 'Vista Alegre', '80810-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17569, 'Ponta Grossa', 'Jacob Zardo', 'Ronda', '84010-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17570, 'São José dos Pinhais', 'Jacob Zem', 'Rio Pequeno', '83065-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17571, 'Londrina', 'Jácomo Amadeu', 'Portal de Versalhes 3', '86055-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17572, 'Apucarana', 'Jácomo Bassi', 'Loteamento Belvedere', '86813-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17573, 'Londrina', 'Jácomo Jacob Batistela', 'Jardim Alphaville', '86084-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17574, 'Londrina', 'Jácomo Peloi', 'Jardim dos Alpes III', '86045-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17575, 'Londrina', 'Jácomo Piccinin', 'Pinheiros', '86063-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17576, 'Cambé', 'Jácomo Rossini', 'Parque Residencial Ana Rosa', '86183-650', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17577, 'Foz do Iguaçu', 'Jácomo Savaris', 'Jardim Residencial São Roque', '85853-696', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17578, 'Londrina', 'Jácomo Storti', 'Estados', '86083-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17579, 'Curitiba', 'Jacopo Tintoretto', 'Guabirotuba', '81510-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17580, 'Arapongas', 'Jacuguaçu', 'Conjunto Flamingos', '86703-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17581, 'Londrina', 'Jacui', 'Barra Grande', '86026-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17582, 'Foz do Iguaçu', 'Jacui', 'Loteamento Campos do Iguaçu', '85857-320', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17583, 'Arapongas', 'Jacumirim', 'Jardim Santo Antônio', '86705-667', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17584, 'Foz do Iguaçu', 'Jacunda', 'Conjunto A', '85860-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17585, 'Foz do Iguaçu', 'Jacupemba', 'Conjunto A', '85866-430', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17586, 'Arapongas', 'Jacupemba', 'Jardim Bandeirantes', '86703-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17587, 'Foz do Iguaçu', 'Jacutinga', 'Jardim Acaray', '85857-010', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17588, 'Francisco Beltrão', 'Jacutinga', 'Padre Eurico', '85604-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17589, 'Londrina', 'Jacutinga', 'Jacomo Violin', '86088-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17590, 'Campo Mourão', 'Jacutinga', 'Jardim Tropical II', '87310-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17592, 'Cascavel', 'Jacutinga', 'Floresta', '85814-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17593, 'Londrina', 'Jacy', 'Oriente', '86027-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17594, 'Colombo', 'Jacy', 'Jardim Curitiba', '83406-590', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17595, 'Curitiba', 'Jacy Loureiro de Campos', 'Centro Cívico', '80530-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17596, 'Apucarana', 'Jacy Martins Cilião de Araújo', 'Loteamento Residencial Cazarin', '86802-419', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17597, 'Paranaguá', 'Jacy Pereira Passos', 'Palmital', '83206-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17598, 'Pato Branco', 'Jacy Rodrigues Ferreira', 'São Vicente', '85506-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17599, 'Foz do Iguaçu', 'Jade', 'Parque Ouro Verde', '85854-125', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17600, 'Londrina', 'Jade', 'Ideal', '86030-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17601, 'Maringá', 'Jade', 'Jardim Santa Helena', '87083-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17602, 'Ponta Grossa', 'Jade', 'Neves', '84021-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17603, 'Telêmaco Borba', 'Jade', 'Vila São Francisco de Assis', '84265-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17604, 'Cascavel', 'Jade', 'Esmeralda', '85806-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17605, 'Paranaguá', 'Jader de Azevedo Vidal', 'Leblon', '83203-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17606, 'Londrina', 'Jaguapita', 'Judith', '86061-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17607, 'Ponta Grossa', 'Jaguapita', 'Boa Vista', '84071-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17608, 'Curitiba', 'Jaguapita', 'Alto Boqueirão', '81770-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17609, 'Cascavel', 'Jaguarão', 'Canadá', '85813-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17610, 'Foz do Iguaçu', 'Jaguari', 'Jardim Dona Fátima Osman', '85856-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17611, 'Pinhais', 'Jaguari', 'Vila Indiacui', '83330-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17612, 'Guarapuava', 'Jaguariaiva', 'Bonsucesso', '85045-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17613, 'Pinhais', 'Jaguariaiva', 'Loteamento Alphaville Graciosa', '83327-076', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17614, 'Ponta Grossa', 'Jaguariaiva', 'Uvaranas', '84025-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17615, 'Castro', 'Jaguariaiva', 'Vila Santa Cruz', '84168-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17616, 'Colombo', 'Jaguariaiva', 'Vila São José', '83410-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17617, 'Foz do Iguaçu', 'Jaguaribe', 'Cohapar II', '85857-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17618, 'Londrina', 'Jaguaribe', 'Oguido', '86025-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17619, 'Curitiba', 'Jaguaruna', 'Cidade Industrial', '81230-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17620, 'Foz do Iguaçu', 'Jaguarundi', 'Conjunto A', '85861-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17621, 'Foz do Iguaçu', 'Jaguatirica', 'Conjunto A', '85861-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17622, 'Telêmaco Borba', 'Jaguatirica', 'Área 02', '84267-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17623, 'Campo Mourão', 'Jaguatirica', 'Jardim Aeroporto', '87310-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17624, 'Guarapuava', 'Jaime Amaral Pacheco', 'Conradinho', '85055-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17625, 'Curitiba', 'Jaime Balão', 'Hugo Lange', '80040-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17626, 'Curitiba', 'Jaime Costa', 'Prado Velho', '80220-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17627, 'Cascavel', 'Jaime Duarte Leal', 'Maria Luiza', '85819-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17628, 'Sarandi', 'Jaime Ezidio dos Santos', 'Conjunto Casa da Família', '87114-840', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17629, 'Londrina', 'Jaime Galmacci', 'Jardim Pacaembu', '86079-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17630, 'Guarapuava', 'Jaime Galvão', 'Bonsucesso', '85045-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17631, 'Colombo', 'Jaime Jardim', 'Sapopema', '83407-096', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17632, 'Curitiba', 'Jaime José Vojciechovski', 'Tatuquara', '81480-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17633, 'Londrina', 'Jaime M. de Lima', 'Luiz de Sá', '86086-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17634, 'Cascavel', 'Jaime Pantaleão de Moraes', 'Santa Felicidade', '85803-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17635, 'Ponta Grossa', 'Jaime Pinto Rosas', 'Jardim Carvalho', '84015-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17636, 'Ponta Grossa', 'Jaime Reis', 'Ronda', '84050-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17637, 'Curitiba', 'Jaime Reis', 'São Francisco', '80510-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17638, 'Curitiba', 'Jaime Ricardo Paciornik', 'Umbará', '81930-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17639, 'Curitiba', 'Jaime Rodrigues da Rocha', 'Capão Raso', '81150-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17640, 'Londrina', 'Jaime Tavares dos Santos', 'Jardim Paris', '86082-078', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17641, 'Curitiba', 'Jaime Veiga', 'Seminário', '80310-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17642, 'Londrina', 'Jaime Velani', 'Lindóia', '86031-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17643, 'Toledo', 'Jaime Zeni', 'Conjunto Residencial Tocantins', '85903-356', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17644, 'Curitiba', 'Jair Batista de Oliveira', 'Cidade Industrial', '81170-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17645, 'Londrina', 'Jair Carvalho de Oliveira', 'Cafezal', '86045-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17646, 'Curitiba', 'Jair Coelho', 'Cidade Industrial', '81450-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17647, 'Maringá', 'Jair do Couto Costa', 'Recanto dos Magnatas', '87060-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17648, 'Curitiba', 'Jair do Nascimento César', 'Santa Cândida', '82630-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17649, 'Curitiba', 'Jair Fernandes de Araújo', 'Fazendinha', '81320-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17650, 'Campo Mourão', 'Jair Ficher Githay', 'Jardim Santa Cruz', '87309-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17651, 'Apucarana', 'Jair Fidélis Marques', 'Jardim Marissol', '86807-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17652, 'Castro', 'Jair Granado', 'Vila Rio Branco', '84172-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17653, 'Guarapuava', 'Jair Machado dos Santos', 'Industrial', '85045-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17654, 'Telêmaco Borba', 'Jair Machado Nocera', 'Centro', '84261-600', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17655, 'Londrina', 'Jair Pereira Batista', 'Parque Residencial Michael Licha', '86078-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17656, 'Londrina', 'Jair Portilho da Cruz', 'Milton Gavetti', '86078-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17657, 'Castro', 'Jair Rolim de Moura', 'Invernada do Matadouro', '84174-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17658, 'Curitiba', 'Jair Silveira', 'Cidade Industrial', '81450-757', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17659, 'Curitiba', 'Jairo Taborda de Camargo', 'Atuba', '82860-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17660, 'Londrina', 'Jakob Marx', 'Jardim Alemanha', '86031-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17661, 'Maringá', 'Jalbas Rodrigues Alves', 'Vila Santa Izabel', '87080-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17662, 'Curitiba', 'Jales Ribeiro de Mello', 'Barreirinha', '82700-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17663, 'Paranaguá', 'Jaly Foes', 'Jardim Araçá', '83221-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17664, 'Francisco Beltrão', 'Jamaica', 'Aeroporto', '85603-843', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17665, 'Pinhais', 'Jamaica', 'Jardim Luzitano', '83320-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17666, 'Colombo', 'Jamaica', 'Vila Marcelina', '83404-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17667, 'Apucarana', 'Jamaica', 'Núcleo Habitacional Vale Verde', '86805-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17668, 'Curitiba', 'Jamaica', 'Lindóia', '81010-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17669, 'Londrina', 'Jambo', 'Jardim Morumbi', '86035-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17670, 'Maringá', 'Jambo', 'Jardim Bertioga', '87055-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17671, 'Curitiba', 'Jambo', 'Uberaba', '81560-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17672, 'Curitiba', 'James Anderson', 'Santa Cândida', '82720-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17673, 'Londrina', 'James Cock', 'Novo Antares', '86036-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17674, 'Curitiba', 'James Portugal de Macedo', 'Mercês', '80430-250', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17675, 'Londrina', 'James Reeberg', 'Real', '86025-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17676, 'Paranaguá', 'Jamil Buffara', 'Costeira', '83203-510', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17677, 'Castro', 'Jamil Elias Fadel', 'Jardim Social Arapongas', '84174-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17678, 'Londrina', 'Jamil Scaff', 'Conjunto Habitacional  Alexandre Urbanas', '86037-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17679, 'Apucarana', 'Jamil Soni', 'Centro', '86800-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17680, 'Guarapuava', 'Jamile Wakin Haich', 'Boqueirão', '85022-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17681, 'Curitiba', 'Jamir de Fátima Santos', 'Tatuquara', '81480-276', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17682, 'Cambé', 'Jan Remesik', 'Jardim Boa Vista', '86191-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17683, 'Araucária', 'Janaína Assef', 'Cachoeira', '83701-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17684, 'Almirante Tamandaré', 'Janaina Virgínia Saldanha Machado', 'Jardim Novo Horizonte da Cachoeira', '83502-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17685, 'Guarapuava', 'Jandaia', 'Primavera', '85050-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17686, 'Londrina', 'Jandaia', 'Jardim Alvorada', '86060-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17687, 'Maringá', 'Jandaia', 'Zona 08', '87050-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17688, 'Umuarama', 'Jandaia', 'Zona III', '87502-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17689, 'Arapongas', 'Jandaia', 'Centro', '86705-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17690, 'Foz do Iguaçu', 'Jandaia do Sul', 'Jardim Ipê', '85869-687', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17691, 'Ponta Grossa', 'Jandaia do Sul', 'Oficinas', '84036-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17692, 'Pinhais', 'Jandaia do Sul', 'Vila Emiliano Perneta', '83324-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17693, 'Sarandi', 'Jandaia do Sul', 'Novo Panorama', '87113-198', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17694, 'Cambé', 'Jandaia do Sul', 'Jardim Ana Eliza', '86188-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17695, 'Araucária', 'Jandaia do Sul', 'Iguaçu', '83701-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17696, 'Curitiba', 'Jandaia do Sul', 'Sítio Cercado', '81935-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17697, 'Arapongas', 'Jandaia-azul', 'Conjunto Padre Bernardo Merckel', '86706-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17698, 'Arapongas', 'Jandaia-de-cabeça-negra', 'Jardim São Bento', '86706-728', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17699, 'Arapongas', 'Jandaia-estrela', 'Parque Veneza', '86701-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17700, 'Arapongas', 'Jandaia-sol', 'Conjunto Novo Centauro', '86709-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17701, 'Curitiba', 'Jandevir Roberto Cecato', 'Capão Raso', '81110-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17702, 'Guarapuava', 'Jandir Luiz Ferrari', 'Primavera', '85053-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17703, 'Piraquara', 'Jandira Alves dos Santos', 'Planta Santa Lúcia', '83311-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17704, 'Paranavaí', 'Janete Clair', 'Jardim São Jorge', '87711-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17705, 'Maringá', 'Jangada', 'Zona 07', '87020-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17706, 'Piraquara', 'Jani Rengel', 'Planta Pontoni Filho', '83314-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17707, 'Cascavel', 'Jânio Quadros', 'Pioneiros Catarinenses', '85805-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17708, 'Almirante Tamandaré', 'Jânio Quadros', 'Jardim Josiane', '83504-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17709, 'São José dos Pinhais', 'Janiópolis', 'Cidade Jardim', '83035-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17710, 'Curitiba', 'Janiópolis', 'Alto Boqueirão', '81860-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17711, 'Curitiba', 'Janis Falgatter Roth', 'Sítio Cercado', '81920-766', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17712, 'Apucarana', 'Janos Dessewffy', 'Jardim Esperança', '86810-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17713, 'Curitiba', 'Janquito do Rosário', 'Tatuquara', '81480-326', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17714, 'Telêmaco Borba', 'Januária', 'Área 08', '84271-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17715, 'Curitiba', 'Januário Alves de Souza', 'Boqueirão', '81750-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17716, 'Curitiba', 'Januário Alves de Souza', 'Boqueirão', '81770-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17717, 'Ponta Grossa', 'Januário de Napoli', 'Uvaranas', '84031-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17718, 'Castro', 'Januário de Sio', 'Jardim Bela Vista', '84165-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17719, 'Piraquara', 'Januário Rodrigues Rocha', 'Planta Santa Catarina', '83312-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17720, 'Curitiba', 'Jany Martins', 'Atuba', '82860-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17721, 'Foz do Iguaçu', 'Jaó', 'Conjunto A', '85866-080', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17722, 'Arapongas', 'Jaó', 'Vila São João', '86708-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17723, 'Arapongas', 'Japacanim', 'Jardim Panorama', '86708-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17724, 'Francisco Beltrão', 'Japão', 'Pinheirinho', '85606-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17725, 'Londrina', 'Japão', 'Cláudia', '86050-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17726, 'Paranaguá', 'Japão', 'Centro Histórico', '83203-160', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17727, 'Toledo', 'Japão', 'Jardim Bandeirantes', '85906-737', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17728, 'Umuarama', 'Japão', 'Zona V', '87504-045', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17729, 'Cambé', 'Japão', 'Jardim Morada do Sol', '86181-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17730, 'Almirante Tamandaré', 'Japão', 'Vila Graziela', '83505-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17731, 'Arapongas', 'Jape-verde', 'Jardim Petrópolis', '86709-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17732, 'Pinhais', 'Japim', 'Jardim Fênix', '83326-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17733, 'Arapongas', 'Japim', 'Jardim Bandeirantes', '86703-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17734, 'Foz do Iguaçu', 'Japinin', 'Portal da Foz', '85859-666', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17735, 'Foz do Iguaçu', 'Japira', 'Jardim Ipê II', '85869-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17736, 'Ponta Grossa', 'Japira', 'Contorno', '84052-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17737, 'Almirante Tamandaré', 'Japira', 'Vila Tefé', '83503-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17738, 'Arapongas', 'Japira', 'Vila Natal', '86708-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17739, 'Curitiba', 'Japira', 'São Braz', '82310-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17740, 'Arapongas', 'Japu', 'Vila Aparecida', '86707-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17741, 'Arapongas', 'Japuguaçu', 'Jardim Caravelle', '86702-236', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17742, 'Arapongas', 'Japuira', 'Conjunto Tropical', '86702-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17743, 'Foz do Iguaçu', 'Japurá', 'Loteamento Campos do Iguaçu', '85857-290', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17744, 'Paranaguá', 'Japurá', 'Jardim Guaraituba', '83209-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17745, 'Maringá', 'Japurá', 'Zona 08', '87050-630', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17746, 'Umuarama', 'Japurá', 'Zona I', '87501-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17747, 'Campo Mourão', 'Japurá', 'Conjunto Habitacional Parigot de Souza', '87310-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17748, 'Foz do Iguaçu', 'Jaqueira', 'Jardim das Laranjeiras', '85868-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17749, 'Foz do Iguaçu', 'Jaqueline Belo', 'Jardim Porto Belo', '85867-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17750, 'Londrina', 'Jaques Morgan', 'Tamandaré', '86061-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17751, 'Maringá', 'Jaracatia', 'Vila Bosque', '87005-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17752, 'Londrina', 'Jaracatiá', 'Leonor', '86071-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17753, 'Curitiba', 'Jaracatiá', 'Uberaba', '81550-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17754, 'Guarapuava', 'Jaraguá', 'Morro Alto', '85065-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17755, 'Cascavel', 'Jaraguá', 'Periolo', '85817-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17756, 'Araucária', 'Jaraguá', 'Estação', '83705-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17757, 'Curitiba', 'Jaraguá do Sul', 'Cidade Industrial', '81270-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17758, 'Cascavel', 'Jarama', 'Interlagos', '85814-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17759, 'Curitiba', 'Jarana', 'Bairro Alto', '82840-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17760, 'Paranaguá', 'Jarbas Nery Chichorro', 'Palmital', '83206-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17761, 'Apucarana', 'Jarbas Paula Lima', 'Loteamento São Geraldo', '86809-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17762, 'Foz do Iguaçu', 'Jardel Filho', 'Jardim das Bandeiras', '85864-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17763, 'Curitiba', 'Jardel Filho', 'Tatuquara', '81480-317', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17764, 'Cascavel', 'Jardel Filho', 'Brasília', '85815-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17765, 'Ponta Grossa', 'Jardim', 'Contorno', '84060-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17766, 'Guarapuava', 'Jardim Alegre', 'Boqueirão', '85023-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17767, 'São José dos Pinhais', 'Jardim Alegre', 'Cruzeiro', '83010-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17768, 'Apucarana', 'Jardim Alegre', 'Núcleo Habitacional Nossa Senhora Aparecida', '86801-406', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17769, 'Curitiba', 'Jardim Alegre', 'Sítio Cercado', '81935-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17770, 'Toledo', 'Jardim Bandeirantes', 'Jardim Bandeirantes', '85906-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17771, 'Londrina', 'Jardim de Alessandra', 'Canadá', '86020-020', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17772, 'Curitiba', 'Jardim Olinda', 'Sítio Cercado', '81935-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17773, 'Campo Mourão', 'Jardineira', 'Jardim Lar Paraná', '87305-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17774, 'Araucária', 'Jardineira', 'Campina da Barra', '83709-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17775, 'Maringá', 'Jardineiro Altino Cardoso', 'Parque Residencial Cidade Nova', '87023-030', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17776, 'Londrina', 'Jardinópolis', 'Jardim Alvorada', '86062-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17777, 'Foz do Iguaçu', 'Jardinópolis', 'Jardim Alvorada', '85859-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17778, 'Apucarana', 'Jardinópolis', 'Vila Vitória Régia', '86801-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17779, 'Foz do Iguaçu', 'Jari', 'Loteamento Campos do Iguaçu', '85857-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17780, 'Araucária', 'Jari', 'Iguaçu', '83701-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17781, 'Cascavel', 'Jarlindo João Grando', 'Centro', '85801-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17782, 'Apucarana', 'Jaroslau Maistrovicz', 'Núcleo Habitacional Osmar G Freire', '86801-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17783, 'Guarapuava', 'Jasmim', 'Jardim das Américas', '85031-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17784, 'Ponta Grossa', 'Jasmim', 'Contorno', '84060-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17785, 'Telêmaco Borba', 'Jasmim', 'Jardim Alegre', '84268-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17786, 'Umuarama', 'Jasmim', 'Parque das Jaboticabeiras', '87509-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17787, 'Almirante Tamandaré', 'Jasmim', 'Loteamento Nova Morada', '83504-698', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17788, 'Campo Mourão', 'Jasmim', 'Jardim Modelo', '87309-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17789, 'Apucarana', 'Jasmim', 'Jardim das Flores I', '86810-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17790, 'Araucária', 'Jasmim', 'Campina da Barra', '83709-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17791, 'Ponta Grossa', 'Jaspe', 'Neves', '84021-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17792, 'Maringá', 'Jaspe', 'Jardim Brasil', '87083-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17793, 'Telêmaco Borba', 'Jaspe', 'Área 10', '84266-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17794, 'Cascavel', 'Jaspe', 'Esmeralda', '85806-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17795, 'Telêmaco Borba', 'Jataí', 'Jardim Adriane', '84272-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17796, 'Cascavel', 'Jataí', 'Recanto Tropical', '85807-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17797, 'Foz do Iguaçu', 'Jataizinho', 'Vila Carima', '85855-717', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17798, 'Ponta Grossa', 'Jataizinho', 'Boa Vista', '84070-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17799, 'Curitiba', 'Jataizinho', 'Alto Boqueirão', '81860-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17800, 'Londrina', 'Jatobá', 'Santa Rita 1', '86071-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17801, 'Maringá', 'Jatobá', 'Jardim Vitória', '87023-720', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17802, 'Pinhais', 'Jatobá', 'Jardim Pio XII', '83328-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17803, 'Ponta Grossa', 'Jatobá', 'Contorno', '84061-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17804, 'Sarandi', 'Jatobá', 'Parque Residencial Nova Aliança', '87111-717', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17805, 'Cascavel', 'Jatobá', 'Parque Verde', '85807-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17806, 'Almirante Tamandaré', 'Jatobá', 'Loteamento Chico Mendes', '83505-749', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17807, 'Londrina', 'Jaú', 'Caravelle', '86039-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17808, 'Guarapuava', 'Jaú', 'Batel', '85015-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17809, 'Foz do Iguaçu', 'Jaú', 'Profilurb I', '85855-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17810, 'Pinhais', 'Jaú', 'Loteamento Alphaville Graciosa', '83327-108', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17811, 'Ponta Grossa', 'Jaú', 'Colônia Dona Luiza', '84046-550', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17812, 'São José dos Pinhais', 'Jaú', 'Boneca do Iguaçu', '83040-446', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17813, 'Pato Branco', 'Jaú', 'São Roque', '85507-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17814, 'Umuarama', 'Jaú', 'Jardim Paraíso', '87507-200', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17815, 'Araucária', 'Jaú', 'Estação', '83705-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17816, 'Colombo', 'Jaú', 'Jardim Curitiba', '83406-570', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17817, 'Cascavel', 'Jaú', 'Recanto Tropical', '85807-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17818, 'Foz do Iguaçu', 'Javaé', 'Jardim Festugato', '85864-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17819, 'Cascavel', 'Javaés', 'Santo Onofre', '85806-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17820, 'Pato Branco', 'Javali', 'Bortot', '85504-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17821, 'Campo Mourão', 'Javali', 'Jardim Lar Paraná', '87306-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17822, 'Londrina', 'Javari', 'Jardim Agari', '86025-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17823, 'Foz do Iguaçu', 'Javari', 'Loteamento Campos do Iguaçu', '85857-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17824, 'Umuarama', 'Javari', 'Zona VII', '87503-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17825, 'São José dos Pinhais', 'Javert Czarnecki Mizerkowski', 'Guatupê', '83060-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17826, 'Guarapuava', 'Javert de Paula Ribas', 'Bonsucesso', '85045-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17827, 'Curitiba', 'Javert Manfredini', 'Atuba', '82860-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17828, 'Ponta Grossa', 'Javert Ribeiro da Fonseca', 'Uvaranas', '84030-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17829, 'Foz do Iguaçu', 'Javier Koelbel', 'Jardim Eliza II', '85854-540', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17830, 'Foz do Iguaçu', 'Javier Koelbel', 'Jardim Eliza I', '85853-610', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17831, 'Londrina', 'Jayme Americano', 'Caravelle', '86040-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17832, 'Apucarana', 'Jayme Broietti', 'Jardim Ponta Grossa', '86804-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17833, 'Apucarana', 'Jayme Broietti', 'Jardim Alvorada', '86805-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17834, 'Curitiba', 'Jayme Canet', 'Santa Quitéria', '80310-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17835, 'Londrina', 'Jayme P. Gonçalves', 'Mangaba', '86015-205', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17836, 'Londrina', 'Jayro de Camargo', 'Dom Pedro I', '86089-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17837, 'Curitiba', 'Jaziel Sotto Maior Lagos', 'Cidade Industrial', '81270-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17838, 'Curitiba', 'Jean Baptista Debret', 'Guabirotuba', '81510-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17839, 'Araucária', 'Jean Becue', 'Iguaçu', '83701-825', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17840, 'Curitiba', 'Jean Gabriel Perboyre', 'Cidade Industrial', '81230-409', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17841, 'Guarapuava', 'Jean Granier', 'Conradinho', '85055-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17842, 'São José dos Pinhais', 'Jean Jacques Rousseau', 'Aristocrata', '83030-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17843, 'Curitiba', 'Jean Jacques Rousseau', 'Barreirinha', '82700-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17844, 'Londrina', 'Jean Mermoz', 'Parque Industrial José Belinati', '86039-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17845, 'Cascavel', 'Jean Paul Sartre', 'Interlagos', '85814-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17846, 'Cascavel', 'Jean Piaget', 'Interlagos', '85814-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17847, 'Pinhais', 'Jeanete Peixoto Vott', 'Planta Vila Bordignon', '83325-574', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17848, 'Apucarana', 'Jeferson Fernando Boica', 'Jardim Catuaí', '86802-608', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17849, 'Foz do Iguaçu', 'Jeferson Rodrigues', 'Jardim Itaipu', '85867-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17850, 'Maringá', 'Jeferson Vanderlei Silva', 'Jardim Internorte', '87045-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17851, 'Curitiba', 'Jefferson Becker', 'Taboão', '82130-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17852, 'Curitiba', 'Jefferson Cesar', 'Vista Alegre', '82100-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17853, 'Curitiba', 'Jefferson Luís Caetano', 'Cidade Industrial', '81315-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17854, 'Cambé', 'Jenoveffa Defende Guizilini', 'Jardim Santa Mônica', '86184-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17855, 'Curitiba', 'Jeová Teixeira de Lara', 'Tatuquara', '81470-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17856, 'Ponta Grossa', 'Jequetibá', 'Neves', '84020-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17857, 'Almirante Tamandaré', 'Jequetibá', 'Jardim Ipanema', '83507-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17858, 'Cascavel', 'Jequetibá', 'Recanto Tropical', '85807-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17859, 'Campo Mourão', 'Jequetibá', 'Jardim Ipê', '87305-530', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17860, 'Foz do Iguaçu', 'Jequié', 'Jardim Santa Rosa', '85869-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17861, 'Maringá', 'Jequitá', 'Parque Residencial Quebec', '87023-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17862, 'Londrina', 'Jequitibá', 'Leonor', '86071-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17863, 'Maringá', 'Jequitibá', 'Parque das Bandeiras', '87023-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17864, 'Umuarama', 'Jequitibá', 'Jardim Paraíso', '87505-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17865, 'Telêmaco Borba', 'Jequitibá', 'Área 06', '84271-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17866, 'Colombo', 'Jequitibá', 'Vila Florestal Grajaú', '83411-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17867, 'Foz do Iguaçu', 'Jequitinhonha', 'Loteamento Campos do Iguaçu', '85857-380', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17868, 'Paranaguá', 'Jequitinhonha', 'Santos Dumont', '83209-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17869, 'Ponta Grossa', 'Jeremias', 'Chapada', '84062-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17870, 'Ponta Grossa', 'Jeremias Álvares Carneiro', 'Jardim Carvalho', '84016-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17871, 'Curitiba', 'Jeremias Eugênio Fernandes', 'Tatuquara', '81470-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17872, 'Ponta Grossa', 'Jeremias Ferreira Pinto', 'Ronda', '84051-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17873, 'Curitiba', 'Jeremias Lissa', 'Vista Alegre', '80810-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17874, 'Curitiba', 'Jeremias Maciel Perretto', 'Campo Comprido', '81210-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17875, 'Ponta Grossa', 'Jeriva', 'Contorno', '84061-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17876, 'Colombo', 'Jerônimo Alberti', 'Jardim Mediterrâneo', '83401-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17877, 'Maringá', 'Jerônimo Altino Cardoso', 'Parque Residencial Cidade Nova', '87023-085', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17878, 'Pinhais', 'Jerônimo Busato Filho', 'Vila Tarumã', '83323-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17879, 'Castro', 'Jerônimo Cabral Pereira do Amaral', 'Jardim dos Bancários', '84172-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17880, 'Castro', 'Jerônimo Cabral Pereira do Amaral', 'Invernada do Matadouro', '84174-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17881, 'Curitiba', 'Jerônimo de Albuquerque Maranhão', 'São Braz', '82300-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17882, 'Curitiba', 'Jerônimo de Souza Sobrinho', 'Cidade Industrial', '81350-619', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17883, 'São José dos Pinhais', 'Jerônimo Durski', 'São Cristóvão', '83005-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17884, 'Campo Largo', 'Jerônimo Durski', 'Loteamento Ouro Verde II', '83606-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17885, 'Curitiba', 'Jerônimo Durski', 'Batel', '80440-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17886, 'Curitiba', 'Jerônimo Durski', 'Bigorrilho', '80730-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17887, 'Curitiba', 'Jerônimo Durski', 'Bigorrilho', '80710-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17888, 'Londrina', 'Jerônimo Gonçalves da Silva', 'Jardim Maria Celina', '86081-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17889, 'Londrina', 'Jerônimo Leite Luraschi', 'Conjunto Café', '86038-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17890, 'Curitiba', 'Jerônimo Luiz Fernandes', 'Pinheirinho', '81825-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17891, 'Pinhais', 'Jerônimo Mendes dos Santos', 'Vila Maria Antonieta', '83331-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17892, 'Apucarana', 'Jerônimo Milano', 'Parque Residencial Milani', '86801-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17893, 'Ponta Grossa', 'Jerônimo Stephano Sikorski', 'Colônia Dona Luiza', '84043-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17894, 'Curitiba', 'Jerônimo Thadeo', 'Alto Boqueirão', '81850-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17895, 'Araucária', 'Jeronin Durski', 'Estação', '83705-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17896, 'Londrina', 'Jeronymo Nogueira de Figueiredo', 'Jamile Dequech', '86048-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17897, 'Curitiba', 'Jerseryna Novakowski', 'Bigorrilho', '80710-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17898, 'Foz do Iguaçu', 'Jerusalém', 'Beverly Falls Park', '85858-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17899, 'Londrina', 'Jerusalém', 'Parque Residencial do Lago', '86050-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17900, 'Ponta Grossa', 'Jerusalém', 'Jardim Carvalho', '84016-697', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17901, 'Curitiba', 'Jerusalém', 'Alto Boqueirão', '81770-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17902, 'Maringá', 'Jessé Rocha da Silva', 'Conjunto Residencial Cidade Alta', '87053-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17903, 'Ponta Grossa', 'Jesser Rouver Bernardi', 'Boa Vista', '84072-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17904, 'Ponta Grossa', 'Jesuíno Antônio de Oliveira', 'Boa Vista', '84073-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17905, 'Londrina', 'Jesuíno Caetano dos Santos', 'Jardim Imagawa', '86080-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17906, 'Curitiba', 'Jesuíno Lopes', 'Seminário', '80310-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17907, 'Ponta Grossa', 'Jesuíno Manoel de Almeida', 'Boa Vista', '84070-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17908, 'Cascavel', 'Jesuíno Marcondes', 'Gramado', '85816-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17909, 'Curitiba', 'Jesuíno Marcondes', 'Centro', '80010-060', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17910, 'Foz do Iguaçu', 'Jesuítas', 'Vila Carima', '85855-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17911, 'Campo Largo', 'Jesuítas', 'Jardim Carmela', '83607-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17912, 'Curitiba', 'Jesus Alves da Cruz', 'Campo de Santana', '81490-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17913, 'Sarandi', 'Jesus de Nazaré', 'Parque Residencial Bom Pastor', '87114-521', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17914, 'Sarandi', 'Jesus Eucarístico', 'Parque Residencial Bom Pastor', '87114-522', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17915, 'Sarandi', 'Jesus Filho do Homem', 'Parque Residencial Bom Pastor', '87114-524', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17916, 'Curitiba', 'Jesus Francisco da Rocha', 'Tatuquara', '81470-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17917, 'Londrina', 'Jesus Gonçalves', 'Conjunto Residencial Vale do Arvoredo', '86047-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17918, 'Sarandi', 'Jesus Pão da Vida', 'Parque Residencial Bom Pastor', '87114-523', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17919, 'Sarandi', 'Jesus Retirante', 'Parque Residencial Bom Pastor', '87114-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17920, 'Londrina', 'Jesus Rojas Gavilan', 'Jardim das Palmeiras', '86083-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17921, 'Colombo', 'Jhonatan Fernando Checato Souza Monteiro', 'Jardim dos Eucaliptos', '83408-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17922, 'Cascavel', 'Jibóia', 'Pioneiros Catarinenses', '85805-426', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17923, 'Maringá', 'Jinroku Kubota', 'Jardim da Glória', '87047-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17924, 'Maringá', 'Jinroku Kubota', 'Vila Morangueira', '87040-480', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17925, 'Maringá', 'Jinroku Kubota', 'Jardim Alvorada', '87033-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17926, 'Paranaguá', 'Ji-Paraná', 'Santos Dumont', '83209-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17927, 'Cascavel', 'Ji-Paraná', 'São Cristóvão', '85816-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17928, 'Telêmaco Borba', 'Jiri Aron', 'Centro', '84261-720', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17929, 'Maringá', 'Jitsuji Fujiwara', 'Zona 08', '87050-030', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17930, 'Londrina', 'Joá', 'São Cristóvão', '86025-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17931, 'Foz do Iguaçu', 'Joaçaba', 'Jardim Aurora', '85862-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17932, 'Guarapuava', 'Joaçaba', 'Boqueirão', '85022-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17933, 'São José dos Pinhais', 'Joaçaba', 'São Sebastião', '83075-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17934, 'Almirante Tamandaré', 'Joaçaba', 'Jardim Apucarana', '83505-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17935, 'Curitiba', 'Joaçaba', 'Cidade Industrial', '81240-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17936, 'Piraquara', 'Joan Elln Nowel', 'Vila Rosa', '83304-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17937, 'Londrina', 'Joana da Glória Lisboa Athayde', 'San Fernando', '86040-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17938, 'Castro', 'Joana da Luz dos Santos', 'Núcleo Habitacional Padre Piva', '84178-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17939, 'Foz do Iguaçu', 'Joana d''Arc', 'Vila CB-1', '85852-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17940, 'Londrina', 'Joana d''Arc', 'Jardim Alah I', '86039-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17941, 'Maringá', 'Joana d''Arc', 'Jardim Liberdade', '87047-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17942, 'Toledo', 'Joana d''Arc', 'Vila Industrial', '85904-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17943, 'Umuarama', 'Joana d''Arc', 'Parque San Marino', '87509-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17944, 'Almirante Tamandaré', 'Joana d''Arc', 'Jardim Campos Elísios', '83508-120', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17945, 'Almirante Tamandaré', 'Joana d''Arc', 'Jardim Josiane', '83504-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17946, 'Londrina', 'Joana de Lourdes Nardo Gomes', 'Jardim Acapulco', '86045-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17947, 'Londrina', 'Joana de Sílvio', 'São Cristóvão', '86025-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17948, 'Colombo', 'Joana Duarte', 'Jardim dos Eucaliptos', '83408-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17949, 'Colombo', 'Joana Gaida', 'Jardim Guarujá', '83407-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17950, 'Araucária', 'Joana Geraldello', 'Barigui', '83707-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17951, 'São José dos Pinhais', 'Joana Jess Micrute', 'Planta Quississana', '83085-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17952, 'Curitiba', 'Joana Kosiba', 'Umbará', '81930-556', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17953, 'Londrina', 'Joana Maria Dourado de Pinho', 'Conjunto Professora Hilda Mandarino', '86080-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17954, 'Curitiba', 'Joana Maria Ferreira', 'Campo Comprido', '81240-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17955, 'Campo Largo', 'Joana Marochi', 'Loteameto Miranda', '83605-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17956, 'Curitiba', 'Joana Mioto Dalla Costa', 'Santa Felicidade', '82410-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17957, 'Foz do Iguaçu', 'Joana Moleda', 'Parque Presidente II', '85863-650', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17958, 'São José dos Pinhais', 'Joana Percegona Zen', 'São Sebastião', '83075-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17959, 'Toledo', 'Joana Pressotto Perin', 'César Park', '85913-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17960, 'Curitiba', 'Joana Souza Gusso', 'Boa Vista', '82560-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17961, 'São José dos Pinhais', 'Joana Tcherezov', 'Ipê', '83055-350', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17962, 'Curitiba', 'Joana Z. Kurek', 'São Braz', '82310-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17963, 'Cascavel', 'Joanes Kepler', 'Interlagos', '85814-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17964, 'Araucária', 'Joani Cabrini', 'Capela Velha', '83706-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17965, 'Campo Largo', 'Joanim Stroparo', 'Vila Bancária', '83601-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17966, 'Colombo', 'Joanin Lovato', 'Campestre', '83415-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17967, 'Curitiba', 'Joanina Oliveira de Andrade', 'Uberaba', '81550-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17968, 'Foz do Iguaçu', 'Joaninha', 'Conjunto A', '85860-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17969, 'Curitiba', 'Joanita Luíza Zaninelli Pereira', 'Uberaba', '81590-336', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17970, 'Curitiba', 'Joanna Costa', 'Santa Felicidade', '82010-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17971, 'Curitiba', 'Joanna Emma Dalpozzo Zardo', 'Santa Felicidade', '82410-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17972, 'Curitiba', 'Joanna Rieke Rutz', 'Campina do Siqueira', '80740-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17973, 'Londrina', 'Joanna Rodrigues Jondral', 'Cilo 2', '86067-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17974, 'São José dos Pinhais', 'Joannina Bonk Blonkowski', 'Rio Pequeno', '83065-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17975, 'Curitiba', 'Joannita Westphalen Corrêa', 'Cidade Industrial', '81450-027', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17976, 'Curitiba', 'Joannita Westphalen Correia', 'Ganchinho', '81935-396', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17977, 'Curitiba', 'João Abrão David', 'Sítio Cercado', '81925-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17978, 'Toledo', 'João Agnes Filho', 'Coopagro', '85903-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17979, 'Curitiba', 'João Aguida', 'Santa Quitéria', '80310-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17980, 'São José dos Pinhais', 'João Alberti', 'Silveira da Motta', '83030-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17981, 'Colombo', 'João Alberti', 'Jardim Guadalajara', '83402-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17982, 'Londrina', 'João Alberto', 'Bancários', '86062-070', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17983, 'Toledo', 'João Alberto', 'Centro', '85901-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17984, 'Londrina', 'João Alberto Godoy', 'Milton Gavetti', '86078-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17985, 'Guarapuava', 'João Alberto Horst', 'Morro Alto', '85065-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17986, 'São José dos Pinhais', 'João Alceu Fialla', 'Afonso Pena', '83050-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17987, 'São José dos Pinhais', 'João Alceu Fialla', 'Ipê', '83055-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17988, 'Curitiba', 'João Alencar Guimarães', 'Campo Comprido', '81220-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17989, 'Curitiba', 'João Alencar Guimarães', 'Santa Quitéria', '80310-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17990, 'Curitiba', 'João Alexandre Kopp', 'Cidade Industrial', '81250-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17991, 'Maringá', 'João Alfredo', 'Zona 04', '87014-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17992, 'Curitiba', 'João Alfredo Dilger', 'Xaxim', '81830-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17993, 'Curitiba', 'João Alfredo Jobbins', 'Cidade Industrial', '81310-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17994, 'Foz do Iguaçu', 'João Alfredo Müller', 'Vila São Sebastião', '85870-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17995, 'Curitiba', 'João Alves', 'Cidade Industrial', '81350-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17996, 'Almirante Tamandaré', 'João Alves Bandeira', 'Jardim Gerhusa', '83502-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17997, 'Colombo', 'João Alves Cordeiro', 'Vila Ana Maria', '83413-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17998, 'Londrina', 'João Alves da Rocha Loures', 'Jardim Neman Sahyun', '86041-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (17999, 'Pato Branco', 'João Alves de Abreu', 'Bonatto', '85506-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18000, 'Curitiba', 'João Alves de Araújo', 'Cajuru', '82980-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18001, 'Curitiba', 'João Alves de Deus', 'Campo Comprido', '81210-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18002, 'Pato Branco', 'João Alves de Medeiros', 'Pinheiros', '85504-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18003, 'São José dos Pinhais', 'João Alves Figueiredo', 'Planta Quississana', '83085-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18004, 'São José dos Pinhais', 'João Alves Lourenço', 'Braga', '83020-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18005, 'Londrina', 'João Alves Moreira', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18006, 'Apucarana', 'João Alves Oliveira Sobrinho', 'Vila Brasil', '86800-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18007, 'Curitiba', 'João Amadeu Pedro Bom', 'Tatuquara', '81940-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18008, 'Ponta Grossa', 'João Amaral de Almeida', 'Contorno', '84062-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18009, 'Curitiba', 'João Amaral de Almeida', 'Cidade Industrial', '81170-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18010, 'Almirante Tamandaré', 'João Amaro Andrade', 'Vila Santa Edwiges', '83504-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18011, 'Curitiba', 'João Amaro da Luz', 'Pinheirinho', '81880-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18012, 'Curitiba', 'João Américo de Oliveira', 'Cabral', '80035-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18013, 'Pinhais', 'João Ananias Pinto', 'Jardim Marumby', '83327-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18014, 'Curitiba', 'João Anderle', 'Alto Boqueirão', '81850-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18015, 'Apucarana', 'João Andolfato', 'Jardim Colonial II', '86812-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18016, 'Cascavel', 'João Andrade de Matos', 'Pioneiros Catarinenses', '85805-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18017, 'Cambé', 'João André', 'Jardim Vila Rica', '86192-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18018, 'Piraquara', 'João André Trinck', 'Guarituba', '83311-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18019, 'São José dos Pinhais', 'João Andriguetto', 'Braga', '83020-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18020, 'São José dos Pinhais', 'João Ângelo Cordeiro', 'São Pedro', '83005-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18021, 'São José dos Pinhais', 'João Ângelo Cordeiro', 'Bom Jesus', '83025-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18022, 'Curitiba', 'João Angely', 'Bacacheri', '82520-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18023, 'Almirante Tamandaré', 'João Antoniacomi Filho', 'Colônia Vila Prado', '83504-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18024, 'Londrina', 'João Antônio Benatto', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18025, 'Apucarana', 'João Antônio Braga Cortes', 'Jardim São Pedro', '86809-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18026, 'Curitiba', 'João Antônio Braga Cortes', 'Fazendinha', '81330-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18027, 'Maringá', 'João Antônio Correia Júnior', 'Conjunto Habitacional Requião', '87047-427', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18028, 'Curitiba', 'João Antônio Culpi', 'Pinheirinho', '81870-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18029, 'Campo Largo', 'João Antônio da Costa', 'Centro', '83601-340', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18030, 'São José dos Pinhais', 'João Antônio da Silva', 'Ipê', '83055-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18031, 'Curitiba', 'João Antônio Dambiski', 'Abranches', '82130-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18032, 'Toledo', 'João Antônio Gasperin', 'Jardim Anápolis', '85905-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18033, 'Curitiba', 'João Antônio Gava', 'Santa Cândida', '82630-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18034, 'São José dos Pinhais', 'João Antônio Matucheski', 'Braga', '83020-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18035, 'Apucarana', 'João Antônio Parra Sanches', 'Jardim Espanha', '86802-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18036, 'Curitiba', 'João Antônio Prosdócimo', 'Uberaba', '81560-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18037, 'Londrina', 'João Antônio Sanches', 'Conjunto Habitacional  Alexandre Urbanas', '86037-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18038, 'Campo Largo', 'João Antônio Savio', 'Loteamento São Gerônimo', '83606-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18039, 'Colombo', 'João Antônio Trevisan', 'Vila São Paulo', '83411-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18040, 'Curitiba', 'João Antônio Xavier', 'Água Verde', '80620-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18041, 'Almirante Tamandaré', 'João Antônio Zem', 'Jardim São José', '83501-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18042, 'Curitiba', 'João Antônio Zen', 'Lamenha Pequena', '82410-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18043, 'Curitiba', 'João Antunes Branco', 'Cachoeira', '82220-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18044, 'Almirante Tamandaré', 'João Antunes de Lara', 'Vila Prosdócimo', '83506-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18045, 'Foz do Iguaçu', 'João Aquino', 'Loteamento Witt', '85862-507', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18046, 'Londrina', 'João Aranda Fenoy', 'São Lourenço', '86043-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18047, 'Pinhais', 'João Arantes Neto', 'Prive Bois de Boulogne', '83330-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18048, 'Toledo', 'João Arcângelo Rupolo', 'César Park', '85913-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18049, 'Curitiba', 'João Argino Nogueira', 'Cidade Industrial', '81315-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18050, 'Piraquara', 'João Aristides Adão', 'Jardim Esmeralda', '83301-366', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18051, 'Cascavel', 'João Arquelau Soares', 'Alto Alegre', '85805-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18052, 'Araucária', 'João Assef', 'Estação', '83705-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18053, 'Curitiba', 'João Augusto Martins', 'Cidade Industrial', '81270-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18054, 'Curitiba', 'João Aurélio Ribeiro', 'Butiatuvinha', '82320-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18055, 'Foz do Iguaçu', 'João Ayres de Aguirra', 'Parque Presidente II', '85863-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18056, 'Curitiba', 'João Azolin', 'Santa Felicidade', '82015-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18057, 'Londrina', 'João B. Rubinho', 'Operária', '86038-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18058, 'Campo Largo', 'João Backo', 'Jardim São Vicente', '83602-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18059, 'Curitiba', 'João Bagé', 'Campo Comprido', '81210-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18060, 'Curitiba', 'João Balla', 'São Braz', '82015-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18061, 'Curitiba', 'João Ballin', 'Pilarzinho', '82120-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18062, 'Apucarana', 'João Balthazar Júnior', 'Jardim Independência', '86811-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18063, 'Ponta Grossa', 'João Baptista Basso Neto', 'Jardim Carvalho', '84016-719', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18064, 'Curitiba', 'João Baptista Belinasso', 'Orleans', '82310-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18065, 'Cambé', 'João Baptista Carletto', 'Novo Bandeirantes', '86188-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18066, 'Curitiba', 'João Baptista Chanoski', 'Orleans', '82310-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18067, 'Londrina', 'João Baptista da Silva', 'Parque Residencial Michael Licha', '86078-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18068, 'Curitiba', 'João Baptista Gabardo', 'Sítio Cercado', '81900-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18069, 'Ponta Grossa', 'João Baptista Gobbo', 'Oficinas', '84045-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18070, 'Curitiba', 'João Baptista Groff', 'Orleans', '82310-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18071, 'Curitiba', 'João Baptista Mayer', 'Abranches', '82220-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18072, 'Londrina', 'João Baptista Montini', 'Cafezal', '86045-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18073, 'Londrina', 'João Baptista Schiavo', 'Jardim Alphaville', '86084-175', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18074, 'Piraquara', 'João Barbick Filho', 'Jardim Curitiba', '83308-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18075, 'Almirante Tamandaré', 'João Barbosa da Silva', 'Loteamento Nova Morada', '83504-688', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18076, 'Curitiba', 'João Barbosa de Almeida', 'Xaxim', '81830-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18077, 'Almirante Tamandaré', 'João Barchik', 'Jardim Apucarana', '83505-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18078, 'Piraquara', 'João Baron', 'Planta Deodoro', '83304-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18079, 'Curitiba', 'João Barwik', 'Cachoeira', '82220-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18080, 'Curitiba', 'João Bastianick', 'Novo Mundo', '81050-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18081, 'Almirante Tamandaré', 'João Batista', 'Jardim Monterrey', '83507-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18082, 'Curitiba', 'João Batista Berno', 'Parolin', '80220-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18083, 'Curitiba', 'João Batista Bettega Júnior', 'Tatuquara', '81480-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18084, 'Apucarana', 'João Batista Boscardin Júnior', 'Loteamento Belvedere', '86813-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18085, 'Curitiba', 'João Batista Burbello', 'Tatuquara', '81940-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18086, 'Campo Largo', 'João Batista Campagnaro', 'Centro', '83601-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18087, 'Araucária', 'João Batista Cantele', 'Costeira', '83708-746', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18088, 'Curitiba', 'João Batista Carcereri', 'Pilarzinho', '82120-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18089, 'Curitiba', 'João Batista Casagrande', 'Butiatuvinha', '82320-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18090, 'Curitiba', 'João Batista Chiarello', 'Cidade Industrial', '81230-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18091, 'Curitiba', 'João Batista Collin', 'Santa Quitéria', '80310-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18092, 'Curitiba', 'João Batista Dallarmi', 'Santo Inácio', '82010-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18093, 'São José dos Pinhais', 'João Batista de Camargo', 'Afonso Pena', '83065-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18094, 'Maringá', 'João Batista de Campos', 'Parque Industrial Bandeirantes', '87070-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18095, 'Foz do Iguaçu', 'João Batista de Oliveira', 'Jardim Evangélico', '85870-606', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18096, 'Londrina', 'João Batista de Paula Lelis', 'Jardim Nova Esperança', '86044-618', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18097, 'Almirante Tamandaré', 'João Batista de Siqueira', 'Vila Rachel', '83501-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18098, 'Curitiba', 'João Batista Demio', 'Cidade Industrial', '81460-229', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18099, 'São José dos Pinhais', 'João Batista Follador', 'Afonso Pena', '83040-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18100, 'Ponta Grossa', 'João Batista Franca e Silva', 'Boa Vista', '84072-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18101, 'Curitiba', 'João Batista Franceschini', 'Santa Felicidade', '82400-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18102, 'Londrina', 'João Batista Francotti', 'Ouro Verde', '86080-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18103, 'Foz do Iguaçu', 'João Batista Frigola', 'Parque Morumbi II', '85859-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18104, 'Castro', 'João Batista Gonçalves', 'Núcleo Habitacional Padre Piva', '84178-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18105, 'Pinhais', 'João Batista Guerra', 'Jardim Triângulo', '83331-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18106, 'Colombo', 'João Batista Lovato', 'Centro', '83414-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18107, 'Paranavaí', 'João Batista Machado', 'Jardim Ibirapuera', '87705-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18108, 'Paranavaí', 'João Batista Machado', 'Jardim Paraíso', '87708-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18109, 'Paranavaí', 'João Batista Machado', 'Jardim Curitiba', '87701-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18110, 'São José dos Pinhais', 'João Batista Manzoque', 'Bom Jesus', '83025-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18111, 'Francisco Beltrão', 'João Batista Martini', 'Sadia', '85606-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18112, 'Campo Largo', 'João Batista Mendes', 'Vila Solene', '83607-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18113, 'Curitiba', 'João Batista Palu', 'Cidade Industrial', '81450-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18114, 'Campo Mourão', 'João Batista Perdoncini', 'Jardim Três Marias', '87309-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18115, 'São José dos Pinhais', 'João Batista Potier', 'Miringuava', '83090-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18116, 'Cambé', 'João Batista Raminelli', 'Jardim José Favaro', '86183-795', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18117, 'Araucária', 'João Batista Ribas', 'Cachoeira', '83701-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18118, 'Curitiba', 'João Batista Ribeiro', 'Jardim Botânico', '80210-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18119, 'Curitiba', 'João Batista Rossato Belinazo', 'Cidade Industrial', '81280-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18120, 'Curitiba', 'João Batista Rossetim', 'Mossunguê', '81200-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18121, 'Campo Mourão', 'João Batista Salvadori', 'Jardim Cidade Nova', '87308-015', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18122, 'Curitiba', 'João Batista Scucato', 'Atuba', '82860-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18123, 'Londrina', 'João Batista Tescaro', 'Novo Amparo', '86043-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18124, 'Castro', 'João Batista Toledo Mascarenhas', 'Jardim Social Arapongas', '84174-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18125, 'Curitiba', 'João Batista Trentin', 'Tingui', '82620-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18126, 'Campo Largo', 'João Batista Valões', 'Vila Santa Terezinha', '83602-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18127, 'Campo Largo', 'João Batista Valões', 'Centro', '83601-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18128, 'Piraquara', 'João Batista Vera', 'Jardim Primavera', '83302-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18129, 'Apucarana', 'João Batista Vidor', 'Jardim Esperança', '86810-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18130, 'Curitiba', 'João Batista Zagonel Passos', 'Xaxim', '81830-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18131, 'Londrina', 'João Battistella', 'Jardim Atlânta', '86042-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18132, 'São José dos Pinhais', 'João Beger', 'Colônia Murici', '83085-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18133, 'Londrina', 'João Beggiato', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18134, 'Curitiba', 'João Benato Valle', 'Santa Felicidade', '82030-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18135, 'Maringá', 'João Benites Encizo', 'Parque Residencial Quebec', '87023-506', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18136, 'Foz do Iguaçu', 'João Benitez', 'Jardim Porto Belo', '85867-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18137, 'Campo Mourão', 'João Bento', 'Centro', '87301-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18138, 'Campo Mourão', 'João Bento', 'Centro', '87300-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18139, 'Cascavel', 'João Berlando', 'Alto Alegre', '85805-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18140, 'Almirante Tamandaré', 'João Berquo', 'Jardim Planalto', '83514-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18141, 'Campo Largo', 'João Bertoja', 'Itaqui de Cima', '83605-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18142, 'Campo Largo', 'João Bertoja Filho', 'Loteamento Itaboa', '83605-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18143, 'Araucária', 'João Besciak', 'Tindiquera', '83708-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18144, 'Curitiba', 'João Bettega', 'Portão', '81070-001', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18145, 'Curitiba', 'João Bettega', 'Portão', '81070-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18146, 'Curitiba', 'João Bettega', 'Cidade Industrial', '81350-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18147, 'Curitiba', 'João Bientinez', 'Capão da Imbuia', '82810-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18148, 'Piraquara', 'João Biss', 'Planta Deodoro', '83304-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18149, 'Laranjeiras do Sul', 'João Blonski', 'São Francisco', '85303-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18150, 'Ponta Grossa', 'João Bochnia', 'Uvaranas', '84031-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18151, 'Toledo', 'João Bombardelli', 'Independência', '85906-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18152, 'Curitiba', 'João Bonat', 'Novo Mundo', '81050-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18153, 'Curitiba', 'João Bonatto', 'Pilarzinho', '82110-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18154, 'Colombo', 'João Bonetti', 'Vila Miracema', '83408-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18155, 'São José dos Pinhais', 'João Bonk', 'Cidade Jardim', '83035-130', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18156, 'Curitiba', 'João Bonn', 'Centro Cívico', '80540-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18157, 'Colombo', 'João Borato', 'Capivari', '83415-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18158, 'Londrina', 'João Borges', 'Jardim Tókio', '86063-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18159, 'Curitiba', 'João Borsato', 'Portão', '81070-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18160, 'São José dos Pinhais', 'João Bortolan', 'Colônia Murici', '83085-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18161, 'Londrina', 'João Bortoleto', 'Barbeta', '86078-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18162, 'Araucária', 'João Bosquetto', 'Thomaz Coelho', '83707-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18163, 'Curitiba', 'João Botto de Barros', 'Portão', '81320-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18164, 'Curitiba', 'João Brasílio Ribas', 'Pilarzinho', '82100-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18165, 'Curitiba', 'João Budel', 'Butiatuvinha', '82400-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18166, 'Campo Mourão', 'João Bueno', 'Vila Rio Grande', '87302-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18167, 'Colombo', 'João Bueno', 'Jardim Belo Rincão', '83412-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18168, 'Ponta Grossa', 'João Buss', 'Chapada', '84063-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18169, 'Francisco Beltrão', 'João C. de Arruda', 'Miniguaçu', '85605-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18170, 'Foz do Iguaçu', 'João Cabral de Mello Neto', 'Parque Residencial Três Bandeiras', '85862-247', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18171, 'Londrina', 'João Caetano', 'Jardim São Francisco de Assis', '86067-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18172, 'Curitiba', 'João Caetano', 'Bigorrilho', '80730-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18173, 'Londrina', 'João Calvino', 'Gleba Fazenda Palhano', '86055-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18174, 'Foz do Iguaçu', 'João Câmara Filho', 'Parque Residencial Três Fronteiras', '85862-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18175, 'Foz do Iguaçu', 'João Camargo', 'Conjunto Habitacional Fernanda', '85862-499', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18176, 'Campo Largo', 'João Campesi', 'Loteamento Itaboa', '83605-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18177, 'Curitiba', 'João Cândido', 'São Francisco', '80410-080', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18178, 'Colombo', 'João Cândido Ceccon', 'Jardim Panorama', '83412-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18179, 'Apucarana', 'João Cândido da Silva', 'Jardim Aeroporto', '86812-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18180, 'Almirante Tamandaré', 'João Cândido de Oliveira Júnior', 'Jardim Campo Verde', '83502-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18181, 'Londrina', 'João Cândido Gonçalves', 'Jardim Atlânta', '86042-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18182, 'Curitiba', 'João Cândido Vosch', 'Atuba', '82620-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18183, 'Londrina', 'João Candote', 'Jamile Dequech', '86048-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18184, 'Londrina', 'João Capello', 'Residencial Abussafe', '86037-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18185, 'Maringá', 'João Cardoso de Lima', 'Jardim Nilza', '87065-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18186, 'Londrina', 'João Carlos C. Giraldes', 'Avelino A Vieira', '86056-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18187, 'Ponta Grossa', 'João Carlos Coggo', 'Boa Vista', '84073-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18188, 'Curitiba', 'João Carlos da Rosa', 'Alto Boqueirão', '81850-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18189, 'Curitiba', 'João Carlos de Souza Castro', 'Guabirotuba', '81520-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18190, 'Curitiba', 'João Carlos Figueiredo', 'Guabirotuba', '81520-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18191, 'Curitiba', 'João Carlos Pedrosa', 'Vista Alegre', '80820-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18192, 'Curitiba', 'João Carlos Pinheiro de Lima', 'Cidade Industrial', '81315-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18193, 'Maringá', 'João Carlos Polo', 'Jardim Higienópolis', '87060-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18194, 'Londrina', 'João Carlos Pontes', 'Jardim Neman Sahyun', '86041-258', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18195, 'Curitiba', 'João Carlos Ribeiro Placha', 'Santa Felicidade', '82400-550', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18196, 'Londrina', 'João Carlos Strass', 'Milton Gavetti', '86078-650', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18197, 'Londrina', 'João Carlos Strass', 'Casone', '86084-460', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18198, 'Londrina', 'João Carlos Strass', 'Parque Industrial Alicante', '86087-350', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18199, 'Colombo', 'João Caron', 'Capivari', '83415-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18200, 'Curitiba', 'João Caron', 'São Braz', '82310-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18201, 'Castro', 'João Carvalho de Macedo', 'Cantagalo', '84178-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18202, 'Curitiba', 'João Casagrande', 'Cidade Industrial', '81230-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18203, 'Campo Mourão', 'João Casturino Smoliak', 'Jardim Alvorada', '87308-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18204, 'Colombo', 'João Catarino Filho', 'Jardim dos Eucaliptos', '83408-536', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18205, 'Curitiba', 'João Cathapan', 'Alto Boqueirão', '81850-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18206, 'Colombo', 'João Cavalheiro', 'Jardim Mediterrâneo', '83401-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18207, 'Campo Largo', 'João Cavalim', 'Loteameto Cavalin', '83605-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18208, 'Curitiba', 'João Caxambu', 'Fazendinha', '81330-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18209, 'Colombo', 'João Ceccon', 'Jardim Videira', '83406-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18210, 'Ponta Grossa', 'João Cecy Filho', 'Uvaranas', '84020-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18211, 'Maringá', 'João Cera', 'Jardim Nilza', '87065-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18212, 'Pinhais', 'João Cezario da Silva', 'Jardim Boa Vista', '83327-066', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18213, 'Curitiba', 'João Chalbaud Biscaia', 'Cidade Industrial', '81315-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18214, 'Curitiba', 'João Chaves', 'Xaxim', '81810-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18215, 'Curitiba', 'João Chede', 'Cidade Industrial', '81170-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18216, 'Almirante Tamandaré', 'João Chequim', 'Jardim Paris', '83508-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18217, 'Araucária', 'João Cichon', 'Porto das Laranjeiras', '83703-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18218, 'Curitiba', 'João Cislinsky', 'Sítio Cercado', '81925-189', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18219, 'Campo Mourão', 'João Claudino', 'Jardim Paulista', '87310-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18220, 'Londrina', 'João Cláudio da Silva', 'Ideal', '86030-015', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18221, 'Curitiba', 'João Clemente Tesseroli', 'Jardim das Américas', '81520-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18222, 'Curitiba', 'João Climaco de Oliveira', 'Xaxim', '81710-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18223, 'Curitiba', 'João Conceição Gumy', 'Cidade Industrial', '81170-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18224, 'Londrina', 'João Consulo Moreira', 'Jardim Alphaville', '86084-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18225, 'Curitiba', 'João Coraiola', 'Santo Inácio', '82010-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18226, 'Almirante Tamandaré', 'João Cordeiro de Cristo', 'Vila Grécia', '83502-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18227, 'Toledo', 'João Cordeiro Gomes', 'Parque Residencial Gisela', '85905-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18228, 'Curitiba', 'João Corrêa', 'Pinheirinho', '81870-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18229, 'Londrina', 'João Corrêa dos Santos', 'Itapoã', '86043-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18230, 'Campo Largo', 'João Cosmo', 'Vila Otto', '83607-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18231, 'Colombo', 'João Couto', 'Sapopema', '83407-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18232, 'Curitiba', 'João Crysostomo da Rosa', 'Cajuru', '82900-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18233, 'Curitiba', 'João Cubas', 'Novo Mundo', '81020-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18234, 'Almirante Tamandaré', 'João Cubis', 'Colônia Vila Prado', '83504-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18235, 'Londrina', 'João da Silva Godoy', 'Ernani de Moura Lima', '86037-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18236, 'Ponta Grossa', 'João Dabul Sobrinho', 'Boa Vista', '84071-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18237, 'Curitiba', 'João Daeski', 'Sítio Cercado', '81935-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18238, 'Colombo', 'João d''Agostin', 'Jardim Bandeirantes', '83408-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18239, 'São José dos Pinhais', 'João Dalagassa', 'Bom Jesus', '83025-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18240, 'Londrina', 'João Dale Vedove', 'Jardim dos Alpes III', '86045-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18241, 'Curitiba', 'João Dalegrave', 'Bacacheri', '82520-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18242, 'Cambé', 'João Dalla Pria', 'Parque Residencial Ana Rosa', '86183-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18243, 'Curitiba', 'João Dalla Stella', 'Santa Felicidade', '82020-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18244, 'Francisco Beltrão', 'João Dalla Vechia', 'Guanabara', '85604-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18245, 'Colombo', 'João Dallazuana', 'Itajacuru', '83407-840', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18246, 'Curitiba', 'João Dalledone Sobrinho', 'Pilarzinho', '82120-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18247, 'Paranavaí', 'João Damasceno Costa', 'Vila City', '87709-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18248, 'Almirante Tamandaré', 'João Damásio Santana', 'Jardim Alvorada', '83505-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18249, 'Almirante Tamandaré', 'João Dambrowski', 'Jardim Bela Vista', '83506-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18250, 'Almirante Tamandaré', 'João Darci Muraro', 'Jardim Areias', '83514-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18251, 'Curitiba', 'João Darif', 'Santa Felicidade', '82410-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18252, 'Guarapuava', 'João David de Góes', 'Boqueirão', '85023-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18253, 'Ponta Grossa', 'João David Justus', 'Uvaranas', '84031-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18254, 'Curitiba', 'João David Perneta', 'Hugo Lange', '80040-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18255, 'Curitiba', 'Joao de Abreu', 'Sítio Cercado', '81900-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18256, 'São José dos Pinhais', 'João de Almeida', 'Costeira', '83015-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18257, 'Umuarama', 'João de barro', 'Jardim Sol Nascente', '87505-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18258, 'Foz do Iguaçu', 'João de Brito', 'Jardim Princesa Daiana', '85867-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18259, 'São José dos Pinhais', 'João de Brito', 'Cruzeiro', '83010-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18260, 'Cascavel', 'João de Deus Araújo', 'Santa Felicidade', '85803-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18261, 'Londrina', 'João de Freitas Rocha Filho', 'Franciscone', '86083-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18262, 'Curitiba', 'João de Lara', 'São Lourenço', '82200-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18263, 'Apucarana', 'João de Marchi', 'Loteamento Jardim Por do Sol', '86801-467', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18264, 'Cascavel', 'João de Matos', 'Coqueiral', '85807-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18265, 'Maringá', 'João de Matos Alberto', 'Vila Santa Izabel', '87080-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18266, 'São José dos Pinhais', 'João de Mattos', 'São Sebastião', '83075-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18267, 'Ponta Grossa', 'João de Mello', 'Cará-cará', '84032-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18268, 'Londrina', 'João de Melo', 'Milton Gavetti', '86046-755', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18269, 'Curitiba', 'João de Mio', 'Portão', '81070-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18270, 'Curitiba', 'João de Oliveira Franco', 'Fanny', '81030-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18271, 'Curitiba', 'João de Paula Cordeiro Filho', 'Novo Mundo', '81050-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18272, 'Sarandi', 'João de Sá', 'Centro', '87111-225', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18273, 'Paranaguá', 'João de Souza Aranha', 'Vila Guadalupe', '83221-556', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18274, 'Maringá', 'João de Souza Brito', 'Parque Residencial Quebec', '87023-492', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18275, 'Curitiba', 'João Dembinski', 'Cidade Industrial', '81240-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18276, 'Curitiba', 'João Dembinski', 'Cidade Industrial', '81270-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18277, 'Curitiba', 'João Dembinski', 'Cidade Industrial', '81230-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18278, 'Apucarana', 'João d''Esquivel Ganem', 'Vila Minas Gerais', '86808-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18279, 'Maringá', 'João Deusada Pelegrina', 'Distrito Industrial 2', '87065-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18280, 'Londrina', 'João Dias da Silva', 'Roseira', '86041-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18281, 'Guarapuava', 'João Dias Sollis', 'Primavera', '85050-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18282, 'Londrina', 'João Dias Toledo', 'Jardim Neman Sahyun', '86041-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18283, 'Curitiba', 'João Diório', 'Tatuquara', '81480-266', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18284, 'Curitiba', 'João Diório', 'Tatuquara', '81470-217', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18285, 'São José dos Pinhais', 'João Dissenha Sobrinho', 'Ouro Fino', '83015-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18286, 'Ponta Grossa', 'João Ditzel', 'Boa Vista', '84073-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18287, 'Curitiba', 'João do Couto Satyro', 'São Braz', '82300-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18288, 'Pinhais', 'João do Pulo', 'Prive Bois de Boulogne', '83330-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18289, 'Araucária', 'João do Vale Lemos', 'Cachoeira', '83701-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18290, 'Curitiba', 'João Domachoski', 'Mossunguê', '81200-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18291, 'São José dos Pinhais', 'João Dombrowski', 'Braga', '83020-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18292, 'Apucarana', 'João Domênico Salgade', 'Loteamento Sanches dos Santos', '86806-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18293, 'Curitiba', 'João Domingos Calvaca', 'Sítio Cercado', '81900-727', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18294, 'Curitiba', 'João Domingos Vizintin', 'Umbará', '81930-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18295, 'Araucária', 'João Domingues', 'Boqueirão', '83703-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18296, 'Londrina', 'João Domingues Gonçalves', 'Novo Horizonte', '86075-025', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18297, 'Ponta Grossa', 'João Donatilio Cyrilo Ferreira', 'Chapada', '84062-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18298, 'Curitiba', 'João dos Santos Moraes', 'Cidade Industrial', '81305-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18299, 'Curitiba', 'João Dranka', 'Cristo Rei', '80050-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18300, 'Ponta Grossa', 'João Dubois', 'Oficinas', '84045-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18301, 'Curitiba', 'João Dudeque', 'Novo Mundo', '81010-440', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18302, 'Foz do Iguaçu', 'João Dutra', 'Jardim N Horizonte', '85855-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18303, 'Londrina', 'João Dutra de Souza', 'Colinas', '86056-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18304, 'Colombo', 'Joao Elias da Silva', 'Vila Campo Alto', '83408-218', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18305, 'Curitiba', 'João Eloy Cardoso', 'Boqueirão', '81750-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18306, 'Curitiba', 'João Eloy de Souza', 'Sítio Cercado', '81910-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18307, 'Curitiba', 'João Emídio Jungles', 'Fazendinha', '81330-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18308, 'Curitiba', 'João Emídio Noqueira', 'Tingui', '82620-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18309, 'Paranaguá', 'João Emílio Silva', 'Conjunto Residencial Prefeito Cominese', '83215-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18310, 'Curitiba', 'João Enéas de Sá', 'Tatuquara', '81470-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18311, 'Curitiba', 'João Enéas de Sá', 'Pilarzinho', '82130-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18312, 'Campo Mourão', 'João Eraston Schneider', 'Jardim Joana D''Arc', '87300-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18313, 'São José dos Pinhais', 'João Ernesto Kilian', 'Silveira da Motta', '83030-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18314, 'Curitiba', 'João Esmanhoto', 'São Braz', '82300-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18315, 'Colombo', 'João Esperanceta', 'Jardim Osasco', '83403-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18316, 'Apucarana', 'João Esteci', 'Núcleo Habitacional das Indústrias', '86806-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18317, 'Paranaguá', 'João Estevão', 'Centro Histórico', '83203-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18318, 'Londrina', 'João Esteves', 'Jardim Primavera', '86086-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18319, 'Paranaguá', 'João Eugênio', 'Costeira', '83203-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18320, 'Curitiba', 'João Eugênio Baptista', 'Xaxim', '81710-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18321, 'Paranaguá', 'João Eugênio Cominese', 'Santos Dumont', '83209-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18322, 'Almirante Tamandaré', 'João Evangelista', 'Jardim Monterrey', '83507-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18323, 'São José dos Pinhais', 'João Evangelista Braga', 'São Sebastião', '83075-287', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18324, 'Curitiba', 'João Evangelista Espíndola', 'Jardim Social', '82520-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18325, 'Curitiba', 'João Evangelista Espíndola', 'Jardim Social', '82530-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18326, 'São José dos Pinhais', 'João Ézio Salazar', 'Miringuava', '83090-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18327, 'Curitiba', 'João Fagundes Machado', 'Guaíra', '80220-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18328, 'Curitiba', 'João Fain', 'Boqueirão', '81730-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18329, 'Curitiba', 'João Falarz', 'Orleans', '81280-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18330, 'Umuarama', 'João Faneco', 'Jardim San Rafael', '87508-156', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18331, 'Maringá', 'João Fanhani', 'Jardim São Silvestre', '87055-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18332, 'Curitiba', 'João Fassi Casagrande', 'Cajuru', '82930-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18333, 'Curitiba', 'João Faucz', 'Portão', '80330-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18334, 'Cascavel', 'João Fazio', 'Parque São Paulo', '85803-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18335, 'Ponta Grossa', 'João Felde', 'Boa Vista', '84072-307', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18336, 'Ponta Grossa', 'João Ferigotti', 'Boa Vista', '84071-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18337, 'Paranaguá', 'João Fernandes', 'Jardim Araçá', '83221-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18338, 'São José dos Pinhais', 'João Fernandes', 'Guatupê', '83060-096', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18339, 'Ponta Grossa', 'João Fernandes de Castro', 'Chapada', '84062-629', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18340, 'Cascavel', 'João Fernandes dos Santos', 'Parque São Paulo', '85803-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18341, 'Curitiba', 'João Fernandes Franca', 'Atuba', '82630-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18342, 'Colombo', 'João Ferrarine', 'Jardim Paraná', '83412-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18343, 'Paranavaí', 'João Ferreira da Costa', 'Parque Morumbi', '87703-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18344, 'Curitiba', 'João Ferreira da Rocha', 'Pinheirinho', '81880-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18345, 'Londrina', 'João Ferreira de Almeida', 'Residencial Abussafe', '86037-767', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18346, 'Curitiba', 'João Ferreira Leite', 'Guabirotuba', '81510-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18347, 'Telêmaco Borba', 'João Ferreira Prestes', 'Bela Vista do Paraíso', '84262-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18348, 'Curitiba', 'João Ferro', 'Santa Felicidade', '82030-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18349, 'Curitiba', 'João Festa', 'Santa Felicidade', '82030-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18350, 'Cambé', 'João Fini', 'Jardim Santo Antônio', '86182-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18351, 'Guarapuava', 'João Fleuri da Rocha', 'Boqueirão', '85020-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18352, 'Curitiba', 'João Fleury da Rocha', 'Sítio Cercado', '81925-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18353, 'Curitiba', 'João Florentino Ansai', 'Cidade Industrial', '81310-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18354, 'Campo Largo', 'João Florindo Zanetti', 'Loteamento Ouro Verde I', '83606-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18355, 'Colombo', 'João Florismundo Alberti', 'Jardim Eldorado', '83402-746', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18356, 'Curitiba', 'João Flygare Telles', 'Cidade Industrial', '81230-406', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18357, 'Curitiba', 'João Fonseca Mercer', 'Atuba', '82630-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18358, 'Guarapuava', 'João Fortkamp', 'Primavera', '85050-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18359, 'Cambé', 'João Fortunato', 'Jardim Tarobá', '86191-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18360, 'São José dos Pinhais', 'João Fraga Neto', 'Guatupê', '83060-540', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18361, 'Sarandi', 'João Fragall', 'Parque São Pedro', '87112-500', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18362, 'Curitiba', 'João Francisco Antunes', 'Cidade Industrial', '81460-368', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18363, 'Londrina', 'João Francisco de Freitas', 'Portal de Versalhes 3', '86055-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18364, 'Ponta Grossa', 'João Francisco Lopes', 'Contorno', '84052-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18365, 'Curitiba', 'João Franco de Camargo', 'Tatuquara', '81480-346', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18366, 'Curitiba', 'João Frederico Foerster', 'Pinheirinho', '81150-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18367, 'Cambé', 'João Fregoneze', 'Jardim Boa Vista', '86191-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18368, 'Londrina', 'João Frisselli', 'Jatobá', '86043-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18369, 'Maringá', 'João Furlan', 'Vila Santa Izabel', '87080-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18370, 'Colombo', 'João Gaida', 'Jardim Samambaia', '83407-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18371, 'Londrina', 'João Gaion', 'Jardim Pioneiros', '86036-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18372, 'Colombo', 'João Gaiovski', 'Centro Industrial Mauá', '83413-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18373, 'Guarapuava', 'João Galiciolli', 'Dos Estados', '85035-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18374, 'Curitiba', 'João Gapski', 'Cidade Industrial', '81460-326', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18375, 'Cambé', 'João Garla', 'Jardim Santana', '86192-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18376, 'Guarapuava', 'João Gaspar Cozechen', 'Primavera', '85050-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18377, 'Campo Largo', 'João Gasparetto Neto', 'Fazendinha', '83607-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18378, 'Campo Largo', 'João Gasparetto Zavatti', 'Loteameto Miranda', '83605-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18379, 'Curitiba', 'João Gasparini', 'Pilarzinho', '82110-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18380, 'Paranavaí', 'João Gaudêncio', 'Vila Argus', '87706-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18381, 'Curitiba', 'João Gava', 'Pilarzinho', '82130-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18382, 'Curitiba', 'João Gbur', 'Santa Cândida', '82640-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18383, 'Curitiba', 'João Geara', 'Portão', '80610-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18384, 'Guarapuava', 'João Gelinski', 'Conradinho', '85055-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18385, 'Londrina', 'João Geremias Fernandes', 'Roseira', '86041-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18386, 'Londrina', 'João Gerhard Filho', 'Mediterrâneo', '86047-087', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18387, 'Francisco Beltrão', 'João Giachini', 'Nossa Senhora Aparecida', '85601-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18388, 'Almirante Tamandaré', 'João Giannini', 'Jardim Giannini', '83511-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18389, 'Curitiba', 'João Gilberto Justus', 'Santa Quitéria', '80310-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18390, 'Londrina', 'João Gilberto Santos', 'Tucano', '86047-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18391, 'Curitiba', 'João Gilberto Santos', 'Santa Quitéria', '80310-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18392, 'Campo Largo', 'João Gionedis', 'Bom Jesus', '83604-410', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18393, 'Curitiba', 'João Golemba', 'Santo Inácio', '82300-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18394, 'Curitiba', 'João Golin', 'Butiatuvinha', '82400-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18395, 'Cambé', 'João Gomes', 'Jardim Vila Rica', '86192-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18396, 'Curitiba', 'João Gomes', 'Novo Mundo', '81020-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18397, 'Curitiba', 'João Gomes Pereira Júnior', 'Cidade Industrial', '81170-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18398, 'Sarandi', 'João Gomes Redondo', 'Parque Alvamar', '87113-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18399, 'Foz do Iguaçu', 'João Gonçalves Batista', 'Vila Carima', '85855-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18400, 'Piraquara', 'João Gonçalves Cordeiro', 'Jardim Esmeralda', '83301-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18401, 'Londrina', 'João Gonçalves de Souza', 'Conjunto Cafezal 3', '86045-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18402, 'Londrina', 'João Gonçalves Padilha', 'Roseira', '86041-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18403, 'Araucária', 'João Gotfrid', 'Boqueirão', '83704-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18404, 'Curitiba', 'João Gotti', 'Atuba', '82840-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18405, 'Guarapuava', 'João Goulart', 'Santana', '85070-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18406, 'Foz do Iguaçu', 'João Goulart', 'Parque Presidente', '85863-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18407, 'Almirante Tamandaré', 'João Goulart', 'Jardim Josiane', '83504-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18408, 'Campo Mourão', 'João Goulart', 'Conjunto Residencial Ilha Bela', '87309-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18409, 'Almirante Tamandaré', 'João Govaski Filho', 'Jardim do Norte', '83511-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18410, 'Londrina', 'João Graciano Maria', 'Conjunto Residencial Marajoara', '86080-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18411, 'Londrina', 'João Grassioto', 'Nova Olinda', '86073-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18412, 'Curitiba', 'João Gribogi', 'Cajuru', '82940-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18413, 'Londrina', 'João Grigloletto', 'Dom Pedro I', '86089-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18414, 'Ponta Grossa', 'João Gualberto', 'Colônia Dona Luiza', '84046-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18415, 'Paranaguá', 'João Gualberto', 'João Gualberto', '83203-545', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18416, 'Castro', 'João Gualberto', 'Centro', '84165-520', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18417, 'Curitiba', 'João Gualberto', 'Alto da Glória', '80030-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18418, 'Curitiba', 'João Gualberto', 'Alto da Glória', '80030-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18419, 'Curitiba', 'João Guariza', 'São Lourenço', '82210-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18420, 'Curitiba', 'João Guerino Fabri', 'Cajuru', '82940-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18421, 'Piraquara', 'João Gugelmin', 'Vila São Cristóvão', '83305-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18422, 'Londrina', 'João Guilherme', 'Tarobá', '86042-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18423, 'Guarapuava', 'João Guimarães Rosa', 'São Cristóvão', '85060-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18424, 'Curitiba', 'João Guntowski', 'Capão da Imbuia', '82810-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18425, 'Apucarana', 'João Gurgel de Macedo', 'Centro', '86800-710', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18426, 'Colombo', 'João Gusso', 'Serrinha', '83415-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18427, 'Araucária', 'João Halinski', 'Thomaz Coelho', '83707-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18428, 'Curitiba', 'João Haupt', 'Cidade Industrial', '81460-206', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18429, 'Curitiba', 'João Havro', 'Boa Vista', '82560-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18430, 'Paranaguá', 'João Hélio Frumento', 'Vila Paranaguá', '83221-057', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18431, 'Colombo', 'João Henrique da Rosa', 'Jardim Curitiba', '83406-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18432, 'Londrina', 'João Hermes de Oliveira', 'Monte Belo', '86041-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18433, 'Foz do Iguaçu', 'João Holler', 'Jardim Guarapuava I', '85856-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18434, 'Ponta Grossa', 'João Holzmann', 'Uvaranas', '84030-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18435, 'Cascavel', 'João Horster', 'Brasília', '85815-216', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18436, 'Guarapuava', 'João Hurmanski', 'Industrial', '85053-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18437, 'Londrina', 'João Huss', 'Gleba Fazenda Palhano', '86050-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18438, 'Ponta Grossa', 'João Hyczy', 'Uvaranas', '84031-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18439, 'Curitiba', 'João Inocêncio de Miranda', 'Santo Inácio', '82010-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18440, 'Curitiba', 'João Inocêncio de Paula', 'Cidade Industrial', '81280-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18441, 'Curitiba', 'João Itiberê', 'Jardim das Américas', '81530-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18442, 'Curitiba', 'João Ivanoski', 'Tingui', '82600-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18443, 'Londrina', 'João Izaias', 'Lolata', '86039-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18444, 'Curitiba', 'João Jacob Manfron', 'Santa Felicidade', '82020-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18445, 'Ponta Grossa', 'João Jerônimo Simonetti', 'Neves', '84020-787', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18446, 'Francisco Beltrão', 'João Joarez Daros', 'Jardim Novo Mundo', '85602-757', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18447, 'Londrina', 'João Jorge Bobroff', 'Avelino A Vieira', '86056-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18448, 'Pinhais', 'João Jorge Porfírio', 'Prive Bois de Boulogne', '83330-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18449, 'Castro', 'João José de Farias', 'Centro', '84165-070', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18450, 'Maringá', 'João José de Oliveira', 'Portal das Torres', '87025-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18451, 'Campo Largo', 'João José Marchiori', 'Ferraria', '83608-660', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18452, 'Londrina', 'João José Nicolau', 'Arpoador', '86046-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18453, 'Curitiba', 'João José Pichet', 'Portão', '80330-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18454, 'Curitiba', 'João José Thauny', 'Bacacheri', '82510-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18455, 'Araucária', 'João José Valentini', 'Costeira', '83709-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18456, 'Curitiba', 'João José Zattar', 'Jardim das Américas', '81540-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18457, 'Apucarana', 'João Juventino Lemos', 'Jardim Esperança', '86810-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18458, 'Curitiba', 'João Kalinowski', 'Cidade Industrial', '81350-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18459, 'Araucária', 'João Kaminski', 'Tindiquera', '83708-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18460, 'Curitiba', 'João Kania', 'Santa Cândida', '82650-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18461, 'Curitiba', 'João Kaniak', 'Cidade Industrial', '81260-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18462, 'Curitiba', 'João Karam', 'Guabirotuba', '81510-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18463, 'Curitiba', 'João Kasdorf', 'Xaxim', '81830-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18464, 'Curitiba', 'João Kaviski', 'Campina do Siqueira', '80730-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18465, 'Guarapuava', 'João Keller', 'Industrial', '85053-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18466, 'Curitiba', 'João Kinelski', 'Cidade Industrial', '81280-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18467, 'Araucária', 'João Kmiecik', 'Barigui', '83707-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18468, 'Londrina', 'João Knox', 'Gleba Fazenda Palhano', '86055-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18469, 'Curitiba', 'João Koleski', 'Cidade Industrial', '81280-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18470, 'Londrina', 'João Korki', 'Portal de Versalhes 3', '86055-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18471, 'São José dos Pinhais', 'João Kosiak', 'Miringuava', '83090-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18472, 'Curitiba', 'João Kososki', 'Mossunguê', '81200-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18473, 'Curitiba', 'João Kowal', 'Cidade Industrial', '81170-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18474, 'Curitiba', 'João Kozera', 'Uberaba', '81570-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18475, 'Paranaguá', 'João Kravitz', 'Rocio', '83221-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18476, 'Curitiba', 'João Krawczyk', 'Sítio Cercado', '81920-737', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18477, 'Curitiba', 'João Krul', 'Cidade Industrial', '81315-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18478, 'Curitiba', 'João Kryzanowski', 'Cachoeira', '82710-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18479, 'Ponta Grossa', 'João Kubinski', 'Boa Vista', '84073-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18480, 'Curitiba', 'João Kubis', 'Abranches', '82130-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18481, 'Curitiba', 'João Kucek', 'Cidade Industrial', '81460-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18482, 'Cascavel', 'João Kuloski', 'Santa Cruz', '85806-077', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18483, 'Guarapuava', 'João Lacerda Caldas', 'Alto da XV', '85065-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18484, 'Curitiba', 'João Laertes Bochnia', 'Pinheirinho', '81870-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18485, 'Campo Largo', 'João Lambach Júnior', 'Loteamento Santa Rita', '83602-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18486, 'Piraquara', 'João Lambaret', 'Planta Vera Cruz', '83314-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18487, 'Curitiba', 'João Leal', 'São Lourenço', '82210-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18488, 'Curitiba', 'João Lech Júnior', 'Bacacheri', '82510-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18489, 'Ponta Grossa', 'João Leite Mendes', 'Uvaranas', '84031-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18490, 'Apucarana', 'João Lemos', 'Vila Social', '86804-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18491, 'Curitiba', 'João Lemos dos Santos', 'Pinheirinho', '81870-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18492, 'Curitiba', 'João Leonildo Rossa', 'Mossunguê', '81210-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18493, 'Pinhais', 'João Leopoldo Jacomel', 'Vila Palmital', '83320-005', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18494, 'Pinhais', 'João Leopoldo Jacomel', 'Jardim Guairacá', '83323-410', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18495, 'Piraquara', 'João Leopoldo Jacomel', 'Jardim Primavera', '83302-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18496, 'Piraquara', 'João Leopoldo Jacomel', 'Jardim Veneza', '83310-170', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18497, 'Pinhais', 'João Leopoldo Jacomel', 'Vila Maria Antonieta', '83331-330', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18498, 'Curitiba', 'João Leopoldo Miecznikowski', 'Santa Cândida', '82630-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18499, 'Colombo', 'João Licério de Brito', 'Jardim Adriana', '83408-476', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18500, 'Cascavel', 'João Lili Cirico', 'Coqueiral', '85807-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18501, 'Foz do Iguaçu', 'João Limirio Martins da Silva', 'Parque Morumbi III', '85859-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18502, 'São José dos Pinhais', 'João Lipinski', 'Colônia Murici', '83085-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18503, 'Curitiba', 'João Lissa', 'Tatuquara', '81470-266', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18504, 'Foz do Iguaçu', 'João Lobato da Mota Machado', 'Jardim Panorama II', '85856-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18505, 'Londrina', 'João Locardaire de Oliveira', 'Cafezal', '86045-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18506, 'Curitiba', 'João Locke', 'Pilarzinho', '82110-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18507, 'Guarapuava', 'João Lopes dos Santos', 'Vila Bela', '85027-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18508, 'Curitiba', 'João Loprete Frega', 'São Lourenço', '82200-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18509, 'Pato Branco', 'João Lora', 'Fundabem', '85507-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18510, 'Londrina', 'Joao Lot', 'Jardim Campos Verdes', '86085-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18511, 'Curitiba', 'João Lourenço de Paula', 'Pinheirinho', '81870-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18512, 'Curitiba', 'João Lourenço Taborda', 'Sítio Cercado', '81900-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18513, 'Curitiba', 'João Lucas', 'Santa Quitéria', '80310-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18514, 'Curitiba', 'João Lucca', 'Santa Felicidade', '82015-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18515, 'Araucária', 'João Luczyszyn', 'Capela Velha', '83706-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18516, 'Cambé', 'João Lugli', 'Planta São Francisco', '86182-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18517, 'Apucarana', 'João Luís Orlando', 'Vila São José Bassa', '86808-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18518, 'Curitiba', 'João Luiz Costa', 'Jardim Social', '82530-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18519, 'Maringá', 'João Luiz Dias', 'Parque Residencial Cidade Nova', '87023-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18520, 'Curitiba', 'João Lunardelli', 'Cidade Industrial', '81460-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18521, 'Curitiba', 'João Luz Foerster', 'Alto Boqueirão', '81850-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18522, 'Curitiba', 'João Macedo Souza', 'São Lourenço', '82210-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18523, 'Curitiba', 'João Machado', 'Xaxim', '81710-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18524, 'Curitiba', 'João Machado de Camargo', 'Barreirinha', '82700-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18525, 'São José dos Pinhais', 'João Maiczak', 'Colônia Murici', '83085-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18526, 'Londrina', 'João Maiolli', 'Santa Rita 2', '86072-325', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18527, 'Londrina', 'João Malaguido', 'Vila Siam', '86039-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18528, 'Ponta Grossa', 'João Malinoski', 'Uvaranas', '84031-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18529, 'Araucária', 'João Malinowski', 'Tindiquera', '83708-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18530, 'Curitiba', 'João Malta de Albuquerque Maranhão', 'Pinheirinho', '81870-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18531, 'Curitiba', 'João Malucelli Neto', 'Cidade Industrial', '81460-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18532, 'Colombo', 'João Manika', 'Jardim Panorama', '83412-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18533, 'Paranavaí', 'João Manoel', 'Jardim Iguaçu', '87705-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18534, 'Curitiba', 'João Manoel', 'São Francisco', '80510-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18535, 'São José dos Pinhais', 'João Manoel da Silva', 'Ouro Fino', '83015-066', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18536, 'Foz do Iguaçu', 'João Manoel de Souza', 'Jardim Iara', '85854-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18537, 'Ponta Grossa', 'João Manoel dos Santos Ribas', 'Nova Rússia', '84051-410', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18538, 'Curitiba', 'João Manoel Geremias', 'Santa Cândida', '82720-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18539, 'Maringá', 'João Manoel Sobrinho', 'Vila Progresso', '87080-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18540, 'Sarandi', 'João Marangoni', 'Novo Panorama', '87113-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18541, 'Sarandi', 'João Marangoni', 'Parque Pioneiros', '87114-630', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18542, 'Curitiba', 'João Maranho', 'Sítio Cercado', '81925-267', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18543, 'Ponta Grossa', 'João Marcelino Mandalozzo', 'Colônia Dona Luiza', '84045-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18544, 'Curitiba', 'João Marchesini', 'Prado Velho', '80215-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18545, 'São José dos Pinhais', 'João Maria Alves de Souza', 'Miringuava', '83090-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18546, 'Guarapuava', 'João Maria Cabral Domingues', 'Jardim das Américas', '85030-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18547, 'Curitiba', 'João Maria Carneiro', 'Xaxim', '81720-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18548, 'Curitiba', 'João Maria Coradassi', 'Cidade Industrial', '81450-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18549, 'Ponta Grossa', 'João Maria Cordeiro', 'Jardim Carvalho', '84020-155', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18550, 'Curitiba', 'João Maria Córdova Passos', 'Atuba', '82630-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18551, 'Cascavel', 'João Maria Correia', 'Santa Cruz', '85806-078', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18552, 'Ponta Grossa', 'João Maria Cruz', 'Boa Vista', '84071-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18553, 'Pinhais', 'João Maria da Silva', 'Loteamento Pineville', '83325-589', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18554, 'Curitiba', 'João Maria da Silveira', 'Novo Mundo', '81050-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18555, 'Maringá', 'João Maria de Andrade', 'Parque da Gávea', '87053-338', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18556, 'Campo Largo', 'João Maria de Miranda', 'Vila Andreassa Miranda', '83605-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18557, 'Apucarana', 'João Maria de Oliveira', 'Jardim Santos Dumont III', '86812-528', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18558, 'São José dos Pinhais', 'João Maria Djazi', 'São Sebastião', '83075-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18559, 'Castro', 'João Maria do Carmo', 'Centro', '84165-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18560, 'Araucária', 'João Maria dos Santos', 'Costeira', '83708-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18561, 'Colombo', 'João Maria dos Santos', 'Parque Residencial Santa Terezinha II', '83408-805', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18562, 'Campo Largo', 'João Maria Ferreira Vieira', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18563, 'São José dos Pinhais', 'João Maria Góes', 'Guatupê', '83060-206', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18564, 'Curitiba', 'João Maria José de Farias', 'Xaxim', '81830-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18565, 'Curitiba', 'João Maria Leandro', 'Uberaba', '81560-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18566, 'Curitiba', 'João Maria Machado do Amaral', 'Cidade Industrial', '81450-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18567, 'São José dos Pinhais', 'João Maria Martins Cordeiro', 'Boneca do Iguaçu', '83040-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18568, 'Campo Mourão', 'João Maria Pereira Carneiro', 'Jardim Izabel', '87309-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18569, 'São José dos Pinhais', 'João Maria Quintino', 'São Sebastião', '83075-469', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18570, 'Curitiba', 'João Maria Ribas', 'Santa Quitéria', '80310-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18571, 'São José dos Pinhais', 'João Maria Rocco', 'São Pedro', '83005-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18572, 'Curitiba', 'João Maria Tigrinho Miquelasso', 'Xaxim', '81710-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18573, 'Curitiba', 'João Mariano Gorski', 'Cidade Industrial', '81170-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18574, 'Campo Largo', 'João Markovsc', 'Vila Nossa Senhora do Carmo', '83601-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18575, 'Almirante Tamandaré', 'João Marques', 'Jardim do Rocio', '83502-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18576, 'Londrina', 'João Marques da Silva', 'Jardim São Jorge', '86082-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18577, 'Campo Largo', 'João Marques dos Santos', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18578, 'Curitiba', 'João Marquesi', 'Capão Raso', '81110-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18579, 'Cambé', 'João Marqueze', 'Jardim Riviera', '86187-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18580, 'Londrina', 'João Martins', 'Roseira', '86041-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18581, 'Curitiba', 'João Martins da Silva Filho', 'Alto Boqueirão', '81720-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18582, 'Telêmaco Borba', 'João Martins de Oliveira', 'Vila São Francisco de Assis', '84264-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18583, 'Pato Branco', 'João Martins de Souza', 'Bonatto', '85506-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18584, 'Sarandi', 'João Martins Garcia', 'Conjunto Casa da Família', '87114-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18585, 'Ponta Grossa', 'João Martins Neves', 'Boa Vista', '84071-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18586, 'Ponta Grossa', 'João Martins Ribas', 'Uvaranas', '84030-500', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18587, 'Curitiba', 'João Martinski', 'Cajuru', '82950-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18588, 'Londrina', 'João Marujo', 'São Lourenço', '86043-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18589, 'Curitiba', 'João Massuchetto', 'Cajuru', '82950-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18590, 'Apucarana', 'João Matiuzzi', 'Parque Bela Vista', '86803-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18591, 'Colombo', 'João Matos de Almeida', 'Centro Industrial Mauá', '83413-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18592, 'Curitiba', 'João Max Rosener', 'Hugo Lange', '80040-290', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18593, 'Curitiba', 'João Maximiliano Baroni', 'Pilarzinho', '82115-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18594, 'Ponta Grossa', 'João Maximiliano Pimentel', 'Cará-cará', '84033-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18595, 'Londrina', 'João Mazzeo', 'Estados', '86083-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18596, 'Londrina', 'João Medeiros da Costa', 'Cilo 3', '86072-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18597, 'Londrina', 'João Medina', 'João Paz', '86087-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18598, 'Piraquara', 'João Meira', 'Vila São Cristóvão', '83305-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18599, 'Piraquara', 'João Meireles', 'Vila Rosa', '83304-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18600, 'São José dos Pinhais', 'João Melanski Filho', 'Planta Quississana', '83085-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18601, 'Pinhais', 'João Mendes Batista', 'Vila Maria Antonieta', '83331-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18602, 'Curitiba', 'João Mendes da Silveira', 'Pinheirinho', '81150-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18603, 'Campo Mourão', 'João Mendes Pereira', 'Jardim Alvorada', '87308-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18604, 'Curitiba', 'João Mendonça', 'Capão da Imbuia', '82810-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18605, 'Curitiba', 'João Menegusso', 'Santa Felicidade', '82020-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18606, 'Curitiba', 'João Mequetti', 'Santa Cândida', '82640-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18607, 'Cascavel', 'João Merlin', 'Universitário', '85819-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18608, 'Piraquara', 'João Meyer', 'Vila Susi', '83304-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18609, 'Paranavaí', 'João Miguel de Souza Cruz', 'Parque Morumbi', '87703-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18610, 'Ponta Grossa', 'João Miguel Maia', 'Chapada', '84063-230', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18611, 'Araucária', 'João Miguel Pizatto', 'Porto das Laranjeiras', '83703-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18612, 'Foz do Iguaçu', 'João Miguel Saldivar', 'Jardim Oriente', '85855-120', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18613, 'Araucária', 'João Mikosz', 'São Miguel', '83706-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18614, 'Cascavel', 'João Miotto', 'Região do Lago 3', '85819-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18615, 'Curitiba', 'João Miqueletto', 'Alto Boqueirão', '81860-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18616, 'Colombo', 'João Mocelin', 'Vila Esperanceta', '83403-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18617, 'Cascavel', 'João Modesto Braga', 'Santos Dumont', '85804-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18618, 'Curitiba', 'João Monteiro', 'Jardim das Américas', '81520-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18619, 'Ponta Grossa', 'João Montes Filho', 'Oficinas', '84040-280', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18620, 'Curitiba', 'João Moraes', 'Alto Boqueirão', '81770-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18621, 'Telêmaco Borba', 'João Morais da Silva', 'Nossa Senhora do Perpétuo Socorro', '84265-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18622, 'Campo Largo', 'João Moreira', 'Vila Gilcy', '83609-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18623, 'Almirante Tamandaré', 'João Moreira', 'Jardim Santa Rita de Cássia', '83506-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18624, 'Ponta Grossa', 'João Moreira Garcez', 'Uvaranas', '84026-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18625, 'Londrina', 'João Munhoz Moreno', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18626, 'Araucária', 'João Muryn', 'Thomaz Coelho', '83707-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18627, 'Paranavaí', 'João Nacimento Tulha', 'Jardim Iguaçu', '87705-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18628, 'Curitiba', 'João Nadvorny', 'Campina do Siqueira', '80730-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18629, 'Curitiba', 'João Natal Slompo', 'Santa Felicidade', '82020-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18630, 'Londrina', 'João Negrão', 'Santos Dumont', '86040-005', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18631, 'Pato Branco', 'João Negrão', 'São Cristóvão', '85508-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18632, 'Toledo', 'João Negrão', 'Jardim Alto Alegre', '85910-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18633, 'Curitiba', 'João Negrão', 'Rebouças', '80230-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18634, 'Curitiba', 'João Negrão', 'Centro', '80010-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18635, 'Londrina', 'João Nervatin', 'Novo Amparo', '86043-025', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18636, 'São José dos Pinhais', 'João Nester', 'Guatupê', '83065-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18637, 'Curitiba', 'João Netzel', 'Cidade Industrial', '81270-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18638, 'Curitiba', 'João Nicco', 'Mossunguê', '81200-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18639, 'Curitiba', 'João Nichele', 'Umbará', '81930-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18640, 'Londrina', 'João Nicolau', 'Jardim Tókio', '86063-005', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18641, 'Curitiba', 'João Nicoletti Daros', 'Xaxim', '81810-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18642, 'Curitiba', 'João Nociti', 'Seminário', '80310-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18643, 'Curitiba', 'João Nogarolli', 'Fanny', '81030-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18644, 'Ponta Grossa', 'João Nunes', 'Olarias', '84026-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18645, 'Curitiba', 'João Oberik Roberto', 'Pinheirinho', '81870-455', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18646, 'Campo Largo', 'João Obrete', 'Vila Santo Antônio', '83601-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18647, 'Curitiba', 'João Obrzut', 'São Braz', '82300-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18648, 'Guarapuava', 'João Odorico Albuquerque', 'Industrial', '85045-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18649, 'São José dos Pinhais', 'João Opszynski', 'Afonso Pena', '83040-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18650, 'Toledo', 'João Orestes Ruaro', 'Sachini', '85903-716', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18651, 'Toledo', 'João Orestes Ruaro', 'Vila Industrial', '85904-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18652, 'Campo Largo', 'João Orlindo Barrichello', 'Conjunto Águas Claras', '83602-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18653, 'Curitiba', 'João Ortolani', 'Santa Cândida', '82720-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18654, 'Guarapuava', 'João Otávio Neto', 'Bonsucesso', '85045-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18655, 'Cascavel', 'João Padilha', 'Santa Cruz', '85806-087', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18656, 'Guarapuava', 'João Padleski', 'Alto da XV', '85070-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18657, 'Apucarana', 'João Pagani Filho', 'Jardim Paraíso', '86807-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18658, 'Cambé', 'João Pagnan', 'Jardim Santa Mônica', '86184-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18659, 'Cambé', 'João Pagotti', 'Jardim José Favaro', '86183-798', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18660, 'São José dos Pinhais', 'João Pallu', 'Ouro Fino', '83015-067', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18661, 'Foz do Iguaçu', 'João Palma', 'Centro', '85851-430', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18662, 'São José dos Pinhais', 'João Palma Moreira', 'Costeira', '83015-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18663, 'Curitiba', 'João Palomeque', 'Novo Mundo', '81050-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18664, 'Londrina', 'João Panchoni', 'Jardim Alphaville', '86084-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18665, 'Maringá', 'João Papile', 'Conjunto Residencial Cidade Alta', '87053-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18666, 'Curitiba', 'João Parize', 'São Braz', '82015-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18667, 'Londrina', 'João Parizotto', 'Jardim Vale Azul', '86041-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18668, 'Curitiba', 'João Parolin', 'Prado Velho', '80220-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18669, 'Londrina', 'João Parreira', 'Del Rey', '86045-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18670, 'Cambé', 'João Passador', 'Jardim Santo Antônio', '86182-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18671, 'Maringá', 'João Paulino Vieira Filho', 'Zona 07', '87020-015', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18672, 'Curitiba', 'João Paulo Bonetti', 'São João', '82030-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18673, 'Paranavaí', 'João Paulo da Costa Velho', 'Jardim Paraíso', '87708-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18674, 'Umuarama', 'João Paulo dos Santos', 'Parque Dom Pedro I', '87508-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18675, 'Londrina', 'João Paulo I', 'Jardim Albatroz', '86039-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18676, 'Guarapuava', 'João Paulo I', 'Industrial', '85045-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18677, 'Toledo', 'João Paulo I', 'Jardim Concórdia', '85906-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18678, 'Colombo', 'João Paulo I', 'Santa Gema', '83407-209', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18679, 'Foz do Iguaçu', 'João Paulo II', 'Loteamento João Paulo II', '85857-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18680, 'Foz do Iguaçu', 'João Paulo II', 'Loteamento João Paulo II', '85856-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18681, 'Toledo', 'João Pedro Bordignon', 'Coopagro', '85903-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18682, 'Ponta Grossa', 'João Pedro da Silva', 'Uvaranas', '84030-510', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18683, 'São José dos Pinhais', 'João Pedro Ferraro', 'Braga', '83020-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18684, 'Curitiba', 'João Pedro Jonsson Kronland', 'Santa Cândida', '82720-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18685, 'Curitiba', 'João Pedro Lucca', 'Xaxim', '81810-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18686, 'Francisco Beltrão', 'João Pedro Mazaro', 'Pinheirinho', '85603-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18687, 'Pato Branco', 'João Penso', 'Vila Esperança', '85503-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18688, 'Londrina', 'João Pereira da Silva', 'Parigot de Souza 2', '86082-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18689, 'Curitiba', 'João Pereira da Silva', 'Pilarzinho', '82100-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18690, 'Londrina', 'João Pereira da Silva Júnior', 'Giovani Lunardelli', '86037-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18691, 'Piraquara', 'João Pereira de Godói', 'Planta Guarituba Pequena', '83310-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18692, 'Araucária', 'João Pereira de Lima', 'Cachoeira', '83701-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18693, 'Curitiba', 'João Pereira do Nascimento', 'Novo Mundo', '81050-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18694, 'Almirante Tamandaré', 'João Pereira Siqueira', 'Planta Nossa Senhora de Lourdes', '83506-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18695, 'Curitiba', 'João Pereira Trindade', 'Campo de Santana', '81490-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18696, 'Campo Largo', 'João Perlaci', 'Jardim Esmeralda', '83604-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18697, 'Campo Mourão', 'João Pessa Júnior', 'Jardim Francisco Ferreira Albuquerque', '87309-117', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18698, 'Foz do Iguaçu', 'João Pessoa', 'Vila Guarani', '85862-347', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18699, 'Francisco Beltrão', 'João Pessoa', 'Presidente Kennedy', '85605-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18700, 'Foz do Iguaçu', 'João Pessoa', 'Conjunto C', '85870-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18701, 'Guarapuava', 'João Pessoa', 'Morro Alto', '85065-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18702, 'Londrina', 'João Pessoa', 'Jardim Agari', '86020-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18703, 'Piraquara', 'João Pessoa', 'Vila Vicente Macedo', '83303-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18704, 'Maringá', 'João Pessoa', 'Vila Esperança', '87020-610', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18705, 'Paranaguá', 'João Pessoa', 'Costeira', '83203-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18706, 'Pato Branco', 'João Pessoa', 'Santa Terezinha', '85506-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18707, 'Pato Branco', 'João Pessoa', 'Santa Terezinha', '85501-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18708, 'Toledo', 'João Pessoa', 'Jardim Europa', '85908-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18709, 'São José dos Pinhais', 'João Pessoa', 'Costeira', '83015-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18710, 'Cascavel', 'João Pessoa', 'Centro', '85812-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18711, 'Campo Largo', 'João Pessoa', 'Centro', '83601-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18712, 'Araucária', 'João Pessoa', 'Centro', '83702-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18713, 'Colombo', 'João Pessoa', 'Jardim São Gabriel', '83407-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18714, 'Cambé', 'João Pessoa', 'Vila Salomé', '86192-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18715, 'Colombo', 'João Petenusso', 'Jardim Ouro Verde', '83405-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18716, 'Castro', 'João PeTrêski', 'Castroville', '84178-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18717, 'Araucária', 'João Pianowski', 'Costeira', '83709-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18718, 'Paranaguá', 'João Picanço Júnior', 'Ponta do Caju', '83206-446', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18719, 'Londrina', 'João Picinin', 'Colonial', '86047-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18720, 'Curitiba', 'João Pienta', 'Butiatuvinha', '82400-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18721, 'Laranjeiras do Sul', 'João Pilarski', 'Água Verde', '85302-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18722, 'Londrina', 'João Pilla', 'Jardim Alto do Cafezal', '86049-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18723, 'Curitiba', 'João Pinto Corrêa', 'Cidade Industrial', '81450-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18724, 'Campo Mourão', 'João Pinto Júnior', 'Jardim Aeroporto', '87310-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18725, 'Colombo', 'João Pinto Martins', 'Vila São Gabriel', '83406-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18726, 'Guarapuava', 'João Pinto Ribeiro', 'Conradinho', '85045-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18727, 'Guarapuava', 'João Pitner', 'Vila Bela', '85025-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18728, 'Araucária', 'João Polak', 'Costeira', '83708-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18729, 'Curitiba', 'João Polak', 'Pilarzinho', '82115-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18730, 'Paranaguá', 'João Policarpo', 'Vila dos Comerciários', '83215-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18731, 'Cascavel', 'João Polles', 'Vila Tolentino', '85802-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18732, 'Curitiba', 'João Ponciano Borges', 'Capão da Imbuia', '82810-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18733, 'Curitiba', 'João Pontoni', 'Cristo Rei', '80050-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18734, 'Curitiba', 'João Prosdócimo', 'Alto da Rua XV', '80060-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18735, 'Colombo', 'João Provoda', 'Jardim César Augusto', '83402-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18736, 'Cambé', 'João Prudêncio', 'Jardim Vitória', '86184-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18737, 'Curitiba', 'João Puchaski', 'Boa Vista', '82650-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18738, 'Ponta Grossa', 'João Rabello Coutinho', 'Boa Vista', '84071-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18739, 'Apucarana', 'João Raduy', 'Vila Nova Cidade', '86811-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18740, 'Londrina', 'João Ramalho', 'Sabará I', '86066-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18741, 'Maringá', 'João Ramalho', 'Jardim Mandacaru', '87080-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18742, 'Curitiba', 'João Ramalho', 'Bairro Alto', '82820-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18743, 'Maringá', 'João Ramalho Leite', 'Conjunto Habitacional Requião', '87047-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18744, 'Londrina', 'João Ramos', 'Jardim Nova Esperança', '86044-619', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18745, 'Curitiba', 'João Raphael Machado', 'Cidade Industrial', '81350-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18746, 'Ponta Grossa', 'João Ratcliff', 'Nova Rússia', '84053-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18747, 'Curitiba', 'João Ravanello', 'Santa Felicidade', '82020-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18748, 'Curitiba', 'João Reboli', 'Santa Cândida', '82640-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18749, 'Curitiba', 'João Reffo', 'Santa Felicidade', '82410-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18750, 'Paranaguá', 'João Régis', 'Centro Histórico', '83203-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18751, 'Curitiba', 'João Régis Teixeira Júnior', 'Centro Cívico', '80530-390', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18752, 'Colombo', 'João Reinaldo Zanon', 'Jardim Palmares', '83412-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18753, 'Apucarana', 'João Reis de Andrade', 'Vila Vitória', '86802-395', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18754, 'Londrina', 'João Rezende Filho', 'Jardim Europa', '86043-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18755, 'Londrina', 'João Ribeiro', 'Coliseu', '86076-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18756, 'Maringá', 'João Ribeiro', 'Zona 05', '87015-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18757, 'Ponta Grossa', 'João Ribeiro', 'Uvaranas', '84030-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18758, 'Curitiba', 'João Ribeiro', 'Jardim das Américas', '81540-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18759, 'Curitiba', 'João Ribeiro Baptista', 'Cidade Industrial', '81315-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18760, 'Colombo', 'João Ribeiro Camargo', 'Jardim Bela Vista', '83404-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18761, 'Curitiba', 'João Ribeiro Dallegrave', 'Sítio Cercado', '81935-130', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18762, 'Campo Mourão', 'João Ribeiro Haenisch', 'Conjunto Habitacional Milton Luiz Pereira', '87306-330', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18763, 'Curitiba', 'João Ribeiro Lemos', 'Novo Mundo', '81020-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18764, 'Cascavel', 'João Ribeiro Pinheiro', 'Santa Felicidade', '85803-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18765, 'Ponta Grossa', 'João Ricardo Von Burel Du Vernay', 'Cará-cará', '84043-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18766, 'Foz do Iguaçu', 'João Ricieri Maran', 'Três Lagoas', '85862-425', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18767, 'Toledo', 'João Riscarolli', 'Vila Brasil', '85909-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18768, 'Curitiba', 'João Risseto', 'Santa Felicidade', '82015-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18769, 'Campo Largo', 'João Rivabem', 'Centro', '83601-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18770, 'Colombo', 'João Roberto Dranginis', 'Parque Residencial Santa Terezinha II', '83408-798', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18771, 'Guarapuava', 'João Rocha Marcondes', 'Industrial', '85045-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18772, 'Campo Largo', 'João Rodolfo Castagnoli', 'Conjunto Águas Claras', '83602-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18773, 'Curitiba', 'João Rodolfo Schlenker', 'Água Verde', '80620-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18774, 'Londrina', 'João Rodrigues', 'Jardim Nova Esperança', '86044-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18775, 'Castro', 'João Rodrigues da Cruz', 'Vila Santa Cruz', '84168-027', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18776, 'Castro', 'João Rodrigues de Macedo', 'Vila Rio Branco', '84172-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18777, 'Pinhais', 'João Rodrigues de Oliveira', 'Jardim Guairacá', '83324-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18778, 'Curitiba', 'João Rodrigues Pinheiro', 'Capão Raso', '81130-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18779, 'Araucária', 'João Roma', 'Barigui', '83707-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18780, 'Londrina', 'João Romanholi', 'Jardim Guararapes', '86038-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18781, 'Araucária', 'João Romanowski', 'Costeira', '83709-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18782, 'Foz do Iguaçu', 'João Rouver', 'Centro', '85851-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18783, 'Londrina', 'João Roveri Sobrinho', 'Portal Norte', '86079-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18784, 'Londrina', 'João Ruiz', 'Conjunto Residencial Itamaraty', '86076-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18785, 'Londrina', 'João Ruiz Filho', 'Jardim Primavera', '86086-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18786, 'Foz do Iguaçu', 'João Sales', 'Jardim Princesa Daiana', '85867-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18787, 'Paranavaí', 'João Salvador', 'Jardim Ipê', '87707-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18788, 'Londrina', 'João Sampaio', 'Jardim Indianápolis', '86010-750', 'Viaduto', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18789, 'Londrina', 'João Sampaio', 'Campo Belo', '86062-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18790, 'Apucarana', 'João Sampaio', 'Jardim Paulista', '86811-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18791, 'Londrina', 'João Sanches Castro', 'Portal de Versalhes 2', '86063-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18792, 'Curitiba', 'João Santo Miola', 'Butiatuvinha', '82320-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18793, 'Sarandi', 'João Saran', 'Vera Cruz', '87111-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18794, 'Curitiba', 'João Sarot', 'Tatuquara', '81480-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18795, 'Toledo', 'João Sartori', 'Residencial Santa Clara', '85907-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18796, 'Curitiba', 'João Sassá', 'Cidade Industrial', '81230-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18797, 'Curitiba', 'João Sawaf', 'Fazendinha', '81330-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18798, 'Curitiba', 'João Scandelari', 'Barreirinha', '82700-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18799, 'Curitiba', 'João Scandelari Filho', 'Pilarzinho', '82115-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18800, 'Curitiba', 'João Schaffer Júnior', 'Bom Retiro', '80520-360', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18801, 'Ponta Grossa', 'João Schaia', 'Jardim Carvalho', '84015-815', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18802, 'Colombo', 'João Scheleder', 'Jardim César Augusto', '83402-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18803, 'Almirante Tamandaré', 'João Schereder', 'Jardim do Rocio', '83502-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18804, 'Londrina', 'João Schiavinatto', 'Franciscato II', '86078-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18805, 'Curitiba', 'João Schleder Sobrinho', 'Boa Vista', '82540-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18806, 'Ponta Grossa', 'João Schmidt Filho', 'Contorno', '84061-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18807, 'Piraquara', 'João Schmitz', 'Vila Susi', '83304-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18808, 'Curitiba', 'João Schreiber', 'Pilarzinho', '82100-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18809, 'Maringá', 'João Scramim Filho', 'Jardim América', '87045-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18810, 'Maringá', 'João Scramim Filho', 'Conjunto Residencial Parigot de Souza', '87047-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18811, 'Cambé', 'João Scramin', 'Jardim Itália', '86192-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18812, 'Ponta Grossa', 'João Scremin', 'Neves', '84020-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18813, 'Curitiba', 'João Scremin', 'Campo Comprido', '81210-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18814, 'Curitiba', 'João Scucato', 'Cachoeira', '82710-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18815, 'Curitiba', 'João Scuissiato', 'Santa Quitéria', '80310-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18816, 'Curitiba', 'João Sebastião', 'Santo Inácio', '82010-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18817, 'Curitiba', 'João Sebastião Bunik', 'Tingui', '82600-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18818, 'São José dos Pinhais', 'João Senegaglia', 'Águas Belas', '83010-510', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18819, 'Campo Mourão', 'João Serathuk', 'Centro', '87302-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18820, 'Araucária', 'João Sérgio Cunha', 'Boqueirão', '83704-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18821, 'Londrina', 'João Severiano da Costa', 'Roseira', '86041-335', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18822, 'Curitiba', 'João Sguario', 'Cidade Industrial', '81170-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18823, 'Curitiba', 'João Sikora', 'Umbará', '81930-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18824, 'Londrina', 'João Silveira de Camargo', 'Catuai', '86086-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18825, 'Paranavaí', 'João Silvestre', 'Jardim Ipê', '87706-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18826, 'Piraquara', 'João Simbalista', 'Jardim Primavera', '83302-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18827, 'Curitiba', 'João Simião', 'Jardim Social', '82520-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18828, 'Telêmaco Borba', 'João Siqueira Filho', 'Socomim', '84266-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18829, 'Araucária', 'João Skraba', 'Estação', '83705-765', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18830, 'Cascavel', 'João Smarczevski', 'Brasília', '85815-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18831, 'Curitiba', 'João Socha', 'Sítio Cercado', '81900-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18832, 'Londrina', 'João Sonoda', 'Jardim dos Alpes III', '86045-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18833, 'Colombo', 'João Soppa', 'Jardim Bandeirantes', '83408-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18834, 'Francisco Beltrão', 'João Soranso', 'Antônio de Paiva Cantelmo', '85603-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18835, 'Londrina', 'João Soriani', 'Conjunto Habitacional José Giordano', '86082-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18836, 'Curitiba', 'João Sovinski', 'Cajuru', '82970-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18837, 'Pinhais', 'João Sprada', 'Jardim Cláudia', '83326-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18838, 'Ponta Grossa', 'João Stanislawczuk', 'Contorno', '84061-640', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18839, 'Colombo', 'João Stanki Baptista', 'Vila Palmital', '83413-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18840, 'Curitiba', 'João Stenzowski', 'Novo Mundo', '81020-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18841, 'Castro', 'João Stocco', 'Vila Farias', '84178-050', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18842, 'Curitiba', 'João Strapasson', 'Santa Felicidade', '82030-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18843, 'Colombo', 'João Strapasson Sobrinho', 'Santa Gema', '83415-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18844, 'Campo Largo', 'João Stukas', 'Jardim São Vicente', '83602-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18845, 'Curitiba', 'João Surian', 'Novo Mundo', '81050-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18846, 'Maringá', 'João Taborianski', 'Parque Residencial Quebec', '87023-496', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18847, 'Curitiba', 'João Tataren', 'Atuba', '82860-160', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18848, 'Colombo', 'João Taverna', 'Jardim Monza', '83406-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18849, 'Curitiba', 'João Tedeschi', 'Barreirinha', '82650-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18850, 'Paranaguá', 'João Teixeira', 'Padre Jackson', '83221-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18851, 'São José dos Pinhais', 'João Teixeira de Carvalho', 'Cruzeiro', '83010-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18852, 'Londrina', 'João Tenório Cavalcanti', 'Parque Universidade', '86056-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18853, 'Curitiba', 'João Thiele', 'Água Verde', '80620-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18854, 'Ponta Grossa', 'João Thome', 'Uvaranas', '84031-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18855, 'Pinhais', 'João Tissot', 'Conjunto Residencial Inocoop', '83326-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18856, 'Curitiba', 'João Tobias de Paiva Netto', 'Cajuru', '82980-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18857, 'Curitiba', 'João Todeschini', 'Santa Felicidade', '82320-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18858, 'Guarapuava', 'João Tokarski', 'Conradinho', '85055-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18859, 'Curitiba', 'João Tokarski', 'Cidade Industrial', '81270-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18860, 'Colombo', 'João Tomacheschi', 'Jardim Samambaia', '83407-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18861, 'Colombo', 'João Toniolo', 'Cercadinho', '83415-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18862, 'Guarapuava', 'João Tonon', 'Vila Bela', '85027-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18863, 'Campo Largo', 'João Torezin Filho', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18864, 'Cambé', 'João Torrezan', 'Parque Residencial Ana Rosa', '86183-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18865, 'Colombo', 'João Trevisan', 'Jardim Monza', '83406-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18866, 'Curitiba', 'João Tschannerl', 'Vista Alegre', '80820-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18867, 'Araucária', 'João Túlio', 'Boqueirão', '83704-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18868, 'Curitiba', 'João Túlio', 'Boa Vista', '82540-430', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18869, 'Curitiba', 'João Turin', 'Água Verde', '80240-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18870, 'Colombo', 'João Valdera', 'Vila Santo Antônio', '83413-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18871, 'Colombo', 'João Valentim Torques', 'Parque Industrial Guaraituba', '83411-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18872, 'Curitiba', 'João Valle', 'Santa Felicidade', '82030-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18873, 'Ponta Grossa', 'João Varassim', 'Jardim Carvalho', '84016-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18874, 'Ponta Grossa', 'João Varassim', 'Chapada', '84062-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18875, 'Cambé', 'João Vasques Bonilha', 'Jardim Vitória', '86184-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18876, 'Campo Mourão', 'João Vecchi', 'Jardim Lar Paraná', '87305-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18877, 'Campo Mourão', 'João Vecchi', 'Jardim Paulino', '87306-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18878, 'Curitiba', 'João Vendramin', 'Santa Felicidade', '82020-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18879, 'Curitiba', 'João Viana Seiler', 'Parolin', '80220-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18880, 'Curitiba', 'João Vianna Seiller Júnior', 'Cajuru', '82940-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18881, 'Londrina', 'João Vicente Martins', 'Portal de Versalhes 2', '86063-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18882, 'São José dos Pinhais', 'João Vidal da Luz', 'Bom Jesus', '83025-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18883, 'Pato Branco', 'João Vidor', 'Bonatto', '85506-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18884, 'Pato Branco', 'João Vigano', 'Anchieta', '85501-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18885, 'Ponta Grossa', 'João Vinharski', 'Neves', '84020-788', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18886, 'Ponta Grossa', 'João Visioni', 'Colônia Dona Luiza', '84046-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18887, 'Curitiba', 'João Vitola', 'Jardim Social', '82520-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18888, 'Colombo', 'João Vitorino', 'Centro Industrial Mauá', '83413-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18889, 'Apucarana', 'João Volpato', 'Jardim Santos Dumont III', '86812-537', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18890, 'Curitiba', 'João Volpe', 'Butiatuvinha', '82320-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18891, 'São José dos Pinhais', 'João Voytovici', 'Guatupê', '83060-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18892, 'Curitiba', 'João Wadouski', 'Santa Cândida', '82640-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18893, 'Laranjeiras do Sul', 'João Wagner', 'Vila Industrial', '85303-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18894, 'Curitiba', 'João Waldir Teixeira de Faria', 'Barreirinha', '82700-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18895, 'Araucária', 'João Waleski', 'Thomaz Coelho', '83707-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18896, 'Londrina', 'João Wanderley', 'Jardim Londrilar', '86010-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18897, 'Londrina', 'João Weffort', 'Esperança', '86046-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18898, 'Cascavel', 'João Wichoski', 'Cascavel Velho', '85818-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18899, 'Londrina', 'João Wielganczuk', 'Jardim Belo Horizonte', '86037-298', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18900, 'Pinhais', 'João Wilker Rodrigues', 'Jardim Triângulo', '83331-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18901, 'Foz do Iguaçu', 'João Winkert', 'Loteamento Parque do Patriarco', '85854-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18902, 'Curitiba', 'João Winter', 'Xaxim', '81720-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18903, 'Curitiba', 'João Wisniewski', 'Cajuru', '82950-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18904, 'Curitiba', 'João Wolf', 'Boa Vista', '82540-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18905, 'Araucária', 'João Wolski', 'Tindiquera', '83708-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18906, 'Londrina', 'João Wyclif', 'Gleba Fazenda Palhano', '86050-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18907, 'Campo Mourão', 'João Xavier Padilha', 'Jardim Copacabana', '87302-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18908, 'Londrina', 'João XXIII', 'Judith', '86060-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18909, 'Guarapuava', 'João XXIII', 'Morro Alto', '85065-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18910, 'Foz do Iguaçu', 'João XXIII', 'Jardim Guaíra', '85855-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18911, 'Toledo', 'João XXIII', 'Jardim Concórdia', '85906-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18912, 'Cascavel', 'João XXIII', 'Brasmadeira', '85814-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18913, 'Apucarana', 'João XXIII', 'Jardim Figueira', '86801-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18914, 'Curitiba', 'João Zaions', 'Sítio Cercado', '81900-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18915, 'Pinhais', 'João Zaitter', 'Jardim Guairacá', '83324-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18916, 'Colombo', 'João Zanetti Filho', 'Walfrido do Rosário', '83413-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18917, 'Paranaguá', 'João Zanicoski', 'Aeroporto', '83209-005', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18918, 'Curitiba', 'João Zaniolo', 'Rebouças', '80220-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18919, 'Toledo', 'João Zanolla', 'Residencial Santa Clara', '85908-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18920, 'São José dos Pinhais', 'João Zarpelon', 'Costeira', '83015-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18921, 'Curitiba', 'João Zílio', 'São Braz', '82300-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18922, 'Araucária', 'João Ziomek', 'Costeira', '83709-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18923, 'Campo Largo', 'João Zoreck', 'Vila Nossa Senhora do Carmo', '83601-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18924, 'Cambé', 'João Zortéa', 'Jardim Riviera', '86187-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18925, 'Francisco Beltrão', 'João-de-barro', 'Luther King', '85605-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18926, 'Francisco Beltrão', 'João-de-barro', 'Miniguaçu', '85605-566', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18927, 'Foz do Iguaçu', 'João-de-barro', 'Portal da Foz', '85859-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18928, 'Guarapuava', 'João-de-barro', 'Boqueirão', '85022-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18929, 'Londrina', 'João-de-barro', 'Indústrias Leves', '86030-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18930, 'Maringá', 'João-de-barro', 'Conjunto Residencial Ney Braga', '87083-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18931, 'Pinhais', 'João-de-barro', 'Jardim Fênix', '83326-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18932, 'Ponta Grossa', 'João-de-barro', 'Chapada', '84064-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18933, 'Sarandi', 'João-de-barro', 'Conjunto Floresta', '87112-690', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18934, 'Telêmaco Borba', 'João-de-barro', 'Jardim São Silvestre', '84270-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18935, 'Cascavel', 'João-de-barro', 'Floresta', '85814-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18936, 'Araucária', 'João-de-barro', 'Estação', '83705-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18937, 'Apucarana', 'João-de-barro', 'Recanto das Araras', '86812-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18938, 'Campo Largo', 'João-de-barro', 'Vila Dona Fina', '83609-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18939, 'Campo Largo', 'João-de-barro', 'Jardim Lise', '83605-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18940, 'Cambé', 'João-de-barro', 'Conjunto Habitacional Waldomiro M Gomes', '86182-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18941, 'Campo Mourão', 'João-de-barro', 'Jardim Tropical I', '87310-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18942, 'Arapongas', 'João-de-barro', 'Conjunto Padre Bernardo Merckel', '86708-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18943, 'Colombo', 'Joãozinho Manika', 'Jardim Eldorado', '83402-757', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18944, 'Apucarana', 'Joaquim A. Santos', 'Parque Bela Vista', '86803-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18945, 'Londrina', 'Joaquim Alício Martins', 'Jardim Marízia II', '86079-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18946, 'Cascavel', 'Joaquim Alves', 'Cascavel Velho', '85818-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18947, 'Apucarana', 'Joaquim Alves', 'Jardim Bela Vista', '86811-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18948, 'Curitiba', 'Joaquim Alves Caldeira', 'Santa Cândida', '82640-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18949, 'São José dos Pinhais', 'Joaquim Alves da Rocha', 'Planta Quississana', '83085-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18950, 'Telêmaco Borba', 'Joaquim Alves de Oliveira', 'Nossa Senhora de Fátima', '84264-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18951, 'Maringá', 'Joaquim Alves de Souza', 'Zona 28', '87053-287', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18952, 'São José dos Pinhais', 'Joaquim Alves Fontes', 'Colônia Murici', '83085-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18953, 'Curitiba', 'Joaquim Amaral', 'Jardim das Américas', '81530-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18954, 'Curitiba', 'Joaquim Américo Guimarães', 'Jardim Social', '82520-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18955, 'Curitiba', 'Joaquim Antônio da Cruz', 'Novo Mundo', '81020-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18956, 'Sarandi', 'Joaquim Antônio da Silva', 'Jardim Nova Independência I', '87114-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18957, 'Londrina', 'Joaquim Antônio dos Santos', 'Lago Juliana', '86038-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18958, 'Piraquara', 'Joaquim Artigas', 'Vila Franca', '83305-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18959, 'Curitiba', 'Joaquim Augusto de Andrade', 'Jardim das Américas', '81520-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18960, 'Maringá', 'Joaquim Barufi', 'Vila Esperança', '87020-450', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18961, 'Campo Largo', 'Joaquim Batista Desidério', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-766', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18962, 'Telêmaco Borba', 'Joaquim Batista Ribeiro', 'Centro', '84261-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18963, 'Londrina', 'Joaquim Bento Lemos', 'Portal de Versalhes 3', '86055-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18964, 'Curitiba', 'Joaquim Caetano da Silva', 'Santa Quitéria', '80330-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18965, 'Piraquara', 'Joaquim Camargo', 'Planta Santa Catarina', '83312-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18966, 'Ponta Grossa', 'Joaquim Camargo Júnior', 'Neves', '84020-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18967, 'Curitiba', 'Joaquim Cardoso da Silveira', 'Boqueirão', '81730-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18968, 'Colombo', 'Joaquim Cardoso de Lima', 'Jardim Parque Verde', '83409-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18969, 'Guarapuava', 'Joaquim Cardoso Teixeira', 'Dos Estados', '85035-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18970, 'Paranavaí', 'Joaquim Castella', 'Jardim Ipê', '87707-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18971, 'Campo Largo', 'Joaquim Celestino Ferreira', 'Jardim Esmeralda', '83604-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18972, 'Curitiba', 'Joaquim Chagas Lima', 'São Braz', '82320-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18973, 'Curitiba', 'Joaquim da Costa Ribeiro', 'Atuba', '82840-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18974, 'Curitiba', 'Joaquim da Costa Ribeiro', 'Bairro Alto', '82820-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18975, 'Paranavaí', 'Joaquim da Silva Pinto', 'Jardim Ouro Branco', '87704-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18976, 'Curitiba', 'Joaquim da Silva Sampaio', 'Mercês', '80710-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18977, 'Apucarana', 'Joaquim Damas Ribeiro', 'Jardim Portal do Lago', '86802-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18978, 'Foz do Iguaçu', 'Joaquim de Almeida', 'Jardim Terra e Lar', '85857-655', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18979, 'Maringá', 'Joaquim de Castro Lopes', 'Parque Industrial Bandeirantes', '87045-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18980, 'Curitiba', 'Joaquim de Freitas', 'Boqueirão', '81730-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18981, 'Curitiba', 'Joaquim de Mello', 'Sítio Cercado', '81910-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18982, 'Curitiba', 'Joaquim de Oliveira Cruz', 'Pinheirinho', '81825-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18983, 'Araucária', 'Joaquim de Oliveira Melo', 'Thomaz Coelho', '83707-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18984, 'Ponta Grossa', 'Joaquim de Paula Xavier', 'Estrela', '84050-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18985, 'Curitiba', 'Joaquim de Siqueira Cortes', 'Cidade Industrial', '81260-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18986, 'Curitiba', 'Joaquim de Souza', 'Cidade Industrial', '81250-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18987, 'Apucarana', 'Joaquim Diogo Pacheco', 'Loteamento Jardim Por do Sol', '86801-469', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18988, 'Londrina', 'Joaquim Domingos Martins', 'Conjunto Farid Libos', '86087-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18989, 'Curitiba', 'Joaquim Domingos Vicentim', 'Campo Comprido', '81220-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18990, 'Curitiba', 'Joaquim dos Anjos', 'Abranches', '82220-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18991, 'Guarapuava', 'Joaquim dos Santos Sobrinho', 'Cascavel', '85040-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18992, 'Maringá', 'Joaquim Duarte Moleirinho', 'Jardim Alamar', '87014-450', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18993, 'Maringá', 'Joaquim Duarte Moleirinho', 'Jardim Betty', '87060-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18994, 'Campo Mourão', 'Joaquim Elias Neto', 'Distrito Industrial I', '87306-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18995, 'Londrina', 'Joaquim Felismino da Silva', 'Cilo 3', '86073-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18996, 'Colombo', 'Joaquim Félix de Godoy', 'Vila São Paulo', '83411-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18997, 'Sarandi', 'Joaquim Ferlini', 'Centro', '87111-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18998, 'Paranaguá', 'Joaquim Ferreira Barbosa', 'Tuiuti', '83203-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (18999, 'Curitiba', 'Joaquim Ferreira Bello', 'Pinheirinho', '81870-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19000, 'São José dos Pinhais', 'Joaquim Ferreira Claudino', 'Cruzeiro', '83010-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19001, 'São José dos Pinhais', 'Joaquim Ferreira das Dores', 'Colônia Rio Grande', '83025-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19002, 'Colombo', 'Joaquim Ferreira Gomes', 'Parque Residencial Santa Terezinha', '83408-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19003, 'Telêmaco Borba', 'Joaquim Ferreira Lobo Nene', 'Nossa Senhora do Perpétuo Socorro', '84265-510', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19004, 'Apucarana', 'Joaquim Ferreira Sobrinho', 'Núcleo Habitacional Parigot de Souza', '86802-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19005, 'Foz do Iguaçu', 'Joaquim Firmino', 'Jardim Eldorado', '85853-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19006, 'Foz do Iguaçu', 'Joaquim Firmino', 'Centro', '85851-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19007, 'Paranaguá', 'Joaquim Fraga de Oliveira', 'Palmital', '83206-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19008, 'Cambé', 'Joaquim Francisco', 'Jardim Vô Zezinho', '86192-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19009, 'Curitiba', 'Joaquim Francisco Bueno', 'Xaxim', '81630-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19010, 'Londrina', 'Joaquim Francisco de Paula', 'Parigot de Souza 2', '86082-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19011, 'Curitiba', 'Joaquim Franco dos Anjos', 'Capão Raso', '81020-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19012, 'Curitiba', 'Joaquim Fressato', 'São Braz', '82300-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19013, 'Curitiba', 'Joaquim Gomes', 'Santa Cândida', '82640-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19014, 'São José dos Pinhais', 'Joaquim Gomes da Silva', 'São Sebastião', '83075-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19015, 'Curitiba', 'Joaquim Gomes Ladeira', 'Barreirinha', '82560-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19016, 'Curitiba', 'Joaquim Gonçalves de Barros', 'Bacacheri', '82600-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19017, 'Curitiba', 'Joaquim Gonçalves Ledo', 'Vista Alegre', '82100-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19018, 'Curitiba', 'Joaquim Gonzaga Pereira', 'Sítio Cercado', '81900-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19019, 'Londrina', 'Joaquim Gregório Marques', 'Jatobá', '86043-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19020, 'São José dos Pinhais', 'Joaquim Guilhermino Primo', 'Ipê', '83055-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19021, 'Foz do Iguaçu', 'Joaquim Guimarães', 'Jardim São Paulo I', '85856-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19022, 'São José dos Pinhais', 'Joaquim Inácio de Souza', 'Cidade Jardim', '83035-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19023, 'Curitiba', 'Joaquim Jovino Martins', 'Cachoeira', '82710-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19024, 'Almirante Tamandaré', 'Joaquim Krüger', 'Jardim Santa Rita de Cássia', '83506-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19025, 'Londrina', 'Joaquim Lacerda', 'Boa Vista', '86015-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19026, 'Ponta Grossa', 'Joaquim Loyola', 'Estrela', '84040-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19027, 'Curitiba', 'Joaquim Macan', 'Boqueirão', '81670-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19028, 'Curitiba', 'Joaquim Machado', 'Cajuru', '82930-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19029, 'Guarapuava', 'Joaquim Manoel de Souza', 'Cascavel', '85025-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19030, 'Curitiba', 'Joaquim Mariano Ribas', 'Guabirotuba', '81520-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19031, 'Apucarana', 'Joaquim Marques Dias', 'Vila Operária 2', '86802-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19032, 'Curitiba', 'Joaquim Marques dos Santos', 'Santa Cândida', '82710-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19033, 'Ponta Grossa', 'Joaquim Mateus Branco e Silva', 'Jardim Carvalho', '84016-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19034, 'Maringá', 'Joaquim Medina Garcia', 'Jardim Novo Horizonte', '87010-148', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19035, 'Paranaguá', 'Joaquim Mendes', 'Vila do Caic', '83215-697', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19036, 'Curitiba', 'Joaquim Mendes da Silva', 'Sítio Cercado', '81925-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19037, 'Maringá', 'Joaquim Mendes Sobrinho', 'Vila Progresso', '87080-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19038, 'Maringá', 'Joaquim Mendonça', 'Jardim Universo', '87060-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19039, 'Curitiba', 'Joaquim Menelau de Almeida Torres', 'Hauer', '81610-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19040, 'Ponta Grossa', 'Joaquim Meneleau de Almeida Torres', 'Uvaranas', '84026-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19041, 'Colombo', 'Joaquim Messias', 'Jardim Paraná', '83412-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19042, 'Londrina', 'Joaquim Murtinho', 'Jardim Novo Sabará', '86066-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19043, 'Maringá', 'Joaquim Murtinho', 'Zona 04', '87014-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19044, 'Ponta Grossa', 'Joaquim Murtinho', 'Boa Vista', '84052-496', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19045, 'Foz do Iguaçu', 'Joaquim Nabuco', 'Vila Brasília', '85864-270', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19046, 'Londrina', 'Joaquim Nabuco', 'Jardim Bandeirantes', '86061-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19047, 'Ponta Grossa', 'Joaquim Nabuco', 'Uvaranas', '84026-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19048, 'Maringá', 'Joaquim Nabuco', 'Zona 01', '87014-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19049, 'Pinhais', 'Joaquim Nabuco', 'Núcleo Colonial de Pinhais', '83321-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19050, 'Pato Branco', 'Joaquim Nabuco', 'Fraron', '85503-360', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19051, 'Toledo', 'Joaquim Nabuco', 'Jardim Paulista', '85910-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19052, 'São José dos Pinhais', 'Joaquim Nabuco', 'Centro', '83005-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19053, 'São José dos Pinhais', 'Joaquim Nabuco', 'Cidade Jardim', '83040-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19054, 'Sarandi', 'Joaquim Nabuco', 'Novo Panorama', '87113-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19055, 'Cambé', 'Joaquim Nabuco', 'Parque Residencial Manela', '86185-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19056, 'Cascavel', 'Joaquim Nabuco', 'Parque São Paulo', '85803-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19057, 'Almirante Tamandaré', 'Joaquim Nabuco', 'Jardim São Carlos', '83507-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19058, 'Colombo', 'Joaquim Nabuco', 'Jardim Planalto', '83409-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19059, 'Curitiba', 'Joaquim Nabuco', 'Tingui', '82620-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19060, 'Curitiba', 'Joaquim Natividade da Silva', 'Cajuru', '82940-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19061, 'Londrina', 'Joaquim Nogueira Azevedo', 'Cafezal 1', '86049-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19062, 'Curitiba', 'Joaquim Oliveira Filho', 'Cidade Industrial', '81270-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19063, 'Guarapuava', 'Joaquim Osório Duque Estrada', 'Santana', '85070-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19064, 'Almirante Tamandaré', 'Joaquim Pedro Krüger', 'Jardim Santa Rita de Cássia', '83506-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19065, 'Londrina', 'Joaquim Pereira', 'Jardim dos Alpes III', '86045-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19066, 'Londrina', 'Joaquim Pereira Filho', 'Residencial Vila Romana', '86031-816', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19067, 'Toledo', 'Joaquim Piazza', 'Jardim Anápolis', '85905-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19068, 'Curitiba', 'Joaquim Pinto Bastos', 'Sítio Cercado', '81900-446', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19069, 'Guarapuava', 'Joaquim Pinto Dias', 'Jardim das Américas', '85030-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19070, 'Araucária', 'Joaquim Poli', 'Campina da Barra', '83709-827', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19071, 'Guarapuava', 'Joaquim Prestes', 'Morro Alto', '85065-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19072, 'Ponta Grossa', 'Joaquim Procópio de Souza e Castro', 'Uvaranas', '84030-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19073, 'Paranavaí', 'Joaquim Quintino da Silva', 'Parque Morumbi', '87703-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19074, 'Araucária', 'Joaquim Ramos Ribeiro', 'Centro', '83702-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19075, 'Campo Largo', 'Joaquim Ribas de Andrade', 'Vila Solene', '83601-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19076, 'Curitiba', 'Joaquim Ribeiro de Camargo', 'Alto Boqueirão', '81770-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19077, 'Colombo', 'Joaquim Ribeiro de Lima', 'Jardim dos Eucaliptos', '83408-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19078, 'Colombo', 'Joaquim Rocha', 'Jardim Bandeirantes', '83408-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19079, 'Apucarana', 'Joaquim Rodrigues', 'Loteamento Sanches dos Santos', '86806-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19080, 'Paranavaí', 'Joaquim Rodrigues de Oliveira', 'Jardim Videira', '87711-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19081, 'Umuarama', 'Joaquim Rodrigues de Oliveira', 'Jardim Colibri', '87506-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19082, 'Londrina', 'Joaquim Silvério Braz', 'Parque Residencial Professora Marieta', '86082-768', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19083, 'Castro', 'Joaquim Silvestre Carvalho', 'Jardim Social Arapongas', '84174-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19084, 'Piraquara', 'Joaquim Simões', 'Jardim Tropical', '83314-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19085, 'Curitiba', 'Joaquim Simões', 'Pinheirinho', '81150-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19086, 'Foz do Iguaçu', 'Joaquim Soares', 'Jardim Princesa Daiana', '85867-677', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19087, 'Piraquara', 'Joaquim Soares Barbosa', 'Planta Vera Cruz', '83314-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19088, 'Londrina', 'Joaquim Távora', 'Jardim Novo Sabará', '86066-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19089, 'Umuarama', 'Joaquim Távora', 'Parque Tarumã', '87508-227', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19090, 'Telêmaco Borba', 'Joaquim Távora', 'Centro', '84261-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19091, 'Colombo', 'Joaquim Távora', 'Planta Rio Negro', '83410-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19092, 'Cascavel', 'Joaquim Távora', 'Parque São Paulo', '85803-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19093, 'Maringá', 'Joaquim Teixeira Coelho', 'Parque Residencial Quebec', '87023-439', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19094, 'Londrina', 'Joaquim Teixeira Leite', 'Jardim Bandeirantes', '86061-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19095, 'Curitiba', 'Joaquim Telêmaco Carneiro', 'Santa Cândida', '82640-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19096, 'Curitiba', 'Joaquim Theodoro Portugal', 'Xaxim', '81810-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19097, 'Paranaguá', 'Joaquim Tigre', 'Bockmann', '83206-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19098, 'Araucária', 'Joaquim Tonchak', 'Porto das Laranjeiras', '83703-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19099, 'Londrina', 'Joaquim Xavier de Lima', 'Jardim Vale Verde', '86040-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19100, 'Paranaguá', 'Joaquim Xavier Neves', 'Leblon', '83203-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19101, 'Londrina', 'Joaquina de Oliveira Perfeito', 'Conjunto Habitacional Violim', '86084-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19102, 'Londrina', 'Joaquina Lopes Ziober', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19103, 'Colombo', 'Joaquina O. Stica', 'Planta Boros', '83413-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19104, 'Curitiba', 'Joaquina Seixas Chagas de Andrade', 'Pilarzinho', '82100-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19105, 'Maringá', 'Joara', 'Parque das Grevíleas', '87025-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19106, 'Londrina', 'Joarez Oliveira César', 'Jardim Lago Norte', '86078-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19107, 'Curitiba', 'Job de Almeida', 'Cidade Industrial', '81350-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19108, 'Curitiba', 'Jocelin Walton Schiavon', 'Pinheirinho', '81880-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19109, 'Londrina', 'Jockei Club', 'Hípica', '86067-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19110, 'Curitiba', 'Jodat Nicolas Kury', 'Campina do Siqueira', '80740-615', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19111, 'Londrina', 'Joel Batista de Carvalho', 'Conjunto Habitacional João Turquino', '86056-835', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19112, 'Londrina', 'Joel Benício Pinto', 'Nova Olinda', '86073-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19113, 'Londrina', 'Joel Braz de Oliveira', 'Jardim Guararapes', '86038-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19114, 'Curitiba', 'Joel Carzino', 'Pinheirinho', '81825-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19115, 'Curitiba', 'Joel Jensen Júnior', 'Barreirinha', '82700-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19116, 'Curitiba', 'Joel Pedrini', 'Uberaba', '81570-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19117, 'Cascavel', 'Joel Sanways', 'Alto Alegre', '85805-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19118, 'Apucarana', 'Joel Tucci', 'Vila Regina', '86801-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19119, 'Curitiba', 'Joffre Darcanchy', 'Seminário', '80740-196', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19120, 'Londrina', 'Jofre Piantini', 'Jardim Alphaville', '86084-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19121, 'São José dos Pinhais', 'Johann Fichte', 'Aristocrata', '83030-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19122, 'Londrina', 'Johann Gutemberg', 'Industrial', '86063-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19123, 'Curitiba', 'Johann Sebastian Bach', 'Vista Alegre', '80820-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19124, 'Londrina', 'John Dalton', 'Universitário', '86050-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19125, 'Curitiba', 'John Elliott', 'Cajuru', '82900-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19126, 'Londrina', 'John Fitzgerald Kennedy', 'Recreio', '86025-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19127, 'Curitiba', 'John Foster Dulles', 'Seminário', '80310-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19128, 'Paranavaí', 'John Kennedy', 'Jardim Iguaçu', '87705-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19129, 'Campo Mourão', 'John Kennedy', 'Jardim Lar Paraná', '87306-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19130, 'Campo Mourão', 'John Kennedy', 'Jardim Lar Paraná', '87305-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19131, 'Almirante Tamandaré', 'John Kennedy', 'Vila Santa Terezinha', '83501-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19132, 'Londrina', 'John Lennon', 'Conjunto Vivi Xavier', '86082-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19133, 'Curitiba', 'John Lennon', 'Tatuquara', '81480-310', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19134, 'São José dos Pinhais', 'John Lennon', 'Afonso Pena', '83050-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19135, 'São José dos Pinhais', 'John Locke', 'Aristocrata', '83030-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19136, 'Curitiba', 'Joilson Marcos Alves', 'Alto Boqueirão', '81770-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19137, 'Guarapuava', 'Joinville', 'Boqueirão', '85022-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19138, 'Pato Branco', 'Joinville', 'Vila Esperança', '85503-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19139, 'Piraquara', 'Joinville', 'Planta São Tiago', '83307-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19140, 'São José dos Pinhais', 'Joinville', 'São Pedro', '83020-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19141, 'São José dos Pinhais', 'Joinville', 'Guatupê', '83060-560', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19142, 'São José dos Pinhais', 'Joinville', 'São Pedro', '83005-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19143, 'Cascavel', 'Joinville', 'Universitário', '85819-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19144, 'Londrina', 'Jonas Barbosa Leite', 'Jardim dos Alpes I', '86075-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19145, 'Castro', 'Jonas Borges Martins', 'Centro', '84165-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19146, 'Londrina', 'Jonas de Faria Castro', 'Centro', '86020-050', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19147, 'Curitiba', 'Jonas Fragoso', 'Atuba', '82860-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19148, 'Curitiba', 'Jonas Marinho da Cunha', 'São Braz', '82315-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19149, 'Apucarana', 'Jonas Matulaitis', 'Jardim Cidade Alta', '86803-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19150, 'Londrina', 'Jonas Matulaitis Neto', 'Jardim Alphaville', '86084-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19151, 'Londrina', 'Jonathas Serrano', 'Quebec', '86060-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19152, 'Araucária', 'Jonet Zanetti Silva', 'Tindiquera', '83708-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19153, 'Curitiba', 'Jóquei Clube', 'Prado Velho', '80215-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19154, 'Curitiba', 'Jóquei Pinheiro Filho', 'Tarumã', '82800-020', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19155, 'Londrina', 'Jordânia', 'Vilas Boas', '86046-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19156, 'Curitiba', 'Jordânia', 'Cajuru', '82960-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19157, 'Curitiba', 'Jordano Durigan', 'São Braz', '82310-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19158, 'Guarapuava', 'Jordão', 'São Cristóvão', '85060-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19159, 'Foz do Iguaçu', 'Jordão', 'Conjunto Libra', '85857-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19160, 'Ponta Grossa', 'Jordão Bahls de Almeida', 'Estrela', '84050-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19161, 'Maringá', 'Jordão Caldeira de Oliveira', 'Jardim Monte Belo', '87080-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19162, 'Curitiba', 'Jordão Corrêa', 'Barreirinha', '82220-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19163, 'Curitiba', 'Jordão Lourenço de Gois', 'Cidade Industrial', '81450-717', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19164, 'Londrina', 'Jordelino Silva', 'Jardim Primavera', '86086-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19165, 'Maringá', 'Jordim Piedade', 'Jardim América', '87045-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19166, 'Guarapuava', 'Joreslau Galan', 'Vila Bela', '85025-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19167, 'Curitiba', 'Jorge Adir Nepomoceno', 'Cidade Industrial', '81280-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19168, 'Campo Largo', 'Jorge Alves Ferreira', 'Loteamento Itaboa', '83605-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19169, 'Ponta Grossa', 'Jorge Alves Pereira', 'Boa Vista', '84072-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19170, 'Guarapuava', 'Jorge Alves Ribeiro', 'Conradinho', '85055-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19171, 'Colombo', 'Jorge Amado', 'Parque Monte Castelo', '83409-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19172, 'Campo Largo', 'Jorge Antochevis', 'Vila Torres I', '83609-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19173, 'Curitiba', 'Jorge Antônio Heil', 'Taboão', '82130-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19174, 'Araucária', 'Jorge Antônio Mansur', 'Centro', '83702-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19175, 'Curitiba', 'Jorge Barbosa', 'Boa Vista', '82200-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19176, 'Curitiba', 'Jorge Basso', 'Abranches', '82130-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19177, 'Curitiba', 'Jorge Batista Crocetti', 'Capão da Imbuia', '82800-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19178, 'Ponta Grossa', 'Jorge Becher', 'Colônia Dona Luiza', '84045-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19179, 'Ponta Grossa', 'Jorge Becher', 'Uvaranas', '84026-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19180, 'Piraquara', 'Jorge Berberi', 'Vila São Cristóvão', '83305-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19181, 'Almirante Tamandaré', 'Jorge Bonfim Alcântara', 'Jardim Bela Vista', '83506-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19182, 'Curitiba', 'Jorge Bonn', 'Tingui', '82600-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19183, 'Curitiba', 'Jorge Borsatto', 'Portão', '80330-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19184, 'Londrina', 'Jorge Bounassar', 'São Lourenço', '86043-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19185, 'Curitiba', 'Jorge Brandel', 'Sítio Cercado', '81900-506', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19186, 'São José dos Pinhais', 'Jorge Brey', 'São Sebastião', '83075-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19187, 'Curitiba', 'Jorge Brey', 'Alto Boqueirão', '81720-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19188, 'Londrina', 'Jorge Calixto', 'Aquilles Sthengel', '86086-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19189, 'Curitiba', 'Jorge Carlos Buczek', 'Alto Boqueirão', '81770-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19190, 'Umuarama', 'Jorge Carlos Jardim', 'Parque Industrial I', '87507-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19191, 'Londrina', 'Jorge Casoni', 'Centro', '86010-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19192, 'Londrina', 'Jorge Casoni', 'Lago Igapó', '86026-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19193, 'Curitiba', 'Jorge Coleraus Barbosa', 'Pinheirinho', '81870-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19194, 'Curitiba', 'Jorge Cuquel', 'Seminário', '80440-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19195, 'Curitiba', 'Jorge Cury Brahim', 'Pilarzinho', '82110-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19196, 'São José dos Pinhais', 'Jorge da Silva', 'Miringuava', '83090-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19197, 'Londrina', 'Jorge da Silva Santos', 'Garden Park Residence', '86079-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19198, 'Curitiba', 'Jorge Dall''Igna', 'Santo Inácio', '82010-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19199, 'Curitiba', 'Jorge Daniel Cordeiro', 'Xaxim', '81810-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19200, 'Londrina', 'Jorge Danielides', 'Centro', '86020-370', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19201, 'Londrina', 'Jorge de Aquino Oliveira', 'Residencial Vila Romana', '86031-809', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19202, 'Colombo', 'Jorge de Jesus Pansolin', 'Jardim Aurora', '83411-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19203, 'Foz do Iguaçu', 'Jorge de Lima', 'Jardim Dom Pedro I', '85856-608', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19204, 'Curitiba', 'Jorge de Poli', 'Xaxim', '81710-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19205, 'Curitiba', 'Jorge de Quadros', 'Cajuru', '82930-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19206, 'Ponta Grossa', 'Jorge dos Santos Fumanchu', 'Boa Vista', '84072-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19207, 'Piraquara', 'Jorge Faustino da Silva', 'Jardim dos Eucaliptos', '83311-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19208, 'Londrina', 'Jorge Feliciano da Silva', 'Monte Belo', '86041-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19209, 'Curitiba', 'Jorge Felipe Daher Filho', 'Fazendinha', '81320-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19210, 'Londrina', 'Jorge Fernandes Baliero', 'Alto da Boa Vista', '86083-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19211, 'Maringá', 'Jorge Ferreira Duque Estrada', 'Vila Progresso', '87080-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19212, 'Maringá', 'Jorge Formighieri Totti', 'Conjunto Habitacional Requião', '87047-497', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19213, 'Londrina', 'Jorge Garcia Villar', 'Santiago', '86071-660', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19214, 'Curitiba', 'Jorge Gava', 'Pilarzinho', '82110-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19215, 'Piraquara', 'Jorge Gelinski', 'Guarituba', '83311-326', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19216, 'Curitiba', 'Jorge Goedicke', 'Santo Inácio', '82300-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19217, 'Curitiba', 'Jorge Gomes Rosa', 'Uberaba', '81540-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19218, 'Pato Branco', 'Jorge Guérios Sobrinho', 'Bonatto', '85506-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19219, 'São José dos Pinhais', 'Jorge Guimarães de Camargo', 'Cruzeiro', '83010-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19220, 'Guarapuava', 'Jorge Haag', 'Primavera', '85050-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19221, 'Curitiba', 'Jorge Haikel Fahd', 'Capão Raso', '81110-170', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19222, 'Londrina', 'Jorge Hannuch', 'Santa Rita 1', '86072-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19223, 'Apucarana', 'Jorge Herculano', 'Jardim Iguatemi', '86810-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19224, 'Ponta Grossa', 'Jorge Holzmann', 'Colônia Dona Luiza', '84043-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19225, 'Ponta Grossa', 'Jorge Holzmann', 'Colônia Dona Luiza', '84045-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19226, 'Foz do Iguaçu', 'Jorge Inácio Franco', 'Jardim Marisa', '85867-619', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19227, 'Londrina', 'Jorge Jobim', 'Shangri-La', '86070-530', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19228, 'Araucária', 'Jorge Joslin', 'Boqueirão', '83704-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19229, 'Cascavel', 'Jorge Lacerda', 'Centro', '85810-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19230, 'Cascavel', 'Jorge Lacerda', 'Claudete', '85811-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19231, 'Curitiba', 'Jorge Lell', 'Mossunguê', '81200-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19232, 'Curitiba', 'Jorge Luís Della Coletta', 'Capão da Imbuia', '82810-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19233, 'Curitiba', 'Jorge Luiz Freygang', 'Uberaba', '81590-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19234, 'Curitiba', 'Jorge Luiz Muraro', 'Abranches', '82220-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19235, 'Paranaguá', 'Jorge Luiz Ultrabo Pinto', 'Jardim Samambaia', '83212-390', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19236, 'São José dos Pinhais', 'Jorge Mansos do Nascimento Teixeira', 'São Pedro', '83005-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19237, 'Paranaguá', 'Jorge Marcondes', 'Conjunto Residencial Prefeito Cominese', '83215-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19238, 'Curitiba', 'Jorge Marques Pinheiro', 'Santa Cândida', '82630-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19239, 'Londrina', 'Jorge Mota', 'Residencial Portal do Sol', '86082-796', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19240, 'Foz do Iguaçu', 'Jorge Nassar', 'Jardim Residencial Bela Vista', '85856-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19241, 'Curitiba', 'Jorge Ney Buchmann', 'Cidade Industrial', '81260-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19242, 'Maringá', 'Jorge P. da Silva', 'Vila Cafelândia', '87045-160', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19243, 'Curitiba', 'Jorge Pedro Anad', 'Sítio Cercado', '81925-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19244, 'Curitiba', 'Jorge Pedro Chueri', 'Tarumã', '82530-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19245, 'Londrina', 'Jorge Pereira de Rezende', 'Roseira', '86041-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19246, 'Londrina', 'Jorge Ribeiro', 'São Lourenço', '86043-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19247, 'Curitiba', 'Jorge Ribeiro', 'Atuba', '82860-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19248, 'Londrina', 'Jorge Roberto Vitori', 'Conjunto Habitacional José Garcia Molina', '86080-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19249, 'Araucária', 'Jorge Saad', 'Boqueirão', '83704-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19250, 'Curitiba', 'Jorge Sabbag', 'Augusta', '81260-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19251, 'Foz do Iguaçu', 'Jorge Sanwais', 'Centro', '85851-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19252, 'Foz do Iguaçu', 'Jorge Sanwais', 'Jardim Guarapuava I', '85856-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19253, 'Foz do Iguaçu', 'Jorge Sanwais', 'Centro', '85852-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19254, 'Telêmaco Borba', 'Jorge Schemberger', 'Centro', '84261-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19255, 'Foz do Iguaçu', 'Jorge Schimmelpfeng', 'Centro', '85851-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19256, 'Guarapuava', 'Jorge Sedenho', 'Primavera', '85050-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19257, 'Almirante Tamandaré', 'Jorge Silva do Prado', 'Jardim do Rocio', '83502-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19258, 'Guarapuava', 'Jorge Silveira do Amaral', 'Cascavel', '85040-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19259, 'Londrina', 'Jorge Silvério de Oliveira', 'Operária', '86038-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19260, 'Londrina', 'Jorge Silvestre', 'Santiago', '86071-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19261, 'Curitiba', 'Jorge Simão', 'Alto Boqueirão', '81850-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19262, 'Curitiba', 'Jorge Tanner', 'Portão', '81320-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19263, 'Maringá', 'Jorge Tibiriçá', 'Vila Ipiranga', '87045-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19264, 'Araucária', 'Jorge Tieto Iwasa', 'Chapada', '83706-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19265, 'Curitiba', 'Jorge Tortato', 'Campo de Santana', '81490-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19266, 'Maringá', 'Jorge Veiga', 'Jardim América', '87045-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19267, 'Londrina', 'Jorge Velho', 'Larsen', '86010-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19268, 'Curitiba', 'Jorge Vergílio Cruzeta', 'Cajuru', '82960-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19269, 'Campo Mourão', 'Jorge Walter', 'Centro', '87303-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19270, 'Campo Mourão', 'Jorge Walter', 'Centro', '87302-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19271, 'Curitiba', 'Jorge Wendler', 'Xaxim', '81720-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19272, 'Foz do Iguaçu', 'Jorge Werner', 'Vila Adriana II', '85854-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19273, 'Curitiba', 'Jornalista Aderbal G. Stresser', 'Cajuru', '82970-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19274, 'Curitiba', 'Jornalista Alceu Chichorro', 'Bairro Alto', '82820-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19275, 'Curitiba', 'Jornalista Ali C. Bark', 'Santa Cândida', '82720-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19276, 'Curitiba', 'Jornalista Alípio Miranda', 'Pilarzinho', '82110-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19277, 'Curitiba', 'Jornalista Augusto Waldrigues', 'Cidade Industrial', '81460-238', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19278, 'Curitiba', 'Jornalista Caio Machado', 'Santa Quitéria', '80310-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19279, 'Curitiba', 'Jornalista Carlos Coelho', 'Água Verde', '80620-470', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19280, 'Curitiba', 'Jornalista Clemente Comandulli', 'Santa Felicidade', '82015-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19281, 'Curitiba', 'Jornalista Divonira Torres Kudri', 'Jardim Botânico', '80210-265', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19282, 'Curitiba', 'Jornalista Emílio Zola Florenzano', 'Tatuquara', '81470-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19283, 'Curitiba', 'Jornalista Geraldo Russe', 'Pilarzinho', '82110-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19284, 'Ponta Grossa', 'Jornalista João Marenda', 'Colônia Dona Luiza', '84045-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19285, 'Curitiba', 'Jornalista José Augusto Gumy', 'Portão', '80330-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19286, 'Curitiba', 'Jornalista José Blansky Filho', 'Alto Boqueirão', '81850-525', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19287, 'Apucarana', 'Jornalista José Canela Bautti', 'Vila Real', '86804-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19288, 'Curitiba', 'Jornalista José Cury', 'Cidade Industrial', '81250-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19289, 'Curitiba', 'Jornalista José Ernesto Ericksen Pereira', 'Pilarzinho', '82110-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19290, 'Curitiba', 'Jornalista José Pedro dos Santos', 'Ganchinho', '81935-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19291, 'Curitiba', 'Jornalista José Wanderley Dias', 'Vista Alegre', '80820-670', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19292, 'Curitiba', 'Jornalista Júlio Alípio Beghetto', 'São João', '82030-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19293, 'Curitiba', 'Jornalista Laertes Artidoro Moreira', 'Campo Comprido', '81220-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19294, 'Curitiba', 'Jornalista Nacim Bacilla Neto', 'Centro Cívico', '80530-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19295, 'Curitiba', 'Jornalista Nelson Luiz Ribas de Oliveira', 'Campina do Siqueira', '80740-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19296, 'Curitiba', 'Jornalista Octávio Secundino', 'Bom Retiro', '80520-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19297, 'Curitiba', 'Jornalista Paulino de Almeida', 'Cajuru', '82970-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19298, 'Curitiba', 'Jornalista Rômulo da Costa Faria', 'Pinheirinho', '81825-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19299, 'Curitiba', 'Jornalista Rúbens Ávila', 'Cidade Industrial', '81460-219', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19300, 'Curitiba', 'Jornalista Samuel Guimarães da Costa', 'Juvevê', '80040-105', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19301, 'Curitiba', 'Jornalista Silvino A. Batista', 'Tatuquara', '81480-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19302, 'Curitiba', 'Jornalista Silvino A. Batista', 'Tatuquara', '81470-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19303, 'Maringá', 'Jornalista Waldomiro Baddini Neto', 'Jardim Novo Horizonte', '87005-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19304, 'São José dos Pinhais', 'Joroslau Sochaki', 'Ipê', '83055-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19305, 'Londrina', 'José Abdala Hanna', 'Conjunto Novo Amparo', '86087-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19306, 'Curitiba', 'José Abentin', 'Vista Alegre', '82100-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19307, 'Curitiba', 'José Abílio Machado Sanford', 'Bairro Alto', '82840-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19308, 'Curitiba', 'José Ader', 'Xaxim', '81710-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19309, 'Curitiba', 'José Affonso Werneck', 'Portão', '80610-370', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19310, 'Curitiba', 'José Afonso Cordeiro', 'Pinheirinho', '81870-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19311, 'Cambé', 'José Afonso dos Santos', 'Jardim Santo Amaro', '86185-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19312, 'Castro', 'José Agnelo Barbosa', 'Cantagalo', '84178-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19313, 'São José dos Pinhais', 'José Airton Cordeiro de Lima', 'Afonso Pena', '83050-126', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19314, 'Campo Mourão', 'José Aladic', 'Jardim Corinthias', '87309-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19315, 'Foz do Iguaçu', 'José Al-Assar', 'Jardim N Horizonte', '85855-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19316, 'Ponta Grossa', 'José Alberto Caos', 'Contorno', '84060-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19317, 'Curitiba', 'José Alberto de Almeida', 'Cajuru', '82950-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19318, 'Curitiba', 'José Alceu Berger', 'Santa Cândida', '82640-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19319, 'Londrina', 'José Alceu Gimenez', 'Monte Carlo', '86040-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19320, 'Curitiba', 'José Alceu Sabatke', 'Sítio Cercado', '81910-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19321, 'Curitiba', 'José Alcides de Lima', 'Novo Mundo', '81050-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19322, 'Curitiba', 'José Alcides de Lima', 'Capão Raso', '81130-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19323, 'Curitiba', 'José Alcides de Lima', 'Capão Raso', '81150-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19324, 'Londrina', 'José Alexandre', 'Jardim Acapulco', '86045-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19325, 'Cambé', 'José Alexandrino', 'Jardim Tarobá', '86191-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19326, 'Curitiba', 'José Alexandrino', 'Mossunguê', '81210-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19327, 'Londrina', 'José Alfredo de Oliveira', 'Antônio M Nogueira Cafezal 4', '86089-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19328, 'Apucarana', 'José Alfredo de Souza', 'Núcleo Habitacional Tancredo Neves', '86807-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19329, 'Curitiba', 'José Algusto Santana', 'Pilarzinho', '82115-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19330, 'Curitiba', 'José Álvaro Tizzot', 'Sítio Cercado', '81935-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19331, 'Paranaguá', 'José Alves', 'Costeira', '83203-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19332, 'Apucarana', 'José Alves de Paula', 'Jardim Catuaí', '86802-609', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19333, 'Apucarana', 'José Alves de Paula Filho', 'Vila São José', '86808-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19334, 'Maringá', 'José Alves dos Santos', 'Conjunto Residencial Planville', '87083-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19335, 'Londrina', 'José Alves Ferreira', 'Giovani Lunardelli', '86037-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19336, 'Maringá', 'José Alves Nendo', 'Jardim São Silvestre', '87055-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19337, 'Maringá', 'José Alves Nendo', 'Jardim Internorte', '87045-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19338, 'Curitiba', 'José Alves Pinto', 'Pilarzinho', '82115-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19339, 'Apucarana', 'José Amadeu dos Santos', 'Jardim Marissol', '86807-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19340, 'Pinhais', 'José Ambrósio de Araújo', 'Jardim Cláudia', '83326-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19341, 'Londrina', 'José Américo', 'Parque Universidade', '86056-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19342, 'Campo Largo', 'José Américo de Almeida', 'São Marcos', '83602-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19343, 'Curitiba', 'José Américo Tizoni', 'Campo Comprido', '81270-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19344, 'Curitiba', 'José Ananias Mauad', 'Jardim Botânico', '80210-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19345, 'Curitiba', 'José Ancelmo Nicco', 'Campina do Siqueira', '80740-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19346, 'Curitiba', 'José Andreassa', 'Seminário', '80740-198', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19347, 'Londrina', 'José Andreolli', 'Parque Universidade', '86056-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19348, 'Toledo', 'José Ângelo Borges', 'Jardim Parque Verde', '85906-727', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19349, 'Curitiba', 'José Ângelo Martins', 'Tatuquara', '81480-186', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19350, 'Curitiba', 'José Ângelo Miquelleto', 'Umbará', '81930-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19351, 'Curitiba', 'José Aníbal Dutra Lamin', 'Tatuquara', '81470-095', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19352, 'Londrina', 'José Anísio de Goes', 'Cafezal', '86045-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19353, 'Curitiba', 'José Antoniassi', 'Vista Alegre', '80810-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19354, 'Curitiba', 'José Antônio Belém', 'Santa Felicidade', '82410-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19355, 'Curitiba', 'José Antônio Bento', 'Santo Inácio', '82010-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19356, 'Castro', 'José Antônio de Oliveira', 'Jardim das Araucárias', '84174-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19357, 'Castro', 'José Antônio F. Telles', 'Jardim Social Primavera', '84174-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19358, 'Londrina', 'José Antônio Formigoni Netto', 'Jardim Alemanha', '86031-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19359, 'Colombo', 'José Antônio Gonçalves', 'Jardim Monza', '83406-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19360, 'Londrina', 'Jose Antônio Gorla', 'Jardim Continental', '86081-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19361, 'Araucária', 'José Antônio Janoski', 'Boqueirão', '83704-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19362, 'Curitiba', 'José Antônio Leprevost', 'Santa Cândida', '82640-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19363, 'Umuarama', 'José Antônio Lopes Rodrigues', 'Parque San Remo I', '87506-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19364, 'Londrina', 'José Antônio Marmo Viotti', 'Catuai', '86086-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19365, 'Paranaguá', 'José Antônio Mendes', 'Divinéia', '83212-435', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19366, 'Curitiba', 'José Antônio Nichele', 'Umbará', '81940-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19367, 'Campo Largo', 'José Antônio Puppi', 'Vila Elizabeth', '83607-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19368, 'Apucarana', 'José Antônio Rocha', 'Núcleo Habitacional Heitor S Pinheiro', '86806-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19369, 'Paranaguá', 'José Antônio Temporao', 'Centro Histórico', '83203-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19370, 'Campo Mourão', 'José Antônio Vieira', 'Jardim Paulista', '87310-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19371, 'Colombo', 'José Antônio Zem', 'Jardim Arapongas', '83402-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19372, 'Curitiba', 'José Antunes Ferreira', 'Cidade Industrial', '81170-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19373, 'Ponta Grossa', 'José Antunes Mendes', 'Uvaranas', '84030-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19374, 'Londrina', 'José Aparecido da Silva', 'Franciscato II', '86078-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19375, 'Curitiba', 'José Araújo Filho', 'Boqueirão', '81750-160', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19376, 'Curitiba', 'José Armando Correia', 'Sítio Cercado', '81925-268', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19377, 'Maringá', 'José Armando Ribas', 'Conjunto Habitacional Requião', '87047-458', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19378, 'Campo Largo', 'José Arnaldo Cosmo', 'Vila Ferrari', '83606-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19379, 'Laranjeiras do Sul', 'José Arnaldo Molinari', 'São Francisco', '85303-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19380, 'Castro', 'José Arthur de Jesus', 'Vila Santa Cruz', '84168-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19381, 'Londrina', 'José Assumpção', 'Parigot de Souza 2', '86082-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19382, 'Londrina', 'José Atanásio Rodrigues', 'Santa Izabel', '86031-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19383, 'Curitiba', 'José Augusto da Silva', 'Sítio Cercado', '81910-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19384, 'Curitiba', 'José Augusto dos Santos', 'Pilarzinho', '82100-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19385, 'Curitiba', 'José Augusto Escobar', 'Cidade Industrial', '81305-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19386, 'São José dos Pinhais', 'José Augusto Gasparello', 'Braga', '83020-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19387, 'Telêmaco Borba', 'José Augusto Nocera', 'Jardim Bom Jesus', '84262-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19388, 'Toledo', 'José Ayres da Silva', 'Coopagro', '85903-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19389, 'Paranavaí', 'José Ayres Júnior', 'Jardim Paulista', '87709-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19390, 'Ponta Grossa', 'José Azevedo de Macedo', 'Uvaranas', '84026-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19391, 'Campo Mourão', 'José Backes', 'Jardim Santa Nilce I', '87308-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19392, 'Curitiba', 'José Bagatin', 'Barreirinha', '82560-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19393, 'Curitiba', 'José Baggio', 'Campo Comprido', '81210-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19394, 'Curitiba', 'José Bajerski', 'Abranches', '82220-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19395, 'Paranaguá', 'José Baka', 'Jardim Samambaia', '83212-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19396, 'Umuarama', 'José Balan', 'Jardim Social', '87506-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19397, 'Maringá', 'José Barão Neto', 'Vila Progresso', '87080-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19398, 'Maringá', 'José Barbosa da Silva', 'Jardim Copacabana', '87023-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19399, 'Telêmaco Borba', 'José Barbosa Santos', 'Jardim Bom Jesus', '84262-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19400, 'Apucarana', 'José Barreto', 'Loteamento Residencial Tami', '86803-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19401, 'Pinhais', 'José Barros da Rocha', 'Moradias Palmital', '83325-608', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19402, 'Apucarana', 'José Barroso Medina', 'Vila Nova II', '86812-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19403, 'Cascavel', 'José Bartinik', 'Região do Lago 3', '85819-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19404, 'Guarapuava', 'José Basílio da Gama', 'Vila Bela', '85027-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19405, 'Curitiba', 'José Bassa', 'Sítio Cercado', '81925-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19406, 'Curitiba', 'José Bassa', 'Sítio Cercado', '81920-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19407, 'Curitiba', 'José Bassani', 'Capão da Imbuia', '82810-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19408, 'Araucária', 'José Basso', 'Tindiquera', '83708-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19409, 'Curitiba', 'José Batista dos Santos', 'Cidade Industrial', '81250-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19410, 'Londrina', 'José Batista Guimarães', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19411, 'Guarapuava', 'José Batistelli Filho', 'Vila Bela', '85027-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19412, 'Curitiba', 'José Becker Davet', 'Santa Cândida', '82630-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19413, 'Colombo', 'José Beira', 'Vila Esperanceta', '83403-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19414, 'Colombo', 'José Beira da Silva', 'Jardim Maria Matutina', '83401-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19415, 'Colombo', 'José Belém', 'Jardim Santa Cândida', '83402-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19416, 'Londrina', 'José Beletti', 'Leste Oeste', '86037-807', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19417, 'Colombo', 'José Belizário', 'Jardim Florença', '83414-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19418, 'Apucarana', 'José Beltoni', 'Recanto Mundo Novo', '86805-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19419, 'Curitiba', 'José Bemben', 'Sítio Cercado', '81900-775', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19420, 'Curitiba', 'José Benato', 'Santa Felicidade', '82020-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19421, 'Curitiba', 'José Benedicto M. de Queiroz', 'Cidade Industrial', '81450-737', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19422, 'Curitiba', 'José Benedito Cottolengo', 'Campo Comprido', '81220-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19423, 'Paranavaí', 'José Benício de Souza', 'Jardim São Jorge', '87710-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19424, 'Paranaguá', 'José Bento Marcelino Filho', 'Vila Guarani', '83215-436', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19425, 'Londrina', 'José Bento Ribeiro', 'Jardim dos Alpes III', '86045-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19426, 'Curitiba', 'José Beppi Lucca', 'São Braz', '82300-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19427, 'Maringá', 'José Bergamasco', 'Jardim Santa Alice', '87040-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19428, 'Almirante Tamandaré', 'José Bernacchi', 'Jardim do Rocio', '83502-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19429, 'Foz do Iguaçu', 'José Bernardi Filho', 'Jardim Santa Rita', '85862-306', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19430, 'Londrina', 'José Bernardo', 'Jardim dos Alpes III', '86045-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19431, 'Cascavel', 'José Bernardo Rosa', 'Santa Felicidade', '85803-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19432, 'Maringá', 'José Bertoni', 'Jardim Alvorada', '87035-115', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19433, 'Araucária', 'José Besciak', 'Barigui', '83707-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19434, 'Colombo', 'José Betinardi', 'Roseira', '83415-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19435, 'Curitiba', 'José Bianeck Filho', 'Barreirinha', '82220-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19436, 'Curitiba', 'José Bim', 'Bigorrilho', '80710-340', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19437, 'Curitiba', 'José Binhara', 'Cajuru', '82940-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19438, 'Araucária', 'José Biscaia', 'Boqueirão', '83704-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19439, 'Campo Largo', 'José Biscouto', 'Vila Torres I', '83609-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19440, 'Curitiba', 'José Blanchet', 'Bacacheri', '82600-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19441, 'Piraquara', 'José Boganiko Sobrinho', 'Planta Santa Clara', '83306-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19442, 'Curitiba', 'José Boguszewski', 'Abranches', '82130-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19443, 'Curitiba', 'José Boiko', 'Santo Inácio', '82010-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19444, 'Campo Largo', 'José Bonato', 'Loteamento Santa Rita', '83602-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19445, 'Colombo', 'José Bonato Strapasson', 'Sapopema', '83414-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19446, 'Almirante Tamandaré', 'José Bonfim Alcântara', 'Jardim Santa Rita de Cássia', '83506-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19447, 'Foz do Iguaçu', 'José Bonifácio', 'Jardim Social', '85853-035', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19448, 'Guarapuava', 'José Bonifácio', 'Vila Bela', '85027-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19449, 'Laranjeiras do Sul', 'José Bonifácio', 'Centro', '85301-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19450, 'Francisco Beltrão', 'José Bonifácio', 'São Miguel', '85602-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19451, 'Londrina', 'José Bonifácio', 'Jardim Bandeirantes', '86061-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19452, 'Paranaguá', 'José Bonifácio', 'Jardim Paranaguá', '83218-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19453, 'Ponta Grossa', 'José Bonifácio', 'Orfãs', '84015-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19454, 'Pinhais', 'José Bonifácio', 'Núcleo Colonial de Pinhais', '83321-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19455, 'Maringá', 'José Bonifácio', 'Zona 01', '87013-290', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19456, 'Pato Branco', 'José Bonifácio', 'Aeroporto', '85503-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19457, 'Sarandi', 'José Bonifácio', 'Jardim Panorama', '87113-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19458, 'Sarandi', 'José Bonifácio', 'Jardim Independência I', '87114-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19459, 'Telêmaco Borba', 'José Bonifácio', 'Vila São Francisco de Assis', '84264-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19460, 'Cascavel', 'José Bonifácio', 'São Cristóvão', '85813-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19461, 'Colombo', 'José Bonifácio', 'Jardim Santa Cândida', '83404-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19462, 'Almirante Tamandaré', 'José Bonifácio', 'Jardim Iracema', '83508-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19463, 'Castro', 'José Bonifácio', 'Vila Rio Branco', '84172-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19464, 'Cambé', 'José Bonifácio', 'Vila Atalaia', '86181-570', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19465, 'Apucarana', 'José Bonifácio', 'Vila São Francisco', '86800-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19466, 'Campo Largo', 'José Bonifácio', 'Vila Bancária', '83601-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19467, 'Curitiba', 'José Bonifácio', 'Centro', '80020-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19468, 'Curitiba', 'José Bonifácio de Barros Pimpão', 'Sítio Cercado', '81900-437', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19469, 'Araucária', 'José Bonvim', 'Tindiquera', '83708-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19470, 'Londrina', 'José Boralli', 'Santa Rita 1', '86071-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19471, 'São José dos Pinhais', 'José Bordim', 'Braga', '83020-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19472, 'Curitiba', 'José Borges de Macedo', 'Centro', '80020-220', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19473, 'Curitiba', 'José Bório', 'Cidade Industrial', '81250-620', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19474, 'Apucarana', 'José Bossato', 'Recanto Bom Retiro', '86803-658', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19475, 'Curitiba', 'José Botega', 'Butiatuvinha', '82400-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19476, 'Ponta Grossa', 'José Branco Ribas', 'Uvaranas', '84030-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19477, 'Curitiba', 'José Braz Gomes', 'Sítio Cercado', '81900-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19478, 'Curitiba', 'José Brenny', 'Pilarzinho', '82120-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19479, 'Campo Largo', 'José Brígido dos Santos', 'Loteamento Ouro Verde I', '83606-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19480, 'Colombo', 'José Brito', 'Jardim César Augusto', '83402-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19481, 'Curitiba', 'José Brum', 'Xaxim', '81710-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19482, 'Curitiba', 'José Brusamolin', 'São Lourenço', '82210-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19483, 'Maringá', 'José Bulla', 'Jardim Internorte', '87045-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19484, 'Londrina', 'José Buranello', 'Jardim Alphaville', '86084-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19485, 'Cambé', 'José Burgo', 'Jardim José Favaro', '86183-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19486, 'Pato Branco', 'José Burin', 'Bortot', '85504-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19487, 'Almirante Tamandaré', 'José Busato', 'Jardim Casa Blanca', '83513-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19488, 'Araucária', 'José Butkoski', 'Estação', '83705-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19489, 'Paranaguá', 'José Cadilhe', 'Serraria do Rocha', '83221-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19490, 'São José dos Pinhais', 'José Cadilhe', 'São Sebastião', '83075-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19491, 'Curitiba', 'José Cadilhe', 'Água Verde', '80620-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19492, 'Apucarana', 'José Caetano da Silva Filho', 'Jardim Aeroporto', '86812-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19493, 'Londrina', 'José Caetano de Oliveira', 'Jatobá', '86043-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19494, 'Cascavel', 'José Caldart', 'Maria Luiza', '85819-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19495, 'Curitiba', 'José Campaneli', 'Xaxim', '81810-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19496, 'Londrina', 'José Campano Filho', 'Jardim Continental', '86081-178', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19497, 'Cambé', 'José Campi', 'Jardim Boa Vista', '86191-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19498, 'Apucarana', 'José Campoy', 'Vila São Francisco', '86813-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19499, 'Londrina', 'José Camuci', 'Jardim Marízia II', '86079-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19500, 'Maringá', 'José Cândido', 'Conjunto Habitacional Hermann Moraes Barros', '87023-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19501, 'São José dos Pinhais', 'José Cândido da Silva Muricy', 'Roseira', '83070-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19502, 'Foz do Iguaçu', 'José Capponi', 'Parque Presidente II', '85863-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19503, 'Apucarana', 'José Cardoso Sobrinho', 'Loteamento Santo Antônio', '86800-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19504, 'Toledo', 'José Carlos Basso', 'Coopagro', '85903-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19505, 'Apucarana', 'José Carlos Bueno', 'Jardim Aviação', '86812-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19506, 'Ponta Grossa', 'José Carlos Cação Ribeiro', 'Uvaranas', '84031-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19507, 'Almirante Tamandaré', 'José Carlos Colodel', 'Vila Santa Terezinha', '83501-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19508, 'Curitiba', 'José Carlos de Godoy', 'Taboão', '82130-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19509, 'Curitiba', 'José Carlos de Macedo Soares', 'Xaxim', '81810-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19510, 'Curitiba', 'José Carlos de Oliveira', 'Taboão', '82130-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19511, 'Curitiba', 'José Carlos Fávaro', 'Cidade Industrial', '81450-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19512, 'Londrina', 'José Carlos Ferreira', 'Jardim São Jorge', '86082-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19513, 'Maringá', 'José Carlos Joaquinzo', 'Ebenezer', '87035-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19514, 'Londrina', 'José Carlos Marques', 'Conjunto Residencial Santa Rita V', '86072-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19515, 'Ponta Grossa', 'José Carlos Miniorino', 'Boa Vista', '84072-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19516, 'Foz do Iguaçu', 'José Carlos Pace', 'Parque Morumbi', '85858-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19517, 'Foz do Iguaçu', 'José Carlos Pace', 'Parque Morumbi II', '85859-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19518, 'Curitiba', 'José Carlos Puppi', 'Barreirinha', '82700-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19519, 'Telêmaco Borba', 'José Carlos Reis', 'Centro', '84261-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19520, 'São José dos Pinhais', 'José Carlos Ribeiro Ribas', 'Guatupê', '83065-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19521, 'Curitiba', 'José Carlos Ribeiro Taborda', 'Santa Cândida', '82640-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19522, 'Ponta Grossa', 'José Carlos Rodrigues', 'Uvaranas', '84030-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19523, 'São José dos Pinhais', 'José Carlos Souza Côrtes', 'Águas Belas', '83010-565', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19524, 'Pinhais', 'José Carlotto', 'Planta Cláudio Mehl', '83326-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19525, 'Guarapuava', 'José Carollo', 'Bonsucesso', '85035-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19526, 'Curitiba', 'José Carolo', 'Mossunguê', '81210-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19527, 'Piraquara', 'José Carreiro Lima', 'Planta Wagner', '83314-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19528, 'Londrina', 'José Carvalho Grade', 'Iguaçu', '86060-275', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19529, 'Francisco Beltrão', 'José Casagrande', 'Pinheirinho', '85606-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19530, 'Curitiba', 'José Casagrande', 'Vista Alegre', '80820-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19531, 'Curitiba', 'José Casemiro Correia', 'Campo Comprido', '81230-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19532, 'Curitiba', 'José Casemiro Stenzowski', 'Novo Mundo', '81010-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19533, 'Pato Branco', 'José Cattani', 'Parzianello', '85504-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19534, 'Londrina', 'José Cavalhieri', 'Dom Pedro I', '86089-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19535, 'Almirante Tamandaré', 'José Cavassin', 'Jardim Maria Luiza', '83514-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19536, 'Colombo', 'José Cavassin', 'Centro', '83414-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19537, 'Curitiba', 'José Cavichiolo', 'Tatuquara', '81940-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19538, 'Toledo', 'José Cazzanatto', 'Panorama', '85911-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19539, 'Curitiba', 'José Cechelero', 'Santo Inácio', '82010-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19540, 'Maringá', 'José Celestino Costa Filho', 'Conjunto Habitacional Santa Felicidade', '87053-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19541, 'Araucária', 'José Celso Batista Bosquet', 'Cachoeira', '83701-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19542, 'Araucária', 'José Cetnarowski', 'Cachoeira', '83701-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19543, 'Curitiba', 'José Chami Sobrinho', 'Pinheirinho', '81870-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19544, 'Araucária', 'José Cheinfert', 'Barigui', '83707-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19545, 'Araucária', 'José Chempeck', 'Barigui', '83707-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19546, 'Almirante Tamandaré', 'José Chevonica', 'Tranqueira', '83514-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19547, 'Apucarana', 'José Chiarelli Filho', 'Residencial Parque da Raposa', '86812-587', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19548, 'Curitiba', 'José Chimanski', 'Umbará', '81930-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19549, 'Campo Largo', 'José Chipanski Filho', 'Vila Bancária', '83601-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19550, 'Curitiba', 'José Choinski', 'Uberaba', '81540-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19551, 'Apucarana', 'José Ciappina', 'Núcleo Habitacional Marcos Freire', '86805-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19552, 'São José dos Pinhais', 'José Claudino Barbosa', 'Afonso Pena', '83040-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19553, 'São José dos Pinhais', 'José Claudino Barbosa', 'Afonso Pena', '83045-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19554, 'Maringá', 'José Clemente', 'Zona 07', '87020-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19555, 'Ponta Grossa', 'José Clemente Pereira', 'Boa Vista', '84070-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19556, 'Curitiba', 'José Clementino Bettega', 'Capão Raso', '81130-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19557, 'Piraquara', 'José Clenck', 'Planta Araçatuba', '83301-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19558, 'Curitiba', 'José Clóvis de Oliveira Weisheimer', 'Cajuru', '82950-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19559, 'Curitiba', 'José Cocconi', 'Bacacheri', '82600-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19560, 'Ponta Grossa', 'José Coimbra', 'Olarias', '84026-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19561, 'Londrina', 'José Colli', 'Jardim Acapulco', '86045-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19562, 'Almirante Tamandaré', 'José Conrado da Silva', 'Jardim Mônica', '83505-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19563, 'Curitiba', 'José Conrado de Souza', 'São Braz', '82300-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19564, 'Colombo', 'José Coradin', 'Jardim Monza', '83406-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19565, 'Piraquara', 'José Cordeiro da Silva', 'Jardim Caiçara', '83314-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19566, 'Paranavaí', 'José Corrêa Farias', 'Vila São Vicente', '87709-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19567, 'São José dos Pinhais', 'José Correia Azeredo', 'Ipê', '83055-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19568, 'Maringá', 'José Correia de Aguiar', 'Jardim Leblon', '87053-276', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19569, 'Foz do Iguaçu', 'José Correia de Lima', 'Parque Residencial Três Bandeiras', '85862-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19570, 'Curitiba', 'José Correia Sérgio', 'Fazendinha', '81320-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19571, 'Curitiba', 'José Correia Tramujas', 'Cidade Industrial', '81230-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19572, 'Cambé', 'José Costa Viana', 'Jardim Tarobá', '86191-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19573, 'Pato Branco', 'José Covaleski', 'Aeroporto', '85503-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19574, 'Piraquara', 'José Cruzetta', 'Planta Santa Clara', '83306-298', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19575, 'Curitiba', 'José Cubas Martins', 'Uberaba', '81590-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19576, 'Curitiba', 'José Culpi', 'Butiatuvinha', '82400-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19577, 'Apucarana', 'José Custódio', 'Vila das Lebres', '86800-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19578, 'Campo Mourão', 'José Custódio de Oliveira', 'Centro', '87301-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19579, 'Campo Mourão', 'José Custódio de Oliveira', 'Centro', '87300-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19580, 'Araucária', 'José Czarnik', 'Costeira', '83708-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19581, 'Paranaguá', 'José da Costa Leite', 'Vila do Povo', '83209-658', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19582, 'Piraquara', 'José da Luz Cavalcanti', 'Vila Franca', '83305-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19583, 'São José dos Pinhais', 'José da Rocha', 'Colônia Rio Grande', '83025-377', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19584, 'Paranaguá', 'José da Rocha Lima', 'Divinéia', '83212-436', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19585, 'Londrina', 'José da Silva', 'Tarobá', '86042-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19586, 'Colombo', 'José da Silva Fontoura', 'Vila Ana Maria', '83413-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19587, 'Londrina', 'José da Silva Paizano', 'Jardim dos Alpes III', '86045-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19588, 'Colombo', 'José da Silva Santos', 'Planta Nodari', '83414-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19589, 'Curitiba', 'José Dal Negro', 'Xaxim', '81720-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19590, 'Toledo', 'José Dal''Bosco', 'Parque Residencial Pancera', '85902-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19591, 'Curitiba', 'José Dallicani', 'Boa Vista', '82560-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19592, 'Pato Branco', 'José Dalmolin', 'Aeroporto', '85503-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19593, 'São José dos Pinhais', 'José Dal''Negro', 'Braga', '83020-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19594, 'Colombo', 'José Dal''Pra', 'Jardim Monte Líbano', '83407-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19595, 'Curitiba', 'José Damarate', 'Santa Felicidade', '82410-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19596, 'Londrina', 'José Damião Bergamo', 'Jardim Bom Pastor', '86082-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19597, 'Londrina', 'José Daniel Kiellander', 'Presidente Vargas', '86083-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19598, 'Londrina', 'José Danielides', 'Conjunto Habitacional  Alexandre Urbanas', '86037-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19599, 'Paranavaí', 'José Dantas de Lima', 'Jardim Ipê', '87707-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19600, 'Cambé', 'José Dario', 'Jardim Tarobá', '86191-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19601, 'Curitiba', 'José Darú', 'Novo Mundo', '81050-636', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19602, 'Curitiba', 'José das Chagas Lima', 'Santa Felicidade', '82020-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19603, 'Londrina', 'José das Neves', 'Jardim Pacaembu', '86079-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19604, 'São José dos Pinhais', 'José de Abreu', 'Guatupê', '83060-546', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19605, 'Londrina', 'José de Alencar', 'Jardim Tatiani', '86070-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19606, 'Foz do Iguaçu', 'José de Alencar', 'Vila Portes', '85865-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19607, 'Francisco Beltrão', 'José de Alencar', 'São Miguel', '85602-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19608, 'Guarapuava', 'José de Alencar', 'Boqueirão', '85023-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19609, 'Laranjeiras do Sul', 'José de Alencar', 'Getúlio Vargas', '85304-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19610, 'Maringá', 'José de Alencar', 'Zona 04', '87014-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19611, 'Paranavaí', 'José de Alencar', 'Jardim São Jorge', '87710-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19612, 'Ponta Grossa', 'José de Alencar', 'Uvaranas', '84025-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19613, 'Pinhais', 'José de Alencar', 'Núcleo Colonial de Pinhais', '83321-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19614, 'Sarandi', 'José de Alencar', 'Novo Panorama', '87113-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19615, 'Toledo', 'José de Alencar', 'Jardim Europa', '85908-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19616, 'Campo Largo', 'José de Alencar', 'Vila Nova', '83605-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19617, 'Colombo', 'José de Alencar', 'Planta Teixeira de Lara', '83409-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19618, 'Curitiba', 'José de Alencar', 'Cristo Rei', '80050-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19619, 'Curitiba', 'José de Alencar', 'Alto da Rua XV', '80040-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19620, 'Curitiba', 'José de Almeida Garrett', 'Portão', '81010-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19621, 'São José dos Pinhais', 'José de Almeida Sobrinho', 'Planta Quississana', '83085-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19622, 'Almirante Tamandaré', 'José de Barros', 'Planta Vila Rica', '83507-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19623, 'Ponta Grossa', 'José de Bortoli', 'Boa Vista', '84071-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19624, 'Curitiba', 'José de Brito', 'Cidade Industrial', '81230-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19625, 'Campo Mourão', 'José de Lima', 'Centro', '87302-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19626, 'Curitiba', 'José de Lima', 'Tingui', '82600-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19627, 'Londrina', 'José de Lima Castro', 'Nova Olinda', '86073-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19628, 'Curitiba', 'José de Mello Braga Júnior', 'Jardim das Américas', '81540-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19629, 'Castro', 'José de Napoli', 'Jardim das Araucárias', '84174-600', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19630, 'Pinhais', 'José de Oliveira', 'Prive Bois de Boulogne', '83330-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19631, 'Campo Mourão', 'José de Oliveira', 'Jardim Fernando', '87305-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19632, 'Ponta Grossa', 'José de Oliveira Franco', 'Chapada', '84062-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19633, 'Curitiba', 'José de Oliveira Franco', 'Bairro Alto', '82840-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19634, 'Curitiba', 'José de Oliveira Franco', 'Bairro Alto', '82820-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19635, 'Curitiba', 'José de Oliveira Rocha', 'Juvevê', '80030-530', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19636, 'Campo Largo', 'José de Paiva Vidal', 'Vila Santa Terezinha', '83602-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19637, 'Curitiba', 'José de Paula Pereira', 'Cajuru', '82930-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19638, 'Londrina', 'José de Paula Sobrinho', 'Gleba Ribeirão Jacutinga', '86087-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19639, 'Cascavel', 'José de Sá Cavalcanti', 'Claudete', '85811-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19640, 'Londrina', 'José de Sousa Peres', 'Residencial Portal do Sol', '86082-795', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19641, 'Colombo', 'José de Souza', 'Jardim Solimões', '83402-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19642, 'Curitiba', 'José de Souza', 'Atuba', '82860-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19643, 'Londrina', 'José de Vasconcellos', 'Aeroporto', '86038-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19644, 'Londrina', 'José Dean', 'Jardim Tropical', '86087-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19645, 'Ponta Grossa', 'José Dechandt', 'Boa Vista', '84072-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19646, 'Londrina', 'José Del Ciel Filho', 'Jardim Imagawa', '86080-780', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19647, 'Ponta Grossa', 'José Delezuk', 'Ronda', '84051-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19648, 'Foz do Iguaçu', 'José Della Pasqua', 'Jardim Panorama II', '85856-566', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19649, 'Cambé', 'José Dellalibera', 'Parque Residencial Ana Rosa', '86183-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19650, 'Curitiba', 'José Demeterco', 'Cajuru', '82900-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19651, 'Londrina', 'José Demétrio Fernades Sola', 'Barbeta', '86078-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19652, 'Londrina', 'José Dias', 'Jardim Marízia I', '86079-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19653, 'Londrina', 'José Dias Aro', 'Vânia', '86025-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19654, 'Colombo', 'José Dias de Camargo', 'Roça Grande', '83401-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19655, 'Umuarama', 'José Dias Lopes', 'Jardim Aratimbó', '87502-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19656, 'Londrina', 'José Dias Trindade', 'Jardim Santa Fé', '86035-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19657, 'Curitiba', 'José Diedsitsch', 'Portão', '81320-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19658, 'Curitiba', 'José Dionísio Ribeiro Baptista', 'Novo Mundo', '81050-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19659, 'Curitiba', 'José do Carmo Neves Filho', 'Umbará', '81930-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19660, 'Foz do Iguaçu', 'José do Patrocínio', 'Vila Portes', '85865-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19661, 'Francisco Beltrão', 'José do Patrocínio', 'São Miguel', '85602-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19662, 'Maringá', 'José do Patrocínio', 'Zona 05', '87015-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19663, 'Ponta Grossa', 'José do Patrocínio', 'Oficinas', '84040-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19664, 'Maringá', 'José do Patrocínio', 'Zona 04', '87014-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19665, 'Toledo', 'José do Patrocínio', 'Jardim Europa', '85908-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19666, 'Toledo', 'José do Patrocínio', 'Jardim Paulista', '85910-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19667, 'São José dos Pinhais', 'José do Patrocínio', 'Afonso Pena', '83050-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19668, 'Cascavel', 'José do Patrocínio', 'Região do Lago 1', '85812-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19669, 'Colombo', 'José do Patrocínio', 'Jardim Central', '83409-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19670, 'Cambé', 'José do Patrocínio', 'Parque Residencial Manela', '86185-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19671, 'Curitiba', 'José do Patrocínio', 'Alto da Glória', '80030-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19672, 'Curitiba', 'José Domakoski', 'Bigorrilho', '80730-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19673, 'Londrina', 'José Domingos de Oliveira', 'Jardim dos Alpes I', '86075-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19674, 'Curitiba', 'José Domingos Marcondes de Carvalho', 'Pilarzinho', '82100-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19675, 'Colombo', 'José Domingues', 'Jardim Nossa Senhora da Penha', '83402-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19676, 'Almirante Tamandaré', 'José Domingues Faria', 'Jardim Alvorada', '83505-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19677, 'Campo Largo', 'José Domingues Pereira', 'Loteamento Ouro Verde I', '83606-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19678, 'Curitiba', 'José Donadello', 'Alto Boqueirão', '81770-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19679, 'Colombo', 'José Donizete Sena', 'Sapopema', '83407-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19680, 'Curitiba', 'José Dorigo', 'Capão Raso', '81110-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19681, 'São José dos Pinhais', 'José Dornelles', 'Afonso Pena', '83050-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19682, 'Guarapuava', 'José dos Santos Andrade', 'Industrial Xarquinho', '85053-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19683, 'Apucarana', 'José dos Santos Lebre', 'Jardim Paraíso', '86807-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19684, 'Curitiba', 'José dos Santos Ribas', 'Sítio Cercado', '81925-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19685, 'Foz do Iguaçu', 'José dos Santos Veiga', 'Jardim Porto Belo', '85867-365', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19686, 'Foz do Iguaçu', 'José dos Santos Vilhordo', 'Conjunto Habitacional Fernanda', '85862-497', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19687, 'Curitiba', 'José Drulla Sobrinho', 'Uberaba', '81550-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19688, 'Umuarama', 'José Duarte Lopes', 'Parque San Caetano', '87506-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19689, 'Curitiba', 'José Duda', 'Cajuru', '82970-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19690, 'Curitiba', 'José Dudek', 'Pinheirinho', '81870-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19691, 'Almirante Tamandaré', 'José Dunainski', 'Jardim Paraíso', '83512-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19692, 'Paranavaí', 'José Ebiner', 'Jardim Ipê', '87706-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19693, 'Apucarana', 'José Egias', 'Vila Social', '86804-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19781, 'Curitiba', 'José Gavioli', 'Fazendinha', '81320-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19694, 'Ponta Grossa', 'José Eleutério dos Santos', 'Jardim Carvalho', '84016-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19695, 'Piraquara', 'José Elizeu Hipólito', 'Centro', '83301-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19696, 'Londrina', 'José Ely Carvalho Grade', 'Lago Juliana', '86038-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19697, 'Sarandi', 'José Emilio de Gusmão', 'Centro', '87111-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19698, 'Ponta Grossa', 'José Epaminondas de Almeida', 'Ronda', '84050-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19699, 'Londrina', 'José Ernâni Neves', 'Jardim Guararapes', '86038-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19700, 'São José dos Pinhais', 'José Estácio Pereira', 'Campina', '83015-610', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19701, 'Almirante Tamandaré', 'José Eudes Cordeiro', 'Vila Pacheco', '83511-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19702, 'Curitiba', 'José Eurípedes Gonçalves', 'Jardim Social', '82520-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19703, 'Maringá', 'José Eustatios Kotsifas', 'Jardim Ivemar', '87065-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19704, 'Londrina', 'José Evanildo Clóvis de Souza', 'Monte Belo', '86041-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19705, 'Curitiba', 'José Fabiano Barcik', 'Cajuru', '82940-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19706, 'Maringá', 'José Fabretti', 'Vila Santo Antônio', '87030-360', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19707, 'Londrina', 'José Fabrini', 'Sabará', '86066-045', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19708, 'Londrina', 'José Faneco', 'Jardim Nova Esperança', '86044-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19709, 'Castro', 'José Fanha', 'Cantagalo', '84178-510', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19710, 'Curitiba', 'José Faria', 'Cidade Industrial', '81170-397', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19711, 'Londrina', 'José Farias', 'Jardim Higienópolis', '86015-105', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19712, 'Londrina', 'José Farias', 'Portal de Versalhes 1', '86057-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19713, 'Curitiba', 'José Faustino Ferro', 'Santa Felicidade', '82400-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19714, 'Apucarana', 'José Fazano Neto', 'Núcleo Habitacional João Goulart', '86807-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19715, 'Campo Largo', 'José Fedalto', 'Loteamento Itaboa', '83605-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19716, 'Colombo', 'José Feitosa', 'Sapopema', '83407-107', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19717, 'Curitiba', 'José Felibrante', 'Cidade Industrial', '81260-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19718, 'Curitiba', 'José Felipe', 'Santo Inácio', '82010-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19719, 'Curitiba', 'José Felipe Meira', 'Cidade Industrial', '81310-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19720, 'Castro', 'José Félix Novaes do Canto e Silva', 'Cantagalo', '84178-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19721, 'Curitiba', 'José Fernandes Alves', 'Uberaba', '81560-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19722, 'São José dos Pinhais', 'José Fernandes Filho', 'Guatupê', '83060-208', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19723, 'Curitiba', 'José Fernandes Maldonado', 'Bairro Alto', '82840-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19724, 'Piraquara', 'José Fernandes Ribeiro', 'Borda do Campo', '83304-427', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19725, 'Apucarana', 'José Ferragine', 'Residencial Parque da Raposa', '86806-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19726, 'Londrina', 'José Ferraz do Prado', 'Santa Rita 1', '86072-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19727, 'Londrina', 'José Ferreira', 'Mazzei', '86015-695', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19728, 'Araucária', 'José Ferreira', 'Estação', '83705-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19729, 'Almirante Tamandaré', 'José Ferreira', 'Planta São Venâncio', '83504-540', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19730, 'Colombo', 'José Ferreira', 'Jardim César Augusto', '83402-280', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19731, 'Curitiba', 'José Ferreira', 'Capão da Imbuia', '82810-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19732, 'Curitiba', 'José Ferreira Barros', 'Fanny', '81030-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19733, 'Cascavel', 'José Ferreira Costa', 'Brasília', '85815-217', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19734, 'Curitiba', 'José Ferreira da Rocha', 'Pinheirinho', '81870-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19735, 'Londrina', 'José Ferreira da Silva', 'Jardim Santa Fé', '86035-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19736, 'Londrina', 'José Ferreira da Silva Filho', 'Universitário', '86050-640', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19737, 'Curitiba', 'José Ferreira da Veiga', 'Cidade Industrial', '81260-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19738, 'Curitiba', 'José Ferreira de Camargo', 'Cidade Industrial', '81350-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19739, 'Ponta Grossa', 'José Ferreira de Menezes', 'Neves', '84020-785', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19740, 'Ponta Grossa', 'José Ferreira de Quadros', 'Colônia Dona Luiza', '84046-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19741, 'Curitiba', 'José Ferreira dos Santos', 'Tarumã', '82530-410', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19742, 'Maringá', 'José Ferreira Maia', 'Vila Esperança', '87020-730', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19743, 'Guarapuava', 'José Ferreira Nunes Bender', 'São Cristóvão', '85060-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19744, 'Curitiba', 'José Ferreira Pinheiro', 'Portão', '80320-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19745, 'Curitiba', 'José Ferreira Vaz', 'Cajuru', '82920-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19746, 'Toledo', 'José Feyr', 'Vila Pioneiro', '85909-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19747, 'Londrina', 'José Fierli', 'Rica', '86025-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19748, 'Curitiba', 'José Fiori', 'Pilarzinho', '82120-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19749, 'Maringá', 'José Firmino Barbosa', 'Jardim Internorte', '87045-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19750, 'Cambé', 'José Firmino de Sales', 'Jardim Tarobá', '86191-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19751, 'Paranavaí', 'José Florindo', 'Jardim Ipê', '87706-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19752, 'Curitiba', 'José Fontana', 'Sítio Cercado', '81925-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19753, 'Londrina', 'José Fortuna', 'Jardim Bandeirantes', '86061-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19754, 'Paranavaí', 'José Fracarolli', 'Jardim Alvorada do Sul', '87707-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19755, 'Paranavaí', 'José Francisco', 'Jardim Belo Horizonte', '87701-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19756, 'Campo Mourão', 'José Francisco da Silva', 'Vila Rio Grande', '87302-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19757, 'Curitiba', 'José Francisco Dalledone', 'São Lourenço', '82200-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19758, 'Apucarana', 'José Francisco Ferreira', 'Jardim Vale do Sol', '86803-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19759, 'Almirante Tamandaré', 'José Francisco Kotoviski', 'Jardim do Norte', '83511-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19760, 'Curitiba', 'José Francisco Leonardi', 'Sítio Cercado', '81925-578', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19761, 'Londrina', 'José Francisco Machado', 'Jardim Oriente', '86035-127', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19762, 'Londrina', 'José Francisco Pereira', 'Jardim Neman Sahyun', '86041-277', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19763, 'Colombo', 'José Franco de Souza', 'Sapopema', '83407-070', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19764, 'Umuarama', 'José Francolin', 'Jardim Canadá', '87505-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19765, 'Pato Branco', 'José Fraron', 'Fraron', '85503-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19766, 'Londrina', 'José Freitas dos Santos', 'Conjunto Residencial Marajoara', '86080-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19767, 'Guarapuava', 'José Freitas Saldanha', 'Morro Alto', '85067-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19768, 'Londrina', 'José Furich', 'Estados', '86083-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19769, 'Londrina', 'José Gabriel de Oliveira', 'Aurora', '86047-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19770, 'Campo Largo', 'José Gabriel Xavier Kuster', 'Jardim Social', '83606-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19771, 'Curitiba', 'José Gadzalinski', 'Uberaba', '81580-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19772, 'Sarandi', 'José Galindo Garcia', 'Jardim Verão', '87111-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19773, 'Cambé', 'José Garbelini', 'Vila Atalaia', '86181-130', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19774, 'Londrina', 'José Garcia Domingues', 'Vale dos Tucanos', '86046-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19775, 'Londrina', 'José Garcia Rodrigues', 'João Paz', '86087-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19776, 'Colombo', 'José Garib', 'Vila Maria do Rosário', '83413-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19777, 'Londrina', 'José Garrido', 'Jardim Marissol', '86030-498', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19778, 'Colombo', 'José Gasparin', 'Fervida', '83415-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19779, 'Curitiba', 'José Gava', 'Pilarzinho', '82115-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19780, 'Almirante Tamandaré', 'José Gavilike', 'Jardim Paraíso', '83512-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19782, 'Francisco Beltrão', 'José Gazola', 'Marrecas', '85601-478', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19783, 'Curitiba', 'José Gelbcke', 'Uberaba', '81590-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19784, 'Londrina', 'José Geraldo Canezin', 'Nova Olinda', '86073-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19785, 'Toledo', 'José Geremias', 'Conjunto Habitacional Britânia', '85903-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19786, 'Cascavel', 'José Germano', 'Maria Luiza', '85819-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19787, 'Curitiba', 'José Gianinni Pancetti', 'Guabirotuba', '81510-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19788, 'Curitiba', 'José Gildo Beleski', 'Tingui', '82620-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19789, 'Curitiba', 'José Giraldi', 'Cajuru', '82920-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19790, 'Londrina', 'José Giraldi', 'Aragarça', '86038-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19791, 'Toledo', 'José Gobbi', 'Conjunto Habitacional São Francisco', '85915-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19792, 'Curitiba', 'José Godoy de Moraes', 'Cidade Industrial', '81460-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19793, 'Paranaguá', 'José Gomes', 'João Gualberto', '83203-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19794, 'Umuarama', 'José Gomes', 'Zona I', '87501-325', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19795, 'Cambé', 'José Gomes', 'Parque Residencial Ana Rosa', '86183-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19796, 'Castro', 'José Gomes Barbosa', 'Vila Santa Cruz', '84168-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19797, 'São José dos Pinhais', 'José Gomes da Rocha', 'São Sebastião', '83075-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19798, 'Curitiba', 'José Gomes de Abreu', 'Capão Raso', '81020-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19799, 'Laranjeiras do Sul', 'José Gomes de Araújo', 'Vila Industrial', '85303-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19800, 'Curitiba', 'José Gomes de Mello', 'Uberaba', '81580-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19801, 'Cambé', 'José Gomes Redondo', 'Parque Residencial Ana Rosa', '86183-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19802, 'Londrina', 'José Gonçalves', 'Jatobá', '86043-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19803, 'Umuarama', 'José Gonçalves', 'Zona VII', '87503-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19804, 'Cambé', 'José Gonçalves', 'Jardim Vitória', '86184-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19805, 'São José dos Pinhais', 'José Gonçalves Bello', 'Miringuava', '83090-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19806, 'Londrina', 'José Gonçalves da Silva', 'Esperança', '86046-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19807, 'Curitiba', 'José Gonçalves Júnior', 'Campo Comprido', '81220-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19808, 'Londrina', 'José Gonçalves Viana Filho', 'Rui Barbosa', '86031-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19809, 'Almirante Tamandaré', 'José Goras', 'Vila Cachoeira', '83504-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19810, 'São José dos Pinhais', 'José Grabias', 'Afonso Pena', '83040-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19811, 'Paranavaí', 'José Gracindo Oliveira', 'Jardim América', '87705-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19812, 'Araucária', 'José Gregório da Silva', 'Tindiquera', '83708-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19813, 'Curitiba', 'José Guercheski', 'Boqueirão', '81730-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19814, 'Pato Branco', 'José Guindani', 'Menino Deus', '85502-095', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19815, 'Maringá', 'José Guiomar', 'Parque das Grevíleas', '87025-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19816, 'Umuarama', 'José Gulart Barbosa', 'Jardim Petrópolis', '87506-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19817, 'Curitiba', 'José Gulin', 'Bacacheri', '82600-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19818, 'Curitiba', 'José Gusso', 'Fazendinha', '81070-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19819, 'Curitiba', 'José Hauer', 'Uberaba', '81580-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19820, 'Curitiba', 'José Hauer', 'Boqueirão', '81730-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19821, 'Londrina', 'José Hélio Luppi', 'San Conrado', '86038-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19822, 'Curitiba', 'José Hella', 'Vista Alegre', '82100-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19823, 'São José dos Pinhais', 'José Henrique de Santa Ritta', 'São Sebastião', '83075-089', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19824, 'Apucarana', 'José Henrique Machado', 'Vila Operária 2', '86802-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19825, 'Cascavel', 'José Hermito de Sá', 'Santa Felicidade', '85803-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19826, 'Francisco Beltrão', 'José Hollmann', 'Sadia', '85606-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19827, 'Londrina', 'José Horácio', 'Conjunto Novo Amparo', '86087-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19828, 'Araucária', 'José Huttner', 'Fazenda Velha', '83703-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19829, 'Maringá', 'José Iba', 'Parque das Grevíleas', '87025-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19830, 'Londrina', 'José Ignacio Marques', 'Andes', '86076-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19831, 'Apucarana', 'José Inácio Filho', 'Jardim Nova América', '86807-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19832, 'Curitiba', 'José Inácio Xavier', 'Pinheirinho', '81870-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19833, 'Londrina', 'José Inez Furtado', 'Conjunto Residencial Nova Perobal', '86043-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19834, 'Curitiba', 'José Ingenieros', 'Vista Alegre', '82100-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19835, 'Londrina', 'José Irineu Vicentini', 'Santa Mônica', '86079-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19836, 'Curitiba', 'José Iunke', 'Boqueirão', '81730-170', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19837, 'São José dos Pinhais', 'José Ivahi Camargo', 'Braga', '83020-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19838, 'Curitiba', 'José Izidoro Biazetto', 'Mossunguê', '81200-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19839, 'Curitiba', 'José Izidoro Filho', 'Pilarzinho', '82115-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19840, 'São José dos Pinhais', 'José Jachinski', 'Miringuava', '83090-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19841, 'Colombo', 'José Januário da Silva', 'Jardim Iracema', '83403-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19842, 'Piraquara', 'José Jardelino de Brito', 'Planta Araçatuba', '83301-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19843, 'Curitiba', 'José João Ferreira de Lima', 'Cidade Industrial', '81170-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19844, 'São José dos Pinhais', 'José João Gabardo', 'Guatupê', '83060-036', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19845, 'Toledo', 'José João Muraro', 'Centro', '85900-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19846, 'Toledo', 'José João Muraro', 'Jardim Porto Alegre', '85906-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19847, 'São José dos Pinhais', 'José João Rodrigues', 'Guatupê', '83060-196', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19848, 'Ponta Grossa', 'José Joaquim da Maia', 'Oficinas', '84036-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19849, 'Curitiba', 'José Joaquim Ferreira', 'Atuba', '82840-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19850, 'Curitiba', 'José Joaquim Ferreira', 'Cidade Industrial', '81460-328', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19851, 'Londrina', 'José Joaquim Lima', 'Parigot de Souza 2', '86082-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19852, 'Ponta Grossa', 'José Joaquim Seabra', 'Olarias', '84035-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19853, 'Curitiba', 'José Joaquim Teixeira', 'Portão', '81070-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19854, 'Apucarana', 'José Jorge', 'Jardim Presidente Kennedy', '86809-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19855, 'Maringá', 'José Jorge Abraão', 'Zona 05', '87015-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19856, 'Londrina', 'José Jorge Chedid', 'Residencial Moradias Tibagi', '86080-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19857, 'Londrina', 'José Juliani', 'São Pedro', '86036-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19858, 'Curitiba', 'José Juliano Ayres', 'Alto Boqueirão', '81770-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19859, 'Curitiba', 'José Júlio Biscaia', 'Portão', '80330-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19860, 'Araucária', 'José Júlio Bueno', 'Costeira', '83708-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19861, 'Curitiba', 'José Júlio Tortato', 'Campo de Santana', '81940-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19862, 'Curitiba', 'José Kalil', 'Cidade Industrial', '81315-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19863, 'Ponta Grossa', 'José Kalinoski', 'Contorno', '84060-160', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19864, 'Curitiba', 'José Kalinowski', 'Bom Retiro', '80520-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19865, 'Colombo', 'José Kamaroski', 'Jardim Magnópolis', '83403-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19866, 'Curitiba', 'José Kaminski', 'Novo Mundo', '81050-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19867, 'Araucária', 'José Karas', 'Thomaz Coelho', '83707-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19868, 'Almirante Tamandaré', 'José Kleina', 'Planta Almirante', '83508-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19869, 'Curitiba', 'José Klisievicz', 'Campina do Siqueira', '80740-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19870, 'Curitiba', 'José Kloss', 'Água Verde', '80620-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19871, 'Curitiba', 'José Knopfholz', 'Centro Cívico', '80030-040', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19872, 'Piraquara', 'José Komadowski', 'Planta Vila Iraí', '83302-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19873, 'Curitiba', 'José Kormann', 'Ahú', '82200-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19874, 'Curitiba', 'José Krefta', 'Alto Boqueirão', '81770-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19875, 'Curitiba', 'José Krenchiclova', 'Tatuquara', '81480-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19876, 'Araucária', 'José Kudlaviec', 'Centro', '83702-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19877, 'Curitiba', 'José Kuester', 'Jardim das Américas', '81530-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19878, 'Curitiba', 'José Kulik', 'Portão', '80330-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19879, 'Pinhais', 'José Kuss', 'Conjunto Residencial Áquila', '83326-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19880, 'Paranaguá', 'José L. Pinto', 'Ponta do Caju', '83203-136', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19881, 'Telêmaco Borba', 'José Lacerda', 'Área 07', '84267-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19882, 'Curitiba', 'José Lacerda Júnior', 'Cidade Industrial', '81170-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19883, 'Toledo', 'José Langer', 'Conjunto Habitacional São Francisco', '85912-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19884, 'Curitiba', 'José Lass', 'Cascatinha', '82020-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19885, 'Londrina', 'José Lázaro de Gouvea', 'Cambezinho', '86040-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19886, 'Araucária', 'José Leal de Oliveira', 'Thomaz Coelho', '83706-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19887, 'Colombo', 'José Leal Fontoura', 'Centro', '83414-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19888, 'Piraquara', 'José Leal Júnior', 'Vila Rosa', '83304-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19889, 'Araucária', 'José Leal Pereira', 'Costeira', '83709-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19890, 'Umuarama', 'José Leite da Silva', 'Conjunto Residencial Porto Belo', '87506-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19891, 'Londrina', 'José Leite de Carvalho', 'Lilian', '86015-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19892, 'Paranaguá', 'José Leite de Farias', 'Itiberê', '83206-357', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19893, 'Pinhais', 'José Leite de Souza', 'Moradias Perdizes', '83326-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19894, 'Araucária', 'José Lemos', 'Thomaz Coelho', '83707-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19895, 'Pato Branco', 'José Leonardi', 'Aeroporto', '85503-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19896, 'Maringá', 'José Leônidas Nerone', 'Jardim Andrade', '87035-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19897, 'Cambé', 'José Leopoldino Rossi', 'Jardim Vila Rica', '86192-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19898, 'Laranjeiras do Sul', 'José Levandoski', 'Centro', '85301-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19899, 'Laranjeiras do Sul', 'José Levandoski', 'Centro', '85301-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19900, 'Guarapuava', 'José Linhares', 'Boqueirão', '85020-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19901, 'Foz do Iguaçu', 'José Linhares', 'Parque Presidente', '85863-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19902, 'Pinhais', 'José Linhares', 'Vila Amélia', '83330-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19903, 'Londrina', 'José Linhares', 'Hedy', '86062-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19904, 'Telêmaco Borba', 'José Linhares', 'Alto das Oliveiras', '84266-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19905, 'Cascavel', 'José Linhares', 'Presidente', '85818-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19906, 'Guarapuava', 'José Lins do Rego', 'Boqueirão', '85020-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19907, 'Francisco Beltrão', 'José Lins do Rego', 'São Miguel', '85602-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19908, 'Foz do Iguaçu', 'José Lins do Rego', 'Jardim Jupira', '85865-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19909, 'Maringá', 'José Lins do Rego', 'Vila Esperança', '87020-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19910, 'Ponta Grossa', 'José Lins do Rego', 'Chapada', '84062-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19911, 'Campo Largo', 'José Lins do Rego', 'São Marcos', '83602-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19912, 'Colombo', 'José Lins do Rego', 'Vila Petrópolis', '83409-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19913, 'Curitiba', 'José Lins do Rego', 'Bairro Alto', '82820-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19914, 'Curitiba', 'José Lírio da Silva', 'Pilarzinho', '82115-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19915, 'Francisco Beltrão', 'José Lopes', 'São Miguel', '85602-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19916, 'Apucarana', 'José Lopes de Oliveira', 'Jardim Catuaí III', '86802-638', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19917, 'Almirante Tamandaré', 'José Lopes dos Santos', 'Jardim Giannini', '83511-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19918, 'Curitiba', 'José Lopes dos Santos', 'Santo Inácio', '82300-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19919, 'Curitiba', 'José Loureiro', 'Centro', '80010-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19920, 'São José dos Pinhais', 'José Lourenço da Rocha', 'Colônia Rio Grande', '83025-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19921, 'Curitiba', 'José Lucas', 'Jardim das Américas', '81540-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19922, 'Cambé', 'José Lucas Pinheiro Filho', 'Jardim Vila Rica', '86191-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19923, 'São José dos Pinhais', 'José Luciano', 'Braga', '83020-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19924, 'Curitiba', 'José Luis Pontes', 'Cidade Industrial', '81350-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19925, 'Ponta Grossa', 'José Luiz', 'Colônia Dona Luiza', '84045-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19926, 'Londrina', 'José Luiz Andrade', 'Conjunto Habitacional Saltinho', '86042-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19927, 'Londrina', 'José Luiz Barbosa', 'Espírito Santo', '86073-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19928, 'São José dos Pinhais', 'José Luiz da Cunha', 'Planta Quississana', '83085-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19929, 'Apucarana', 'José Luiz da Silva', 'Vila Brasil', '86800-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19930, 'Londrina', 'José Luiz de Oliveira', 'Jardim dos Alpes II', '86075-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19931, 'Curitiba', 'José Luiz Demeterco', 'São Francisco', '80510-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19932, 'Curitiba', 'José Luiz Franceschi', 'Sítio Cercado', '81910-195', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19933, 'Curitiba', 'José Luiz Oberik Roberto', 'Cidade Industrial', '81250-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19934, 'Maringá', 'José Luiz Pereira', 'Jardim Andrade', '87035-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19935, 'Sarandi', 'José Luiz Pereira', 'Jardim Nova Independência I', '87114-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19936, 'Paranaguá', 'José Luiz Pontes', 'Parque São João', '83212-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19937, 'Colombo', 'José Luiz Rausis', 'Vila Maria do Rosário', '83413-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19938, 'Curitiba', 'José Luiz Rissardi', 'Pilarzinho', '80520-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19939, 'Ponta Grossa', 'José Luiz Trujillo de Freitas', 'Uvaranas', '84030-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19940, 'Campo Largo', 'José Lunardon', 'Vila Ferrari II', '83606-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19941, 'Curitiba', 'José Lunardon', 'Cidade Industrial', '81305-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19942, 'Curitiba', 'José Luvizotti', 'Alto da Rua XV', '80050-080', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19943, 'Castro', 'José Macedo Dantas', 'Cantagalo', '84178-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19944, 'Ponta Grossa', 'José Machado de Oliveira', 'Ronda', '84052-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19945, 'Almirante Tamandaré', 'José Machado Vaz', 'Vila Primor', '83507-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19946, 'Curitiba', 'José Malinowski Sobrinho', 'Cachoeira', '82710-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19947, 'Apucarana', 'José Manoel de Oliveira', 'Jardim Trabalhista', '86807-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19948, 'Londrina', 'José Manoel Ruiz', 'Conjunto Residencial Itamaraty', '86076-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19949, 'Curitiba', 'José Manoel Voluz', 'Pinheirinho', '81870-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19950, 'Curitiba', 'José Mansur', 'Barreirinha', '82540-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19951, 'Apucarana', 'José Manzano', 'Núcleo Habitacional José Mercadante', '86804-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19952, 'Maringá', 'José Marasca Filho', 'Parque Industrial Bandeirantes', '87070-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19953, 'Londrina', 'José Marcantonio', 'Residencial José Lázaro Gouvea', '86050-759', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19954, 'Curitiba', 'José Marcassa', 'Xaxim', '81810-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19955, 'Piraquara', 'José Marcelino Artigas', 'Vila Juliana', '83306-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19956, 'Paranaguá', 'José Marcelo de Moura', 'Vila do Caic', '83215-686', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19957, 'Apucarana', 'José Marchiori', 'Jardim Presidente Kennedy', '86809-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19958, 'Francisco Beltrão', 'José Marcon', 'Jardim Novo Mundo', '85602-758', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19959, 'Curitiba', 'José Marcos Caldonazo', 'Cajuru', '82980-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19960, 'São José dos Pinhais', 'José Marek', 'Afonso Pena', '83045-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19961, 'Londrina', 'José Maria Aranda', 'San Conrado', '86038-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19962, 'Curitiba', 'José Maria Braga Munhoz da Rocha', 'São Lourenço', '82200-610', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19963, 'Londrina', 'José Maria da Costa', 'Parque Residencial Campos Elísios', '86044-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19964, 'Londrina', 'José Maria da Silva Paranhos', 'Itamarati', '86061-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19965, 'Colombo', 'José Maria da Silva Paranhos', 'Jardim Quitandinha', '83409-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19966, 'Curitiba', 'José Maria de Barros Faria', 'Cidade Industrial', '81280-146', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19967, 'Foz do Iguaçu', 'José Maria de Brito', 'Jardim das Nações', '85864-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19968, 'Foz do Iguaçu', 'José Maria de Brito', 'Jardim Central', '85863-730', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19969, 'Londrina', 'José Maria de Mello Carvalho', 'Colinas', '86056-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19970, 'Londrina', 'Jose Maria de Oliveira', 'Conjunto Residencial Santa Rita V', '86072-507', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19971, 'Araucária', 'José Maria dos Anjos', 'Capela Velha', '83705-795', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19972, 'São José dos Pinhais', 'José Maria Garcia', 'Rio Pequeno', '83085-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19973, 'Curitiba', 'José Maria Marengo Bonetti', 'Santa Felicidade', '82410-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19974, 'Londrina', 'José Maria Pereira', 'Conjunto Vivi Xavier', '86082-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19975, 'Londrina', 'José Maria Perez', 'Aquilles Sthengel', '86086-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19976, 'Curitiba', 'José Maria Pinheiro Lima', 'Xaxim', '81810-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19977, 'Apucarana', 'José Maria Pinto', 'Núcleo Bandeirantes', '86812-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19978, 'Araucária', 'José Maria Rodrigues', 'Estação', '83705-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19979, 'Foz do Iguaçu', 'José Maria Tavares', 'Alto São Francisco', '85863-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19980, 'Paranavaí', 'José Maria Tenório', 'Vila Prudêncio', '87702-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19981, 'Apucarana', 'José Maria Verdasca', 'Parque Bela Vista', '86803-520', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19982, 'Curitiba', 'José Maria Wabeski', 'São João', '82030-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19983, 'Paranaguá', 'José Maria Whitaker', 'Raia', '83206-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19984, 'Paranaguá', 'José Mariano Alves', 'Jardim Guaraituba', '83209-296', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19985, 'Pinhais', 'José Mariano dos Santos', 'Vila Tarumã', '83323-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19986, 'Londrina', 'José Marinho', 'Conjunto Residencial Nova Perobal', '86043-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19987, 'Almirante Tamandaré', 'José Mário da Silva', 'Vila Tefé', '83503-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19988, 'Curitiba', 'José Mário de Oliveira', 'Bacacheri', '82520-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19989, 'Telêmaco Borba', 'José Mário Moreira', 'Jardim Bom Jesus', '84262-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19990, 'Araucária', 'José Marques', 'Thomaz Coelho', '83706-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19991, 'Curitiba', 'José Marques da Cunha', 'Umbará', '81930-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19992, 'Araucária', 'José Marszalek', 'Thomaz Coelho', '83707-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19993, 'Curitiba', 'José Martim', 'Mossunguê', '81200-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19994, 'Piraquara', 'José Martinez Cano', 'Planta Granjas Eldorado', '83309-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19995, 'Curitiba', 'José Martinho Lissa', 'Mossunguê', '81210-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19996, 'Telêmaco Borba', 'José Martins', 'Vila São Francisco de Assis', '84264-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19997, 'Londrina', 'José Martins de Oliveira', 'Arthur Thomas', '86031-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19998, 'Maringá', 'José Martins de Oliveira', 'Vila Progresso', '87080-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (19999, 'Paranaguá', 'José Martins do Carmo', 'Bockmann', '83206-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20000, 'Londrina', 'José Martins Gomes', 'Taliana', '86035-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20001, 'Sarandi', 'Jose Martins Mochi', 'Parque Industrial IV', '87111-678', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20002, 'Laranjeiras do Sul', 'José Martins Pavlak', 'São Francisco', '85303-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20003, 'Sarandi', 'José Martins Valente', 'Parque Industrial IV', '87111-677', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20004, 'Londrina', 'José Mateus de Souza', 'Conjunto Habitacional João Turquino', '86056-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20005, 'São José dos Pinhais', 'José Mauri Zen', 'Bom Jesus', '83025-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20006, 'Ponta Grossa', 'José Maurício', 'Uvaranas', '84025-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20007, 'Londrina', 'José Maurício Barroso', 'Conjunto Habitacional Saltinho', '86042-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20008, 'Londrina', 'José Maurício da Silva', 'Oscavo Santos', '86079-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20009, 'São José dos Pinhais', 'José Maurílio da Cruz', 'Boneca do Iguaçu', '83040-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20010, 'Londrina', 'José Mauro Orceli', 'Jamile Dequech', '86048-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20011, 'Umuarama', 'José Mauro Roveron', 'Jardim San Rafael', '87508-158', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20012, 'Curitiba', 'José Mayanet', 'Bom Retiro', '80520-490', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20013, 'Curitiba', 'José Mayer', 'Sítio Cercado', '81925-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20014, 'Curitiba', 'José Mazepa', 'Bacacheri', '82600-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20015, 'Castro', 'José Mazzine Galetto', 'Vila Frei Mathias', '84165-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20016, 'Londrina', 'José Mendes da Silva', 'Residencial Abussafe', '86037-758', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20017, 'Curitiba', 'José Mendes Sobrinho', 'Cidade Industrial', '81350-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20018, 'Foz do Iguaçu', 'José Menezes', 'Jardim Guarapuava II', '85856-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20019, 'Guarapuava', 'José Merchiori', 'Industrial Xarquinho', '85053-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20020, 'Curitiba', 'José Merhy', 'Boa Vista', '82560-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20021, 'Curitiba', 'José Merhy', 'Boa Vista', '82540-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20022, 'Paranaguá', 'José Merino', 'Parque São João', '83212-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20023, 'Ponta Grossa', 'José Miara', 'Orfãs', '84015-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20024, 'Curitiba', 'José Michna Filho', 'Orleans', '82310-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20025, 'Londrina', 'José Miguel', 'Jardim Alto do Cafezal', '86049-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20026, 'Londrina', 'José Miguel Arias', 'San Fernando', '86040-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20027, 'Curitiba', 'José Miguel dos Santos', 'São Braz', '82015-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20028, 'Colombo', 'José Milani', 'Jardim das Flores', '83402-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20029, 'Almirante Tamandaré', 'José Milek Filho', 'Vila Feliz', '83505-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20030, 'Curitiba', 'José Milleck', 'Boa Vista', '82560-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20031, 'Campo Largo', 'José Miotto', 'Vila Bancária', '83601-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20032, 'Curitiba', 'José Miranda de Castro', 'Portão', '80330-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20033, 'Apucarana', 'José Miskowski', 'Vila Residencial Malibu', '86812-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20034, 'Curitiba', 'José Molenda', 'Xaxim', '81820-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20035, 'Londrina', 'José Monteiro de Mello', 'Jardim do Lago', '86050-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20036, 'Londrina', 'José Montier', 'Santiago', '86071-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20037, 'Curitiba', 'José Morais', 'Pilarzinho', '82110-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20038, 'Maringá', 'José Moreno Júnior', 'Jardim Aclimação', '87050-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20039, 'Curitiba', 'José Muggiati Sobrinho', 'Abranches', '82130-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20040, 'Curitiba', 'José Mulaski Gebert', 'Tatuquara', '81480-327', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20041, 'Londrina', 'José Munhoz', 'Santa Izabel', '86031-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20042, 'Sarandi', 'José Munhoz', 'Jardim Castelo', '87112-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20043, 'Sarandi', 'José Munhoz', 'Centro', '87111-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20044, 'Colombo', 'José Nadolny', 'Jardim Marambaia', '83404-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20045, 'Curitiba', 'José Nassar', 'Cajuru', '82920-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20046, 'Curitiba', 'José Naves da Cunha', 'Seminário', '80310-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20047, 'Londrina', 'José Negri', 'Jardim Neman Sahyun', '86041-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20048, 'Londrina', 'José Neri de Santana', 'Conjunto Semiramis Barros Braga', '86088-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20049, 'Piraquara', 'José Nestor de Campos', 'Vila Susi', '83304-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20050, 'Sarandi', 'José Neves', 'Vera Cruz', '87111-768', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20051, 'Curitiba', 'José Nicco', 'Mossunguê', '81200-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20052, 'Curitiba', 'José Nicolau Abage', 'Bigorrilho', '80430-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20053, 'Curitiba', 'José Nicolletti', 'Ahú', '82200-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20054, 'Curitiba', 'José Noga', 'Alto Boqueirão', '81850-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20055, 'Curitiba', 'José Nogarolli', 'Mercês', '80710-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20056, 'São José dos Pinhais', 'José Nogueira', 'Costeira', '83015-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20057, 'Londrina', 'José Nogueira Franco', 'Parque Residencial Alcântara', '86047-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20058, 'São José dos Pinhais', 'José Nonato Filho', 'Guatupê', '83060-097', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20059, 'Foz do Iguaçu', 'José Nunes de Farias', 'Vila Itajubá', '85852-160', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20060, 'São José dos Pinhais', 'José Nunes Pacheco', 'Afonso Pena', '83050-127', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20061, 'Londrina', 'José Oiticica', 'Los Angeles', '86060-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20062, 'Londrina', 'José Olavo Leles', 'Conjunto Novo Amparo 2', '86056-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20063, 'Maringá', 'José Olympio da Silva', 'Jardim Licce', '87025-648', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20064, 'Umuarama', 'José Onofrio Ramos', 'Zona II', '87502-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20065, 'Curitiba', 'José Opolz', 'Pilarzinho', '82100-705', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20066, 'Curitiba', 'José Osires Baglioli', 'Pinheirinho', '81820-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20067, 'Guarapuava', 'José Pacheco', 'Morro Alto', '85067-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20068, 'Londrina', 'José Pagliarini', 'Cafezal 1', '86049-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20069, 'Londrina', 'José Paiva Cavalcante', 'Santa Izabel', '86031-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20070, 'Curitiba', 'José Palu', 'Novo Mundo', '81020-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20071, 'São José dos Pinhais', 'José Pampuh', 'Braga', '83020-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20072, 'Curitiba', 'José Paschoal Paula', 'Barreirinha', '82560-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20073, 'Toledo', 'José Pasqualli', 'Jardim Pasqualli', '85905-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20074, 'São José dos Pinhais', 'José Pedro Andriguetto', 'Águas Belas', '83040-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20075, 'Maringá', 'José Pedro de Miranda', 'Vila Esperança', '87020-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20076, 'Cambé', 'José Pedro de Souza', 'Jardim Flórida', '86182-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20077, 'Londrina', 'José Pedro Garcia Lopes', 'Conjunto Novo Amparo', '86087-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20078, 'Ponta Grossa', 'José Pedro Moreira', 'Ronda', '84050-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20079, 'Pinhais', 'José Pedro Porto', 'Moradias Palmital', '83325-609', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20080, 'Araucária', 'José Pedro Saad', 'Thomaz Coelho', '83707-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20081, 'Guarapuava', 'José Pedro Seleme', 'Cascavel', '85025-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20082, 'Ponta Grossa', 'José Pedro Silveira Godoy Gomes', 'Boa Vista', '84073-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20083, 'Londrina', 'José Pegoraro', 'Londrina', '86060-315', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20084, 'Curitiba', 'José Peixoto de Lacerda Wernek', 'Boqueirão', '81650-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20085, 'Curitiba', 'José Pellanda', 'Umbará', '81940-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20086, 'Curitiba', 'José Percival Sobrinho', 'Pinheirinho', '81880-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20087, 'Maringá', 'José Pereira da Costa', 'Vila Marumby', '87005-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20088, 'Curitiba', 'José Pereira de Araújo', 'Capão Raso', '81130-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20089, 'Campo Largo', 'José Pereira de Lima', 'Jardim Florestal', '83602-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20090, 'São José dos Pinhais', 'José Pereira do Valle Filho', 'Cidade Jardim', '83035-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20091, 'Curitiba', 'José Pereira dos Anjos', 'Cidade Industrial', '81270-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20092, 'Londrina', 'José Pereira dos Santos', 'Conjunto Habitacional José Giordano', '86082-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20093, 'Paranaguá', 'José Pereira dos Santos Andrade', 'Vila Paranaguá', '83221-015', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20094, 'Cambé', 'José Peres Filho', 'Jardim Tarobá', '86191-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20095, 'Araucária', 'José Perini', 'Estação', '83705-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20096, 'Curitiba', 'José Perussi', 'Butiatuvinha', '82400-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20097, 'Curitiba', 'José Petroski', 'Xaxim', '81710-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20098, 'Londrina', 'José Pezarini', 'Conjunto Habitacional  Alexandre Urbanas', '86037-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20099, 'Castro', 'José Pianowski', 'Cantagalo', '84178-430', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20100, 'Ponta Grossa', 'José Pierri', 'Chapada', '84062-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20101, 'Londrina', 'José Pilla', 'Jardim Alto do Cafezal', '86049-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20102, 'Londrina', 'José Piloto', 'Jardim Maracanã', '86056-866', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20103, 'São José dos Pinhais', 'José Pinto da Rocha', 'Campina', '83015-146', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20104, 'Curitiba', 'José Pinto Novaes', 'Bacacheri', '82600-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20105, 'Londrina', 'José Pirola', 'Residencial Vila Romana', '86031-817', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20106, 'Londrina', 'José Pivetta', 'Vale das Araucárias', '86047-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20107, 'Guarapuava', 'José Podolan', 'Primavera', '85050-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20108, 'Paranaguá', 'José Policarpo Ribeiro', 'Vila do Caic', '83215-685', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20109, 'Londrina', 'José Ponciano de Oliveira', 'Ponte Seca', '86042-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20110, 'Paranavaí', 'José Porto', 'Jardim Ipê', '87707-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20111, 'Ponta Grossa', 'José Primor', 'Uvaranas', '84031-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20112, 'Curitiba', 'José Prussak', 'Sítio Cercado', '81900-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20113, 'Londrina', 'José Puralise', 'Residencial José Lázaro Gouvea', '86050-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20114, 'Sarandi', 'José Raimundo de Magalhães', 'Jardim Europa', '87111-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20115, 'Curitiba', 'José Raksa', 'Capão Raso', '81130-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20116, 'Cambé', 'José Ramineli', 'Jardim José Favaro', '86183-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20117, 'Apucarana', 'José Ramon Sanches', 'Jardim Flamingos', '86811-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20118, 'Colombo', 'José Ramos', 'Jardim Las Palmas', '83409-158', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20119, 'Apucarana', 'José Ramos de Oliveira', 'Jardim Eldorado', '86802-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20120, 'Guarapuava', 'José Raul Capablanca', 'São Cristóvão', '85060-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20121, 'Almirante Tamandaré', 'José Real Prado', 'Jardim Campo Verde', '83502-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20122, 'Almirante Tamandaré', 'José Real Prado', 'Jardim São Francisco', '83501-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20123, 'Curitiba', 'José Rebelato', 'Xaxim', '81710-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20124, 'Curitiba', 'José Rechetello', 'Cidade Industrial', '81460-226', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20125, 'Londrina', 'José Reinaldo Zani', 'Residencial José Lázaro Gouvea', '86050-758', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20126, 'Campo Largo', 'José Reni Andrade dos Santos', 'Cercadinho', '83608-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20127, 'Curitiba', 'José Renno Pereira Filho', 'Boqueirão', '81670-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20128, 'Apucarana', 'José Rezende', 'Loteamento Jardim Gramados', '86801-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20129, 'Curitiba', 'José Ribeiro Baptista', 'Campo de Santana', '81490-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20130, 'Curitiba', 'José Ribeiro de Cristo', 'Pilarzinho', '82115-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20131, 'Curitiba', 'José Ribeiro de Macedo Júnior', 'Jardim Social', '82520-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20132, 'São José dos Pinhais', 'José Ribeiro de Paula', 'Ipê', '83055-528', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20133, 'Campo Mourão', 'José Ribeiro Filho', 'Jardim Ana Eliza', '87303-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20134, 'Almirante Tamandaré', 'José Ribeiro Filho', 'Vila Formosa', '83506-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20135, 'Araucária', 'José Ribinski', 'Tindiquera', '83708-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20136, 'São José dos Pinhais', 'José Ricardo Ferreira', 'Ipê', '83055-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20137, 'Londrina', 'José Ricardo Vechia', 'Aragarça', '86038-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20138, 'Paranaguá', 'José Rieira Filho', 'Jardim Araçá', '83221-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20139, 'Curitiba', 'José Rietmeyer', 'Guabirotuba', '81510-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20140, 'Curitiba', 'José Rissato', 'Capão da Imbuia', '82800-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20141, 'Curitiba', 'José Risseto', 'Santa Felicidade', '82015-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20142, 'Apucarana', 'José Riva', 'Jardim Espanha', '86802-017', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20143, 'Campo Largo', 'José Rivabem', 'Vila Bancária', '83601-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20144, 'Campo Largo', 'José Robacker', 'Vila Otto', '83607-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20145, 'Londrina', 'José Roberto Barion', 'Jardim Santa Fé', '86035-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20146, 'Londrina', 'José Roberto Buck', 'Jardim Nova Esperança', '86044-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20147, 'Paranavaí', 'José Roberto da Silva Arrais', 'Jardim Campo Belo', '87711-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20148, 'Umuarama', 'José Roberto Janeiro', 'Jardim Petrópolis', '87506-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20149, 'Campo Mourão', 'José Roberto Rodrigues', 'Jardim Modelo', '87309-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20150, 'Curitiba', 'José Roberto Wachelke', 'Augusta', '81260-556', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20151, 'Pinhais', 'José Rocha', 'Moradias Perdizes', '83326-718', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20152, 'Pato Branco', 'José Rodrigues', 'Cristo Rei', '85506-266', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20153, 'Apucarana', 'José Rodrigues de Almeida', 'Loteamento Belvedere', '86813-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20154, 'Londrina', 'José Rodrigues Martins', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-530', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20155, 'Laranjeiras do Sul', 'José Rodrigues Medina', 'São Francisco', '85303-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20156, 'Curitiba', 'José Rodrigues Pinheiro', 'Capão Raso', '81130-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20157, 'Curitiba', 'José Rodrigues Pinheiro', 'Cidade Industrial', '81170-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20158, 'Pato Branco', 'José Rodrigues Pinto', 'Sambugaro', '85502-470', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20159, 'Curitiba', 'José Romano', 'Atuba', '82630-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20160, 'Londrina', 'José Romeiro Merllos', 'Ernani de Moura Lima', '86037-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20161, 'Campo Largo', 'José Rompkowski', 'Jardim Guarany I', '83608-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20162, 'Cambé', 'José Rosa de Oliveira', 'Jardim José Favaro', '86183-777', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20163, 'Maringá', 'José Rosa dos Santos', 'Copacabana Residencial', '87023-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20164, 'Francisco Beltrão', 'José Rosin', 'Água Branca', '85601-333', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20165, 'Londrina', 'José Rossafa Garcia', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20166, 'Curitiba', 'José Rossetin', 'Santo Inácio', '82300-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20167, 'Curitiba', 'José Rúbens de Lima', 'São Braz', '82315-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20168, 'Londrina', 'José Ruzzon', 'Jardim Bom Pastor', '86082-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20169, 'Campo Largo', 'José Sabim', 'Itaqui de Cima', '83605-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20170, 'Curitiba', 'José Sabóia Cortes', 'Centro Cívico', '80530-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20171, 'Apucarana', 'José Salido', 'Núcleo Habitacional João Goulart', '86807-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20172, 'Campo Largo', 'José Salles Pinto', 'Bom Jesus', '83601-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20173, 'Ponta Grossa', 'José Salles Rosa', 'Olarias', '84032-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20174, 'Apucarana', 'José Salvador Pelissari', 'Núcleo Habitacional Djalma Mendes de Oliveira', '86806-547', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20175, 'Londrina', 'José Samartano', 'Conjunto Parigot de Souza 1', '86081-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20176, 'Cascavel', 'José Sampaio Xavier', 'Santa Felicidade', '85803-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20177, 'Curitiba', 'José Sanson', 'São Lourenço', '82210-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20178, 'Londrina', 'José Santa Ella', 'Jardim Delta', '86065-825', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20179, 'Apucarana', 'José Santana Figueiredo', 'Núcleo Habitacional Heitor S Pinheiro', '86806-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20180, 'Londrina', 'José Santiago de Queiroz', 'Tarobá', '86042-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20181, 'Curitiba', 'José Santiago Paladino', 'Santa Felicidade', '82015-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20182, 'São José dos Pinhais', 'José Sary', 'Braga', '83020-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20183, 'Curitiba', 'José Scrickte', 'Cascatinha', '82020-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20184, 'São José dos Pinhais', 'José Scrobot Sobrinho', 'Colônia Murici', '83085-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20185, 'Curitiba', 'José Scroccaro', 'Umbará', '81930-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20186, 'Curitiba', 'José Scuissiato', 'Seminário', '80740-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20187, 'Curitiba', 'José Sebastião Baltazar', 'Cidade Industrial', '81260-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20188, 'Curitiba', 'José Seixas', 'Sítio Cercado', '81920-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20189, 'Araucária', 'José Senegaglia', 'Centro', '83702-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20190, 'Sarandi', 'José Senhorini', 'Vera Cruz', '87111-757', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20191, 'Curitiba', 'José Sens', 'Xaxim', '81830-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20192, 'Curitiba', 'José Serrato', 'Santa Cândida', '82640-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20193, 'Colombo', 'José Sgoda', 'Santa Gema', '83407-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20194, 'Curitiba', 'José Sigismundo Vendramin', 'Santa Felicidade', '82320-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20195, 'Curitiba', 'José Sikora', 'Portão', '81070-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20196, 'Curitiba', 'José Sikorski', 'Santo Inácio', '82010-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20197, 'Curitiba', 'José Silva de Lima', 'Capão Raso', '81150-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20198, 'Londrina', 'José Silva Sá', 'Conjunto Semiramis Barros Braga', '86088-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20199, 'Colombo', 'José Simioni', 'Planta Folloni', '83413-520', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20200, 'Guarapuava', 'José Siqueira de Campos', 'Conradinho', '85060-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20201, 'Araucária', 'José Skraba', 'Boqueirão', '83704-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20202, 'Cascavel', 'José Smarczewski', 'Nova Cidade', '85803-136', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20203, 'Curitiba', 'José Smolinski', 'Cidade Industrial', '81270-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20204, 'Ponta Grossa', 'José Sniegovski', 'Uvaranas', '84030-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20205, 'Londrina', 'José Soares', 'Avelino A Vieira', '86056-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20206, 'Foz do Iguaçu', 'José Soares', 'Jardim Norma', '85869-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20207, 'Foz do Iguaçu', 'José Soares de Araújo', 'Parque Residencial Três Bandeiras', '85862-258', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20208, 'Curitiba', 'José Soares Grobe', 'Sítio Cercado', '81925-545', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20209, 'Campo Largo', 'José Soares Pinto', 'Vila Bancária', '83601-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20210, 'Araucária', 'José Sokulski', 'Tindiquera', '83708-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20211, 'Apucarana', 'José Souza Falcão', 'Jardim Eldorado', '86802-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20212, 'Paranavaí', 'José Souza Leite', 'Vila Operária', '87708-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20213, 'Curitiba', 'José Sperancetta', 'São Lourenço', '82210-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20214, 'Araucária', 'José Stanczyk', 'Thomaz Coelho', '83707-030', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20215, 'São José dos Pinhais', 'José Stankevecz', 'Ipê', '83055-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20216, 'Londrina', 'José Stella', 'Assis', '86085-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20217, 'Colombo', 'José Strapasson', 'Santa Gema', '83407-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20218, 'Curitiba', 'José Surugi', 'Seminário', '80440-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20219, 'Curitiba', 'José Symchack', 'Pinheirinho', '81870-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20220, 'São José dos Pinhais', 'José Szczepanski', 'Afonso Pena', '83040-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20221, 'Campo Largo', 'José Szpak', 'Vila Cilka', '83606-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20222, 'Colombo', 'José Taborda dos Santos', 'Vila Santa Helena', '83406-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20223, 'Colombo', 'José Taborda Ribas', 'Vila Ana Maria', '83413-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20224, 'Campo Mourão', 'José Tadeu Nunes', 'Jardim Nossa Senhora Aparecida', '87309-295', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20225, 'Londrina', 'José Tait', 'Conjunto Professora Hilda Mandarino', '86080-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20226, 'Campo Mourão', 'José Taques', 'Conjunto Residencial Ilha Bela', '87309-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20227, 'Curitiba', 'José Taschner', 'Fanny', '81030-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20228, 'Pato Branco', 'José Tatto', 'Aeroporto', '85503-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20229, 'Colombo', 'José Tavares da Rosa', 'Jardim Florença', '83414-340', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20230, 'Umuarama', 'José Teixeira d''Ávila', 'Zona I', '87501-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20231, 'Curitiba', 'José Teixeira de Mello', 'Fazendinha', '81330-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20232, 'Apucarana', 'José Tejada Garcia', 'Jardim Morada do Sol', '86811-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20233, 'Foz do Iguaçu', 'José Teles da Conceição', 'Parque Morumbi II', '85858-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20234, 'Campo Mourão', 'José Teodoro de Oliveira', 'Jardim Flórida', '87300-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20235, 'Maringá', 'José Ternes Sobrinho', 'Vila Cafelândia', '87045-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20236, 'Umuarama', 'José Tertuliano Teixeira Morais', 'Parque Cidade Jardim', '87506-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20237, 'Londrina', 'José Tetuo Saito', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20238, 'Ponta Grossa', 'José Theodomiro Kapp', 'Colônia Dona Luiza', '84043-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20239, 'Ponta Grossa', 'José Theodoro Miro Guimarães', 'Chapada', '84062-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20240, 'Curitiba', 'José Tissi', 'Cidade Industrial', '81280-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20241, 'Curitiba', 'José Todeschini', 'Jardim das Américas', '81520-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20242, 'Colombo', 'José Tomacheski', 'Vila São Gabriel', '83406-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20243, 'Curitiba', 'José Tomasi', 'Santa Felicidade', '82015-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20244, 'Almirante Tamandaré', 'José Tomaz', 'Jardim Vitória', '83508-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20245, 'Maringá', 'José Toral Querubim', 'Conjunto Habitacional Requião', '87047-438', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20246, 'Campo Largo', 'José Torres', 'Jardim São Vicente', '83602-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20247, 'Curitiba', 'José Torres Neto', 'Cidade Industrial', '81310-026', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20248, 'Apucarana', 'José Toth', 'Loteamento Jardim Por do Sol', '86801-466', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20249, 'Londrina', 'José Tramontini', 'Portal de Versalhes 3', '86055-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20250, 'Paranaguá', 'José Tramujas', 'Tuiuti', '83203-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20251, 'São José dos Pinhais', 'José Trevisan', 'Miringuava', '83090-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20252, 'Londrina', 'José Trizotti', '', '86084-835', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20253, 'Ponta Grossa', 'José Trujillo de Freitas', 'Uvaranas', '84030-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20254, 'Araucária', 'José Túlio', 'Tindiquera', '83708-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20255, 'Curitiba', 'José Túlio', 'Santa Felicidade', '82030-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20256, 'Araucária', 'José Tyrka', 'Sabiá', '83708-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20257, 'Curitiba', 'José Ursolino Filho', 'Santa Cândida', '82720-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20258, 'Curitiba', 'José V. Pinheiro de Proença', 'Fazendinha', '81320-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20259, 'Almirante Tamandaré', 'José Valdir Piekas', 'Jardim Novo Horizonte da Cachoeira', '83502-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20260, 'Curitiba', 'José Valla', 'Orleans', '82300-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20261, 'Curitiba', 'José Valle', 'São João', '82020-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20262, 'Londrina', 'José Vargas', 'Eucaliptos', '86031-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20263, 'Curitiba', 'José Veiga', 'São Braz', '82315-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20264, 'Toledo', 'José Venâncio Heiss', 'Jardim Alto Alegre', '85910-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20265, 'Curitiba', 'José Vendrametto', 'Xaxim', '81710-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20266, 'Curitiba', 'José Vendramin', 'Tatuquara', '81480-207', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20267, 'Londrina', 'José Ventura Pinto', 'Monte Carlo', '86040-570', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20268, 'Pato Branco', 'José Vergílio Cantu', 'Bancários', '85504-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20269, 'Ponta Grossa', 'José Veríssimo', 'Boa Vista', '84070-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20270, 'Curitiba', 'José Veríssimo', 'Tarumã', '82820-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20271, 'Londrina', 'José Vicente', 'Jardim Brasília', '86039-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20272, 'Maringá', 'José Vicente Dias', 'Conjunto Habitacional Requião', '87047-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20273, 'Foz do Iguaçu', 'José Vicente Ferreira', 'Alto São Francisco', '85863-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20274, 'Almirante Tamandaré', 'José Vicente Gowatiski', 'Jardim Paraíso', '83512-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20275, 'Guarapuava', 'José Vicentim', 'Primavera', '85050-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20276, 'Curitiba', 'José Vidal Vanhoni', 'Tatuquara', '81470-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20277, 'Colombo', 'José Vidolin', 'Jardim Paraná', '83412-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20278, 'Curitiba', 'José Vieira de Paula', 'Sítio Cercado', '81920-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20279, 'Pato Branco', 'José Vigano', 'Industrial', '85506-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20280, 'Curitiba', 'José Vilmar Nichele', 'Cidade Industrial', '81280-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20281, 'Londrina', 'José Vitachi Filho', 'Monte Carlo', '86040-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20282, 'Londrina', 'José Vitorino', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20283, 'Piraquara', 'José Vitorino de Almeida', 'Borda do Campo', '83304-428', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20284, 'Cambé', 'José Vituri', 'Jardim Itália', '86192-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20285, 'Londrina', 'José Vizentin', 'Pinheiros', '86063-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20286, 'Sarandi', 'José Volpato', 'Parque Alvamar', '87113-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20287, 'Londrina', 'José Von Stein', 'Jardim Alphaville', '86084-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20288, 'Londrina', 'José Wagenheimer', 'Jardim Campos Verdes', '86085-257', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20289, 'Curitiba', 'José Waldemar Baron', 'Cachoeira', '82710-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20290, 'Castro', 'José Waldemar Iucksh', 'Jardim das Araucárias', '84174-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20291, 'Pinhais', 'José Waltemyr Costa Lima', 'Planta Cláudio Mehl', '83326-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20292, 'Pato Branco', 'José Waterkemper', 'Bela Vista', '85509-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20293, 'Campo Mourão', 'José Wierzchon', 'Conjunto Residencial Ilha Bela', '87309-088', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20294, 'Curitiba', 'José Wilczak', 'Sítio Cercado', '81900-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20295, 'Araucária', 'José Wisocki', 'Tindiquera', '83708-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20296, 'Curitiba', 'José Wosch Sobrinho', 'Tingui', '82620-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20297, 'Araucária', 'José Wsoek', 'Tindiquera', '83708-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20298, 'Curitiba', 'José Xavier', 'São Braz', '82315-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20299, 'Guarapuava', 'José Zagonel Passos', 'Vila Bela', '85027-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20300, 'Foz do Iguaçu', 'José Zaguir', 'Conjunto Habitacional Fernanda', '85862-506', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20301, 'Curitiba', 'José Zaleski', 'Capão Raso', '81130-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20302, 'Guarapuava', 'José Zampier Filho', 'Industrial', '85045-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20303, 'Pato Branco', 'José Zanella', 'Bela Vista', '85509-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20304, 'Curitiba', 'José Zanoncini', 'Tatuquara', '81480-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20305, 'Curitiba', 'José Zap', 'Uberaba', '81580-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20306, 'Curitiba', 'José Zaramella', 'Boa Vista', '82560-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20307, 'Curitiba', 'José Zardo', 'Santa Felicidade', '82410-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20308, 'São José dos Pinhais', 'José Zen', 'Bom Jesus', '83025-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20309, 'São José dos Pinhais', 'José Zen Neto', 'Ipê', '83055-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20310, 'Curitiba', 'José Zgoda', 'Bairro Alto', '82820-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20311, 'São José dos Pinhais', 'José Ziliotto', 'Centro', '83005-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20312, 'Piraquara', 'José Zippim', 'Jardim Veneza', '83310-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20313, 'Curitiba', 'José Zonatto', 'Bom Retiro', '80520-130', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20314, 'Curitiba', 'Josefa Cecília Portela', 'Cidade Industrial', '81170-707', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20315, 'Londrina', 'Josefa Corrado', 'Andes', '86076-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20316, 'Araucária', 'Josefa Muchau', 'Tindiquera', '83708-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20317, 'Araucária', 'Josefa Resner', 'Estação', '83705-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20318, 'Maringá', 'Josefa Ruiz Velosco', 'Vila Nevada', '87020-518', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20319, 'Londrina', 'Josefa Simões Gimenez', 'Colinas', '86056-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20320, 'Colombo', 'Josefa Tomacheski', 'Jardim Guarujá', '83407-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20321, 'Curitiba', 'Josefa Zaions', 'Sítio Cercado', '81900-776', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20322, 'Toledo', 'Josefina C. Cazzanatto', 'Panorama', '85911-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20323, 'São José dos Pinhais', 'Josefina Dal''Negro', 'Afonso Pena', '83065-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20324, 'Sarandi', 'Josefina Maria de Jesus', 'Jardim Independência I', '87114-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20325, 'Pato Branco', 'Josefina Maria Leonardi', 'Aeroporto', '85503-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20326, 'Londrina', 'Josefina Padovan', 'Parque Industrial Buena Vista', '86032-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20327, 'Toledo', 'Josefina Passarini', 'Passarini IV', '85906-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20328, 'Toledo', 'Josefina Reffatti', 'Panorama', '85915-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20329, 'Curitiba', 'Josefina Rocha', 'Batel', '80440-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20330, 'Londrina', 'Josefina Rossi Filoco', 'Aragarça', '86038-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20331, 'Curitiba', 'Josefina Trevisan Strapasson', 'Santa Felicidade', '82320-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20332, 'Campo Largo', 'Josefina Vidal', 'Moradias Bom Jesus', '83602-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20333, 'Curitiba', 'Josefina Zanier', 'Prado Velho', '80215-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20334, 'Piraquara', 'Josemael Alberti', 'Jardim Esmeralda', '83301-330', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20335, 'Guarapuava', 'Josemar Ramos de Siqueira', 'Industrial Xarquinho', '85053-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20336, 'Londrina', 'Joseph Aspdin', 'Industrial', '86063-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20337, 'Curitiba', 'Joseph Smith', 'Portão', '80610-210', 'Recanto', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20338, 'Curitiba', 'Josepha Deren Destefani', 'Boqueirão', '81650-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20339, 'Curitiba', 'Josépha Mattozo', 'Cachoeira', '82710-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20340, 'Londrina', 'Josephina Colombo', 'Conjunto Semiramis Barros Braga', '86088-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20341, 'Curitiba', 'Josephina Demeterco', 'Cidade Industrial', '81280-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20342, 'São José dos Pinhais', 'Josephina Franciosi Haluch', 'Braga', '83020-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20343, 'Cascavel', 'Josephina Galafassi Venturini', 'Presidente', '85818-158', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20344, 'Londrina', 'Josephina Lorenzon Benatto', 'Guanabara Parque Boulevard', '86050-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20345, 'Londrina', 'Josephina Martine Bottura', 'Jardim Alphaville', '86084-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20346, 'Colombo', 'Josephina P. Guimarães', 'Planta Boros', '83413-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20347, 'Curitiba', 'Josephina Toaldo Moraes', 'Cidade Industrial', '81305-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20348, 'Campo Mourão', 'Josephina Wendling Nunes', 'Jardim Laura', '87300-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20349, 'Londrina', 'Josephina Zambrin Brunetto', 'Jardim Vale Verde', '86040-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20350, 'Umuarama', 'Josias Antunes de Souza', 'Parque Dom Bosco', '87505-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20351, 'Curitiba', 'Josias da SE Escorsin', 'São Braz', '82310-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20352, 'Londrina', 'Josias de Souza', 'Conjunto Novo Amparo', '86087-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20353, 'Paranavaí', 'Josias Soares de Lima', 'Vila São Vicente', '87709-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20354, 'Curitiba', 'Josina Ramos Régio', 'Lindóia', '81010-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20355, 'Londrina', 'Josip Kloc', 'Jardim Imagawa', '86080-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20356, 'Umuarama', 'Josué', 'Parque Dom Pedro II', '87508-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20357, 'Curitiba', 'Josué de Castro', 'São Braz', '82300-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20358, 'Cascavel', 'Josué Guimarães', 'Nova Cidade', '85803-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20359, 'Londrina', 'Josué Lins Rodrigues', 'Cafezal', '86045-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20360, 'Maringá', 'Josué Moraes', 'Jardim Ipanema', '87053-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20361, 'Maringá', 'Josueis Gonçalves', 'Conjunto Habitacional Karina', '87047-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20362, 'Campo Mourão', 'Josueis Gonçalves', 'Jardim Modelo', '87309-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20363, 'Londrina', 'Joubert de Carvalho', 'Leonardo da Vinci', '86060-320', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20364, 'Londrina', 'Joubert de Carvalho', 'Conjunto Vivi Xavier', '86082-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20365, 'Maringá', 'Joubert de Carvalho', 'Zona 01', '87013-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20366, 'Maringá', 'Jouji Nakamura', 'Jardim Novo Horizonte', '87010-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20367, 'Araucária', 'Joval de Paula Souza', 'Thomaz Coelho', '83707-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20368, 'Curitiba', 'Jovany Scorsin', 'Cidade Industrial', '81305-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20369, 'Campo Largo', 'Jovelino Apolinário', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20370, 'Almirante Tamandaré', 'Jovêncio Bertão', 'Jardim Kokot', '83505-121', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20371, 'Curitiba', 'Jovenilson Américo de Oliveira', 'Tatuquara', '81480-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20372, 'Curitiba', 'Joviano Marques de Oliveira', 'Boqueirão', '81670-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20373, 'Curitiba', 'Jovina de Oliveira Karan', 'Capão Raso', '81110-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20374, 'Apucarana', 'Joviniano Machado Peixoto', 'Jardim Colonial II', '86812-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20375, 'Curitiba', 'Jovino Cavalheiro dos Santos', 'Atuba', '82630-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20376, 'São José dos Pinhais', 'Jovino Dissenha', 'Colônia Rio Grande', '83025-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20377, 'Curitiba', 'Jovino do Rosário', 'Boa Vista', '82510-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20378, 'Araucária', 'Jovino Franco da Paz', 'Campina da Barra', '83709-847', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20379, 'Londrina', 'Jovino José Dias', 'Jardim dos Alpes III', '86045-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20380, 'Londrina', 'Joycielle de Souza', 'Jardim Santa Fé', '86035-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20381, 'Almirante Tamandaré', 'Juá', 'Loteamento Chico Mendes', '83505-759', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20382, 'Curitiba', 'Juá', 'Uberaba', '81550-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20383, 'Foz do Iguaçu', 'Juan Anzoategui', 'Vila Itajubá', '85852-360', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20384, 'Curitiba', 'Juan Belvedere', 'Sítio Cercado', '81925-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20385, 'São José dos Pinhais', 'Juares de Lima Pereira', 'São Sebastião', '83075-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20386, 'Curitiba', 'Juarez Antônio Bittencourt', 'Atuba', '82860-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20387, 'Curitiba', 'Juarez Antônio Mattei', 'Xaxim', '81830-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20388, 'Curitiba', 'Juarez Borges', 'Tatuquara', '81470-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20389, 'Curitiba', 'Juarez Manoel Ramos Ribeiro', 'Sítio Cercado', '81900-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20390, 'Guarapuava', 'Juarez Martins Lustosa', 'Industrial', '85053-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20391, 'Campo Mourão', 'Juarez R. do Prado', 'Centro', '87302-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20392, 'Curitiba', 'Juarez Silva', 'Cachoeira', '82710-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20393, 'Londrina', 'Juarez Távora', 'Sebastião de Melo César', '86084-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20394, 'Curitiba', 'Juarez Távora', 'Tatuquara', '81480-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20395, 'Foz do Iguaçu', 'Juazeiro', 'Jardim Duarte', '85861-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20396, 'Foz do Iguaçu', 'Jubarte', 'Conjunto A', '85861-390', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20397, 'Londrina', 'Jubileu de Ouro', 'Jardim Tókio', '86063-055', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20398, 'Londrina', 'Jubilino Barbosa Cabral', 'Conjunto Parigot de Souza 3', '86081-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20399, 'Curitiba', 'Jucundino da Silva Furtado', 'Cidade Industrial', '81460-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20400, 'Arapongas', 'Jucurutu', 'Vila Dalva', '86708-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20401, 'Umuarama', 'Judá', 'Conjunto Residencial Vinte e Seis de Junho', '87508-088', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20402, 'Guarapuava', 'Judite Bastos de Oliveira', 'Jardim das Américas', '85030-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20403, 'Toledo', 'Judite Dedendo', 'Conjunto Habitacional São Francisco', '85915-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20404, 'Araucária', 'Judith Brunato Cantador', 'Iguaçu', '83701-826', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20405, 'Curitiba', 'Judith de Freitas Granato', 'Pilarzinho', '82115-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20406, 'São José dos Pinhais', 'Judith Ferreira Walbach', 'Três Marias', '83030-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20407, 'Curitiba', 'Judith Manosso', 'Butiatuvinha', '82400-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20408, 'Curitiba', 'Judith Sanson Tedeschi', 'Barreirinha', '82650-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20409, 'Colombo', 'Judith Schluga', 'Centro Industrial Mauá', '83413-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20410, 'Londrina', 'Judithe do Carmo', 'Coliseu', '86076-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20411, 'Londrina', 'Juhei Muramoto', 'Jardim Tókio', '86063-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20412, 'Londrina', 'Juiz Acyr Quadros', 'Rica', '86025-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20413, 'São José dos Pinhais', 'Juiz Danilo Bertolin Precoma', 'Cidade Jardim', '83035-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20414, 'Londrina', 'Juiz de Fora', 'Hedy', '86062-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20415, 'Maringá', 'Juiz Fernando Antônio Vieira', 'Conjunto Habitacional Karina', '87047-430', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20416, 'Maringá', 'Juiz Fernando Antônio Vieira', 'Jardim América', '87043-230', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20417, 'Curitiba', 'Juiz Hely Lopes Meirelles', 'Cidade Industrial', '81170-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20418, 'Toledo', 'Julci Luiz Strieder', 'Vila Industrial', '85904-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20419, 'Toledo', 'Julcimar Coppini', 'Coopagro', '85903-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20420, 'Foz do Iguaçu', 'Jules Rimet', 'Beverly Falls Park', '85858-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20421, 'Londrina', 'Jules Verne', 'Conjunto Santa Rita 7', '86072-450', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20422, 'Piraquara', 'Júlia Alves de Almeida', 'Planta Granjas Eldorado', '83309-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20423, 'Curitiba', 'Júlia Aurora Zanetti Piovezan', 'São João', '82030-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20424, 'Londrina', 'Júlia Bellini Bertaglia', 'Residencial Vila Romana', '86031-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20425, 'Curitiba', 'Júlia Borges de Freitas Wichinieski', 'Santa Felicidade', '82015-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20426, 'Foz do Iguaçu', 'Júlia da Costa', 'Jardim Cláudia', '85852-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20427, 'Piraquara', 'Júlia da Costa', 'Jardim Bela Vista', '83301-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20428, 'Ponta Grossa', 'Júlia da Costa', 'Colônia Dona Luiza', '84045-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20429, 'Paranaguá', 'Júlia da Costa', 'Centro Histórico', '83203-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20430, 'São José dos Pinhais', 'Júlia da Costa', 'São Sebastião', '83075-297', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20431, 'Curitiba', 'Júlia da Costa', 'São Francisco', '80410-070', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20432, 'Curitiba', 'Júlia da Costa', 'Bigorrilho', '80730-070', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20433, 'Curitiba', 'Júlia da Costa', 'Mercês', '80430-110', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20434, 'Piraquara', 'Júlia da Silva', 'Jardim Bela Vista', '83301-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20435, 'Ponta Grossa', 'Júlia Diniz', 'Olarias', '84035-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20436, 'Curitiba', 'Júlia Domingos Bortolotto', 'Cachoeira', '82220-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20437, 'Londrina', 'Júlia Fernandes Bertolucci', 'Conjunto Habitacional José Belinati', '86084-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20438, 'Curitiba', 'Júlia Kankel Glodzinski', 'Abranches', '82220-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20439, 'Ponta Grossa', 'Júlia Lopes', 'Nova Rússia', '84070-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20440, 'Cambé', 'Júlia Maria da Costa', 'Jardim Silvino', '86188-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20441, 'Araucária', 'Júlia Ohpis', 'Vila Nova', '83703-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20442, 'São José dos Pinhais', 'Júlia Pallu Zen', 'Ouro Fino', '83015-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20443, 'Almirante Tamandaré', 'Júlia Pedrosa de Morais', 'Vila Prosdócimo', '83506-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20444, 'Curitiba', 'Júlia Scroccaro Burbelo', 'Umbará', '81940-440', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20445, 'Curitiba', 'Júlia Skora', 'Tingui', '82600-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20446, 'Colombo', 'Júlia Stenghel Coller', 'Jardim Rio Verde', '83405-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20447, 'Araucária', 'Júlia Thereza Bini', 'Centro', '83702-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20448, 'Ponta Grossa', 'Júlia Wanderley', 'Centro', '84010-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20449, 'Curitiba', 'Júlia Wanderley', 'Mercês', '80710-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20450, 'Curitiba', 'Júlia Wanderley', 'Mercês', '80430-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20451, 'Londrina', 'Julião de Souza Santana', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20452, 'Curitiba', 'Julieta Abrão Sado', 'Uberaba', '81550-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20453, 'Londrina', 'Julieta Leite de Carvalho', 'Conjunto Habitacional José Giordano', '86082-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20454, 'Curitiba', 'Julieta Rigão Schrederhof', 'Tatuquara', '81470-175', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20455, 'São José dos Pinhais', 'Julieta Rocha da Silva Grassi', 'São Sebastião', '83075-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20456, 'Curitiba', 'Julieta Scaramussa Marques', 'Alto Boqueirão', '81770-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20457, 'Araucária', 'Julieta Vidal Osório', 'Centro', '83702-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20458, 'Curitiba', 'Julieta Ziliotto', 'Santo Inácio', '82300-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20459, 'Ponta Grossa', 'Júlio Albuquero', 'Cará-cará', '84043-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20460, 'Francisco Beltrão', 'Júlio Assis Cavalheiro', 'Centro', '85601-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20461, 'Curitiba', 'Júlio Augusto Ansiutti', 'Bacacheri', '82600-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20462, 'Apucarana', 'Júlio Baena Rodrigues', 'Jardim Cidade Alta', '86803-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20463, 'Curitiba', 'Júlio Bartolomeu Taborda Luiz', 'Tingui', '82600-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20464, 'Curitiba', 'Júlio Batista Pereira', 'Tatuquara', '81480-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20465, 'Piraquara', 'Júlio Biss', 'Vila Fuck', '83305-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20466, 'Cambé', 'Júlio Bocatto', 'Jardim Vô Zezinho', '86192-777', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20467, 'Curitiba', 'Júlio Bond', 'Jardim das Américas', '81530-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20468, 'Curitiba', 'Júlio Buskei', 'Campina do Siqueira', '80740-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20469, 'Foz do Iguaçu', 'Júlio Carneiro Portes', 'Jardim Jupira', '85865-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20470, 'Ponta Grossa', 'Júlio César Barbosa', 'Contorno', '84062-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20471, 'Umuarama', 'Júlio César Jarros', 'Jardim Alto da Boa Vista', '87506-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20472, 'Londrina', 'Júlio César Ribeiro', 'Lolata', '86039-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20473, 'Curitiba', 'Júlio César Ribeiro de Souza', 'Hauer', '81630-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20474, 'Curitiba', 'Júlio César Ribeiro de Souza', 'Hauer', '81610-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20475, 'São José dos Pinhais', 'Júlio César Setenareski', 'Colônia Murici', '83085-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20476, 'Campo Mourão', 'Júlio Cezar', 'Jardim Lar Paraná', '87305-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20477, 'Araucária', 'Júlio Cezar Grabowski', 'Costeira', '83708-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20478, 'Pinhais', 'Júlio Colaço', 'Moradias Perdizes', '83326-717', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20479, 'Ponta Grossa', 'Júlio Cortazar', 'Cará-cará', '84043-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20480, 'São José dos Pinhais', 'Júlio Cozzetti', 'Afonso Pena', '83050-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20481, 'Guarapuava', 'Júlio de Castilho', 'Vila Carli', '85040-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20482, 'Londrina', 'Júlio de Castilho', 'Sabará', '86066-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20483, 'Ponta Grossa', 'Júlio de Castilho', 'Centro', '84010-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20484, 'Toledo', 'Júlio de Castilho', 'Vila Industrial', '85904-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20485, 'Londrina', 'Júlio de Mesquita', 'Penterich', '86010-570', 'Viaduto', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20486, 'Maringá', 'Júlio de Mesquita', 'Jardim Liberdade', '87045-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20487, 'Maringá', 'Júlio de Mesquita', 'Jardim Liberdade', '87047-036', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20488, 'Londrina', 'Júlio de Mesquita Filho', 'Vila Ipiranga', '86010-040', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20489, 'Maringá', 'Júlio de Mesquita Filho', 'Zona 01', '87013-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20490, 'Colombo', 'Júlio de Souza', 'Jardim Osasco', '83403-047', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20491, 'Curitiba', 'Júlio de Souza Portela', 'Sítio Cercado', '81935-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20492, 'Foz do Iguaçu', 'Júlio Delamare', 'Loteamento Lindóia', '85856-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20493, 'Foz do Iguaçu', 'Júlio Delamare', 'Parque Residencial Santa Rita', '85858-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20494, 'Curitiba', 'Júlio Diniz', 'Guaíra', '81010-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20495, 'Maringá', 'Júlio do Carmo Esteves', 'Zona 01', '87013-066', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20496, 'Paranaguá', 'Júlio do Rosário Passos', 'Alvorada', '83206-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20497, 'Curitiba', 'Júlio Dotti', 'Barreirinha', '82700-590', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20498, 'Sarandi', 'Júlio Dvoranen', 'Centro', '87111-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20499, 'Curitiba', 'Júlio Eduardo Gineste', 'Santa Quitéria', '80310-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20500, 'Londrina', 'Júlio Estrela Moreira', 'Canaã', '86015-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20501, 'Londrina', 'Júlio Farináceo', 'Assis', '86085-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20502, 'Maringá', 'Júlio Favoretto', 'Vila Esperança', '87020-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20503, 'Curitiba', 'Júlio Fleming', 'Vila Izabel', '80240-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20504, 'Castro', 'Julio Gerytch', 'Loteamento Jardim Pandorf', '84182-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20505, 'Curitiba', 'Júlio Graf', 'Vista Alegre', '80820-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20506, 'Paranaguá', 'Júlio Groth Elias', 'Divinéia', '83212-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20507, 'Paranaguá', 'Júlio Groth Elias Filho', 'Vila Garcia', '83218-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20508, 'Curitiba', 'Júlio Hoog', 'Xaxim', '81830-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20509, 'Maringá', 'Júlio Jerônimo dos Santos', 'Zona 07', '87030-510', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20510, 'Colombo', 'Júlio Jordão', 'Jardim João Paulo II', '83402-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20511, 'Almirante Tamandaré', 'Júlio José dos Santos', 'Jardim Vitória', '83508-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20512, 'Piraquara', 'Júlio Keques', 'Planta Araçatuba', '83301-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20513, 'Ponta Grossa', 'Júlio Lago', 'Nova Rússia', '84015-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20514, 'Maringá', 'Júlio Limonta', 'Residencial Ibirapuera', '87045-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20515, 'Sarandi', 'Júlio Limonta', 'Novo Panorama', '87113-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20516, 'Curitiba', 'Júlio Lopes', 'Atuba', '82860-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20517, 'Curitiba', 'Júlio Maito Sobrinho', 'Uberaba', '81560-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20518, 'Laranjeiras do Sul', 'Júlio Maurer', 'Centro', '85301-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20519, 'Maringá', 'Júlio Meneguetti', 'Jardim Novo Horizonte', '87010-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20520, 'Colombo', 'Júlio Mesquita', 'Vila Petrópolis', '83409-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20521, 'Curitiba', 'Júlio Mesquita', 'Fazendinha', '81330-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20522, 'Curitiba', 'Júlio Moreira', 'Centro', '80020-140', 'Galeria', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20523, 'Londrina', 'Júlio Morgueti', 'Roseira', '86041-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20524, 'Curitiba', 'Júlio Moura Rodrigues', 'Sítio Cercado', '81920-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20525, 'Londrina', 'Júlio Munaretto', 'Vale das Araucárias', '86047-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20526, 'Londrina', 'Júlio Palharini', 'Aritana', '86037-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20527, 'Foz do Iguaçu', 'Júlio Pasa', 'Centro', '85851-370', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20528, 'Curitiba', 'Júlio Pasa', 'Uberaba', '81570-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20529, 'Sarandi', 'Júlio Paviano', 'Jardim Primavera', '87111-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20530, 'Londrina', 'Júlio Pedro de Mello', 'Conjunto Habitacional Saltinho', '86042-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20531, 'Curitiba', 'Júlio Pedroso de Morais', 'Boa Vista', '82540-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20532, 'Londrina', 'Júlio Pelizzer', 'Eucaliptos', '86031-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20533, 'Curitiba', 'Júlio Pereira Sobrinho', 'Campo de Santana', '81490-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20534, 'Curitiba', 'Júlio Perneta', 'Mercês', '80810-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20535, 'Ponta Grossa', 'Júlio Perneta', 'Jardim Carvalho', '84016-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20536, 'Pinhais', 'Júlio Perneta', 'Planta Núcleo Colonial de Pinhais', '83321-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20537, 'Araucária', 'Júlio Pintor Szymanski', 'Tindiquera', '83708-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20538, 'Foz do Iguaçu', 'Júlio Prestes', 'Parque Presidente', '85863-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20539, 'Londrina', 'Júlio Prestes', 'Bancários', '86062-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20540, 'Cascavel', 'Júlio Prestes', 'Parque São Paulo', '85803-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20541, 'Colombo', 'Júlio Prestes de Araújo', 'Centro', '83414-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20542, 'Apucarana', 'Júlio Ravazzi', 'Parque Industrial Zona Norte', '86806-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20543, 'Colombo', 'Júlio Ribeiro', 'Vila Petrópolis', '83409-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20544, 'Piraquara', 'Júlio Ribeiro de Barros', 'Vila São Cristóvão', '83305-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20545, 'São José dos Pinhais', 'Júlio Rocco', 'Campina', '83015-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20546, 'Curitiba', 'Júlio Rocha Xavier', 'Portão', '80310-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20547, 'Curitiba', 'Júlio Salsamendi', 'Tatuquara', '81470-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20548, 'Cascavel', 'Júlio Szymanski', 'Região do Lago 3', '85819-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20549, 'Curitiba', 'Júlio Szymanski', 'Rebouças', '80220-210', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20550, 'Paranaguá', 'Júlio Veiga Mendes', 'Bockmann', '83206-288', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20551, 'Sarandi', 'Júlio Verne', 'Jardim Universal', '87114-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20552, 'Toledo', 'Júlio Verne', 'Jardim Porto Alegre', '85906-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20553, 'Cascavel', 'Júlio Verne', 'Nova Cidade', '85803-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20554, 'Ponta Grossa', 'Júlio Viana de Azevedo', 'Oficinas', '84035-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20555, 'Curitiba', 'Júlio Vicente Roda', 'Pilarzinho', '82120-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20556, 'Curitiba', 'Júlio Wischral', 'Uberaba', '81540-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20557, 'Curitiba', 'Júlio Woss', 'Cidade Industrial', '81280-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20558, 'Curitiba', 'Júlio Xavier Vianna', 'Cidade Industrial', '81460-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20559, 'Curitiba', 'Júlio Zandona', 'Alto Boqueirão', '81720-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20560, 'Londrina', 'Júlio Zanette', 'Jardim Nápoles', '86062-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20561, 'Curitiba', 'Júlio Zaninelli', 'Bom Retiro', '80520-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20562, 'Curitiba', 'Julius Forrer', 'Barreirinha', '82700-265', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20563, 'Londrina', 'Julles Rimet', 'Eliza', '86026-210', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20564, 'Ponta Grossa', 'Jumbo', 'Cará-cará', '84043-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20565, 'Foz do Iguaçu', 'Jundiá', 'Conjunto A', '85860-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20566, 'Londrina', 'Jundiaí', 'Jardim Alvorada', '86062-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20567, 'Francisco Beltrão', 'Jundiaí', 'Pinheirinho', '85603-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20568, 'Guarapuava', 'Jundiaí', 'Boqueirão', '85020-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20569, 'Foz do Iguaçu', 'Jundiaí', 'Jardim Paraná', '85867-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20570, 'Pato Branco', 'Jundiaí', 'São Roque', '85507-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20571, 'Telêmaco Borba', 'Jundiaí', 'Área 06', '84271-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20572, 'Cambé', 'Jundiaí', 'Jardim São Paulo', '86191-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20573, 'Castro', 'Jundiaí', 'Vila Santa Cruz', '84168-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20574, 'Curitiba', 'Jundiaí do Sul', 'Sítio Cercado', '81935-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20575, 'Guarapuava', 'Junqueira Freire', 'São Cristóvão', '85060-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20576, 'Ponta Grossa', 'Junqueira Freire', 'Uvaranas', '84026-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20577, 'Foz do Iguaçu', 'Jupará', 'Conjunto A', '85861-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20578, 'Foz do Iguaçu', 'Juparaná', 'Três Lagoas', '85862-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20579, 'Maringá', 'Jupia', 'Parque das Grevíleas', '87025-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20580, 'Londrina', 'Jupira', 'Oriente', '86027-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20581, 'Maringá', 'Júpiter', 'Jardim Imperial II', '87023-007', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20582, 'Ponta Grossa', 'Júpiter', 'Uvaranas', '84031-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20583, 'Telêmaco Borba', 'Júpiter', 'Nossa Senhora de Fátima', '84264-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20584, 'Sarandi', 'Júpiter', 'Jardim Universal', '87114-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20585, 'Cambé', 'Júpiter', 'Parque Maracanã', '86185-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20586, 'Apucarana', 'Júpiter', 'Jardim Vale do Sol', '86803-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20587, 'Curitiba', 'Júpiter', 'Sítio Cercado', '81910-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20588, 'Foz do Iguaçu', 'Juquiá', 'Vila Carima', '85855-696', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20589, 'Curitiba', 'Juraci Nadalin', 'Fazendinha', '81320-500', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20590, 'Foz do Iguaçu', 'Juraci Pozo', 'Loteamento Witt', '85862-508', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20591, 'Colombo', 'Juraci Sebastiana de Lima', 'Jardim das Flores', '83402-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20592, 'Sarandi', 'Juraci Terra Guelfi', 'Jardim Panorama', '87113-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20593, 'Cascavel', 'Juracy Antônio Capra', 'Country', '85813-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20594, 'Londrina', 'Juracy Camargo Figueiredo', 'Conjunto Oscavo Gomes Santos', '86045-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20595, 'Londrina', 'Juracy Huga Cabral Messias', 'Jardim Alphaville', '86084-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20596, 'Curitiba', 'Jurandir A. Loro', 'Bacacheri', '82510-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20597, 'Ponta Grossa', 'Jurandir Bernardi', 'Boa Vista', '84072-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20598, 'Curitiba', 'Jurandir Caldas', 'Sítio Cercado', '81920-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20599, 'Toledo', 'Jurandir dal''Pra', 'Vila Becker', '85902-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20600, 'Curitiba', 'Jurandir Mendes de Lima', 'Ganchinho', '81935-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20601, 'Londrina', 'Jurandir Panza', 'João Paz', '86087-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20602, 'Cascavel', 'Jurandir Simonato', 'Santa Cruz', '85806-067', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20603, 'Londrina', 'Jurema', 'Antares', '86036-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20604, 'Maringá', 'Jurema', 'Jardim Vitória', '87023-630', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20605, 'Apucarana', 'Jurema', 'Jardim Ponta Grossa', '86804-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20606, 'Apucarana', 'Jurema', 'Jardim Ouro Verde', '86805-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20607, 'Colombo', 'Jurema', 'Jardim Curitiba', '83406-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20608, 'Paranaguá', 'Jurema Alves Mendes', 'Jardim Samambaia', '83212-529', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20609, 'Campo Mourão', 'Jurema Pompeu Miguel', 'Jardim Country Club', '87300-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20610, 'Londrina', 'Jurgen Jakobs Puls', 'Cilo 2', '86067-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20611, 'Piraquara', 'Juri Danilenko', 'Planta Santa Lúcia', '83311-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20612, 'Foz do Iguaçu', 'Juriti', 'Portal da Foz', '85859-396', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20613, 'Francisco Beltrão', 'Juriti', 'Padre Eurico', '85604-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20614, 'Londrina', 'Juriti', 'Conjunto Habitacional Violim', '86084-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20615, 'Ponta Grossa', 'Juriti', 'Colônia Dona Luiza', '84043-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20616, 'Pato Branco', 'Juriti', 'Planalto', '85509-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20617, 'Maringá', 'Juriti', 'Conjunto Residencial Ney Braga', '87083-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20618, 'Pinhais', 'Juriti', 'Jardim Cláudia', '83326-500', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20619, 'Umuarama', 'Juriti', 'Jardim Sol Nascente', '87505-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20620, 'Campo Mourão', 'Juriti', 'Conjunto Habitacional Milton Luiz Pereira', '87306-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20621, 'Arapongas', 'Juriti', 'Vila Industrial', '86706-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20622, 'Arapongas', 'Juriti-da-floresta', 'Conjunto Palmares', '86706-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20623, 'Arapongas', 'Juriti-piranga', 'Jardim São Rafael', '86703-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20624, 'Arapongas', 'Juriti-safira', 'Casa Família Arapongas IV', '86709-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20625, 'Arapongas', 'Juriti-vermelha', 'Parque Industrial V', '86702-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20626, 'Foz do Iguaçu', 'Juruá', 'Loteamento Campos do Iguaçu', '85857-560', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20627, 'Londrina', 'Juruá', 'Jardim Agari', '86025-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20628, 'Maringá', 'Juruá', 'Vila Morangueira', '87040-240', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20629, 'Araucária', 'Juruá', 'Iguaçu', '83701-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20630, 'Arapongas', 'Juruacu', 'Jardim Panorama', '86708-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20631, 'Curitiba', 'Juruacu', 'São Braz', '82015-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20632, 'Cascavel', 'Juruna', 'Santa Cruz', '85806-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20633, 'Foz do Iguaçu', 'Jurupoca', 'Conjunto A', '85860-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20634, 'Telêmaco Borba', 'Jurutanhi', 'Área 06', '84271-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20635, 'Arapongas', 'Jurutau', 'Jardim Bandeirantes', '86703-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20636, 'Apucarana', 'Juruti', 'Recanto das Araras', '86812-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20637, 'Foz do Iguaçu', 'Juruva', 'Conjunto A', '85866-330', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20638, 'Arapongas', 'Juruva', 'Vila São João', '86708-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20639, 'Arapongas', 'Juruva-canela', 'Jardim dos Pássaros', '86702-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20640, 'Arapongas', 'Juruviara', 'Jardim Cultura', '86707-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20641, 'Arapongas', 'Juruviara-fosca', 'Conjunto Águias', '86704-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20642, 'Arapongas', 'Juruviara-parda', 'Conjunto Flamingos III', '86703-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20643, 'Curitiba', 'Juscelino Gonçalves', 'São Braz', '82015-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20644, 'Guarapuava', 'Juscelino Kubitschek', 'Santa Cruz', '85015-590', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20645, 'Foz do Iguaçu', 'Juscelino Kubitschek', 'Centro', '85851-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20646, 'Foz do Iguaçu', 'Juscelino Kubitschek', 'Vila Portes', '85865-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20647, 'Foz do Iguaçu', 'Juscelino Kubitschek', 'Vila Paraguaia', '85864-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20648, 'Guarapuava', 'Juscelino Kubitschek', 'Boqueirão', '85020-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20649, 'Londrina', 'Juscelino Kubitschek', 'Vila Canziani', '86039-120', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20650, 'Londrina', 'Juscelino Kubitschek', 'Vila Ipiranga', '86010-540', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20651, 'Londrina', 'Juscelino Kubitschek', 'Jardim Santo Ângelo', '86020-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20652, 'Pinhais', 'Juscelino Kubitschek', 'Vila Amélia', '83330-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20653, 'Umuarama', 'Juscelino Kubitschek', 'Zona II', '87501-377', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20654, 'Campo Mourão', 'Juscelino Kubitschek', 'Jardim Corinthias', '87309-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20655, 'Telêmaco Borba', 'Juscelino Kubitschek de Oliveira', 'Centro', '84261-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20656, 'Apucarana', 'Juscelino Kubitschek de Oliveira', 'Jardim Trabalhista', '86807-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20657, 'Curitiba', 'Juscelino Kubitschek de Oliveira', 'Cidade Industrial', '81170-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20658, 'Curitiba', 'Juscelino Kubitschek de Oliveira', 'Cidade Industrial', '81290-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20659, 'Curitiba', 'Juscelino Kubitschek de Oliveira', 'Cidade Industrial', '81280-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20660, 'Curitiba', 'Juscelino Kubitschek de Oliveira', 'Cidade Industrial', '81350-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20661, 'Curitiba', 'Juscelino Kubitschek de Oliveira', 'Cidade Industrial', '81450-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20662, 'Curitiba', 'Juscelino Kubitschek de Oliveira', 'Cidade Industrial', '81250-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20663, 'Curitiba', 'Juscelino Kubitschek de Oliveira', 'Cidade Industrial', '81260-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20664, 'Curitiba', 'Juscelino Kubitschek de Oliveira', 'Cidade Industrial', '81270-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20665, 'Ponta Grossa', 'Jussara', 'Uvaranas', '84025-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20666, 'Umuarama', 'Jussara', 'Zona I', '87501-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20667, 'Curitiba', 'Jussara', 'Sítio Cercado', '81920-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20668, 'Curitiba', 'Jussara', 'Sítio Cercado', '81925-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20669, 'Maringá', 'Jussara Lina', 'Jardim Mandacaru', '87080-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20670, 'São José dos Pinhais', 'Justa Maria de Oliveira', 'Zaniolo', '83025-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20671, 'Pinhais', 'Justiliano Mendes da Silva', 'Vila Irene Margarida', '83326-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20672, 'Pinhais', 'Justina Marques dos Santos', 'Moradias Palmital', '83325-618', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20673, 'Colombo', 'Justiniano Alves de Souza', 'Jardim Guadalajara', '83402-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20674, 'Curitiba', 'Justiniano de Melo Silva', 'Jardim Social', '82530-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20675, 'Londrina', 'Justino Araújo Vilela', 'Jamile Dequech', '86048-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20676, 'Francisco Beltrão', 'Justino Backes', 'Alvorada', '85601-568', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20677, 'Londrina', 'Justino Vicente', 'Monte Belo', '86041-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20678, 'Londrina', 'Justino Vicente Filho', 'Colonial', '86047-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20679, 'Colombo', 'Justo Betinardi', 'Vila São Gabriel', '83406-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20680, 'Paranaguá', 'Justo Eris Almada Insfran', 'Costeira', '83203-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20681, 'Apucarana', 'Justo Laranjeiras', 'Jardim Laranjeiras', '86811-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20682, 'Almirante Tamandaré', 'Justo Manfron', 'Loteamento Montparnasse', '83508-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20683, 'Curitiba', 'Justo Manfron', 'Santa Felicidade', '82410-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20684, 'Londrina', 'Jutaí', 'Santa Rita 1', '86071-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20685, 'Guarapuava', 'Juvelina Cunha', 'Primavera', '85050-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20686, 'Londrina', 'Juvenal Alves de Camargo', 'Jardim Paraty', '86081-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20687, 'Londrina', 'Juvenal Borges de Macedo', 'Mediterrâneo', '86047-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20688, 'Guarapuava', 'Juvenal Caldas', 'Trianon', '85015-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20689, 'Guarapuava', 'Juvenal Caldas', 'Trianon', '85012-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20690, 'Almirante Tamandaré', 'Juvenal Cordeiro', 'Vila Grécia', '83502-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20691, 'Guarapuava', 'Juvenal de Assis Machado', 'Santana', '85070-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20692, 'Guarapuava', 'Juvenal de Souza', 'Morro Alto', '85065-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20693, 'Curitiba', 'Juvenal Dias Garcez', 'Cajuru', '82950-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20694, 'Curitiba', 'Juvenal dos Santos', 'Cascatinha', '82020-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20695, 'Apucarana', 'Juvenal Ferreira da Silva', 'Núcleo Habitacional Djalma Mendes de Oliveira', '86806-556', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20696, 'Curitiba', 'Juvenal Galeno', 'Jardim Social', '82520-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20697, 'Londrina', 'Juvenal Pioetraroia', 'Colúmbia', '86057-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20698, 'Castro', 'Juvenal Ribas', 'Jardim Social Arapongas', '84174-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20699, 'Almirante Tamandaré', 'Juvêncio Fermino de Brito', 'Planta Mosacal', '83513-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20700, 'Almirante Tamandaré', 'Juvenil de O. Bini', 'Jardim São Domingos', '83501-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20701, 'Toledo', 'Juvenildo Lorandi', 'Centro', '85901-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20702, 'Curitiba', 'Juventina Abib', 'Tarumã', '82530-540', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20703, 'Curitiba', 'Juventino Mosele', 'Novo Mundo', '81050-637', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20704, 'Ponta Grossa', 'Juvevê', 'Contorno', '84061-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20705, 'Colombo', 'Juvevê', 'Jardim Curitiba', '83406-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20706, 'Foz do Iguaçu', 'Juvino Carvalho', 'Jardim Cedro', '85862-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20707, 'Guarapuava', 'Juvino Lara Galvão', 'Bonsucesso', '85035-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20708, 'Curitiba', 'Juvino Ransolim', 'Campo Comprido', '81270-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20709, 'Ponta Grossa', 'K', 'Boa Vista', '84072-287', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20710, 'Umuarama', 'K', 'Parque das Jaboticabeiras', '87509-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20711, 'Umuarama', 'K', 'Parque Dom Pedro I', '87508-029', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20712, 'Campo Largo', 'K', 'Jardim Três Rios', '83603-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20713, 'Campo Largo', 'K', 'Vila Torres I', '83609-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20714, 'Campo Largo', 'K', 'Popular Nova', '83602-638', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20715, 'Curitiba', 'Kai Sizuo', 'Alto Boqueirão', '81850-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20716, 'Apucarana', 'Kaingang', 'Núcleo Habitacional Colonial', '86812-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20717, 'Maringá', 'Kakogawa', 'Parque das Grevíleas', '87025-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20718, 'Curitiba', 'Kalil Antônio Farran', 'Vista Alegre', '80820-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20719, 'Curitiba', 'Kalil Elias Warde', 'Campina do Siqueira', '80740-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20720, 'Curitiba', 'Kalil Karan', 'Alto da Rua XV', '80040-030', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20721, 'Curitiba', 'Kalil Karan Filho', 'Tatuquara', '81470-215', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20722, 'Curitiba', 'Kalore', 'Alto Boqueirão', '81860-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20723, 'Cascavel', 'Kamacas', 'Santa Cruz', '85806-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20724, 'Cascavel', 'Kamayuras', 'Santa Cruz', '85806-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20725, 'Londrina', 'Kanane Monma', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20726, 'Sarandi', 'Kane Ando', 'Parque São Pedro', '87112-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20727, 'Londrina', 'Kansas', 'Iguaçu', '86060-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20728, 'Castro', 'Karl Joseph Hoffman', 'Cantagalo', '84178-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20729, 'Londrina', 'Karl Schollenberger', 'Garden Park Residence', '86079-248', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20730, 'Maringá', 'Katisuji Nishiyama', 'Parque da Gávea', '87053-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20731, 'Maringá', 'Katisuji Nishiyama', 'Jardim Aclimação', '87050-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20732, 'Maringá', 'Katsuzo Fujiwara', 'Jardim Acema', '87030-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20733, 'Cascavel', 'Kayabis', 'Santa Cruz', '85806-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20734, 'Foz do Iguaçu', 'Kayaby', 'Jardim Festugato', '85864-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20735, 'Londrina', 'Kazuko Hiramatsu', 'Cafezal', '86045-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20736, 'Londrina', 'Kazuo Nishiyama', 'Portal de Versalhes 1', '86057-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20737, 'Londrina', 'Kazutaro Morimitsu', 'Jardim dos Alpes III', '86045-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20738, 'Londrina', 'Keimi Kazahaia', 'Flores', '86046-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20739, 'Curitiba', 'Kellers', 'São Francisco', '80410-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20740, 'Campo Largo', 'Kelly Cristina', 'Jardim Keli Cristina', '83609-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20741, 'Colombo', 'Kelvin', 'Vila Guarani', '83408-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20742, 'Colombo', 'Kenia', 'Vila Alto da Cruz II', '83405-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20743, 'Apucarana', 'Kenkiti Nakayama', 'Loteamento Sanches dos Santos', '86806-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20744, 'Francisco Beltrão', 'Kennedy', 'Presidente Kennedy', '85605-345', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20745, 'Paranaguá', 'Kennedy', 'Jardim Araçá', '83221-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20746, 'Curitiba', 'Khalil Mahfoud', 'Mercês', '80710-275', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20747, 'Foz do Iguaçu', 'Kid Jofre', 'Parque Morumbi I', '85858-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20748, 'Maringá', 'Kingston', 'Jardim Canadá', '87080-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20749, 'Sarandi', 'Kiozo Ando', 'Parque São Pedro', '87112-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20750, 'Maringá', 'Kiri', 'Parque Residencial Quebec', '87023-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20751, 'Maringá', 'Kiri', 'Parque das Grevíleas', '87025-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20752, 'Londrina', 'Kirio Miyamura', 'Conjunto Novo Amparo', '86087-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20753, 'Apucarana', 'Kishitaro Nayukawa', 'Jardim Europa', '86802-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20754, 'Londrina', 'Kiyofume Morioka', 'Colinas', '86056-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20755, 'Ponta Grossa', 'Kleber Justus', 'Ronda', '84050-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20756, 'Almirante Tamandaré', 'Kleina', 'Planta Almirante', '83508-540', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20757, 'Maringá', 'Kobe', 'Jardim Imperial II', '87023-029', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20758, 'Apucarana', 'Koei Tatesuji', 'Jardim Cidade Alta', '86803-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20759, 'Londrina', 'Koichi Hasegawa', 'Franciscato II', '86078-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20760, 'Curitiba', 'Konrad Adenauer', 'Tarumã', '82820-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20761, 'Curitiba', 'Konrad Kuno Frank', 'Xaxim', '81720-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20762, 'Curitiba', 'Kornel Denega', 'Portão', '80620-520', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20763, 'Londrina', 'Kotaro Hayasaka', 'Milton Gavetti', '86046-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20764, 'Londrina', 'Kozen Igue', 'Parque Residencial Granville', '86047-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20765, 'Cascavel', 'Krahos', 'Santa Cruz', '85806-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20766, 'Piraquara', 'KS-101', 'Chácara Águas Claras', '83309-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20767, 'Piraquara', 'KS-105', 'Planta Laranjeiras', '83307-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20768, 'Piraquara', 'KS-204', 'Chácara Águas Claras', '83309-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20769, 'Piraquara', 'KS-205', 'Planta Laranjeiras', '83307-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20770, 'Piraquara', 'KS-504', 'Planta Laranjeiras', '83307-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20771, 'Curitiba', 'Ksenia Weschuck Twerdochlib', 'Orleans', '82310-365', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20772, 'Piraquara', 'Kullian Fuck', 'Vila Fuck', '83305-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20773, 'Colombo', 'Kurt Rantemberg', 'Jardim Parque Verde', '83409-416', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20774, 'Ponta Grossa', 'Kurt Rodolph Zitlau', 'Colônia Dona Luiza', '84045-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20775, 'Curitiba', 'Kurt Walther Hasper', 'Novo Mundo', '81050-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20776, 'Curitiba', 'Kuwait', 'Santo Inácio', '82010-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20777, 'Cascavel', 'Kyalami', 'Interlagos', '85814-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20778, 'Maringá', 'Kyoto', 'Jardim Imperial II', '87023-027', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20779, 'Foz do Iguaçu', 'L', 'Conjunto C', '85870-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20780, 'Ponta Grossa', 'L', 'Boa Vista', '84072-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20781, 'Umuarama', 'L', 'Parque das Jaboticabeiras', '87509-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20782, 'Umuarama', 'L', 'Parque Dom Pedro I', '87508-028', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20783, 'Campo Largo', 'L', 'Popular Nova', '83602-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20784, 'Campo Largo', 'L', 'Jardim Três Rios', '83603-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20785, 'Castro', 'L', 'Vila do Rosário', '84168-088', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20786, 'Campo Largo', 'L', 'Vila Torres I', '83609-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20787, 'Londrina', 'La Paz', 'Guanabara', '86050-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20788, 'Francisco Beltrão', 'La Paz', 'Miniguaçu', '85605-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20789, 'Guarapuava', 'La Paz', 'São Cristóvão', '85063-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20790, 'Maringá', 'La Paz', 'Vila Morangueira', '87040-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20791, 'Telêmaco Borba', 'La Paz', 'Nossa Senhora de Fátima', '84264-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20792, 'Umuarama', 'La Paz', 'Jardim Los Angeles', '87509-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20793, 'Colombo', 'La Paz', 'Planta Cristóvão Colombo', '83404-530', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20794, 'Maringá', 'La Rioja', 'Loteamento Madrid', '87053-517', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20795, 'Londrina', 'La Salle', 'Canadá', '86020-480', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20796, 'Cascavel', 'La Salle', 'São Cristóvão', '85816-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20797, 'Curitiba', 'La Salle', 'Pinheirinho', '81880-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20798, 'Curitiba', 'Lacerdópolis', 'Cidade Industrial', '81240-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20799, 'Curitiba', 'Lacrides Fernandes Santos', 'Uberaba', '81550-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20800, 'Francisco Beltrão', 'Lacto', 'Jardim Floresta', '85603-387', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20801, 'Sarandi', 'Ladario', 'Jardim Esplanada', '87112-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20802, 'Paranavaí', 'Ladislao Morowis', 'Jardim São Jorge', '87710-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20803, 'Araucária', 'Ladislau Brongel', 'Capela Velha', '83706-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20804, 'Araucária', 'Ladislau Gembaroski', 'Thomaz Coelho', '83707-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20805, 'Almirante Tamandaré', 'Ladislau Gubaua', 'Jardim Ipanema', '83507-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20806, 'Guarapuava', 'Ladislau Kaminski', 'Jardim das Américas', '85030-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20807, 'Curitiba', 'Ladislau Luka', 'Cidade Industrial', '81460-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20808, 'Curitiba', 'Ladislau Mikosz', 'Cajuru', '82970-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20809, 'Curitiba', 'Ladislau Paszkiewicz', 'Uberaba', '81590-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20810, 'Curitiba', 'Ladislau Polovey', 'Alto Boqueirão', '81770-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20811, 'Curitiba', 'Ladislau Sikora', 'São Braz', '82310-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20812, 'Curitiba', 'Ladislau Smak', 'Uberaba', '81580-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20813, 'São José dos Pinhais', 'Ladislau Toczeck', 'Colônia Murici', '83085-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20814, 'Curitiba', 'Ladislau Trojan', 'Bacacheri', '82600-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20815, 'Curitiba', 'Ladislau Veiga', 'Cidade Industrial', '81310-408', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20816, 'Londrina', 'Lady Diana', 'Residencial Abussafe', '86037-769', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20817, 'Maringá', 'Laélia', 'Jardim Ipiranga', '87020-140', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20818, 'Ponta Grossa', 'Laércio Gama Durante', 'Ronda', '84051-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20819, 'São José dos Pinhais', 'Laerte Fenelon', 'Ipê', '83055-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20820, 'Curitiba', 'Laertes Lambertucci', 'Cidade Industrial', '81230-427', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20821, 'Curitiba', 'Laertes Luiz Fugiato', 'Sítio Cercado', '81920-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20822, 'Pato Branco', 'Lafaiete', 'Menino Deus', '85502-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20823, 'Maringá', 'Lafayete Tourinho', 'Zona 05', '87015-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20824, 'Curitiba', 'Lafayette Queirolo', 'Uberaba', '81540-375', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20825, 'Cascavel', 'Lageado', 'Canadá', '85813-600', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20826, 'Cascavel', 'Lageado', 'Canadá', '85813-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20827, 'Francisco Beltrão', 'Lages', 'Pinheirinho', '85603-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20828, 'Guarapuava', 'Lages', 'Santa Cruz', '85015-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20829, 'Foz do Iguaçu', 'Lages', 'Jardim Lancaster I', '85869-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20830, 'São José dos Pinhais', 'Lages', 'São Sebastião', '83075-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20831, 'Guarapuava', 'Lago Azul', 'Industrial', '85045-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20832, 'Telêmaco Borba', 'Lagoa', 'Área 02', '84267-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20833, 'Cascavel', 'Lagoa Araucária', 'Lago Azul', '85817-805', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20834, 'Cambé', 'Lagoa Azul', 'Jardim do Lago', '86192-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20835, 'Cascavel', 'Lagoa Bonita', 'Periolo', '85817-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20836, 'Cascavel', 'Lagoa Camacho', 'Lago Azul', '85817-815', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20837, 'Cascavel', 'Lagoa Camarim', 'Lago Azul', '85817-827', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20838, 'Cascavel', 'Lagoa Conceição', 'Lago Azul', '85817-818', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20839, 'Cascavel', 'Lagoa da Mangabeira', 'Lago Azul', '85817-829', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20840, 'Cascavel', 'Lagoa da Pinguela', 'Lago Azul', '85817-826', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20841, 'Cascavel', 'Lagoa dios Patos', 'Lago Azul', '85817-807', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20842, 'Cambé', 'Lagoa dos Patos', 'Jardim do Lago', '86192-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20843, 'Telêmaco Borba', 'Lagoa Dourada', 'Vila Ozorio', '84268-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20844, 'Cambé', 'Lagoa Dourada', 'Jardim do Lago', '86192-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20845, 'Curitiba', 'Lagoa Dourada', 'Campo Comprido', '81240-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20846, 'Cascavel', 'Lagoa Grande', 'Lago Azul', '85817-819', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20847, 'Cascavel', 'Lagoa Ibirapuera', 'Lago Azul', '85817-816', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20848, 'Cascavel', 'Lagoa Itapeva', 'Lago Azul', '85817-808', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20849, 'Cascavel', 'Lagoa Mancaba', 'Lago Azul', '85817-828', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20850, 'Cascavel', 'Lagoa Mangueira', 'Lago Azul', '85817-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20851, 'Cascavel', 'Lagoa Marapende', 'Lago Azul', '85817-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20852, 'Cascavel', 'Lagoa Marico', 'Lago Azul', '85817-809', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20853, 'Cascavel', 'Lagoa Mirim', 'Canadá', '85813-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20854, 'Cascavel', 'Lagoa Mirim', 'Lago Azul', '85817-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20855, 'Cascavel', 'Lagoa Mundau', 'Lago Azul', '85817-817', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20856, 'Cascavel', 'Lagoa Rodrigo de Freitas', 'Lago Azul', '85817-825', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20857, 'Cambé', 'Lagoa Santa', 'Jardim do Lago', '86192-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20858, 'Cascavel', 'Lagoa Saquarema', 'Lago Azul', '85817-806', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20859, 'Cambé', 'Lagoa Verde', 'Jardim do Lago', '86192-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20860, 'Foz do Iguaçu', 'Lagoa Vermelha', 'Jardim Vitória', '85853-677', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20861, 'Cambé', 'Lagoa Vermelha', 'Jardim do Lago', '86192-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20862, 'Cascavel', 'Lagoa Vermelha', 'Canadá', '85813-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20863, 'Foz do Iguaçu', 'Laguna', 'Jardim Aurora', '85862-206', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20864, 'Paranavaí', 'Laguna', 'Jardim São Jorge', '87710-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20865, 'Piraquara', 'Laguna', 'Planta São Tiago', '83307-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20866, 'Maringá', 'Laguna', 'Zona 01', '87050-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20867, 'Toledo', 'Laguna', 'Jardim Paulista', '85909-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20868, 'Umuarama', 'Laguna', 'Jardim Europa', '87502-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20869, 'São José dos Pinhais', 'Laguna', 'Guatupê', '83065-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20870, 'Foz do Iguaçu', 'Laila Osman', 'Jardim Dona Fátima Osman', '85856-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20871, 'Londrina', 'Laís Bárbara Muniz Silva', 'Conjunto Residencial Vale do Arvoredo', '86047-528', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20872, 'Foz do Iguaçu', 'Lajeado', 'Jardim Vasco da Gama', '85862-398', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20873, 'Foz do Iguaçu', 'Lajeado Mirim', 'Jardim Vale do Sol', '85862-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20874, 'Cascavel', 'Lajes', 'Universitário', '85819-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20875, 'Curitiba', 'Lali Maria Soecki', 'Umbará', '81940-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20876, 'Foz do Iguaçu', 'Lall Singh', 'Cr 5', '85863-715', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20877, 'Foz do Iguaçu', 'Lamartine Babo', 'Vila Pérola', '85865-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20878, 'Foz do Iguaçu', 'Lamartine Babo', 'Jardim Comercial das Bandeiras', '85864-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20879, 'Apucarana', 'Lamartine Babo', 'Núcleo Habitacional Castelo Branco', '86812-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20880, 'Curitiba', 'Lamartine Babo', 'Xaxim', '81810-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20881, 'Pato Branco', 'Lamartine Barbo', 'Chaparral', '85507-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20882, 'Ponta Grossa', 'Lambari', 'Cará-cará', '84043-729', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20883, 'Campo Mourão', 'Lambari', 'Jardim Alvorada', '87308-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20884, 'Ponta Grossa', 'Lamenha Lins', 'Uvaranas', '84025-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20885, 'Colombo', 'Lamenha Lins', 'Jardim Quitandinha', '83409-490', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20886, 'Curitiba', 'Lamenha Lins', 'Centro', '80250-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20887, 'Curitiba', 'Lamenha Lins', 'Parolin', '80220-081', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20888, 'Curitiba', 'Lamenha Lins', 'Rebouças', '80220-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20889, 'Londrina', 'Landulfo Mendes de Souza', 'Kennedy', '86060-185', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20890, 'Curitiba', 'Lange', 'Água Verde', '80240-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20891, 'Curitiba', 'Lange de Morretes', 'Jardim Social', '82520-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20892, 'Foz do Iguaçu', 'Lapa', 'Jardim Belvedere I', '85867-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20893, 'Paranaguá', 'Lapa', 'Emboguaçu', '83209-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20894, 'Paranavaí', 'Lapa', 'Jardim Ouro Branco', '87704-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20895, 'Piraquara', 'Lapa', 'Planta Araçatuba', '83301-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20896, 'Paranavaí', 'Lapa', 'Jardim Ibirapuera', '87705-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20897, 'Ponta Grossa', 'Lapa', 'Cará-cará', '84032-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20898, 'São José dos Pinhais', 'Lapa', 'Cruzeiro', '83010-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20899, 'Toledo', 'Lapa', 'Jardim Bressan', '85913-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20900, 'Colombo', 'Lapa', 'Jardim Cristina III', '83410-750', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20901, 'Apucarana', 'Lapa', 'Centro', '86800-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20902, 'Maringá', 'Lápis-Lazuli', 'Jardim Santa Helena', '87083-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20903, 'Ponta Grossa', 'Laplace', 'Colônia Dona Luiza', '84045-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20904, 'Campo Mourão', 'Lar Paraná', 'Jardim Lar Paraná', '87305-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20905, 'Telêmaco Borba', 'Laranja', 'Fazenda Limeira', '84270-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20906, 'Cascavel', 'Laranja', 'Brasília', '85815-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20907, 'Piraquara', 'Laranjeira', 'Jardim Primavera', '83302-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20908, 'Foz do Iguaçu', 'Laranjeiras', 'Parque Morumbi', '85858-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20909, 'Francisco Beltrão', 'Laranjeiras', 'Cango', '85603-815', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20910, 'Londrina', 'Laranjeiras', 'Marumbi', '86035-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20911, 'Ponta Grossa', 'Laranjeiras', 'Chapada', '84064-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20912, 'Araucária', 'Laranjeiras', 'Estação', '83705-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20913, 'Curitiba', 'Laranjeiras', 'Bairro Alto', '82840-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20914, 'Foz do Iguaçu', 'Laranjeiras do Sul', 'Jardim Duarte', '85861-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20915, 'Ponta Grossa', 'Laranjeiras do Sul', 'Contorno', '84052-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20916, 'Cascavel', 'Laranjeiras do Sul', 'São Cristóvão', '85816-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20917, 'Curitiba', 'Laranjeiras do Sul', 'Alto Boqueirão', '81770-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20918, 'Campo Mourão', 'Largo', 'Jardim Paulista', '87300-510', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20919, 'Francisco Beltrão', 'Las Palmas', 'Pinheirinho', '85603-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20920, 'Francisco Beltrão', 'Las Vegas', 'Pinheirinho', '85603-320', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20921, 'Sarandi', 'Las Vegas', 'Jardim Califórnia', '87112-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20922, 'Umuarama', 'Las Vegas', 'Jardim Los Angeles', '87509-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20923, 'Colombo', 'Las Vegas', 'Vila Miracema', '83408-340', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20924, 'Foz do Iguaçu', 'Latife Osman', 'Jardim Dona Fátima Osman', '85856-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20925, 'Ponta Grossa', 'Latino Coelho', 'Colônia Dona Luiza', '84043-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20926, 'Ponta Grossa', 'Latino Coelho', 'Colônia Dona Luiza', '84045-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20927, 'Colombo', 'Laudelina Ferreira Colere', 'Jardim dos Eucaliptos', '83408-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20928, 'Curitiba', 'Laudelino Afonso da Rocha', 'Xaxim', '81820-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20929, 'Curitiba', 'Laudelino Ferreira Lopes', 'Novo Mundo', '81050-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20930, 'Curitiba', 'Laudelino Ferreira Lopes', 'Capão Raso', '81130-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20931, 'Curitiba', 'Laudelino Ferreira Lopes', 'Capão Raso', '81150-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20932, 'Londrina', 'Laudelino Lazari', 'João Paz', '86087-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20933, 'Maringá', 'Laudelino Pedro da Silva', 'Conjunto Habitacional Karina', '87047-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20934, 'Maringá', 'Laudelino Pedro da Silva', 'Jardim América', '87045-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20935, 'Curitiba', 'Laudelino Ramos', 'Vista Alegre', '80820-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20936, 'Curitiba', 'Laudemeri Rodrigues Apolônio', 'Sítio Cercado', '81920-755', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20937, 'Curitiba', 'Laudemiro do Valle', 'Pilarzinho', '82110-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20938, 'Curitiba', 'Laura Evangelina Bastos do Valle', 'Cidade Industrial', '81270-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20939, 'Curitiba', 'Laura Gonçalves dos Santos', 'Cidade Industrial', '81250-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20940, 'Apucarana', 'Laura Ilkiu da Silva', 'Vila Shangri-La', '86812-145', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20941, 'Pinhais', 'Laura Lopes dos Santos', 'Vila Tarumã', '83323-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20942, 'São José dos Pinhais', 'Laura Lopes Latuf', 'Cruzeiro', '83010-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20943, 'Maringá', 'Laura Luzia Franzoi', 'Conjunto Habitacional Requião', '87047-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20944, 'São José dos Pinhais', 'Laura Nunes Fernandes', 'Afonso Pena', '83050-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20945, 'Curitiba', 'Laura Rodrigues Macedo', 'Cidade Industrial', '81460-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20946, 'Londrina', 'Laurentina Maria de Freitas', 'Jardim Alphaville', '86084-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20947, 'Campo Mourão', 'Laurentino Batista Guimarães', 'Jardim Nossa Senhora Aparecida', '87309-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20948, 'Maringá', 'Laurentino Evangelista do Prado', 'Parque Avenida', '87025-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20949, 'Ponta Grossa', 'Laurentino Fagundes', 'Jardim Carvalho', '84015-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20950, 'Londrina', 'Laurentino Gomes Hubner', 'Jardim dos Alpes III', '86045-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20951, 'Londrina', 'Lauresto Franco', 'Conjunto Habitacional  Alexandre Urbanas', '86037-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20952, 'Londrina', 'Lauretana L. C. Pisconti', 'Cafezal', '86045-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20953, 'Londrina', 'Laurinda Ferreira', 'Parque Residencial Elizabeth', '86077-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20954, 'Piraquara', 'Laurinda Ribeiro Vieira', 'Vila Fuck', '83305-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20955, 'Curitiba', 'Laurindo Antônio Segalla', 'Cajuru', '82980-195', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20956, 'Campo Mourão', 'Laurindo Borges', 'Centro', '87300-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20957, 'Campo Mourão', 'Laurindo Borges', 'Centro', '87303-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20958, 'Apucarana', 'Laurindo Cândido de Melo Lopes', 'Parque Industrial Zona Oeste II', '86800-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20959, 'Curitiba', 'Laurindo de Paula Cordeiro', 'Novo Mundo', '81050-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20960, 'São José dos Pinhais', 'Laurindo Grutter', 'Guatupê', '83065-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20961, 'Toledo', 'Laurindo Moterle', 'Coopagro', '85903-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20962, 'Londrina', 'Laurindo Pereira', 'Monte Belo', '86041-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20963, 'Almirante Tamandaré', 'Laurindo Pereira Machado', 'Vila Primor', '83507-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20964, 'Francisco Beltrão', 'Laurindo Pitt', 'Seminário', '85605-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20965, 'Ponta Grossa', 'Laurindo Rabelo', 'Jardim Carvalho', '84016-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20966, 'Guarapuava', 'Laurindo Rocha', 'Conradinho', '85060-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20967, 'Toledo', 'Laurindo Salvador', 'Boa Esperança', '85909-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20968, 'Apucarana', 'Laurindo Xavier', 'Residencial Parque da Raposa', '86812-597', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20969, 'Londrina', 'Lauro Alves do Nascimento', 'Pinheiros', '86063-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20970, 'Francisco Beltrão', 'Lauro Bachiroto Baggio', 'São Miguel', '85602-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20971, 'Pato Branco', 'Lauro Bertol', 'Santa Terezinha', '85501-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20972, 'Ponta Grossa', 'Lauro Bittencourt Neto', 'Jardim Carvalho', '84016-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20973, 'Castro', 'Lauro Bueno', 'Núcleo Habitacional Padre Piva', '84178-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20974, 'Curitiba', 'Lauro Calixto', 'Tatuquara', '81470-276', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20975, 'Castro', 'Lauro Caxambu', 'Loteamento Jardim Pandorf', '84182-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20976, 'Curitiba', 'Lauro Corona', 'Pinheirinho', '81150-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20977, 'Curitiba', 'Lauro da Silva', 'Cidade Industrial', '81305-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20978, 'Ponta Grossa', 'Lauro d''Almeida', 'Boa Vista', '84072-308', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20979, 'Londrina', 'Lauro Dantas de Faria', 'Jardim Santa Fé', '86035-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20980, 'Campo Largo', 'Lauro Domingues de Ramos', 'Itaqui', '83604-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20981, 'Curitiba', 'Lauro dos Santos Milão', 'Pilarzinho', '82100-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20982, 'Curitiba', 'Lauro Esmanhoto', 'Santa Felicidade', '82020-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20983, 'Ponta Grossa', 'Lauro Ferreira Ribas', 'Uvaranas', '84030-666', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20984, 'Araucária', 'Lauro Furlan', 'Capela Velha', '83706-730', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20985, 'Curitiba', 'Lauro Gatner de Morais', 'Butiatuvinha', '82320-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20986, 'Paranaguá', 'Lauro Gomes da Veiga Pessoa', 'Raia', '83206-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20987, 'Curitiba', 'Lauro Grein', 'Cidade Industrial', '81260-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20988, 'Londrina', 'Lauro J. P. Müller', 'Erotildes', '86015-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20989, 'Araucária', 'Lauro Machoski', 'Cachoeira', '83701-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20990, 'Curitiba', 'Lauro Mallin', 'Cascatinha', '82020-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20991, 'Ponta Grossa', 'Lauro Marcondes Ferreira', 'Jardim Carvalho', '84015-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20992, 'Ponta Grossa', 'Lauro Müller', 'Uvaranas', '84025-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20993, 'Piraquara', 'Lauro Müller', 'Jardim Itiberê', '83314-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20994, 'Ponta Grossa', 'Lauro P. Ribas', 'Boa Vista', '84071-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20995, 'Foz do Iguaçu', 'Lauro Peters', 'Parque Presidente II', '85863-660', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20996, 'Curitiba', 'Lauro Scheleder', 'Boa Vista', '82650-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20997, 'Londrina', 'Lauro Sebastião Pesushi', 'Novo Amparo', '86043-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20998, 'Curitiba', 'Lauro Shereiber', 'Cidade Industrial', '81450-718', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (20999, 'Curitiba', 'Lauro Tavares Rodrigues', 'Xaxim', '81720-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21000, 'Apucarana', 'Lauro Teixeira Osório', 'Vila Nossa Senhora da Aparecida', '86810-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21001, 'Curitiba', 'Lauro Varombi', 'Santa Cândida', '82720-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21002, 'Londrina', 'Lausanne', 'Bela Suiça', '86050-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21003, 'Arapongas', 'Lavadeira', 'Jardim Cultura', '86707-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21004, 'Curitiba', 'Lavínia Zanon', 'Bacacheri', '82600-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21005, 'Colombo', 'Lavoisier', 'Vila Guarani', '83408-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21006, 'Curitiba', 'Lavrador João Silva Ortiz', 'Novo Mundo', '81050-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21007, 'Foz do Iguaçu', 'Lavras', 'Jardim Veneza', '85870-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21008, 'Londrina', 'Lázara Mendes Ribeiro', 'Jardim Império do Sol', '86073-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21009, 'Apucarana', 'Lázaro Benedito', 'Jardim Aviação', '86812-517', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21010, 'Maringá', 'Lázaro Benedito Carnielli', 'Jardim Canadá', '87080-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21011, 'Maringá', 'Lázaro Bento', 'Parque Residencial Aeroporto', '87055-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21012, 'Umuarama', 'Lázaro Bom', 'Jardim Petrópolis', '87506-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21013, 'Curitiba', 'Lázaro Borssatto', 'Alto Boqueirão', '81770-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21014, 'Londrina', 'Lázaro Brandino da Silva', 'Jardim Paris', '86082-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21015, 'Londrina', 'Lázaro de Toledo', 'Conjunto Parigot de Souza 3', '86081-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21016, 'Paranavaí', 'Lázaro Figueiredo Vieira', 'Jardim Avaré', '87709-330', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21017, 'Paranavaí', 'Lázaro Figueiredo Vieira', 'Jardim Progresso', '87701-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21018, 'Londrina', 'Lázaro Inácio Tavares', 'Parque Residencial João Piza', '86041-095', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21019, 'Londrina', 'Lázaro José Carias de Souza', 'Conjunto Semiramis Barros Braga', '86088-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21020, 'Pinhais', 'Lázaro Moreira', 'Vila Maria Antonieta', '83331-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21021, 'Curitiba', 'Lázaro Nini de Campos', 'Uberaba', '81560-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21022, 'Londrina', 'Lázaro Soares de Souza', 'Portal de Versalhes 3', '86055-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21023, 'Curitiba', 'Lázaro Zacarias dos Santos', 'Santa Cândida', '82630-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21024, 'Londrina', 'Lázaro Zamenhof', 'San Fernando', '86040-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21025, 'Maringá', 'Lazurita', 'Jardim Brasil', '87083-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21026, 'Ponta Grossa', 'Lazurita', 'Neves', '84021-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21027, 'Cascavel', 'Le Mans', 'Interlagos', '85814-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21028, 'Curitiba', 'Léa Moreira de Souza Moura', 'Cidade Industrial', '81315-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21029, 'Ponta Grossa', 'Leandro', 'Contorno', '84061-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21030, 'Colombo', 'Leandro Alberti', 'Jardim dos Eucaliptos', '83408-548', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21031, 'Curitiba', 'Leandro Dacheux do Nascimento Júnior', 'Cidade Industrial', '81270-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21032, 'Castro', 'Leandro Galeto', 'Cantagalo', '84178-500', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21033, 'Londrina', 'Leandro Maciel', 'Sebastião de Melo César', '86084-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21034, 'Curitiba', 'Leandro Pilatti', 'Pilarzinho', '82120-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21035, 'Curitiba', 'Leão Benjamin Breda', 'São Braz', '82015-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21036, 'Ponta Grossa', 'Leão Federmann', 'Jardim Carvalho', '84015-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21037, 'Cascavel', 'Leão Iankoski', 'Cataratas', '85818-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21038, 'Curitiba', 'Leão Sallum', 'Boa Vista', '82540-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21039, 'Curitiba', 'Leão Trauczynski', 'Tatuquara', '81470-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21040, 'Guarapuava', 'Leão XIII', 'Morro Alto', '85065-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21041, 'Curitiba', 'Leão Zeigelboim', 'Santa Felicidade', '82020-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21042, 'Londrina', 'Leblon', 'Ipanema', '86015-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21043, 'Cascavel', 'Leblon', 'Periolo', '85817-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21044, 'Londrina', 'Leci Suzana Garcia', 'Ernani de Moura Lima', '86037-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21045, 'Arapongas', 'Lecre', 'Vila Conceição', '86708-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21046, 'Londrina', 'Leda Coutinho Gomes', 'Jardim Império do Sol', '86073-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21047, 'Toledo', 'Ledi Fischer Maas', 'Jardim Europa', '85907-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21048, 'Toledo', 'Ledoíno José Biavatti', 'Vila Industrial', '85904-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21049, 'Toledo', 'Ledoíno José Biavatti', 'Vila Industrial', '85905-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21050, 'Pato Branco', 'Ledovino Fazolin', 'Fundabem', '85509-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21051, 'Curitiba', 'Leduína dos Santos Silva', 'Augusta', '81260-547', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21052, 'Curitiba', 'Léia Filomena Dias', 'Fazendinha', '81330-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21053, 'Foz do Iguaçu', 'Leila Diniz', 'Jardim Central', '85864-450', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21054, 'Londrina', 'Leila Diniz', 'Conjunto Vivi Xavier', '86082-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21055, 'Paranavaí', 'Leila Diniz', 'Jardim São Jorge', '87711-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21056, 'Pinhais', 'Leila Diniz', 'Vila Maria Antonieta', '83331-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21057, 'Cascavel', 'Leila Diniz', 'Alto Alegre', '85805-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21058, 'Maringá', 'Leining', 'Vila Regina', '87045-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21059, 'Curitiba', 'Lélia Corrêa de Azevedo', 'Seminário', '80440-230', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21060, 'Londrina', 'Lélio Orlando Policastro', 'Jardim Atlânta', '86042-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21061, 'Londrina', 'Lelis de Castilho Pimentel', 'Jardim Honda II', '86076-206', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21062, 'Curitiba', 'Lello Marchine', 'Campo Comprido', '81240-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21063, 'Foz do Iguaçu', 'Leme', 'Loteameto Dona Amanda', '85853-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21064, 'Guarapuava', 'Lemos', 'Morro Alto', '85067-490', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21065, 'Campo Mourão', 'Lemos do Prado', 'Jardim Lar Paraná', '87305-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21066, 'Curitiba', 'Lendina Germano Ribeiro', 'Atuba', '82860-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21067, 'Londrina', 'Leni Remonato Mendes', 'Jardim Hirata', '86080-396', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21068, 'Curitiba', 'Lenira Maria dos Santos Reis', 'Cidade Industrial', '81250-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21069, 'Londrina', 'Lenita Cesár', 'Conjunto Novo Amparo 2', '86056-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21070, 'Curitiba', 'Lenita Rosa Chella', 'Cidade Industrial', '81460-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21071, 'Londrina', 'Leo', 'Sol', '86070-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21072, 'Castro', 'Leo Afonso M. de Souza', 'Jardim Dona Helena', '84178-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21073, 'Paranaguá', 'Leo César Manso da Silva', 'Ponta do Caju', '83206-448', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21074, 'Curitiba', 'Leo de Abreu Miró', 'Uberaba', '81590-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21075, 'Curitiba', 'Leo Marcondes Zanardini', 'Tatuquara', '81480-167', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21076, 'Curitiba', 'Leo Roberto Diedrich', 'Cidade Industrial', '81170-570', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21077, 'Pinhais', 'Leo Vaz', 'Núcleo Colonial de Pinhais', '83321-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21078, 'Piraquara', 'Leocádia Cordeiro Siqueira', 'Vila Fuck', '83305-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21079, 'Araucária', 'Leocádia Skczipek Belo', 'Thomaz Coelho', '83707-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21080, 'São José dos Pinhais', 'Leocádia Sochaki', 'Guatupê', '83060-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21081, 'Almirante Tamandaré', 'Leocádia Vistuba Peressutti', 'Jardim Novo Horizonte da Cachoeira', '83502-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21082, 'Ponta Grossa', 'Leocádio Correia', 'Oficinas', '84035-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21083, 'Castro', 'Leocádio José Correia', 'Centro', '84165-035', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21084, 'Curitiba', 'Leocádio Júlio de Assumpção', 'Cascatinha', '82020-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21085, 'Curitiba', 'Leocádio Pereira da Costa', 'Jardim Botânico', '80210-210', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21086, 'Curitiba', 'Leocádio Robison de Lima Damazio', 'Alto Boqueirão', '81860-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21087, 'Curitiba', 'Leoclides Pereira de Macedo', 'Cajuru', '82940-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21088, 'Curitiba', 'Leodenir Vendramin', 'Campina do Siqueira', '80730-490', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21089, 'Apucarana', 'Leodoro de Moura', 'Loteamento Residencial Miguel Sochacki', '86802-376', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21090, 'Foz do Iguaçu', 'Leodoro Fernandes', 'Alto São Francisco', '85863-768', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21091, 'Curitiba', 'Leodoro Ferreira de Castro', 'Cajuru', '82930-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21092, 'Cambé', 'Leões', 'Centro', '86181-030', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21093, 'Londrina', 'Leolina Mathias Peres', 'Conjunto Habitacional Saltinho', '86042-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21094, 'Londrina', 'Leon Denis', 'Califórnia', '86040-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21095, 'Toledo', 'Leon Denis', 'Parque Residencial Pancera', '85902-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21096, 'Curitiba', 'Leon Nicolas', 'Capão Raso', '81150-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21097, 'Curitiba', 'Leon Tolstoi', 'Lindóia', '81010-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21098, 'Curitiba', 'Leonardo Abagge', 'Sítio Cercado', '81900-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21099, 'Foz do Iguaçu', 'Leonardo Almeida', 'Loteamento Witt', '85862-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21100, 'Umuarama', 'Leonardo Bacarin', 'Jardim San Fernando', '87508-177', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21101, 'Araucária', 'Leonardo Bocon', 'Barigui', '83707-630', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21102, 'Curitiba', 'Leonardo Bonato', 'Xaxim', '81830-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21103, 'Toledo', 'Leonardo Bracht', 'Passarini IV', '85906-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21104, 'Curitiba', 'Leonardo Cândido Ferreira', 'Cidade Industrial', '81305-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21105, 'Guarapuava', 'Leonardo Coblinski', 'Boqueirão', '85022-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21106, 'Guarapuava', 'Leonardo Coblinski', 'Boqueirão', '85023-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21107, 'Londrina', 'Leonardo da Vinci', 'Caravelle', '86039-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21108, 'Umuarama', 'Leonardo Da Vinci', 'Conjunto Residencial Ouro Preto', '87504-607', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21109, 'Cambé', 'Leonardo da Vinci', 'Jardim Montecatini', '86186-250', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21110, 'Cascavel', 'Leonardo da Vinci', 'Interlagos', '85814-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21111, 'Curitiba', 'Leonardo da Vinci', 'Guabirotuba', '81510-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21112, 'São José dos Pinhais', 'Leonardo Difert', 'Barro Preto', '83015-807', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21113, 'Colombo', 'Leonardo Druz', 'Jardim Marambaia', '83404-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21114, 'Toledo', 'Leonardo Francisco Nogueira', 'Coopagro', '85903-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21115, 'Piraquara', 'Leonardo Gluczkowski', 'Planta Terezinha', '83311-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21116, 'Curitiba', 'Leonardo Guembaroski', 'Sítio Cercado', '81910-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21117, 'São José dos Pinhais', 'Leonardo Henke', 'São Sebastião', '83075-088', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21118, 'Curitiba', 'Leonardo Jareski', 'Cajuru', '82970-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21119, 'Curitiba', 'Leonardo Javorski', 'Fazendinha', '81330-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21120, 'Toledo', 'Leonardo Júlio Perna', 'Centro', '85900-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21121, 'Araucária', 'Leonardo Karas', 'Porto das Laranjeiras', '83703-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21122, 'Almirante Tamandaré', 'Leonardo Kleina', 'Jardim Santa Rita de Cássia', '83506-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21123, 'Curitiba', 'Leonardo Krasinski', 'Boa Vista', '82540-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21124, 'Curitiba', 'Leonardo Krasinski', 'Boa Vista', '82560-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21125, 'Curitiba', 'Leonardo Kubis', 'Orleans', '82310-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21126, 'Curitiba', 'Leonardo Kucek', 'Sítio Cercado', '81925-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21127, 'Almirante Tamandaré', 'Leonardo Muraski', 'Jardim Paraíso', '83512-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21128, 'Curitiba', 'Leonardo Pianowski', 'Pinheirinho', '81150-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21129, 'Araucária', 'Leonardo Piska', 'Costeira', '83709-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21130, 'Ponta Grossa', 'Leonardo Rocha Wendler', 'Jardim Carvalho', '84015-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21131, 'Londrina', 'Leonardo S. F. da Rosa', 'Estados', '86083-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21132, 'Guarapuava', 'Leonardo Valente Hiczy', 'Primavera', '85050-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21133, 'Curitiba', 'Leonardo Werbitzki', 'Ganchinho', '81935-350', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21134, 'Curitiba', 'Leonardo Wesolowski', 'Campo Comprido', '81230-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21135, 'Curitiba', 'Leonardo Zillmann', 'Pilarzinho', '82100-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21136, 'Pato Branco', 'Leôncio Amadori', 'Aeroporto', '85503-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21137, 'São José dos Pinhais', 'Leôncio Corrêa', 'São Sebastião', '83075-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21138, 'Pinhais', 'Leôncio Correia', 'Planta Núcleo Colonial de Pinhais', '83321-340', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21139, 'Curitiba', 'Leôncio Correia', 'Água Verde', '80240-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21140, 'Curitiba', 'Leôncio Derosso', 'Xaxim', '81810-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21141, 'Curitiba', 'Leôncio Lopes Cortiano', 'Xaxim', '81720-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21142, 'Curitiba', 'Leôncio Lopes Cortiano', 'Xaxim', '81830-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21143, 'Maringá', 'Leone Antônio Fregonese', 'Conjunto Residencial Cidade Alta', '87053-075', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21144, 'Campo Mourão', 'Leone Biagio', 'Jardim Capricórnio', '87301-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21145, 'São José dos Pinhais', 'Leone Décimo Dal''Negro', 'Colônia Rio Grande', '83025-440', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21146, 'São José dos Pinhais', 'Leonel Bassan', 'Cidade Jardim', '83035-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21147, 'Ponta Grossa', 'Leonel Berger', 'Orfãs', '84015-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21148, 'Londrina', 'Leonel de Oliveira Reis', 'Coliseu', '86076-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21149, 'Curitiba', 'Leonel Franca', 'Fanny', '81030-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21150, 'Curitiba', 'Leonel Furlan', 'Santa Felicidade', '82320-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21151, 'Londrina', 'Leonel Moraes Costa', 'Estados', '86083-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21152, 'Francisco Beltrão', 'Leonel Pramio', 'São Cristóvão', '85601-343', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21153, 'São José dos Pinhais', 'Leonel Simões', 'Guatupê', '83060-446', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21154, 'Campo Mourão', 'Leonel Sonsin', 'Parque Industrial I', '87306-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21155, 'Curitiba', 'Leonélio Dalledone', 'Uberaba', '81540-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21156, 'Guarapuava', 'Leoni de Jesus A. da Mota', 'Vila Bela', '85027-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21157, 'Guarapuava', 'Leoni de Lima', 'Vila Bela', '85025-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21158, 'Colombo', 'Leônidas Alberti', 'Jardim Guilhermina', '83410-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21159, 'Piraquara', 'Leônidas Alves Cordeiro', 'Vila Juliana', '83306-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21160, 'Paranavaí', 'Leônidas de Barros', 'Jardim Santos Dumont', '87706-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21161, 'Cascavel', 'Leônidas Fagundes', 'Claudete', '85811-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21162, 'Telêmaco Borba', 'Leônidas Garcia Rodrigues', 'Centro', '84261-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21163, 'Paranaguá', 'Leônidas Moreira', 'Vila Paranaguá', '83221-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21164, 'Araucária', 'Leônidas Poly', 'Costeira', '83708-737', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21165, 'Londrina', 'Leônidas Rezende Dutra', 'Santa Joana', '86044-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21166, 'São José dos Pinhais', 'Leônidas Sechi', 'Afonso Pena', '83050-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21167, 'Curitiba', 'Leônidas Silva', 'Cajuru', '82960-220', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21168, 'Curitiba', 'Leônidas Vicente de Castro', 'Ahú', '80540-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21169, 'Curitiba', 'Leônidas Xavier de Freitas', 'Pilarzinho', '82115-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21170, 'Londrina', 'Leonides Ferreira', 'Jardim Perobal', '86043-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21171, 'Londrina', 'Leonidia Pereira de Oliveira', 'Conjunto Habitacional José Garcia Molina', '86080-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21172, 'Londrina', 'Leonidia Pereira de Oliveira', 'Residencial Moradias Tibagi', '86080-446', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21173, 'Curitiba', 'Leonídio Balaban', 'Pinheirinho', '81820-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21174, 'Curitiba', 'Leonilda Duarte da Rosa', 'Alto Boqueirão', '81850-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21175, 'São José dos Pinhais', 'Leonilda Melo de Farias', 'Afonso Pena', '83065-126', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21176, 'Colombo', 'Leonilda Sibila Nadolny', 'Centro Industrial Mauá', '83413-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21177, 'Curitiba', 'Leonildo Burbello', 'Tatuquara', '81940-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21178, 'Curitiba', 'Leonildo Rigo', 'Cidade Industrial', '81460-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21179, 'Maringá', 'Leonildo Rubio', 'Parque Tarumã', '87053-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21180, 'Umuarama', 'Leonildo Stecca', 'Jardim Cruzeiro', '87504-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21181, 'Toledo', 'Leonir Giareta', 'Vila Becker', '85902-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21182, 'Foz do Iguaçu', 'Leonir José Gyer', 'Jardim Porto Belo', '85867-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21183, 'Londrina', 'Leonita Augusta', 'Jardim Belo Horizonte', '86037-297', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21184, 'Londrina', 'Leonor Bocchi Girotto', 'Jardim Ilha do Mel', '86081-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21185, 'Paranaguá', 'Leonor Bonaldi Scomasson', 'Campo Grande', '83203-716', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21186, 'Curitiba', 'Leonor Cardoso', 'Campo Comprido', '81240-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21187, 'Curitiba', 'Leonor Caron Alves', 'Parolin', '80220-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21188, 'Curitiba', 'Leonor Castellano', 'Pilarzinho', '82120-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21189, 'Ponta Grossa', 'Leonor Cavagnari Maciel', 'Contorno', '84052-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21190, 'Araucária', 'Leonor Cordeiro Iarek', 'Campina da Barra', '83709-828', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21191, 'Colombo', 'Leonor Dugonski', 'Jardim Guarujá', '83407-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21192, 'Curitiba', 'Leonor Helvig Nadolny', 'Atuba', '82630-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21193, 'Londrina', 'Leonor Maria Ribeiro', 'Jardim Primavera', '86086-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21194, 'Curitiba', 'Leonor Negrello Baldan', 'Tatuquara', '81940-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21195, 'Curitiba', 'Leonor Ribas Pires da Rocha', 'Pilarzinho', '82115-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21196, 'Guarapuava', 'Leonor Terezinha Ogiboski', 'Santa Cruz', '85015-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21197, 'Curitiba', 'Leonor Twardowski', 'Centro', '80060-280', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21198, 'Londrina', 'Leonora Armstrong', 'Champagnat', '86062-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21199, 'Ponta Grossa', 'Leonora Staciaki', 'Chapada', '84062-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21200, 'Ponta Grossa', 'Leonora Szimanecki', 'Chapada', '84064-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21201, 'Londrina', 'Leontina da Conceição Gaion', 'Ernani de Moura Lima', '86037-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21202, 'Londrina', 'Leontina de Souza Machado', 'Jardim Vale Verde', '86040-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21203, 'Curitiba', 'Leony Azeredo Rocha', 'Cajuru', '82950-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21204, 'Curitiba', 'Leony Margarida Machado', 'Bacacheri', '82520-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21205, 'Curitiba', 'Leony Medeiros Guimarães', 'Cidade Industrial', '81450-028', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21206, 'Curitiba', 'Leony Veiga', 'Pinheirinho', '81870-017', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21207, 'Campo Mourão', 'Leopardo', 'Jardim Aeroporto', '87310-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21208, 'Pato Branco', 'Leopoldina Iunk', 'São Roque', '85507-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21209, 'Curitiba', 'Leopoldina Zibarth', 'Uberaba', '81550-045', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21210, 'Londrina', 'Leopoldino José Teixeira', 'Conjunto Habitacional João Turquino', '86056-840', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21211, 'Toledo', 'Leopoldo Angeli', 'Residencial Santa Clara', '85903-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21212, 'Colombo', 'Leopoldo Appel', 'Itajacuru', '83407-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21213, 'Londrina', 'Leopoldo Battini', 'Jatobá', '86043-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21214, 'Guarapuava', 'Leopoldo Bischof', 'Jardim das Américas', '85030-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21215, 'Campo Largo', 'Leopoldo Chulik', 'Cercadinho', '83608-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21216, 'Ponta Grossa', 'Leopoldo de Almeida Taques', 'Uvaranas', '84031-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21217, 'Curitiba', 'Leopoldo de Lazari', 'Cidade Industrial', '81240-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21218, 'Ponta Grossa', 'Leopoldo Froes', 'Uvaranas', '84030-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21219, 'Curitiba', 'Leopoldo Froes', 'Prado Velho', '80220-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21220, 'Telêmaco Borba', 'Leopoldo Jarmuscheviski Woigt', 'Centro', '84261-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21221, 'Curitiba', 'Leopoldo Knaut Romanovski', 'Sítio Cercado', '81920-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21222, 'Curitiba', 'Leopoldo Kojarski', 'Xaxim', '81720-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21223, 'Curitiba', 'Leopoldo Lesniowski', 'Cidade Industrial', '81350-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21224, 'Curitiba', 'Leopoldo Manson Vaz', 'Boa Vista', '82540-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21225, 'Londrina', 'Leopoldo Meyer', 'Lago Juliana', '86038-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21226, 'São José dos Pinhais', 'Leopoldo Meyer', 'Ipê', '83055-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21227, 'Ponta Grossa', 'Leopoldo Miquez', 'Estrela', '84050-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21228, 'Campo Largo', 'Leopoldo Okraska', 'Jardim Nossa Senhora do Perpétuo Socorro', '83604-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21229, 'São José dos Pinhais', 'Leopoldo Pasqualin', 'Colônia Rio Grande', '83025-378', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21230, 'Ponta Grossa', 'Leopoldo Pinto Rosas', 'Oficinas', '84035-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21231, 'Pato Branco', 'Leopoldo Polazzo', 'Vila Verde', '85506-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21232, 'São José dos Pinhais', 'Leopoldo Precoma', 'Afonso Pena', '83050-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21233, 'Toledo', 'Leopoldo Rambo', 'Boa Esperança', '85909-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21234, 'Toledo', 'Leopoldo Rodhe', 'Jardim Taiobá', '85909-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21235, 'Toledo', 'Leopoldo Schmidt', 'Jardim Concórdia', '85906-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21236, 'Araucária', 'Leopoldo Sokulski', 'Barigui', '83707-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21237, 'Curitiba', 'Leopoldo Teuber', 'Pilarzinho', '80520-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21238, 'Araucária', 'Leopoldo Tuleski', 'Barigui', '83707-455', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21239, 'Curitiba', 'Leópolis', 'Alto Boqueirão', '81770-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21240, 'Curitiba', 'Leovegildo Marchioro', 'Cidade Industrial', '81310-405', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21241, 'Curitiba', 'Lerina Maciel Ribas', 'Barreirinha', '82710-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21242, 'Londrina', 'Leste', 'Leste Oeste', '86072-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21243, 'São José dos Pinhais', 'Leste', 'Miringuava', '83090-470', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21244, 'Sarandi', 'Leste', 'Jardim Perimetral', '87111-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21245, 'Apucarana', 'Leterio Livoti', 'Jardim Tarobá', '86813-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21246, 'Umuarama', 'Levi', 'Conjunto Residencial Vinte e Seis de Junho', '87508-089', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21247, 'Curitiba', 'Levi Alves Cordeiro', 'Cajuru', '82900-440', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21248, 'Cascavel', 'Levi Ireno Gonçalves', 'Parque Verde', '85807-716', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21249, 'Ponta Grossa', 'Levi Monastirski', 'Colônia Dona Luiza', '84043-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21250, 'Guarapuava', 'Levino Neitzke', 'Vila Bela', '85027-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21251, 'Curitiba', 'Levir Luiz Toaldo', 'Santa Felicidade', '82320-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21252, 'Ponta Grossa', 'Levítico', 'Chapada', '84062-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21253, 'Cambé', 'Levítico', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21254, 'Curitiba', 'Lia Garbaccio', 'Tatuquara', '81480-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21255, 'Toledo', 'Líbano', 'Jardim La Salle', '85903-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21256, 'Cambé', 'Líbano', 'Jardim Morada do Sol', '86181-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21257, 'Colombo', 'Libera Gasparin Fiorese', 'Jardim Bandeirantes', '83408-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21258, 'Toledo', 'Liberal Bottin', 'Conjunto Habitacional São Francisco', '85915-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21259, 'Cascavel', 'Liberal Cechin', 'Santos Dumont', '85804-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21260, 'Curitiba', 'Liberalino Estevan', 'Umbará', '81930-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21261, 'Toledo', 'Liberata Pedrini', 'Conjunto Habitacional São Francisco', '85915-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21262, 'Colombo', 'Liberato Cavalli Sobrinho', 'Campestre', '83415-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21263, 'Apucarana', 'Liberato de Souza Sardinha', 'Jardim Tibagi', '86813-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21264, 'Curitiba', 'Liberato Evangelista do Prado', 'Cajuru', '82930-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21265, 'Paranavaí', 'Liberdade', 'Jardim Videira', '87711-520', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21266, 'Maringá', 'Liberdade', 'Zona 08', '87050-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21267, 'São José dos Pinhais', 'Liberdade', 'Afonso Pena', '83050-030', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21268, 'São José dos Pinhais', 'Liberdade', 'Afonso Pena', '83050-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21269, 'Umuarama', 'Liberdade', 'Jardim Iguaçu', '87501-460', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21270, 'Campo Mourão', 'Liberdade', 'Conjunto Habitacional Mendes', '87306-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21271, 'Pinhais', 'Libéria', 'Vila Esplanada', '83320-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21272, 'Curitiba', 'Líbero Aguiar', 'Taboão', '82115-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21273, 'Foz do Iguaçu', 'Líbero Badaró', 'Jardim Jupira', '85865-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21274, 'Londrina', 'Líbero Badaró', 'Nova Londres', '86015-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21275, 'Maringá', 'Líbero Badaró', 'Zona 07', '87030-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21276, 'Ponta Grossa', 'Líbero Badaró', 'Uvaranas', '84032-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21277, 'Curitiba', 'Líbero Sant''Ana Nunes', 'Xaxim', '81830-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21278, 'Maringá', 'Libertador San Martim', 'Conjunto Habitacional Requião', '87047-416', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21279, 'Pinhais', 'Líbia', 'Vila Palmital', '83320-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21280, 'Telêmaco Borba', 'Líbia', 'Vila Cristina', '84272-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21281, 'Colombo', 'Líbia', 'Vila Alto da Cruz II', '83405-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21282, 'Curitiba', 'Líbia', 'Atuba', '82630-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21283, 'Foz do Iguaçu', 'Líbia Matias', 'Jardim Iara', '85854-165', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21284, 'Londrina', 'Libra', 'Sol', '86070-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21285, 'Curitiba', 'Liceria Rodrigues Miranda', 'Cidade Industrial', '81270-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21286, 'Almirante Tamandaré', 'Licídia Lemos Paixão', 'Loteamento Recanto dos Papagaios', '83512-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21287, 'Castro', 'Licínio Lopes', 'Jardim das Araucárias', '84174-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21288, 'Castro', 'Licínio Pereira Bueno', 'Cantagalo', '84178-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21289, 'Campo Mourão', 'Licínio Rodrigues dos Santos', 'Jardim Lar Paraná', '87305-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21290, 'Almirante Tamandaré', 'Lício de Barros Teixeira', 'Planta Bela Vista', '83514-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21291, 'Londrina', 'Licurgo', 'Jardim Yoshikawa', '86025-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21292, 'Curitiba', 'Lídia Abreu Pires', 'Seminário', '80740-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21293, 'Curitiba', 'Lídia Klinger', 'Abranches', '82130-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21294, 'Ponta Grossa', 'Lídia Scheidt Curi', 'Boa Vista', '84072-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21295, 'Curitiba', 'Lídia Schwarzbach Slomski', 'Cidade Industrial', '81350-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21296, 'Castro', 'Lídia Stella Biassio', 'Vila Santa Cruz', '84168-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21297, 'Curitiba', 'Lídia Wosch', 'Santa Cândida', '82650-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21298, 'Curitiba', 'Lídio Bolzani', 'Uberaba', '81560-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21299, 'Colombo', 'Lídio de Mello', 'Jardim Guaíra', '83402-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21300, 'Pato Branco', 'Lídio Guerra', 'La Salle', '85505-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21301, 'Curitiba', 'Lígia Barbosa Ribas', 'Mercês', '80430-020', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21302, 'Curitiba', 'Lila Mazurkievicz Graciano', 'Cidade Industrial', '81305-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21303, 'Cascavel', 'Lilás', 'Brasília', '85815-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21304, 'Londrina', 'Lilian Castelo Branco', 'Conjunto Novo Amparo 2', '86056-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21305, 'Londrina', 'Lilian Castelo Branco', 'São Lourenço', '86043-425', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21306, 'Curitiba', 'Lilian Júlia de Oliveira', 'Pilarzinho', '82115-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21307, 'São José dos Pinhais', 'Lilian Viana de Araújo', 'Cidade Jardim', '83035-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21308, 'Ponta Grossa', 'Lilita Nunes da Rocha', 'Estrela', '84050-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21309, 'Londrina', 'Lima', 'Guanabara', '86050-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21310, 'Foz do Iguaçu', 'Lima', 'Jardim Alice I', '85858-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21311, 'Paranaguá', 'Lima', 'Parque Agari', '83215-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21312, 'Maringá', 'Lima', 'Vila Morangueira', '87030-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21313, 'Telêmaco Borba', 'Lima', 'Nossa Senhora de Fátima', '84264-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21314, 'Cascavel', 'Lima', 'Região do Lago 2', '85816-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21315, 'Curitiba', 'Lima', 'Uberaba', '81560-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21316, 'Francisco Beltrão', 'Lima Barreto', 'São Miguel', '85602-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21317, 'Foz do Iguaçu', 'Lima Barreto', 'Jardim Central', '85864-500', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21318, 'Almirante Tamandaré', 'Lima Barreto', 'Vila Marta', '83508-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21319, 'Campo Largo', 'Lima Barreto', 'São Marcos', '83602-677', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21320, 'Cascavel', 'Lima Barreto', 'Cancelli', '85811-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21321, 'Curitiba', 'Lima Barreto', 'Jardim das Américas', '81530-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21322, 'Londrina', 'Limão', 'Glória', '86035-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21323, 'Telêmaco Borba', 'Limão', 'Fazenda Limeira', '84270-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21324, 'Francisco Beltrão', 'Limeira', 'Pinheirinho', '85603-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21325, 'Foz do Iguaçu', 'Limeira', 'Jardim das Laranjeiras', '85868-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21326, 'Guarapuava', 'Limeira', 'Alto Cascavel', '85031-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21327, 'Campo Largo', 'Limeira', 'Jardim Carmela', '83607-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21328, 'Cascavel', 'Limeira', 'Brasmadeira', '85814-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21329, 'Cambé', 'Limeira', 'Jardim São Paulo', '86191-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21330, 'Maringá', 'Limoeiro', 'Jardim Bertioga', '87055-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21331, 'Ponta Grossa', 'Limoeiro', 'Chapada', '84064-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21332, 'Cascavel', 'Limoeiro', 'Brasmadeira', '85814-137', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21333, 'Almirante Tamandaré', 'Limoeiro', 'Loteamento Chico Mendes', '83505-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21334, 'Campo Mourão', 'Limoeiro', 'Jardim Lar Paraná', '87305-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21335, 'Araucária', 'Limoeiros', 'Estação', '83705-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21336, 'Ponta Grossa', 'Limpo de Abreu', 'Uvaranas', '84031-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21337, 'Curitiba', 'Lina Maria Martins Moreira', 'Pinheirinho', '81870-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21338, 'Londrina', 'Lina Nazatto', 'Conjunto Semiramis Barros Braga', '86088-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21339, 'Campo Mourão', 'Lince', 'Jardim Alvorada', '87308-390', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21340, 'Guarapuava', 'Lincoln Ribas Prestes', 'Boqueirão', '85020-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21341, 'Araucária', 'Lincoln Setembrino Coimbra', 'Vila Nova', '83703-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21342, 'Pato Branco', 'Linda Marmentini', 'Centro', '85501-105', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21343, 'Almirante Tamandaré', 'Lindair de Goes', 'Vila Primor', '83507-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21344, 'Londrina', 'Lindalva Bandeira Milhomem Campos', 'Jardim Paraty', '86081-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21345, 'Londrina', 'Lindalva Silva Bassetto', 'Alto da Boa Vista', '86083-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21346, 'Curitiba', 'Lindamir Pizatto Mazzarotto', 'Santa Felicidade', '82030-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21347, 'Londrina', 'Lindaura Vasquez de Souza', 'Jardim Vale Azul', '86041-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21348, 'Foz do Iguaçu', 'Lindoeste', 'Jardim Ipanema', '85862-308', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21349, 'Londrina', 'Lindóia', 'Amaro', '86062-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21350, 'Umuarama', 'Lindolar', 'Parque Industrial I', '87507-057', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21351, 'Colombo', 'Lindolfo Alves das Neves', 'Jardim Aurora', '83411-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21352, 'Curitiba', 'Lindolfo Collor', 'Guabirotuba', '81510-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21353, 'São José dos Pinhais', 'Lindolfo Damann', 'Guatupê', '83060-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21354, 'Pato Branco', 'Lindolfo Dietrich', 'La Salle', '85505-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21355, 'Guarapuava', 'Lindolfo Kuster', 'Jardim das Américas', '85030-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21356, 'Araucária', 'Lindolfo Luiz Boell', 'Tindiquera', '83708-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21357, 'Curitiba', 'Lindolfo Pasquali', 'Santa Felicidade', '82015-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21358, 'Curitiba', 'Lindolfo Pessoa', 'Seminário', '80240-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21359, 'Foz do Iguaçu', 'Lindolfo Ribeiro dos Santos', 'Loteamento Universitário das Américas', '85870-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21360, 'Apucarana', 'Lineo Domingos Carletto', 'Loteamento Vila das Paineiras', '86802-086', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21361, 'Curitiba', 'Lineu Ferreira do Amaral', 'Boqueirão', '81670-050', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21362, 'Foz do Iguaçu', 'Lineu Rosa', 'Centro', '85851-420', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21363, 'Foz do Iguaçu', 'Linguado', 'Profilurb I', '85855-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21364, 'Guarapuava', 'Linhares', 'Boqueirão', '85022-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21365, 'Foz do Iguaçu', 'Linhares', 'Jardim Santa Rosa', '85869-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21366, 'Piraquara', 'Linhares', 'Jardim Tropical', '83314-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21367, 'Londrina', 'Lino Galbetti', 'Conjunto Residencial Marajoara', '86080-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21368, 'Campo Mourão', 'Lino Hermógenes da Silva', 'Vila Rio Grande', '87302-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21369, 'Pinhais', 'Lino Jacomel', 'Planta Lazaro P Bayer', '83326-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21370, 'Guarapuava', 'Lino Queiroz', 'Primavera', '85050-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21371, 'Londrina', 'Lino Sachetin', 'Assis', '86085-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21372, 'Curitiba', 'Lino Silva', 'Santa Cândida', '82630-195', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21373, 'Londrina', 'Lins', 'Jardim Alvorada', '86062-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21374, 'Foz do Iguaçu', 'Lins', 'Jardim Lancaster II', '85869-270', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21375, 'Cascavel', 'Lins', 'São Cristóvão', '85813-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21376, 'Cambé', 'Lins', 'Jardim São Paulo', '86191-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21377, 'Curitiba', 'Lins', 'Cajuru', '82930-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21378, 'Londrina', 'Lins de Vasconcellos', 'Conjunto Residencial Vale do Arvoredo', '86047-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21379, 'Curitiba', 'Lins de Vasconcelos', 'Cidade Industrial', '81250-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21380, 'Curitiba', 'Lionidetti Sovinski Pachecot', 'Lamenha Pequena', '82410-556', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21381, 'Guarapuava', 'Lions', 'Santana', '85070-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21382, 'Maringá', 'Lions', 'Zona 04', '87014-255', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21383, 'Umuarama', 'Lions', 'Jardim Lisboa', '87502-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21384, 'Telêmaco Borba', 'Lions Club', 'Nossa Senhora de Fátima', '84264-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21385, 'Ponta Grossa', 'Lions Club de Ponta Grossa', 'Chapada', '84062-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21386, 'Cascavel', 'Lions Clube', 'Maria Luiza', '85819-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21387, 'Guarapuava', 'Lira', 'Boqueirão', '85020-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21388, 'Curitiba', 'Lira', 'Sítio Cercado', '81910-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21389, 'Ponta Grossa', 'Lírio', 'Contorno', '84060-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21390, 'Apucarana', 'Lírio', 'Jardim das Flores I', '86810-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21391, 'Araucária', 'Lírio Bonetto', 'Estação', '83705-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21392, 'São José dos Pinhais', 'Lírio Gonçalves', 'Guatupê', '83060-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21393, 'Piraquara', 'Lírio Jacomel', 'Planta Deodoro', '83304-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21394, 'Curitiba', 'Lírio Jacomel', 'Santa Cândida', '82650-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21395, 'Toledo', 'Lírio Pedro Belenzier', 'César Park', '85913-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21396, 'Maringá', 'Lírio Real', 'Jardim Industrial', '87065-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21397, 'Curitiba', 'Lírio-do-vale', 'Cajuru', '82980-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21398, 'Londrina', 'Lirios-dos-vales', 'Novo Amparo', '86043-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21399, 'Ponta Grossa', 'Lisandro Alves de Araújo', 'Chapada', '84062-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21400, 'Londrina', 'Lisboa', 'Parque Residencial João Piza', '86041-225', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21401, 'Guarapuava', 'Lisboa', 'Santana', '85070-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21402, 'Londrina', 'Lisboa', 'Parque Residencial João Piza', '86041-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21403, 'Foz do Iguaçu', 'Lisboa', 'Jardim Alice I', '85858-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21404, 'Paranaguá', 'Lisboa', 'Parque Agari', '83215-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21405, 'Telêmaco Borba', 'Lisboa', 'Nossa Senhora do Perpétuo Socorro', '84265-480', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21406, 'Umuarama', 'Lisboa', 'Jardim Panorama', '87501-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21407, 'Toledo', 'Lisboa', 'Jardim Paulista', '85909-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21408, 'Colombo', 'Lisboa', 'Vila Alto da Cruz', '83405-450', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21409, 'Cascavel', 'Lisboa', 'Cascavel Velho', '85818-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21410, 'Londrina', 'Lituânia', 'São Vicente', '86046-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21411, 'Guarapuava', 'Lituânia', 'Jardim das Américas', '85030-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21412, 'Cambé', 'Lituânia', 'Jardim Morada do Sol', '86181-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21413, 'Foz do Iguaçu', 'Liverpool', 'Jardim Alice I', '85858-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21414, 'Curitiba', 'Lívio Moreira', 'São Lourenço', '82200-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21415, 'Curitiba', 'Lívio Petterle', 'Atuba', '82620-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21416, 'Apucarana', 'Lívio Vidal Ferreira', 'Vila Santista', '86800-690', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21417, 'Cambé', 'Livorno', 'Jardim Montecatini', '86186-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21418, 'Curitiba', 'Livorno', 'Parolin', '80220-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21419, 'Francisco Beltrão', 'Livramento', 'Pinheirinho', '85603-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21420, 'Curitiba', 'Lizímaco Serapião', 'Novo Mundo', '81020-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21421, 'Francisco Beltrão', 'Loanda', 'Pinheirinho', '85603-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21422, 'Foz do Iguaçu', 'Loanda', 'Jardim Curitibano II', '85869-528', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21423, 'Pinhais', 'Loanda', 'Planta Ubirajara', '83325-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21424, 'Ponta Grossa', 'Loanda', 'Nova Rússia', '84053-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21425, 'Londrina', 'Loanda', 'Novo Amparo', '86043-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21426, 'São José dos Pinhais', 'Loanda', 'Boneca do Iguaçu', '83040-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21427, 'Cambé', 'Loanda', 'Jardim Ana Eliza', '86188-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21428, 'Campo Mourão', 'Loanda', 'Conjunto Habitacional Parigot de Souza', '87310-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21429, 'Colombo', 'Loanda', 'Jardim Cristina', '83410-620', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21430, 'Curitiba', 'Loanda', 'Alto Boqueirão', '81770-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21431, 'Campo Mourão', 'Lobato', 'Conjunto Residencial Antilhas', '87308-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21432, 'Maringá', 'Lobélia', 'Jardim Industrial', '87065-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21433, 'Foz do Iguaçu', 'Lobo-marinho', 'Profilurb I', '85855-390', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21434, 'Curitiba', 'Lodovico Geronazzo', 'Boa Vista', '82560-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21435, 'Curitiba', 'Lodovico Kaminski', 'Cidade Industrial', '81260-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21436, 'Arapongas', 'Lofoforo', 'Jardim São Cristóvão', '86709-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21437, 'Londrina', 'Loidemar Baggio', 'Jardim Primavera', '86086-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21438, 'Guarapuava', 'Lomas Valentinas', 'Vila Carli', '85040-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21439, 'Curitiba', 'Lombardo Furlan', 'Santa Felicidade', '82020-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21440, 'Foz do Iguaçu', 'Londres', 'Jardim Alice I', '85858-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21441, 'Paranaguá', 'Londres', 'Parque Agari', '83215-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21442, 'Toledo', 'Londres', 'Centro', '85900-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21443, 'Telêmaco Borba', 'Londres', 'Nossa Senhora do Perpétuo Socorro', '84265-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21444, 'Umuarama', 'Londres', 'Jardim San Martim', '87508-129', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21445, 'Colombo', 'Londres', 'Vila Alto da Cruz II', '83405-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21446, 'Cascavel', 'Londres', 'Cascavel Velho', '85818-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21447, 'Francisco Beltrão', 'Londrina', 'Vila Nova', '85605-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21448, 'Laranjeiras do Sul', 'Londrina', 'Água Verde', '85302-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21449, 'Foz do Iguaçu', 'Londrina', 'Jardim Paraná', '85867-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21450, 'Guarapuava', 'Londrina', 'Bonsucesso', '85045-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21451, 'Londrina', 'Londrina', 'Rodocentro', '86070-025', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21452, 'Pato Branco', 'Londrina', 'Cristo Rei', '85507-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21453, 'Maringá', 'Londrina', 'Zona 08', '87050-730', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21454, 'Maringá', 'Londrina', 'Jardim América', '87045-590', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21455, 'Paranaguá', 'Londrina', 'Jardim Paranaguá', '83218-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21456, 'Piraquara', 'Londrina', 'Planta Araçatuba', '83301-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21457, 'Ponta Grossa', 'Londrina', 'Nova Rússia', '84053-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21458, 'Maringá', 'Londrina', 'Jardim Aclimação', '87050-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21459, 'Pinhais', 'Londrina', 'Jardim Dona Joaquina I', '83325-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21460, 'Toledo', 'Londrina', 'Jardim Bressan', '85913-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21461, 'Umuarama', 'Londrina', 'Zona II', '87502-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21462, 'Sarandi', 'Londrina', 'Centro', '87111-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21463, 'Sarandi', 'Londrina', 'Jardim Independência I', '87114-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21464, 'São José dos Pinhais', 'Londrina', 'São Cristóvão', '83040-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21465, 'Telêmaco Borba', 'Londrina', 'Centro', '84261-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21466, 'Apucarana', 'Londrina', 'Vila São Carlos', '86800-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21467, 'Cambé', 'Londrina', 'Jardim Ana Eliza', '86187-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21468, 'Almirante Tamandaré', 'Londrina', 'Jardim Taíza', '83505-129', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21469, 'Araucária', 'Londrina', 'Iguaçu', '83701-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21470, 'Colombo', 'Londrina', 'Jardim La Paloma', '83412-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21471, 'Cascavel', 'Londrina', 'São Cristóvão', '85813-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21472, 'Castro', 'Londrina', 'Vila Santa Cruz', '84168-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21473, 'Campo Mourão', 'Londrina', 'Centro', '87303-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21474, 'Cascavel', 'Londrina', 'Country', '85812-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21475, 'Curitiba', 'Londrina', 'Pinheirinho', '81880-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21476, 'Curitiba', 'Londrina', 'Sítio Cercado', '81900-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21477, 'Londrina', 'Londrina Esporte Clube', 'Cilo 2', '86067-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21478, 'Paranavaí', 'Longuino Eduardo Boraczynski', 'Jardim São Jorge', '87710-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21479, 'Foz do Iguaçu', 'Lontra', 'Conjunto A', '85861-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21480, 'Toledo', 'Lopei', 'Jardim Paulista', '85910-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21481, 'Maringá', 'Lopes Trovão', 'Zona 04', '87014-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21482, 'Paranavaí', 'Lopes Trovão', 'Jardim São Jorge', '87710-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21483, 'Ponta Grossa', 'Lopes Trovão', 'Boa Vista', '84040-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21484, 'Londrina', 'Lord Lovat', 'Jardim Londrilar', '86010-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21485, 'Umuarama', 'Lord Lovat', 'Zona VII', '87503-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21486, 'Curitiba', 'Lord Lovat', 'Uberaba', '81510-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21487, 'Foz do Iguaçu', 'Lorena', 'Vila Carima', '85855-695', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21488, 'Pato Branco', 'Lorena', 'São Roque', '85507-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21489, 'Curitiba', 'Lorenço Costa', 'Santa Felicidade', '82020-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21490, 'Umuarama', 'Lorenz', 'Parque Industrial I', '87507-059', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21491, 'Arapongas', 'Lori', 'Centro', '86701-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21492, 'Arapongas', 'Lori', 'Jardim Panorama', '86708-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21493, 'Curitiba', 'Loriceia Antonello', 'Cidade Industrial', '81170-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21494, 'Curitiba', 'Lóris Escorsin', 'Mossunguê', '81210-285', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21495, 'São José dos Pinhais', 'Lorival Locatelli', 'Ipê', '83055-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21496, 'Ponta Grossa', 'Loro', 'Contorno', '84061-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21497, 'Curitiba', 'Lory Lunardon', 'Taboão', '82130-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21498, 'Francisco Beltrão', 'Los Angeles', 'Pinheirinho', '85603-310', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21499, 'Sarandi', 'Los Angeles', 'Jardim Califórnia', '87112-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21500, 'Cambé', 'Los Angeles', 'Jardim Califórnia', '86182-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21501, 'Curitiba', 'Lotário Seifert', 'Vista Alegre', '80810-380', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21502, 'Toledo', 'Lothario Aloísio Anschau', 'Jardim Bandeirantes', '85906-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21503, 'Curitiba', 'Lothario Boutin', 'Pinheirinho', '81110-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21504, 'Campo Mourão', 'Lotus', 'Jardim Paulista', '87310-450', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21505, 'Telêmaco Borba', 'Lótus', 'Jardim Alegre', '84268-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21506, 'Araucária', 'Lótus', 'Campina da Barra', '83709-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21507, 'Colombo', 'Lótus', 'Parque Monte Castelo', '83411-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21508, 'Araucária', 'Louis Becue', 'Vila Nova', '83703-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21509, 'Curitiba', 'Louis Esquier', 'Uberaba', '81560-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21510, 'Londrina', 'Louis Francisconi', 'Vila Matsunaga', '86026-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21511, 'Maringá', 'Louis Pasteur', 'Jardim Alvorada', '87035-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21512, 'Londrina', 'Louiz Braille', 'Industrial', '86063-415', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21513, 'Curitiba', 'Lourdes Aparecida Schimidt', 'Cidade Industrial', '81310-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21514, 'Araucária', 'Lourdes Belniok Brongel', 'Costeira', '83708-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21515, 'Curitiba', 'Lourdes Bertuzzi Cenci', 'Cidade Industrial', '81305-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21516, 'Curitiba', 'Lourdes Betezek', 'Cidade Industrial', '81460-356', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21517, 'Curitiba', 'Lourdes Gomes de Carvalho', 'Cidade Industrial', '81460-338', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21518, 'Pinhais', 'Lourdes Rodrigues', 'Moradias Perdizes', '83326-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21519, 'Almirante Tamandaré', 'Loureço Ângelo Buzato', 'Vila Santa Terezinha', '83501-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21520, 'Curitiba', 'Louremir Luiz Gouveia', 'Alto Boqueirão', '81770-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21521, 'Londrina', 'Lourenço Antônio da Veiga', 'Cristal', '86044-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21522, 'Curitiba', 'Lourenço Bizinelli', 'Campo Comprido', '81220-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21523, 'Londrina', 'Lourenço da Veiga', 'Sabará I', '86066-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21524, 'Curitiba', 'Lourenço Darif', 'Pilarzinho', '82110-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21525, 'Cambé', 'Lourenço Fadel', 'Jardim Boa Vista', '86191-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21526, 'Curitiba', 'Lourenço Garzaro', 'Butiatuvinha', '82400-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21527, 'Curitiba', 'Lourenço Gbur', 'Campina do Siqueira', '80730-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21528, 'Araucária', 'Lourenço Grabowski', 'Thomaz Coelho', '83707-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21529, 'Curitiba', 'Lourenço Imoski', 'Sítio Cercado', '81900-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21530, 'Araucária', 'Lourenço Jankowski', 'Boqueirão', '83704-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21531, 'Araucária', 'Lourenço Jasiocha', 'Centro', '83702-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21532, 'São José dos Pinhais', 'Lourenço José de Paula', 'Afonso Pena', '83050-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21533, 'Curitiba', 'Lourenço José Tiepolo', 'Jardim Botânico', '80210-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21534, 'São José dos Pinhais', 'Lourenço Maoski', 'Afonso Pena', '83050-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21535, 'Apucarana', 'Lourenço Montanucci', 'Jardim Paineiras II', '86802-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21536, 'Curitiba', 'Lourenço Mourão', 'Seminário', '80310-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21537, 'Curitiba', 'Lourenço Pinto', 'Centro', '80010-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21538, 'Ponta Grossa', 'Lourenço Simionato', 'Chapada', '84063-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21539, 'Curitiba', 'Lourenço Tuletzki', 'Campo Comprido', '81220-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21540, 'Curitiba', 'Lourenço Volpi', 'Santa Cândida', '82640-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21541, 'Guarapuava', 'Lourival Araújo', 'São Cristóvão', '85063-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21542, 'São José dos Pinhais', 'Lourival Belmiro Berti', 'Cidade Jardim', '83035-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21543, 'Campo Mourão', 'Lourival Borba', 'Jardim Izabel', '87309-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21544, 'Curitiba', 'Lourival Cordeiro', 'Uberaba', '81550-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21545, 'Curitiba', 'Lourival Franca Pereira', 'São Braz', '82015-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21546, 'Curitiba', 'Lourival Francisco Ribeiro', 'Campo Comprido', '81220-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21547, 'Curitiba', 'Lourival Francisco Ribeiro', 'Cidade Industrial', '81350-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21548, 'Curitiba', 'Lourival João Hauer', 'Boqueirão', '81750-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21549, 'Ponta Grossa', 'Lourival Justus', 'Oficinas', '84036-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21550, 'Curitiba', 'Lourival Manoel de Freitas', 'Cidade Industrial', '81315-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21551, 'Ponta Grossa', 'Lourival Oliveira Guedes', 'Jardim Carvalho', '84016-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21552, 'Curitiba', 'Lourival Pinheiro', 'Guabirotuba', '81510-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21553, 'Campo Largo', 'Lourival Portela de Brito', 'Jardim Florestal', '83602-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21554, 'Curitiba', 'Lourival Portella Natel', 'Portão', '80610-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21555, 'Paranavaí', 'Lourival Rauen', 'Jardim Nakamura', '87701-320', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21556, 'Ponta Grossa', 'Lourival Santos Lima', 'Orfãs', '84015-835', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21557, 'Curitiba', 'Lourival Schilipak', 'Guabirotuba', '81510-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21558, 'Curitiba', 'Lourival Wendler', 'Cajuru', '82960-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21559, 'Curitiba', 'Lourivaldo José da Costa', 'Santa Cândida', '82720-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21560, 'Arapongas', 'Louro-verde', 'Conjunto Del Condor', '86703-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21561, 'Foz do Iguaçu', 'Louveira', 'Jardim das Palmeiras', '85869-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21562, 'Cascavel', 'Loyola', 'Brasmadeira', '85814-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21563, 'Telêmaco Borba', 'Luba Klabin', 'Centro', '84261-750', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21564, 'Cambé', 'Lucas Conchon', 'Jardim Boa Vista', '86191-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21565, 'Colombo', 'Lucas Cubis', 'Jardim Esplanada', '83402-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21566, 'São José dos Pinhais', 'Lucas Gbur', 'Colônia Rio Grande', '83025-338', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21567, 'Cascavel', 'Lucas José de Souza', 'Cascavel Velho', '85818-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21568, 'Curitiba', 'Lucas Schereiner Júnior', 'Cajuru', '82930-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21569, 'Araucária', 'Lucas Wilczak', 'Costeira', '83708-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21570, 'Francisco Beltrão', 'Lúcia Benedetti', 'São Miguel', '85602-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21571, 'Curitiba', 'Lúcia Bozza Pilatti', 'Pilarzinho', '82120-530', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21572, 'Curitiba', 'Lúcia Buturi Foltran', 'Sítio Cercado', '81935-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21573, 'Curitiba', 'Lúcia Dechandt', 'Abranches', '82220-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21574, 'Curitiba', 'Lúcia Filla Pampuch', 'Pilarzinho', '82115-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21575, 'Londrina', 'Lúcia Helena Gonçalves Vianna', 'Jardim Pacaembu', '86079-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21576, 'Toledo', 'Lúcia Lorenzetti Malacarne', 'Jardim Parizzotto', '85914-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21577, 'Francisco Beltrão', 'Lúcia Machado de Almeida', 'São Miguel', '85602-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21578, 'Francisco Beltrão', 'Lúcia Rauber Drei', 'São Miguel', '85602-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21579, 'Curitiba', 'Lúcia Salles Kalluf', 'Tatuquara', '81470-160', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21580, 'Paranavaí', 'Luciana Martins Andrade', 'Jardim São Jorge', '87711-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21581, 'Curitiba', 'Luciana Sammut Rosenthal', 'Novo Mundo', '81050-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21582, 'Colombo', 'Luciano Betinardi', 'Roseira', '83415-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21583, 'Curitiba', 'Luciano Cardinale', 'Cabral', '80035-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21584, 'Apucarana', 'Luciano Castro Mathias', 'Loteamento Vila das Paineiras', '86802-087', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21585, 'Cascavel', 'Luciano Correia de Siqueira', 'Coqueiral', '85807-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21586, 'Londrina', 'Luciano Ferracini', 'Ernani de Moura Lima', '86037-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21587, 'Colombo', 'Luciano Floriano dos Santos', 'Vila Rosemari Galvão', '83411-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21588, 'Curitiba', 'Luciano Guimarães de Gracia', 'Taboão', '82130-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21589, 'Curitiba', 'Luciano Hella', 'Campina do Siqueira', '80740-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21590, 'Curitiba', 'Luciano José de Pauli', 'Uberaba', '81580-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21591, 'Campo Mourão', 'Luciano Marmontel', 'Jardim Araucária', '87301-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21592, 'Paranaguá', 'Luciano Morozowski', 'Jardim Araçá', '83221-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21593, 'Curitiba', 'Luciano Piuzzi', 'Pinheirinho', '81820-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21594, 'Curitiba', 'Luciano Salkovski', 'Alto Boqueirão', '81850-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21595, 'Cascavel', 'Lucídio Ângelo Nazari', '14 de Novembro', '85804-107', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21596, 'Foz do Iguaçu', 'Lucídio Freire Rocha', 'Jardim Soledade', '85858-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21597, 'Curitiba', 'Lucídio Zanotto', 'Bom Retiro', '80520-730', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21598, 'Apucarana', 'Lucidoro S. Karner', 'Jardim Morada do Sol', '86811-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21599, 'São José dos Pinhais', 'Lucie Laval', 'São Sebastião', '83075-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21600, 'Londrina', 'Lucílio de Held', 'Coliseu', '86076-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21601, 'Maringá', 'Lucílio de Held', 'Jardim Alvorada', '87033-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21602, 'Londrina', 'Lucilla Ballalai', 'Monções', '86015-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21603, 'Londrina', 'Lucimeri Piloto', 'Jardim Maracanã', '86056-867', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21604, 'Paranaguá', 'Lucinda Rodrigues Campos', 'Divinéia', '83212-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21605, 'Curitiba', 'Lucindo Cavalheiro dos Santos', 'Santa Cândida', '82720-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21606, 'Londrina', 'Lucinei Vasconcelos de Castilho', 'Condomínio Royal Golf Residence', '86055-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21607, 'Apucarana', 'Lucinéia de Fátima Cardoso Martins', 'Residencial Parque da Raposa', '86812-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21608, 'Londrina', 'Lúcio Alves', 'Jardim Piazentin', '86043-006', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21609, 'Ponta Grossa', 'Lúcio Alves da Silva', 'Neves', '84020-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21610, 'Ponta Grossa', 'Lúcio Alves da Silva', 'Olarias', '84035-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21611, 'Ponta Grossa', 'Lúcio de Mendonça', 'Oficinas', '84035-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21612, 'Curitiba', 'Lúcio de Oliveira Lara', 'Ganchinho', '81935-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21613, 'Araucária', 'Lúcio de Paula Lopes', 'Thomaz Coelho', '83707-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21614, 'Curitiba', 'Lúcio Marcos da Silva', 'Cidade Industrial', '81460-196', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21615, 'Foz do Iguaçu', 'Lúcio Padilha', 'Vila São Sebastião', '85870-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21616, 'Curitiba', 'Lúcio Pereira', 'Tingui', '82600-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21617, 'Curitiba', 'Lúcio Rasera', 'Bigorrilho', '80710-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21618, 'Francisco Beltrão', 'Lucir Telmo Christ Filho', 'São Cristóvão', '85601-344', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21619, 'Colombo', 'Lucy', 'Jardim Curitiba', '83406-610', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21620, 'Ponta Grossa', 'Ludgero Pavão', 'Neves', '84020-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21621, 'Curitiba', 'Ludovica Robert', 'Sítio Cercado', '81920-720', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21622, 'Curitiba', 'Ludovico Bauml', 'Fazendinha', '81330-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21623, 'Maringá', 'Ludovico Del Guércio', 'Jardim Cerro Azul', '87010-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21624, 'Colombo', 'Ludovico Kachel', 'Jardim Marajó', '83404-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21625, 'Colombo', 'Ludovico Klindinger', 'Vila Miracema', '83408-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21626, 'Curitiba', 'Ludovico Lucca', 'São Braz', '82315-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21627, 'Curitiba', 'Ludovico Seyer', 'Jardim Botânico', '80210-310', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21628, 'Ponta Grossa', 'Ludovico Szesz', 'Chapada', '84063-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21629, 'Curitiba', 'Ludovico Zanier', 'Cidade Industrial', '81350-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21630, 'Curitiba', 'Ludovika Bordenoski Lopes', 'Boqueirão', '81650-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21631, 'Londrina', 'Ludovina da Silva Barroso', 'Del Rey', '86045-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21632, 'Araucária', 'Ludovina Furman', 'Boqueirão', '83704-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21633, 'Curitiba', 'Ludvina Schuster Paes', 'Cidade Industrial', '81460-298', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21634, 'Londrina', 'Ludwig Dreeger', 'Heimtal', '86084-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21635, 'Londrina', 'Ludwig Ernest', 'Heimtal', '86084-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21636, 'Curitiba', 'Lufrido Costa', 'Pinheirinho', '81880-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21637, 'Arapongas', 'Lugre', 'Vila Fortunato', '86705-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21638, 'Londrina', 'Luigi Amorese', 'Leonor', '86071-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21639, 'Londrina', 'Luigi Amorese', 'Leonor', '86072-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21640, 'Londrina', 'Luigi Borghesi', 'Canaã', '86015-075', 'Parque', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21641, 'São José dos Pinhais', 'Luigi Pirandello', 'Aristocrata', '83030-270', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21642, 'Curitiba', 'Luigi Romano', 'Jardim das Américas', '81540-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21643, 'Toledo', 'Luigia Olympia Genari Bottin', 'Jardim Parizzotto', '85914-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21644, 'Colombo', 'Luís Agostinho Trevisan', 'Vila Rosemari Galvão', '83411-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21645, 'Maringá', 'Luís Alberto Favoreto', 'Conjunto Habitacional João de Barro Thaís', '87075-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21646, 'São José dos Pinhais', 'Luís Américo Tetti', 'Miringuava', '83090-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21647, 'Guarapuava', 'Luís Antônio Ribas Caldas', 'Trianon', '85012-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21648, 'Curitiba', 'Luís Atílio de Macedo', 'Cidade Industrial', '81460-198', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21649, 'Colombo', 'Luís Batistão', 'Vila Ana Maria', '83413-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21650, 'Colombo', 'Luís Carlos Arcie', 'Sapopema', '83407-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21651, 'Curitiba', 'Luís Carlos Marrero', 'Cidade Industrial', '81315-675', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21652, 'Piraquara', 'Luís Carlos Oliveira', 'Jardim Caiçara', '83314-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21653, 'Maringá', 'Luís Carlos Prestes', 'Jardim São Silvestre', '87055-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21654, 'Guarapuava', 'Luís Carollo', 'Vila Bela', '85025-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21655, 'Guarapuava', 'Luís Cavalcanti da Silva', 'Bonsucesso', '85045-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21656, 'Guarapuava', 'Luís Ciscato', 'Santa Cruz', '85015-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21657, 'Guarapuava', 'Luís Cúnico', 'Vila Bela', '85027-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21658, 'Colombo', 'Luís da Gama', 'Jardim Central', '83409-720', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21659, 'Pinhais', 'Luís de Camões', 'Núcleo Colonial de Pinhais', '83321-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21660, 'Colombo', 'Luís Gasparin', 'Jardim Adriana', '83408-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21661, 'Apucarana', 'Luís Gomes Godoy', 'Loteamento Residencial Miguel Sochacki', '86802-367', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21662, 'Guarapuava', 'Luís Gonzaga Júnior', 'Santana', '85070-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21663, 'Curitiba', 'Luís Ivancheck', 'Fazendinha', '81070-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21664, 'Curitiba', 'Luís Manoel Agner', 'Bacacheri', '82600-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21665, 'Cascavel', 'Luís Paese', 'Brasília', '85815-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21666, 'Londrina', 'Luís Pasteur', 'Cilo 3', '86073-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21667, 'Guarapuava', 'Luís Pletz Cleve', 'Alto Cascavel', '85031-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21668, 'Francisco Beltrão', 'Luís Prestes', 'São Miguel', '85602-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21669, 'Guarapuava', 'Luís Vicente Verlangieri', 'Bonsucesso', '85045-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21670, 'Campo Mourão', 'Luís XV', 'Jardim Lar Paraná', '87305-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21671, 'Curitiba', 'Luísa Bueno Gomm', 'Batel', '80420-240', 'Bosque', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21672, 'Curitiba', 'Luísa Dariva', 'Campina do Siqueira', '80730-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21673, 'Curitiba', 'Luiz Alberti', 'Campo Comprido', '81220-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21674, 'Colombo', 'Luiz Alberto Ferreira', 'Jardim Campo Alto', '83408-316', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21675, 'Londrina', 'Luiz Alves de Lima e Silva', 'Itamarati', '86061-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21676, 'Londrina', 'Luiz Alves Neto', 'Roseira', '86041-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21677, 'Sarandi', 'Luiz Amaral de Souza', 'Jardim Gralha Azul', '87112-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21678, 'Curitiba', 'Luiz Amora', 'Capão Raso', '81020-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21679, 'Colombo', 'Luiz Andreta', 'Walfrido do Rosário', '83413-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21680, 'Londrina', 'Luiz Anelli', 'Franciscato', '86043-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21681, 'Londrina', 'Luiz Ângelo Basseto', 'Santa Maria', '86035-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21682, 'Curitiba', 'Luiz Antonieto', 'Jardim das Américas', '81520-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21683, 'Curitiba', 'Luiz Antônio Biazzetto', 'São Lourenço', '82200-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21684, 'Apucarana', 'Luiz Antônio Cazangi', 'Núcleo Habitacional Djalma Mendes de Oliveira', '86806-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21685, 'Castro', 'Luiz Antônio Dalarmi', 'Água Suja', '84165-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21686, 'Curitiba', 'Luiz Antônio de Andrade Vieira', 'Uberaba', '81590-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21687, 'Umuarama', 'Luiz Antônio de Carvalho', 'Jardim Cruzeiro', '87504-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21688, 'Francisco Beltrão', 'Luiz Antônio Faedo', 'Centro', '85601-275', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21689, 'Colombo', 'Luiz Ariosto Cunha', 'Embrapa', '83407-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21690, 'Colombo', 'Luiz Aristo Cunha', 'Santa Gema', '83407-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21691, 'Araucária', 'Luiz Armando Ohpis', 'Boqueirão', '83704-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21692, 'Francisco Beltrão', 'Luiz Artuzo', 'São Miguel', '85602-528', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21693, 'Curitiba', 'Luiz Augusto de Toledo Leite', 'Umbará', '81930-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21694, 'Cascavel', 'Luiz Augusto Pereira', 'Santa Felicidade', '85803-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21695, 'Campo Mourão', 'Luiz Aurélio Gurgel', 'Jardim Aeroporto', '87310-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21696, 'Curitiba', 'Luiz Bagé', 'Campo Comprido', '81210-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21697, 'Curitiba', 'Luiz Barreto Murat', 'Bairro Alto', '82820-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21698, 'Curitiba', 'Luiz Batista Gnoato', 'Santa Felicidade', '82015-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21699, 'Curitiba', 'Luiz Batistel Ramos Júnior', 'Sítio Cercado', '81935-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21700, 'Pato Branco', 'Luiz Batistus', 'Parzianello', '85504-490', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21701, 'Londrina', 'Luiz Beraldi', 'Leste Oeste', '86037-819', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21702, 'Colombo', 'Luiz Berlesi', 'Jardim Panorama', '83412-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21703, 'Curitiba', 'Luiz Bertolini', 'Cajuru', '82920-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21704, 'Londrina', 'Luiz Betti', 'Jardim Marissol', '86030-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21705, 'Londrina', 'Luiz Bolognesi', 'Jardim Morumbi', '86035-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21706, 'Londrina', 'Luiz Bon', 'Santiago', '86071-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21707, 'Colombo', 'Luiz Bonato', 'Sapopema', '83407-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21708, 'Guarapuava', 'Luiz Borges de Lis', 'Morro Alto', '85065-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21709, 'São José dos Pinhais', 'Luiz Bortolan', 'Guatupê', '83060-377', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21710, 'Curitiba', 'Luiz Bozza', 'Butiatuvinha', '82400-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21711, 'Curitiba', 'Luiz Braille', 'São Braz', '82015-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21712, 'Curitiba', 'Luiz Brambilla', 'Tarumã', '82530-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21713, 'Curitiba', 'Luiz Bressan Filho', 'Pinheirinho', '81870-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21714, 'Laranjeiras do Sul', 'Luiz Brondani', 'São Francisco', '85303-076', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21715, 'Londrina', 'Luiz Brugin', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21716, 'Araucária', 'Luiz Brunatto', 'Estação', '83705-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21717, 'Araucária', 'Luiz Budziak', 'Barigui', '83707-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21718, 'Almirante Tamandaré', 'Luiz Bugalski', 'Jardim Marize', '83507-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21719, 'Curitiba', 'Luiz Burda', 'Tatuquara', '81480-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21720, 'São José dos Pinhais', 'Luiz Calegari', 'Afonso Pena', '83040-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21721, 'Cambé', 'Luiz Calsavara', 'Parque Residencial Ana Rosa', '86183-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21722, 'Apucarana', 'Luiz Canezin', 'Jardim Eldorado', '86802-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21723, 'Londrina', 'Luiz Capelari', 'Jardim Perobal', '86043-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21724, 'Castro', 'Luiz Cardoso', 'Jardim das Araucárias', '84172-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21725, 'Curitiba', 'Luiz Cardoso', 'Cidade Industrial', '81350-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21726, 'Foz do Iguaçu', 'Luiz Carinzio', 'Centro', '85851-470', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21727, 'Campo Largo', 'Luiz Carlos Barbosa', 'Conjunto Águas Claras', '83602-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21728, 'Curitiba', 'Luiz Carlos Boavista do Rego Monteiro', 'Barreirinha', '82700-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21729, 'Curitiba', 'Luiz Carlos Bruginski', 'Fazendinha', '81320-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21730, 'Curitiba', 'Luiz Carlos Canesso', 'Alto Boqueirão', '81860-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21731, 'Araucária', 'Luiz Carlos Czelusniak da Costa', 'Cachoeira', '83701-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21732, 'Londrina', 'Luiz Carlos de Castro Costa', 'Luiz de Sá', '86086-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21733, 'Colombo', 'Luiz Carlos de Lima', 'Jardim Araguaia', '83404-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21734, 'Curitiba', 'Luiz Carlos Dorecki', 'Cajuru', '82980-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21735, 'Curitiba', 'Luiz Carlos Krüger Pereira', 'Jardim das Américas', '81530-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21736, 'São José dos Pinhais', 'Luiz Carlos Luz', 'Colônia Rio Grande', '83025-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21737, 'Curitiba', 'Luiz Carlos Muggiati', 'Alto Boqueirão', '81770-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21738, 'Apucarana', 'Luiz Carlos Paes', 'Núcleo Habitacional Heitor S Pinheiro', '86806-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21739, 'Curitiba', 'Luiz Carlos Ribeiro', 'Água Verde', '80620-215', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21740, 'Maringá', 'Luiz Carlos Sossai', 'Vila Cafelândia', '87045-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21741, 'Guarapuava', 'Luiz Carollo', 'Morro Alto', '85070-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21742, 'Londrina', 'Luiz Carvalho de Araújo', 'Jardim Vale Azul', '86041-850', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21743, 'Curitiba', 'Luiz Casagrande', 'Cidade Industrial', '81230-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21744, 'Curitiba', 'Luiz Cavichiolo I', 'Abranches', '82220-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21745, 'Curitiba', 'Luiz Cavichiolo II', 'Vila Izabel', '80240-080', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21746, 'Curitiba', 'Luiz Celso Bornancin', 'Uberaba', '81570-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21747, 'Apucarana', 'Luiz Cláudio Matsui', 'Jardim Colonial II', '86812-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21748, 'Colombo', 'Luiz Colere', 'Jardim Samambaia', '83407-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21749, 'Curitiba', 'Luiz Condessa', 'Jardim das Américas', '81530-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21750, 'Londrina', 'Luiz Consentino', 'Ouro Branco', '86042-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21751, 'Ponta Grossa', 'Luiz Copla', 'Jardim Carvalho', '84016-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21752, 'Paranaguá', 'Luiz Cordeiro', 'Industrial', '83203-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21753, 'Araucária', 'Luiz Cordeiro', 'Capela Velha', '83706-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21754, 'Maringá', 'Luiz Corrêa', 'Cidade Jardim', '87020-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21755, 'Foz do Iguaçu', 'Luiz dAgner', 'Vila Shalon', '85853-118', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21756, 'Londrina', 'Luiz da Costa Manso', 'Conjunto Habitacional Jamile Dequech', '86048-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21757, 'Colombo', 'Luiz d''Agostin', 'Jardim Las Palmas', '83409-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21758, 'Londrina', 'Luiz D''Alaqua', 'Bandeirantes', '86065-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21759, 'Toledo', 'Luiz Dalcanalle Filho', 'Panorama', '85911-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21760, 'Curitiba', 'Luiz Dallagassa', 'Boqueirão', '81670-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21761, 'Ponta Grossa', 'Luiz Daloski', 'Boa Vista', '84073-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21762, 'Castro', 'Luiz de Biassio', 'Vila do Rosário', '84168-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21763, 'Londrina', 'Luiz de Brito Almeida', 'Sabará I', '86066-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21764, 'Ponta Grossa', 'Luiz de Camões', 'Uvaranas', '84020-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21765, 'Londrina', 'Luiz de Camões', 'Jardim Tatiani', '86070-015', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21766, 'Maringá', 'Luiz de Camões', 'Zona 01', '87013-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21767, 'Cascavel', 'Luiz de Camões', 'Interlagos', '85814-276', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21768, 'Toledo', 'Luiz de Conto', 'Jardim Parizzotto', '85914-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21769, 'Curitiba', 'Luiz de Freitas', 'Guabirotuba', '81510-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21770, 'Apucarana', 'Luiz de Oliveira', 'Barra Funda', '86800-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21771, 'Colombo', 'Luiz de Souza', 'Jardim das Flores', '83402-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21772, 'Curitiba', 'Luiz de Souza Arcega', 'Santo Inácio', '82300-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21773, 'Pato Branco', 'Luiz Debarba', 'Menino Deus', '85502-240', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21774, 'Curitiba', 'Luiz Del Gobbo', 'Capão Raso', '81130-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21775, 'Londrina', 'Luiz Delfino', 'Shangri-La', '86070-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21776, 'Ponta Grossa', 'Luiz Delfino', 'Colônia Dona Luiza', '84045-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21777, 'Curitiba', 'Luiz Delfino', 'Portão', '80330-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21778, 'Londrina', 'Luiz Dias', 'Jardim Londrilar', '86015-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21779, 'Guarapuava', 'Luiz Dias de Lima', 'Boqueirão', '85020-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21780, 'Londrina', 'Luiz do Espírito Santo Júnior', 'Estados', '86083-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21781, 'Francisco Beltrão', 'Luiz Domingos Folador', 'Nova Petrópolis', '85601-147', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21782, 'Paranavaí', 'Luiz Durigan', 'Jardim Iguaçu', '87705-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21783, 'Apucarana', 'Luiz Facio', 'Núcleo Popular', '86812-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21784, 'Londrina', 'Luiz Favoretto', 'Jardim Alphaville', '86084-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21785, 'Pato Branco', 'Luiz Favretto', 'Centro', '85505-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21786, 'Campo Largo', 'Luiz Fedalto', 'Loteamento São José', '83606-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21787, 'Curitiba', 'Luiz Fernandes Daros', 'Bom Retiro', '80520-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21788, 'Curitiba', 'Luiz Fernando Pinheiro Lima de Abreu', 'Sítio Cercado', '81925-187', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21789, 'Cambé', 'Luiz Ferreira', 'Jardim Imperatriz', '86183-346', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21790, 'Curitiba', 'Luiz Foggiatto', 'Orleans', '82310-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21791, 'Curitiba', 'Luiz Franca', 'Cajuru', '82900-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21792, 'Curitiba', 'Luiz Franca', 'Cajuru', '82940-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21793, 'Sarandi', 'Luiz Francalin Feitosa', 'Jardim Jaqueline', '87112-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21794, 'Araucária', 'Luiz Franceschi', 'Thomaz Coelho', '83707-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21795, 'Curitiba', 'Luiz Francisco Gomes', 'Capão da Imbuia', '82810-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21796, 'Colombo', 'Luiz Frazon', 'Planta Folloni', '83413-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21797, 'Castro', 'Luiz Gaertner', 'Jardim Samambaia', '84182-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21798, 'Londrina', 'Luiz Gaion', 'Conjunto Semiramis Barros Braga', '86088-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21799, 'Curitiba', 'Luiz Gallieri', 'Uberaba', '81560-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21800, 'Foz do Iguaçu', 'Luiz Gama', 'Jardim Festugato', '85864-015', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21801, 'Maringá', 'Luiz Gama', 'Zona 01', '87014-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21802, 'Ponta Grossa', 'Luiz Gama', 'Oficinas', '84040-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21803, 'Curitiba', 'Luiz Gama', 'Bigorrilho', '80730-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21804, 'Londrina', 'Luiz Garcia Rodrigues', 'Conjunto Semiramis Barros Braga', '86088-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21805, 'Curitiba', 'Luiz Gaspari', 'Parolin', '81030-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21806, 'Almirante Tamandaré', 'Luiz Gasparim', 'Jardim Vitória', '83508-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21807, 'Cambé', 'Luiz Gava', 'Jardim Silvino', '86188-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21808, 'Toledo', 'Luiz Genari', 'Jardim Alta Floresta', '85905-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21809, 'Londrina', 'Luiz Generoso da Silva', 'Leste Oeste', '86037-808', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21810, 'Almirante Tamandaré', 'Luiz Gilberto Pavoni', 'Jardim Santa Rita de Cássia', '83506-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21811, 'Londrina', 'Luiz Gomes da Silva', 'João Paz', '86087-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21812, 'Araucária', 'Luiz Gomes de Amorim', 'Thomaz Coelho', '83707-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21813, 'Piraquara', 'Luiz Gonçalves de Araújo', 'Vila Ipanema', '83301-058', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21814, 'Curitiba', 'Luiz Gonçalves de Moura', 'Santo Inácio', '82010-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21815, 'Londrina', 'Luiz Gonçalves Matos', 'Parigot de Souza 2', '86082-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21816, 'Curitiba', 'Luiz Gonzaga', 'Tatuquara', '81470-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21817, 'Londrina', 'Luiz Gonzaga', 'Conjunto Vivi Xavier', '86082-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21818, 'Maringá', 'Luiz Gonzaga', 'Jardim Higienópolis', '87060-400', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21819, 'Cambé', 'Luiz Gonzaga', 'Jardim Josiane', '86188-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21820, 'Londrina', 'Luiz Gonzaga Lopes', 'Conjunto Santa Rita 6', '86072-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21821, 'Ponta Grossa', 'Luiz Gonzaga Pereira da Cunha', 'Estrela', '84050-200', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21822, 'Colombo', 'Luiz Gotardo', 'Sapopema', '83407-097', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21823, 'Ponta Grossa', 'Luiz Guimarães', 'Uvaranas', '84031-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21824, 'Curitiba', 'Luiz Guimarães Júnior', 'Guabirotuba', '81510-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21825, 'Colombo', 'Luiz Gulin', 'Roça Grande', '83403-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21826, 'Curitiba', 'Luiz Gurgel do Amaral Valente', 'Sítio Cercado', '81925-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21827, 'Curitiba', 'Luiz Gurgel do Amaral Valente', 'Sítio Cercado', '81920-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21828, 'Curitiba', 'Luiz Gusso', 'Boa Vista', '82560-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21829, 'Araucária', 'Luiz Gustavo Astolpho Guerino', 'Costeira', '83708-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21830, 'Paranaguá', 'Luiz Gutierrez', 'Vila dos Comerciários', '83215-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21831, 'Curitiba', 'Luiz Havro', 'Santa Cândida', '82640-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21832, 'Curitiba', 'Luiz Homann', 'São Braz', '82310-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21833, 'Ponta Grossa', 'Luiz Humberto Gobbo', 'Chapada', '84064-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21834, 'Cambé', 'Luiz Imbriani', 'Jardim Imperatriz', '86181-338', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21835, 'Araucária', 'Luiz Incot', 'Cachoeira', '83701-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21836, 'Curitiba', 'Luiz Jabonski', 'Novo Mundo', '81020-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21837, 'Ponta Grossa', 'Luiz José da Silva', 'Jardim Carvalho', '84015-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21838, 'Curitiba', 'Luiz Júlio', 'Campo Comprido', '81200-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21839, 'Almirante Tamandaré', 'Luiz Júlio Falcade', 'Jardim Rosana', '83502-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21840, 'Cascavel', 'Luiz Justino Backer', 'Presidente', '85818-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21841, 'Almirante Tamandaré', 'Luiz Krüger', 'Jardim Santa Rita de Cássia', '83506-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21842, 'Curitiba', 'Luiz Kula', 'Santo Inácio', '82010-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21843, 'Curitiba', 'Luiz Leal da Rocha', 'Campo de Santana', '81490-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21844, 'Curitiba', 'Luiz Leão', 'Centro', '80030-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21845, 'Curitiba', 'Luiz Leduc', 'Vista Alegre', '82100-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21846, 'Curitiba', 'Luiz Leitner', 'Bigorrilho', '80710-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21847, 'Londrina', 'Luiz Leopoldo', 'Parigot de Souza 2', '86082-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21848, 'Curitiba', 'Luiz Leopoldo Landal', 'Novo Mundo', '81050-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21849, 'Londrina', 'Luiz Lerco', 'Loteamento Terra Bonita', '86047-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21850, 'Cascavel', 'Luiz Liberali', 'Maria Luiza', '85819-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21851, 'Cambé', 'Luiz Loni', 'Conjunto Residencial Roberto Conceição', '86183-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21852, 'Paranavaí', 'Luiz Lorenzett', 'Jardim Prudente', '87703-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21853, 'Apucarana', 'Luiz Lourenço', 'Recanto Bom Retiro', '86803-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21854, 'Curitiba', 'Luiz Lourenço de Freitas', 'Xaxim', '81820-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21855, 'Curitiba', 'Luiz Lucca', 'São Braz', '82315-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21856, 'Guarapuava', 'Luiz M. Pizzano', 'Primavera', '85050-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21857, 'Francisco Beltrão', 'Luiz Macagnar', 'Jardim Novo Mundo', '85602-759', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21858, 'Apucarana', 'Luiz Machado da Silva', 'Jardim Monções', '86807-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21859, 'Curitiba', 'Luiz Machuca', 'Alto Boqueirão', '81770-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21860, 'Guarapuava', 'Luiz Maister Filho', 'São Cristóvão', '85063-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21861, 'Foz do Iguaçu', 'Luiz Manoel Amorim', 'Loteamento Universitário das Américas II', '85870-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21862, 'Curitiba', 'Luiz Manzochi', 'Mercês', '80710-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21863, 'Curitiba', 'Luiz Marcassa', 'Pilarzinho', '82100-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21864, 'Londrina', 'Luiz Martins', 'Conjunto Habitacional Novo Amparo II', '86087-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21865, 'Curitiba', 'Luiz Massuquetto', 'Bacacheri', '82600-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21866, 'Toledo', 'Luiz Matielo', 'Loteamento Lidia Joana Vols', '85912-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21867, 'Apucarana', 'Luiz Matiuzzi', 'Núcleo Habitacional Marcos Freire', '86805-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21868, 'Almirante Tamandaré', 'Luiz Mendes Rocha', 'Jardim Parati', '83503-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21869, 'Maringá', 'Luiz Messias Simino', 'Jardim América', '87045-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21870, 'Ponta Grossa', 'Luiz Migdalski', 'Estrela', '84050-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21871, 'Curitiba', 'Luiz Miguel Fanchin', 'Seminário', '80740-199', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21872, 'Londrina', 'Luiz Modesto', 'Rui Barbosa', '86031-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21873, 'Londrina', 'Luiz Mondek', 'Leste Oeste', '86037-818', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21874, 'Londrina', 'Luiz Montanher', 'Jardim das Palmeiras', '86083-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21875, 'Londrina', 'Luiz Monteiro', 'Jardim San Diego', '86073-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21876, 'Maringá', 'Luiz Moreira Carvalho', 'Novo Centro', '87020-035', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21877, 'Pato Branco', 'Luiz Morelatto', 'Vila Esperança', '85503-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21878, 'Apucarana', 'Luiz Moretti Filho', 'Núcleo Habitacional das Indústrias', '86806-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21879, 'São José dos Pinhais', 'Luiz Moro Conke', 'São Cristóvão', '83040-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21880, 'Londrina', 'Luiz Morselli Filho', 'Jardim San Diego', '86073-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21881, 'Colombo', 'Luiz Motin', 'Jardim Adriana', '83408-478', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21882, 'Curitiba', 'Luiz Muraro', 'Abranches', '82220-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21883, 'Pinhais', 'Luiz Murat', 'Núcleo Colonial de Pinhais', '83321-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21884, 'Ponta Grossa', 'Luiz Muratt', 'Colônia Dona Luiza', '84045-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21885, 'Ponta Grossa', 'Luiz Nadal Motti', 'Jardim Carvalho', '84016-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21886, 'Londrina', 'Luiz Natal Bonin', 'Parque Residencial Granville', '86047-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21887, 'Curitiba', 'Luiz Nichele', 'Umbará', '81940-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21888, 'Londrina', 'Luiz Nogueira Monteiro', 'Colúmbia', '86057-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21889, 'Ponta Grossa', 'Luiz Oliveira e Silva', 'Orfãs', '84015-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21890, 'Curitiba', 'Luiz Otávio Leal', 'Cidade Industrial', '81315-500', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21891, 'Toledo', 'Luiz P. Londero', 'Conjunto Barão do Rio Branco II', '85905-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21892, 'Curitiba', 'Luiz Parigot de Souza', 'Portão', '81070-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21893, 'Pato Branco', 'Luiz Parzianello', 'Fraron', '85503-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21894, 'Toledo', 'Luiz Pavan', 'Conjunto Habitacional São Francisco', '85912-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21895, 'Toledo', 'Luiz Pedro Heck', 'Jardim Anápolis', '85905-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21896, 'Maringá', 'Luiz Pedro Poltronieri', 'Zona 04', '87035-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21897, 'Curitiba', 'Luiz Pelegrino Toaldo', 'Butiatuvinha', '82320-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21898, 'Curitiba', 'Luiz Pellanda', 'Umbará', '81940-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21899, 'Ponta Grossa', 'Luiz Pereira Barreto', 'Boa Vista', '84072-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21900, 'Maringá', 'Luiz Pereira Camacho', 'Parque Tarumã', '87053-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21901, 'Colombo', 'Luiz Perin', 'Vila Santo Antônio', '83413-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21902, 'Curitiba', 'Luiz Perrone', 'Seminário', '80310-090', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21903, 'Londrina', 'Luiz Picelli', 'Jardim Pacaembu', '86079-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21904, 'Toledo', 'Luiz Pierozan', 'Independência', '85906-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21905, 'Curitiba', 'Luiz Pinto da Rocha', 'Jardim Social', '82520-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21906, 'São José dos Pinhais', 'Luiz Pissaia', 'Rio Pequeno', '83070-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21907, 'São José dos Pinhais', 'Luiz Rafael Poplade', 'Afonso Pena', '83065-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21908, 'Castro', 'Luiz Razera', 'Água Suja', '84165-295', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21909, 'Curitiba', 'Luiz Rebellatto', 'Xaxim', '81810-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21910, 'Curitiba', 'Luiz Renato Mocelin', 'Xaxim', '81710-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21911, 'Colombo', 'Luiz Renato Tosin II', 'Centro', '83414-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21912, 'São José dos Pinhais', 'Luiz Rezende', 'São Sebastião', '83075-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21913, 'Sarandi', 'Luiz Rezzini', 'Jardim Escala', '87114-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21914, 'Colombo', 'Luiz Rissardi', 'Jardim Esperança', '83402-450', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21915, 'Campo Largo', 'Luiz Rivabem', 'Vila Rivabem', '83605-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21916, 'Foz do Iguaçu', 'Luiz Rodrigues Coelho', 'Jardim Porto Belo', '85867-355', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21917, 'Araucária', 'Luiz Rodrigues Velho', 'Thomaz Coelho', '83707-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21918, 'Curitiba', 'Luiz Ronaldo Canalli', 'Campo Comprido', '81230-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21919, 'Londrina', 'Luiz Rosseto', 'Caravelle', '86039-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21920, 'Guarapuava', 'Luiz Scorsim', 'São Cristóvão', '85060-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21921, 'Curitiba', 'Luiz Scuissatto', 'Fazendinha', '81330-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21922, 'Colombo', 'Luiz Sebastião Baldo', 'Jardim dos Eucaliptos', '83408-506', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21923, 'Toledo', 'Luiz Segundo Rossoni', 'Centro', '85901-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21924, 'São José dos Pinhais', 'Luiz Senegaglia', 'Afonso Pena', '83065-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21925, 'Curitiba', 'Luiz Sérgio Schatzmann', 'Uberaba', '81590-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21926, 'Curitiba', 'Luiz Sieracki', 'Santo Inácio', '82010-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21927, 'Ponta Grossa', 'Luiz Sodré Swensson', 'Neves', '84020-779', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21928, 'Francisco Beltrão', 'Luiz Soeter', 'Sadia', '85606-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21929, 'Curitiba', 'Luiz Sperandio', 'Santo Inácio', '82300-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21930, 'Paranavaí', 'Luiz Spigolon', 'Centro', '87703-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21931, 'Paranavaí', 'Luiz Spigolon', 'Centro', '87704-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21932, 'Paranavaí', 'Luiz Spigolon', 'Centro', '87705-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21933, 'Paranavaí', 'Luiz Spigolon', 'Jardim Alvorada do Sul I', '87707-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21934, 'Londrina', 'Luiz Spoladore', 'Jardim Graziela', '86036-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21935, 'Curitiba', 'Luiz Stival', 'Santa Felicidade', '82030-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21936, 'Curitiba', 'Luiz Stopinski', 'Cidade Industrial', '81460-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21937, 'Colombo', 'Luiz Tadeu Colere', 'Jardim Aurora', '83411-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21938, 'Arapongas', 'Luiz Teglia Júnior', 'Centro', '86701-365', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21939, 'Paranaguá', 'Luiz Teixeira da Silva', 'Vila Paranaguá', '83221-056', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21940, 'Maringá', 'Luiz Teixeira Mendes', 'Zona 05', '87015-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21941, 'Maringá', 'Luiz Teixeira Mendes', 'Zona 04', '87015-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21942, 'Curitiba', 'Luiz Tramontin', 'Campo Comprido', '81230-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21943, 'Ponta Grossa', 'Luiz Trentin', 'Olarias', '84026-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21944, 'Colombo', 'Luiz Trevisan', 'Jardim dos Eucaliptos', '83408-519', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21945, 'Curitiba', 'Luiz Valenza', 'Cidade Industrial', '81350-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21946, 'Pinhais', 'Luiz Vasselai', 'Vila Irene Margarida', '83326-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21947, 'Curitiba', 'Luiz Venâncio', 'Uberaba', '81590-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21948, 'Cascavel', 'Luiz Venturim', 'Claudete', '85811-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21949, 'Cascavel', 'Luiz Vianey Pereira', 'Maria Luiza', '85819-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21950, 'Londrina', 'Luiz Vicente Amadeu Gongora', 'Franciscato II', '86078-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21951, 'Apucarana', 'Luiz Vicentini', 'Parque Bela Vista', '86803-175', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21952, 'Cascavel', 'Luiz Vilwock', 'Nova Cidade', '85803-177', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21953, 'Londrina', 'Luiz Viotti', 'Jardim Belo Horizonte', '86037-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21954, 'Curitiba', 'Luiz Visinoni', 'Cajuru', '82980-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21955, 'Araucária', 'Luiz Wachowicz', 'Thomaz Coelho', '83706-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21956, 'Toledo', 'Luiz Woiski', 'Sachini', '85903-718', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21957, 'Pato Branco', 'Luiz Xavier', 'São Cristóvão', '85508-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21958, 'Curitiba', 'Luiz Xavier', 'Centro', '80020-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21959, 'Paranavaí', 'Luiz Zaros', 'Jardim Ipê', '87706-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21960, 'Campo Largo', 'Luiz Zeribeto', 'Vila Bancária', '83601-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21961, 'Curitiba', 'Luiz Zilli', 'Campo Comprido', '81220-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21962, 'São José dos Pinhais', 'Luiza Adão', 'Ipê', '83055-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21963, 'Colombo', 'Luiza Baldon Borato', 'Jardim das Oliveiras', '83407-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21964, 'Curitiba', 'Luiza Borges Fanini', 'Sítio Cercado', '81920-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21965, 'Curitiba', 'Luiza Borges Fanini', 'Sítio Cercado', '81925-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21966, 'Londrina', 'Luiza Denardin Menoncin', 'Jardim Campos Verdes', '86085-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21967, 'Londrina', 'Luiza Donoso Gonzalez', 'Jardim Ilha do Mel', '86081-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21968, 'Colombo', 'Luiza Furlan Berlesi', 'Vila Igasa', '83412-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21969, 'Curitiba', 'Luiza Gasola Santi', 'Uberaba', '81560-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21970, 'Apucarana', 'Luiza Gregório Clebis', 'Loteamento Sol Nascente', '86801-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21971, 'Colombo', 'Luiza Guarise Tosin', 'Jardim Belo Rincão', '83412-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21972, 'Curitiba', 'Luiza Gulin', 'Bacacheri', '82600-650', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21973, 'São José dos Pinhais', 'Luiza Hummelgen Nester', 'Rio Pequeno', '83065-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21974, 'Curitiba', 'Luiza Lélia Gulin Geronasso', 'Boa Vista', '82650-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21975, 'Curitiba', 'Luiza Mahin', 'Cajuru', '82920-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21976, 'Londrina', 'Luiza Maria do Nascimento', 'Jardim Bavária', '86082-016', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21977, 'Araucária', 'Luiza Maria Knopik', 'Costeira', '83708-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21978, 'Curitiba', 'Luiza Mazetto Baggio', 'Mossunguê', '81200-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21979, 'Londrina', 'Luiza Meranca Munaretto', 'Vale das Araucárias', '86047-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21980, 'Piraquara', 'Luiza Milk Rodrigues', 'Vila Izabel', '83305-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21981, 'Cascavel', 'Luiza Padovani Fanhame', 'Morumbi', '85817-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21982, 'Londrina', 'Luíza Rodrigues Zanette', 'Jardim Nápoles', '86062-635', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21983, 'Curitiba', 'Luiza Tortato', 'Sítio Cercado', '81900-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21984, 'Curitiba', 'Luiza Vardanega Marzani', 'Campo Comprido', '81230-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21985, 'Curitiba', 'Luiza Verone Piccoli', 'Tingui', '82600-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21986, 'Foz do Iguaçu', 'Luiza Wandscheer', 'Jardim Copacabana', '85856-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21987, 'Maringá', 'Luiza Zequim', 'Jardim Santa Rosa', '87060-026', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21988, 'Foz do Iguaçu', 'Lulas', 'Profilurb I', '85855-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21989, 'Londrina', 'Lupércio Pozatto', 'Conjunto Habitacional José Belinati', '86084-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21990, 'Londrina', 'Lupicínio Rodrigues', 'Cilo 2', '86067-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21991, 'Maringá', 'Lupicínio Rodrigues', 'Conjunto Habitacional Itatiaia', '87045-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21992, 'Pato Branco', 'Lupicínio Rodrigues', 'Pinheirinho', '85506-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21993, 'Pato Branco', 'Lupicínio Rodrigues', 'Chaparral', '85507-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21994, 'Cascavel', 'Lupicínio Rodrigues', 'Brasília', '85815-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21995, 'Ponta Grossa', 'Lupionópolis', 'Cará-cará', '84032-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21996, 'Curitiba', 'Lupionópolis', 'Sítio Cercado', '81925-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21997, 'Curitiba', 'Lupionópolis', 'Sítio Cercado', '81920-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21998, 'São José dos Pinhais', 'Lurdes Nunes Ezidio', 'Guatupê', '83060-447', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (21999, 'Colombo', 'Lusitana', 'Parque Residencial Santa Terezinha', '83408-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22000, 'Curitiba', 'Luthero', 'Alto da Glória', '80030-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22001, 'Londrina', 'Luxemburgo', 'Jerumenha', '86046-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22002, 'Francisco Beltrão', 'Luz', 'Antônio de Paiva Cantelmo', '85603-535', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22003, 'Foz do Iguaçu', 'Luz Marina', 'Parque Imperatriz', '85862-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22004, 'Londrina', 'Luzia Accorsi', 'Jardim das Palmeiras', '86083-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22005, 'Londrina', 'Luzia Antônio Bretas', 'Ernani de Moura Lima', '86037-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22006, 'Londrina', 'Luzia Costa e Silva', 'Ernani de Moura Lima', '86037-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22007, 'Curitiba', 'Luzia dos Santos Silveira', 'Alto Boqueirão', '81860-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22008, 'Cascavel', 'Luzia Onofre de Souza', 'Cascavel Velho', '85818-516', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22009, 'Londrina', 'Luzia Rosa Lobato', 'Vale do Reno', '86047-305', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22010, 'Londrina', 'Luzia Russo Rodrigues', 'Jardim Nova Esperança', '86044-649', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22011, 'Foz do Iguaçu', 'Luziania', 'Jardim Paraná', '85867-665', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22012, 'São José dos Pinhais', 'Luziano Cordeiro', 'Afonso Pena', '83050-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22013, 'Paranavaí', 'Luzitana', 'Jardim Santos Dumont', '87706-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22014, 'Londrina', 'Lyda Monteiro da Silva', 'Santa Mônica', '86079-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22015, 'Ponta Grossa', 'Lydia Henneberg Fanchin', 'Boa Vista', '84072-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22016, 'Londrina', 'Lydia Monteiro', 'Jardim Itaparica', '86087-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22017, 'Almirante Tamandaré', 'Lydia Rose Zanlutti', 'Jardim Cíntia Mara', '83513-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22018, 'Curitiba', 'Lydio Paulo Bettega', 'Cidade Industrial', '81460-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22019, 'Curitiba', 'Lygia Erichsen Carneiro', 'Uberaba', '81590-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22020, 'Londrina', 'Lyra', 'Sol', '86070-026', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22021, 'São José dos Pinhais', 'Lyrio Dallagassa', 'Afonso Pena', '83050-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22022, 'Ponta Grossa', 'Lysandro Antunes Sampaio', 'Ronda', '84050-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22023, 'Curitiba', 'Lysimaco Ferreira da Costa', 'Centro Cívico', '80530-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22024, 'Foz do Iguaçu', 'M', 'Conjunto C', '85870-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22025, 'Ponta Grossa', 'M', 'Boa Vista', '84072-007', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22026, 'Pinhais', 'M', 'Jardim Pio XII', '83328-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22028, 'Umuarama', 'M', 'Parque das Jaboticabeiras', '87509-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22029, 'Umuarama', 'M', 'Parque Dom Pedro I', '87508-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22030, 'Campo Largo', 'M', 'Vila Torres II', '83609-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22031, 'Campo Largo', 'M', 'Popular Nova', '83602-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22032, 'Campo Largo', 'M', 'Jardim Três Rios', '83603-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22033, 'Arapongas', 'M-1', 'Jardim Petrópolis', '86709-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22034, 'Arapongas', 'M-2', 'Jardim Petrópolis', '86709-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22035, 'Arapongas', 'M-3', 'Jardim Petrópolis', '86709-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22036, 'Arapongas', 'M-4', 'Jardim Caravelle', '86702-007', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22037, 'Arapongas', 'M-5', 'Jardim Caravelle', '86702-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22038, 'Arapongas', 'M-6', 'Jardim Caravelle', '86702-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22039, 'Arapongas', 'M-7', 'Jardim Petrópolis', '86709-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22040, 'Guarapuava', 'Mabel Granier', 'Conradinho', '85055-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22041, 'Londrina', 'Mabio Gonçalve Palhano', 'Gleba Fazenda Palhano', '86055-585', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22042, 'Telêmaco Borba', 'Maçã', 'Fazenda Limeira', '84270-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22043, 'Foz do Iguaçu', 'Macaé', 'Jardim Petropólis', '85868-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22044, 'Francisco Beltrão', 'Macaé', 'Pinheirinho', '85603-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22045, 'Guarapuava', 'Macapá', 'Conradinho', '85055-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22046, 'Foz do Iguaçu', 'Macapá', 'Jardim Duarte', '85861-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22047, 'Pinhais', 'Macapá', 'Conjunto Residencial Renato Bonilauri', '83325-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22048, 'Maringá', 'Macapá', 'Jardim Social', '87010-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22049, 'Umuarama', 'Macapá', 'Zona VII', '87503-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22050, 'Telêmaco Borba', 'Macapá', 'Vila Esperança', '84272-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22051, 'São José dos Pinhais', 'Macapá', 'Águas Belas', '83010-580', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22052, 'Curitiba', 'Macapá', 'Tingui', '82620-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22053, 'Londrina', 'Maçaranduba', 'Santa Rita 1', '86071-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22054, 'Arapongas', 'Maçaricão', 'Vila Estrela', '86708-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22055, 'Arapongas', 'Maçarico-do-campo', 'Jardim Monte Carlo', '86704-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22056, 'Arapongas', 'Maçarico-pintado', 'Jardim Colúmbia IV', '86707-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22057, 'Londrina', 'Macau', 'São Lourenço', '86026-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22058, 'Cascavel', 'Macau', 'São Cristóvão', '85816-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22059, 'Arapongas', 'Macauã', 'Jardim Santo Antônio', '86705-668', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22060, 'Ponta Grossa', 'Macauba', 'Neves', '84020-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22061, 'Guarapuava', 'Macedônia', 'Boqueirão', '85020-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22062, 'Foz do Iguaçu', 'Maceió', 'Jardim Petropólis', '85868-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22063, 'Foz do Iguaçu', 'Maceió', 'Conjunto C', '85870-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22064, 'Londrina', 'Maceió', 'Boa Vista', '86020-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22065, 'Maringá', 'Maceió', 'Vila Morangueira', '87030-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22066, 'Piraquara', 'Maceió', 'Vila Vicente Macedo', '83303-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22067, 'Umuarama', 'Maceió', 'Zona V', '87504-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22068, 'São José dos Pinhais', 'Maceió', 'Águas Belas', '83010-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22069, 'Toledo', 'Maceió', 'Walter Fontana', '85909-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22070, 'Telêmaco Borba', 'Maceió', 'Vila Santa Rita', '84263-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22071, 'Cascavel', 'Maceió', 'São Cristóvão', '85816-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22072, 'Cambé', 'Maceió', 'Vila Salomé', '86192-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22073, 'Curitiba', 'Maceió', 'Cajuru', '82920-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22074, 'Curitiba', 'Maceió', 'Cajuru', '82930-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22075, 'Francisco Beltrão', 'Machado de Assis', 'São Miguel', '85602-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22076, 'Laranjeiras do Sul', 'Machado de Assis', 'Centro', '85301-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22077, 'Guarapuava', 'Machado de Assis', 'Vila Bela', '85027-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22078, 'Londrina', 'Machado de Assis', 'Jardim Tatiani', '86070-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22079, 'Foz do Iguaçu', 'Machado de Assis', 'Jardim Jupira', '85865-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22080, 'Pato Branco', 'Machado de Assis', 'Anchieta', '85502-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22081, 'Paranavaí', 'Machado de Assis', 'Jardim São Jorge', '87710-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22082, 'Ponta Grossa', 'Machado de Assis', 'Uvaranas', '84025-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22083, 'Pinhais', 'Machado de Assis', 'Núcleo Colonial de Pinhais', '83321-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22084, 'Maringá', 'Machado de Assis', 'Zona 06', '87015-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22085, 'Sarandi', 'Machado de Assis', 'Jardim Panorama', '87113-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22086, 'Sarandi', 'Machado de Assis', 'Jardim Independência I', '87114-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22087, 'Toledo', 'Machado de Assis', 'Jardim Paulista', '85909-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22088, 'Telêmaco Borba', 'Machado de Assis', 'Vila Santa Rita', '84263-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22089, 'Campo Largo', 'Machado de Assis', 'Vila Nova', '83605-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22090, 'Almirante Tamandaré', 'Machado de Assis', 'Vila Marta', '83508-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22091, 'Cascavel', 'Machado de Assis', 'Região do Lago 1', '85812-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22092, 'Colombo', 'Machado de Assis', 'Jardim Central', '83409-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22093, 'Curitiba', 'Machado de Assis', 'Juvevê', '80030-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22094, 'Curitiba', 'Machado de Assis', 'Juvevê', '80040-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22095, 'Foz do Iguaçu', 'Macieira', 'Jardim Mônaco', '85862-426', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22096, 'Ponta Grossa', 'Macieira', 'Chapada', '84064-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22097, 'Araucária', 'Macieiras', 'Estação', '83705-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22098, 'Londrina', 'Macuco', 'Jacomo Violin', '86088-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22099, 'Campo Mourão', 'Macuco', 'Jardim Tropical I', '87310-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22100, 'Arapongas', 'Macuco', 'Centro', '86701-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22101, 'Foz do Iguaçu', 'Macucos', 'Portal da Foz', '85859-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22102, 'Arapongas', 'Macuquinho', 'Jardim do Sol', '86705-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22103, 'Arapongas', 'Macuquinho-de-colar', 'Conjunto Flamingos III', '86703-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22104, 'Arapongas', 'Macuru', 'Conjunto Flamingos', '86703-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22105, 'Arapongas', 'Macuru-pintado', 'Jardim São Bento', '86706-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22106, 'Pinhais', 'Madagascar', 'Jardim Hipódromo', '83320-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22107, 'Colombo', 'Madagascar', 'Vila Alto da Cruz II', '83405-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22108, 'Cambé', 'Madalena Cogo Raminelli', 'Jardim José Favaro', '86183-778', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22109, 'Foz do Iguaçu', 'Madalena Sotelo', 'Jardim Porto Belo', '85867-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22110, 'Cascavel', 'Madalena Tagliaferro', 'Brasília', '85815-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22111, 'Londrina', 'Madame Curie', 'Brasília', '86039-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22112, 'Curitiba', 'Madame Curie', 'Pinheirinho', '81820-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22113, 'Londrina', 'Madeira', 'Matarazzo', '86026-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22114, 'Cascavel', 'Madeira', 'Presidente', '85818-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22115, 'Curitiba', 'Madre Carmela de Jesus', 'Cidade Industrial', '81230-426', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22116, 'Curitiba', 'Madre Clélia Merloni', 'Santa Felicidade', '82030-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22117, 'Telêmaco Borba', 'Madre de Deus', 'Vila Santa Rita', '84263-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22118, 'Curitiba', 'Madre Emília Riquelme', 'Sítio Cercado', '81900-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22119, 'Curitiba', 'Madre Geral', 'Novo Mundo', '81050-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22120, 'Curitiba', 'Madre Geral', 'Novo Mundo', '80050-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22121, 'Londrina', 'Madre Henriqueta Dominici', 'Lagoa Dourada', '86041-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22122, 'Curitiba', 'Madre Isabel dos Anjos', 'Guabirotuba', '81520-520', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22123, 'Curitiba', 'Madre Júlia', 'Cristo Rei', '80050-160', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22124, 'Londrina', 'Madre Leonia Milito', 'Bela Suiça', '86050-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22125, 'Curitiba', 'Madre Leonie', 'Jardim Social', '82530-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22126, 'Curitiba', 'Madre Leopoldina de Santa Tereza', 'Xaxim', '81830-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22127, 'Colombo', 'Madre Maria Avosani', 'Vila Ana Maria', '83413-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22128, 'Ponta Grossa', 'Madre Maria dos Anjos', 'Oficinas', '84040-320', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22129, 'Curitiba', 'Madre Maria dos Anjos', 'Água Verde', '80250-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22130, 'Curitiba', 'Madre Maria Lúcia', 'Guabirotuba', '81510-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22131, 'Maringá', 'Madre Mônica Maria', 'Conjunto Habitacional Lea Leal', '87040-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22132, 'Colombo', 'Madre Paulina', 'Jardim dos Eucaliptos', '83408-545', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22133, 'Curitiba', 'Madre Paulina', 'Cidade Industrial', '81230-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22134, 'Maringá', 'Madre Sueli Alice Gion', 'Zona 03', '87050-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22135, 'São José dos Pinhais', 'Madre Tereza de Calcutá', 'Guatupê', '83060-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22136, 'Londrina', 'Madre Tonina Ugolini', 'Caravelle', '86039-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22137, 'Curitiba', 'Madre Úrsula Ledochowska', 'Capão Raso', '81110-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22138, 'Londrina', 'Madressilva', 'Novo Amparo', '86042-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22139, 'Guarapuava', 'Madri', 'Santana', '85070-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22140, 'Foz do Iguaçu', 'Madri', 'Jardim Liberdade', '85858-115', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22141, 'Paranaguá', 'Madri', 'Parque Agari', '83215-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22142, 'Toledo', 'Madrid', 'Centro', '85900-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22143, 'Telêmaco Borba', 'Madrid', 'Nossa Senhora do Perpétuo Socorro', '84265-060', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22144, 'Cascavel', 'Madrid', 'Cascavel Velho', '85818-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22145, 'Colombo', 'Madrid', 'Vila Alto da Cruz', '83405-460', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22146, 'Ponta Grossa', 'Madureira', 'Boa Vista', '84073-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22147, 'Curitiba', 'Madureira', 'Cajuru', '82940-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22148, 'Cascavel', 'Mãe Catira', 'Cataratas', '85818-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22149, 'Curitiba', 'Mãe do Catira', 'Uberaba', '81550-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22150, 'Curitiba', 'Mãe Menininha do Gantois', 'Cajuru', '82920-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22151, 'Arapongas', 'Mãe-da-lua', 'Conjunto Tropical', '86702-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22152, 'Arapongas', 'Mãe-da-taoca', 'Jardim Aeroporto', '86702-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22153, 'Curitiba', 'Maestro Acyr Benedito Tedeschi', 'Alto Boqueirão', '81770-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22154, 'Londrina', 'Maestro Andrea Nuzzi', 'Jardim Itatiaia 1', '86047-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22155, 'Curitiba', 'Maestro Ângelo Antonello', 'Jardim das Américas', '81540-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22156, 'Maringá', 'Maestro Aniceto Matti', 'Jardim Alvorada', '87035-130', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22157, 'Almirante Tamandaré', 'Maestro Antonelo', 'Loteamento Recanto dos Papagaios', '83512-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22158, 'Castro', 'Maestro Benedito Pereira', 'Centro', '84165-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22159, 'Curitiba', 'Maestro Bento Mossorunga', 'Jardim das Américas', '81530-290', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22160, 'Ponta Grossa', 'Maestro Bento Mossurunga', 'Chapada', '84062-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22161, 'Castro', 'Maestro Bento Mossurunga', 'Centro', '84165-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22162, 'Almirante Tamandaré', 'Maestro Bento Mossurunga', 'Jardim Apucarana', '83505-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22163, 'Curitiba', 'Maestro Carlos Frank', 'Boqueirão', '81770-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22164, 'Curitiba', 'Maestro Carlos Frank', 'Boqueirão', '81750-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22165, 'Curitiba', 'Maestro Carlos Frank', 'Boqueirão', '81730-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22166, 'Curitiba', 'Maestro Dorival Rossi', 'Cidade Industrial', '81230-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22167, 'Londrina', 'Maestro Egídio Camargo do Amaral', 'Centro', '86010-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22168, 'Londrina', 'Maestro Erlon Chaves', 'Conjunto Vivi Xavier', '86082-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22169, 'Curitiba', 'Maestro Fernando Alves', 'Alto Boqueirão', '81720-350', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22170, 'Curitiba', 'Maestro Francisco Antonello', 'Fanny', '81030-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22171, 'Maringá', 'Maestro Fumimasa Otani', 'Zona 20', '87060-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22172, 'Curitiba', 'Maestro Herrmann', 'Pilarzinho', '82100-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22173, 'Curitiba', 'Maestro Idilio Donatti', 'Prado Velho', '80215-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22174, 'Curitiba', 'Maestro Lindolpho Gaya', 'Santa Felicidade', '82015-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22175, 'Ponta Grossa', 'Maestro Paulino Martins Alves', 'Chapada', '84062-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22176, 'Castro', 'Maestro Pedro Maia', 'Jardim das Araucárias', '84174-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22177, 'Curitiba', 'Maestro Remo de Persis', 'Jardim das Américas', '81530-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22178, 'Curitiba', 'Maestro Romualdo Suriani', 'Jardim das Américas', '81520-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22179, 'Curitiba', 'Maestro Vicente d''Alo', 'Tatuquara', '81480-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22180, 'Piraquara', 'Maestro Wassilio Zebulski', 'Jardim Santa Mônica', '83302-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22181, 'Foz do Iguaçu', 'Mafra', 'Loteamento Witt', '85862-529', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22182, 'Cascavel', 'Mafra', 'Universitário', '85819-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22183, 'Curitiba', 'Mafra', 'Cidade Industrial', '81270-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22184, 'Curitiba', 'Magdalena Chagas Lima', 'São Braz', '82300-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22185, 'Curitiba', 'Magdalena de Almeida', 'Capão Raso', '81130-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22186, 'Curitiba', 'Magdalena Taborda Ribas', 'Novo Mundo', '81050-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22187, 'Maringá', 'Magnatas', 'Recanto dos Magnatas', '87060-620', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22188, 'Maringá', 'Magnólia', 'Jardim Pinheiros', '87043-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22189, 'Ponta Grossa', 'Magnólia', 'Contorno', '84060-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22190, 'Telêmaco Borba', 'Magnólia', 'Jardim Alegre', '84268-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22191, 'Cascavel', 'Magnólia', 'Parque Verde', '85807-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22192, 'Araucária', 'Magnólia', 'Campina da Barra', '83709-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22193, 'Foz do Iguaçu', 'Maguari', 'Parque Morumbi III', '85859-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22194, 'Arapongas', 'Maguari', 'Conjunto Padre Chico', '86707-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22195, 'Curitiba', 'Maguari', 'São Braz', '82015-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22196, 'São José dos Pinhais', 'Mahatma Gandhi', 'Aristocrata', '83030-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22197, 'Curitiba', 'Mahatma Gandhi', 'Xaxim', '81810-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22198, 'Londrina', 'Mahatma Ghandi', 'Califórnia', '86040-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22199, 'Foz do Iguaçu', 'Mahmoud Osman', 'Jardim Dom Miguel Osman', '85856-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22200, 'Ponta Grossa', 'Maina', 'Colônia Dona Luiza', '84046-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22201, 'Arapongas', 'Mainá', 'Vila Vicentini', '86708-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22202, 'Londrina', 'Maine', 'Araxá', '86061-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22203, 'Colombo', 'Maiorca', 'Parque Residencial Santa Terezinha', '83408-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22204, 'Guarapuava', 'Maira', 'São Cristóvão', '85063-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22205, 'Maringá', 'Maísa', 'Conjunto Residencial Cidade Alta', '87053-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22206, 'Arapongas', 'Maitaca', 'Jardim Bandeirantes', '86703-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22207, 'Arapongas', 'Maitaca-roxa', 'Jardim São Rafael', '86703-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22208, 'Arapongas', 'Maitaca-verde', 'Jardim Petrópolis', '86709-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22209, 'Maringá', 'Major Abelardo José da Cruz', 'Jardim Rebouças', '87083-570', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22210, 'Maringá', 'Major Abelardo José da Cruz', 'Conjunto João de Barro Itaparica', '87043-490', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22297, 'Londrina', 'Malvino de Carvalho Grade', 'Jardim Alphaville', '86084-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22211, 'Maringá', 'Major Abelardo José da Cruz', 'Conjunto Habitacional Requião', '87047-426', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22212, 'Maringá', 'Major Abelardo José da Cruz', 'Jardim Copacabana', '87023-215', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22213, 'Maringá', 'Major Abelardo José da Cruz', 'Parque das Grevíleas', '87025-630', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22214, 'Maringá', 'Major Abelardo José da Cruz', 'Jardim Andrade', '87035-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22215, 'Foz do Iguaçu', 'Major Acylino de Castro', 'Vila Yolanda', '85853-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22216, 'Sarandi', 'Major Afonso Delambert de Oliveira', 'Jardim Ouro Preto', '87114-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22217, 'Apucarana', 'Major Agostinho José Rodrigues', 'Jardim Aviação', '86812-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22218, 'Curitiba', 'Major Alberto Pereira Jorge', 'Seminário', '80740-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22219, 'Ponta Grossa', 'Major Alceu Teixeira Pinto', 'Estrela', '84050-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22220, 'Ponta Grossa', 'Major Alceu Teixeira Pinto', 'Uvaranas', '84030-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22221, 'Curitiba', 'Major Antônio Alves da Rocha Loures', 'Cidade Industrial', '81270-650', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22222, 'Curitiba', 'Major Antônio Gomes Ferreira', 'Cristo Rei', '80050-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22223, 'Londrina', 'Major Archilles Pimpão', 'Jardim Vale Verde', '86040-020', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22224, 'Curitiba', 'Major Ariovaldo Bianco', 'Cidade Industrial', '81230-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22225, 'Castro', 'Major Átila Cunningham', 'Jardim das Araucárias', '84174-618', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22226, 'Piraquara', 'Major Bernardino Bormann', 'Vila Militar I', '83303-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22227, 'Castro', 'Major Cândido Cruz', 'Jardim dos Bancários', '84172-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22228, 'Curitiba', 'Major Carlos Francisco Berleze', 'Pinheirinho', '81825-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22229, 'Curitiba', 'Major Casemiro Ignacio Mazur', 'Alto Boqueirão', '81850-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22230, 'Curitiba', 'Major Claro Américo Guimarães', 'Jardim Social', '82520-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22231, 'Curitiba', 'Major Correia Lima', 'Jardim Botânico', '80210-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22232, 'Curitiba', 'Major Couto Pereira', 'Cidade Industrial', '81310-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22233, 'Piraquara', 'Major Dirceu Mendes', 'Jardim Diguimabri', '83307-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22234, 'Curitiba', 'Major Ernâni Belmiro Mazalli', 'Cristo Rei', '80050-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22235, 'Paranaguá', 'Major Ernâni Vidal', 'Alvorada', '83206-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22236, 'São José dos Pinhais', 'Major Estanislau Grossmann', 'Afonso Pena', '83045-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22237, 'Curitiba', 'Major Estanislau Grossmann', 'Cajuru', '82980-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22238, 'Curitiba', 'Major Eulálio Dudek', 'Pinheirinho', '81870-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22239, 'Piraquara', 'Major Fabriciano do Rego Barros', 'Vila Militar I', '83303-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22240, 'Curitiba', 'Major Fabriciano do Rego Barros', 'Hauer', '81630-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22241, 'Curitiba', 'Major Fabriciano do Rego Barros', 'Hauer', '81610-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22242, 'Curitiba', 'Major Fidêncio Lemos do Prado', 'Tarumã', '82530-210', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22243, 'Curitiba', 'Major Franca Gomes', 'Santa Quitéria', '80310-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22244, 'Curitiba', 'Major Francisco Hardy', 'Campo Comprido', '81230-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22245, 'Ponta Grossa', 'Major Gabriel Menna Barreto', 'Estrela', '84050-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22246, 'Curitiba', 'Major Heitor Guimarães', 'Campina do Siqueira', '80740-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22247, 'Curitiba', 'Major Heitor Guimarães', 'Seminário', '80440-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22248, 'Curitiba', 'Major Idegaldo Coutinho Bacci', 'Cabral', '80035-300', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22249, 'Piraquara', 'Major Inácio Gomes da Costa', 'Vila Militar I', '83303-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22250, 'Curitiba', 'Major Inácio Gomes da Costa', 'Uberaba', '81570-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22251, 'Curitiba', 'Major João de Carvalho', 'Novo Mundo', '81010-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22252, 'Curitiba', 'Major José Dequech', 'Santa Felicidade', '82410-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22253, 'Piraquara', 'Major José Luciano', 'Centro', '83301-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22254, 'Curitiba', 'Major Júlio Ribeiro de Campos', 'Sítio Cercado', '81925-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22255, 'Ponta Grossa', 'Major Manoel Grott', 'Orfãs', '84015-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22256, 'Curitiba', 'Major Miguel Balbino Blasi', 'Sítio Cercado', '81925-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22257, 'Ponta Grossa', 'Major Miguel Farias', 'Uvaranas', '84030-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22258, 'Ponta Grossa', 'Major Nabuo Oba', 'Uvaranas', '84031-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22259, 'Curitiba', 'Major Nestor Luiz de Oliveira Júnior', 'Santo Inácio', '82300-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22260, 'Cascavel', 'Major Oscar Ramos Pereira', 'Vila Tolentino', '85802-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22261, 'Castro', 'Major Otávio Novaes', 'Centro', '84165-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22262, 'Curitiba', 'Major Pedro de Abreu Finkensieper', 'Novo Mundo', '81020-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22263, 'Curitiba', 'Major Pery Leite Ferreira', 'Campina do Siqueira', '80740-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22264, 'Foz do Iguaçu', 'Major Raul de Matos', 'Vila Yolanda', '85853-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22265, 'Curitiba', 'Major Salvador João Fernandes', 'Tatuquara', '81480-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22266, 'Curitiba', 'Major Samuel Pereira', 'Bacacheri', '82515-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22267, 'Curitiba', 'Major Saul de Carvalho Chaves', 'Santa Cândida', '82640-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22268, 'Curitiba', 'Major Sebastião Izidoro Pereira', 'Capão Raso', '81110-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22269, 'Araucária', 'Major Sezino Pereira de Souza', 'Centro', '83702-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22270, 'Ponta Grossa', 'Major Sólon', 'Nova Rússia', '84053-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22271, 'Curitiba', 'Major Theolindo Ferreira Ribas', 'Hauer', '81630-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22272, 'Curitiba', 'Major Theolindo Ferreira Ribas', 'Boqueirão', '81670-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22273, 'Piraquara', 'Major Vicente de Castro', 'Vila Militar I', '83303-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22274, 'Curitiba', 'Major Vicente de Castro', 'Fanny', '81030-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22275, 'Curitiba', 'Major Victor Feijó', 'Cidade Industrial', '81460-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22276, 'Curitiba', 'Major Virgolino Esmanhotto', 'Vista Alegre', '80820-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22277, 'Curitiba', 'Major-Brigadeiro-do-AR Moacir Valporto de Sá', 'Butiatuvinha', '82400-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22278, 'Apucarana', 'Makoto Kutsunugi', 'Barra Funda', '86800-529', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22279, 'Ponta Grossa', 'Malaquita', 'Neves', '84021-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22280, 'Pinhais', 'Malásia', 'Jardim Hipódromo', '83320-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22281, 'Curitiba', 'Malba Gama Scremin', 'Cajuru', '82920-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22282, 'Londrina', 'Malba Tahan', 'Londrina', '86060-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22283, 'Sarandi', 'Malboro', 'Jardim Califórnia', '87112-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22284, 'Piraquara', 'Malet', 'Planta Araçatuba', '83301-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22285, 'Guarapuava', 'Mallet', 'Boqueirão', '85022-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22286, 'Colombo', 'Mallet', 'Jardim Cristina III', '83410-527', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22287, 'Umuarama', 'Malta', 'Jardim Campo Belo', '87507-560', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22288, 'Foz do Iguaçu', 'Malu', 'Jardim Dona Fátima Osman', '85856-686', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22289, 'Umuarama', 'Malu', 'Zona I-A', '87504-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22290, 'Umuarama', 'Malu', 'Zona I', '87501-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22291, 'Piraquara', 'Malva', 'Vila Santa Maria', '83306-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22292, 'Araucária', 'Malva', 'Campina da Barra', '83709-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22293, 'Campo Mourão', 'Malva', 'Jardim Paulista', '87310-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22294, 'Foz do Iguaçu', 'Malva Rosa', 'Jardim das Flores', '85855-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22295, 'Guarapuava', 'Malvinas', 'Boqueirão', '85023-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22296, 'Francisco Beltrão', 'Malvinas', 'Seminário', '85605-656', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22298, 'Maringá', 'Malvino Gardin', 'Jardim Alvorada', '87035-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22299, 'Telêmaco Borba', 'Mamão', 'Fazenda Limeira', '84270-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22300, 'Curitiba', 'Mamão', 'Uberaba', '81540-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22301, 'Guarapuava', 'Mamborê', 'Santa Cruz', '85015-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22302, 'Campo Mourão', 'Mamborê', 'Centro', '87301-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22303, 'Campo Mourão', 'Mamborê', 'Centro', '87302-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22304, 'Curitiba', 'Mamborê', 'Cidade Industrial', '81250-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22305, 'Londrina', 'Mambure', 'Castelo', '86027-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22306, 'Londrina', 'Mamoeiro', 'Charrua', '86071-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22307, 'Londrina', 'Mamoré', 'Vila Monteiro', '86025-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22308, 'Foz do Iguaçu', 'Mamoré', 'Loteamento Campos do Iguaçu', '85857-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22309, 'Londrina', 'Mamoré', 'Vila Monteiro', '86025-555', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22310, 'Pinhais', 'Mamoré', 'Loteamento Alphaville Graciosa', '83327-086', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22311, 'Maringá', 'Mamoré', 'Parque das Grevíleas', '87025-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22312, 'Colombo', 'Mamoré', 'Vila Campo Alto', '83408-329', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22313, 'Curitiba', 'Mamoré', 'Mercês', '80810-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22314, 'Curitiba', 'Mamoré', 'São Francisco', '80510-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22315, 'Pinhais', 'Manacá', 'Jardim Pio XII', '83328-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22316, 'Maringá', 'Manacá', 'Parque Palmeiras', '87023-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22317, 'Piraquara', 'Manacá', 'Vila Santa Maria', '83306-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22318, 'Telêmaco Borba', 'Manacá', 'Jardim Alegre', '84268-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22319, 'Araucária', 'Manacá', 'Campina da Barra', '83709-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22320, 'Maringá', 'Managua', 'Vila Morangueira', '87040-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22321, 'Pinhais', 'Managua', 'Jardim Luzitano', '83320-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22322, 'Cascavel', 'Managua', 'Periolo', '85817-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22323, 'Londrina', 'Manágua', 'Arco Íris', '86050-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22324, 'Arapongas', 'Manaquim', 'Jardim Bandeirantes', '86703-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22325, 'Foz do Iguaçu', 'Manati', 'Conjunto A', '85861-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22326, 'Francisco Beltrão', 'Manaus', 'Alvorada', '85601-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22327, 'Londrina', 'Manaus', 'Jacomo Violin', '86020-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22328, 'Foz do Iguaçu', 'Manaus', 'Jardim das Laranjeiras', '85868-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22329, 'Foz do Iguaçu', 'Manaus', 'Conjunto C', '85870-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22330, 'Foz do Iguaçu', 'Manaus', 'Jardim Paraná', '85867-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22331, 'Maringá', 'Manaus', 'Parque das Grevíleas', '87025-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22332, 'Pato Branco', 'Manaus', 'Pinheiros', '85504-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22333, 'Piraquara', 'Manaus', 'Vila Vicente Macedo', '83303-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22334, 'São José dos Pinhais', 'Manaus', 'Costeira', '83015-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22335, 'Umuarama', 'Manaus', 'Zona I', '87501-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22336, 'Sarandi', 'Manaus', 'Parque Residencial Nova Aliança', '87111-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22337, 'Telêmaco Borba', 'Manaus', 'Vila Santa Rita', '84263-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22338, 'Campo Largo', 'Manaus', 'Jardim Esmeralda', '83604-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22339, 'Cambé', 'Manaus', 'Vila Prata', '86182-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22340, 'Cascavel', 'Manaus', 'Recanto Tropical', '85807-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22341, 'Cascavel', 'Manaus', 'São Cristóvão', '85813-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22342, 'Cascavel', 'Manaus', 'Cancelli', '85811-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22343, 'Telêmaco Borba', 'Mandacaia', 'Área 02', '84267-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22344, 'Londrina', 'Mandacaru', 'Damasco', '86035-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22345, 'Maringá', 'Mandacaru', 'Parque das Laranjeiras', '87083-240', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22346, 'Maringá', 'Mandacaru', 'Vila Santa Izabel', '87080-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22347, 'Apucarana', 'Mandacaru', 'Vila Santa Adélia', '86802-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22348, 'Londrina', 'Mandaguaçu', 'Lindóia', '86031-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22349, 'Maringá', 'Mandaguaçu', 'Jardim Olímpico', '87070-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22350, 'Pinhais', 'Mandaguaçu', 'Jardim Pedro Demeterco', '83324-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22351, 'Ponta Grossa', 'Mandaguaçu', 'Oficinas', '84036-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22352, 'Sarandi', 'Mandaguaçu', 'Novo Panorama', '87113-195', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22353, 'Campo Mourão', 'Mandaguaçu', 'Conjunto Residencial Antilhas', '87308-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22354, 'Curitiba', 'Mandaguaçu', 'Sítio Cercado', '81925-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22355, 'Guarapuava', 'Mandaguari', 'Morro Alto', '85067-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22356, 'Londrina', 'Mandaguari', 'Lindóia', '86031-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22357, 'Francisco Beltrão', 'Mandaguari', 'Luther King', '85605-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22358, 'Foz do Iguaçu', 'Mandaguari', 'Jardim Santa Rosa', '85869-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22359, 'Maringá', 'Mandaguari', 'Zona 07', '87020-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22360, 'Pinhais', 'Mandaguari', 'Planta Portal da Serra', '83325-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22361, 'Pinhais', 'Mandaguari', 'Jardim Pedro Demeterco', '83324-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22362, 'São José dos Pinhais', 'Mandaguari', 'Cruzeiro', '83010-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22363, 'Sarandi', 'Mandaguari', 'Novo Panorama', '87113-197', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22364, 'Umuarama', 'Mandaguari', 'Zona III', '87502-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22365, 'Colombo', 'Mandaguari', 'Jardim São José', '83410-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22366, 'Cambé', 'Mandaguari', 'Jardim Silvino', '86187-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22367, 'Curitiba', 'Mandaguari', 'Pinheirinho', '81880-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22368, 'Ponta Grossa', 'Mandaguary', 'Cará-cará', '84032-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22369, 'Arapongas', 'Mandarim', 'Jardim Panorama', '86708-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22370, 'Curitiba', 'Mandarim', 'São Braz', '82315-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22371, 'Londrina', 'Mandarin', 'Conjunto Habitacional Violim', '86084-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22372, 'Foz do Iguaçu', 'Mandi', 'Profilurb I', '85855-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22373, 'São José dos Pinhais', 'Mandirituba', 'Afonso Pena', '83045-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22374, 'Almirante Tamandaré', 'Mandirituba', 'Jardim Roma', '83504-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22375, 'Colombo', 'Mandirituba', 'Jardim La Paloma', '83412-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22376, 'Curitiba', 'Mandirituba', 'Sítio Cercado', '81900-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22377, 'Curitiba', 'Mandirituba', 'Sítio Cercado', '81925-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22378, 'Foz do Iguaçu', 'Manduva', 'Conjunto A', '85860-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22379, 'Curitiba', 'Mané Garrincha', 'Tatuquara', '81470-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22380, 'Foz do Iguaçu', 'Mané Garrincha', 'Conjunto Libra', '85857-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22381, 'Foz do Iguaçu', 'Mané Garrincha', 'Parque Morumbi II', '85859-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22382, 'Toledo', 'Mané Garrincha', 'Vila Industrial', '85904-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22383, 'Paranaguá', 'Maneco Viana', 'Alto São Sebastião', '83206-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22384, 'Foz do Iguaçu', 'Manêncio Martins', 'Vila Yolanda', '85853-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22385, 'Londrina', 'Mangaba', 'Panorama', '86035-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22386, 'Curitiba', 'Mangaba', 'Uberaba', '81560-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22387, 'Foz do Iguaçu', 'Manganês', 'Parque Ouro Verde', '85854-190', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22388, 'Londrina', 'Manganês', 'Ideal', '86030-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22389, 'Apucarana', 'Manganês', 'Parque Industrial Zona Norte', '86806-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22390, 'Foz do Iguaçu', 'Mangaritiba', 'Parque Imperatriz', '85862-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22391, 'Curitiba', 'Mangas', 'Uberaba', '81550-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22392, 'Cascavel', 'Mangerona', 'Guarujá', '85804-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22393, 'Foz do Iguaçu', 'Manguaba', 'Jardim Bandeirantes', '85862-438', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22394, 'Francisco Beltrão', 'Mangueira', 'São Cristóvão', '85601-369', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22395, 'Foz do Iguaçu', 'Mangueira', 'Jardim das Laranjeiras', '85868-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22396, 'Telêmaco Borba', 'Mangueira', 'Vila Cristina', '84272-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22397, 'Francisco Beltrão', 'Mangueirinha', 'Marrecas', '85601-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22398, 'Ponta Grossa', 'Mangueirinha', 'Ronda', '84051-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22399, 'Foz do Iguaçu', 'Manguruju', 'Profilurb I', '85855-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22400, 'Curitiba', 'Mani Zir Bourges', 'Pinheirinho', '81825-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22401, 'Curitiba', 'Manife Tacla', 'Pilarzinho', '82120-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22402, 'Londrina', 'Manila', 'Cláudia', '86050-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22403, 'Londrina', 'Manjericão', 'Jardim Novo Sabará', '86066-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22404, 'Curitiba', 'Manoel Abilhoa', 'Umbará', '81930-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22405, 'Curitiba', 'Manoel Albano Roskamp', 'Cajuru', '82920-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22406, 'Colombo', 'Manoel Alberti', 'Jardim Osasco', '83403-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22407, 'Pinhais', 'Manoel Alher', 'Prive Bois de Boulogne', '83330-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22408, 'Londrina', 'Manoel Alves da Silva', 'Conjunto Habitacional João Turquino', '86056-850', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22409, 'Londrina', 'Manoel Alves de Oliveira', 'Jardim Alphaville', '86084-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22410, 'São José dos Pinhais', 'Manoel Alves de Oliveira', 'São Pedro', '83005-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22411, 'Foz do Iguaçu', 'Manoel Alves dos Santos', 'Alto São Francisco', '85863-767', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22412, 'Londrina', 'Manoel Alves dos Santos', 'Aurora', '86047-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22413, 'Colombo', 'Manoel Alves Franco', 'Jardim Ouro Verde', '83405-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22414, 'Francisco Beltrão', 'Manoel Alves Ribeiro', 'São Miguel', '85602-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22415, 'Piraquara', 'Manoel Alves Teixeira', 'Vila Ipanema', '83301-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22416, 'Pinhais', 'Manoel Alves Vieira', 'Vila Maria Antonieta', '83331-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22417, 'Curitiba', 'Manoel Amálio de Souza', 'Vista Alegre', '80820-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22418, 'Guarapuava', 'Manoel Antônio', 'Vila Bela', '85027-270', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22419, 'Curitiba', 'Manoel Antônio Becker', 'Pilarzinho', '82110-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22420, 'Cascavel', 'Manoel Antônio de Oliveira', 'Maria Luiza', '85819-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22421, 'Cascavel', 'Manoel Antônio de Oliveira', 'Parque São Paulo', '85803-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22422, 'Ponta Grossa', 'Manoel Antônio Martins de Oliveira', 'Jardim Carvalho', '84016-718', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22423, 'Curitiba', 'Manoel Aranha', 'Abranches', '82220-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22424, 'Curitiba', 'Manoel Aristides de Farias', 'Barreirinha', '82650-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22425, 'Curitiba', 'Manoel Ascenção Fernandes', 'Bom Retiro', '80520-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22426, 'Londrina', 'Manoel B. F. Barbosa', 'Colonial', '86047-255', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22427, 'Londrina', 'Manoel Bandeira', 'Palermo', '86060-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22428, 'Francisco Beltrão', 'Manoel Bandeira', 'São Miguel', '85602-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22429, 'Foz do Iguaçu', 'Manoel Bandeira', 'Vila Brasília', '85864-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22430, 'Pato Branco', 'Manoel Bandeira', 'São Cristóvão', '85508-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22431, 'Pinhais', 'Manoel Bandeira', 'Núcleo Colonial de Pinhais', '83321-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22432, 'Toledo', 'Manoel Bandeira', 'Jardim Europa', '85908-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22433, 'Colombo', 'Manoel Bandeira', 'Jardim Quitandinha', '83409-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22434, 'Londrina', 'Manoel Barbosa da Fonseca Filho', 'San Izidro', '86040-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22435, 'São José dos Pinhais', 'Manoel Bento Marques', 'São Sebastião', '83075-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22436, 'Ponta Grossa', 'Manoel Bernardes', 'Boa Vista', '84073-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22437, 'Paranaguá', 'Manoel Bonifácio', 'Centro Histórico', '83203-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22438, 'Cambé', 'Manoel Bonilha', 'Planta São Francisco', '86182-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22439, 'Curitiba', 'Manoel Borba', 'Pinheirinho', '81870-457', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22440, 'Telêmaco Borba', 'Manoel Borba Gato', 'Núcleo Bandeirantes', '84269-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22441, 'Curitiba', 'Manoel Borba Gato', 'Barreirinha', '82220-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22442, 'Curitiba', 'Manoel Borges', 'Capão da Imbuia', '82810-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22443, 'Londrina', 'Manoel Borges Leão', 'Sabará III', '86066-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22444, 'Paranavaí', 'Manoel Borrachina', 'Jardim Canadá', '87708-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22445, 'Umuarama', 'Manoel Botelho Cordeiro', 'Jardim Alto da Boa Vista', '87506-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22446, 'Umuarama', 'Manoel Bretas Evaristo', 'Jardim Ipanema', '87508-157', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22447, 'Castro', 'Manoel C. C. Ribas', 'Jardim Dona Helena', '84178-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22448, 'Londrina', 'Manoel Canuto Gouveia Filho', 'Jardim Primavera', '86086-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22449, 'São José dos Pinhais', 'Manoel Cardoso', 'Guatupê', '83060-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22450, 'Londrina', 'Manoel Carlos Ferraz de Almeida', 'Jardim Império do Sol', '86073-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22451, 'Londrina', 'Manoel Carlos Mendes', 'Jardim Hirata', '86080-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22452, 'Curitiba', 'Manoel Carvalho dos Anjos', 'Alto Boqueirão', '81860-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22453, 'Curitiba', 'Manoel Celestino Boaventura', 'São Braz', '82315-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22454, 'Colombo', 'Manoel Celestino Pinto', 'Itajacuru', '83407-838', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22455, 'Londrina', 'Manoel Cipriano', 'Progresso', '86079-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22456, 'Curitiba', 'Manoel Claro Alves', 'Cajuru', '82950-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22457, 'Londrina', 'Manoel Cordeiro', 'Parigot de Souza 2', '86082-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22458, 'Curitiba', 'Manoel Cordeiro', 'Cajuru', '82950-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22459, 'Paranaguá', 'Manoel Corrêa', 'Palmital', '83206-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22460, 'Paranaguá', 'Manoel Corrêa', 'Costeira', '83203-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22461, 'Curitiba', 'Manoel Correia de Freitas', 'Jardim Social', '82530-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22462, 'Curitiba', 'Manoel Correia de Freitas', 'Jardim Social', '82520-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22463, 'Colombo', 'Manoel Costacurta', 'Jardim Iracema', '83403-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22464, 'Curitiba', 'Manoel Cotture', 'Sítio Cercado', '81925-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22465, 'Londrina', 'Manoel Cruz Malassise', 'Residencial Vila Romana', '86031-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22466, 'Cambé', 'Manoel da Borba Gato', 'Jardim Ana Eliza', '86187-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22467, 'Maringá', 'Manoel da Costa', 'Loteamento Grajaú', '87043-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22468, 'Londrina', 'Manoel da Cruz Gallo', 'Portal de Versalhes 3', '86055-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22469, 'Foz do Iguaçu', 'Manoel da Luz', 'Jardim Porto Belo', '85867-356', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22470, 'Sarandi', 'Manoel da Luz', 'Parque Alvamar', '87113-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22471, 'Araucária', 'Manoel da Motta Correia', 'Tindiquera', '83708-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22472, 'Foz do Iguaçu', 'Manoel da Nóbrega', 'Vila Brasília', '85864-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22473, 'Pato Branco', 'Manoel da Nóbrega', 'Aeroporto', '85503-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22474, 'Toledo', 'Manoel da Nóbrega', 'Jardim Paulista', '85910-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22475, 'Apucarana', 'Manoel da Nóbrega', 'Núcleo Habitacional Castelo Branco', '86812-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22476, 'Cascavel', 'Manoel da Nóbrega', 'Parque São Paulo', '85803-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22477, 'Curitiba', 'Manoel da Rocha Kuster', 'Cajuru', '82950-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22478, 'Colombo', 'Manoel da Silva Rosa', 'Vila Santa Maria', '83402-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22479, 'Castro', 'Manoel das Chagas Lima', 'Jardim Colonial', '84178-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22480, 'Curitiba', 'Manoel das Chagas Lima', 'São Braz', '82300-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22481, 'Londrina', 'Manoel de Almeida Filho', 'Assis', '86085-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22482, 'Apucarana', 'Manoel de Almeida Filho', 'Jardim Laranjeiras', '86811-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22483, 'Colombo', 'Manoel de Carvalho', 'Jardim Santa Cândida', '83402-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22484, 'Araucária', 'Manoel de Carvalho', 'Thomaz Coelho', '83707-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22485, 'Guarapuava', 'Manoel de Macedo', 'São Cristóvão', '85060-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22486, 'Maringá', 'Manoel de Macedo', 'Zona 07', '87020-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22487, 'Curitiba', 'Manoel de Matos', 'Santa Cândida', '82710-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22488, 'Londrina', 'Manoel de Oliveira', 'Ernani de Moura Lima', '86037-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22489, 'Colombo', 'Manoel de Souza', 'Jardim Itambé', '83402-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22490, 'Curitiba', 'Manoel de Souza Dias Negrão', 'Boa Vista', '82540-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22491, 'Colombo', 'Manoel de Souza Ramos', 'Jardim Central', '83409-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22492, 'Londrina', 'Manoel de Souza Sobrinho', 'São Lourenço', '86043-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22493, 'Curitiba', 'Manoel Diniz', 'Santa Quitéria', '80310-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22494, 'Curitiba', 'Manoel dos Santos', 'Uberaba', '81570-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22495, 'Curitiba', 'Manoel dos Santos Barreto', 'Juvevê', '80530-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22496, 'Curitiba', 'Manoel dos Santos da Silva', 'São Lourenço', '82130-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22497, 'Londrina', 'Manoel Duarte Bilhão', 'Colinas', '86056-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22498, 'Foz do Iguaçu', 'Manoel Dutra', 'Jardim Princesa Daiana', '85867-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22499, 'Curitiba', 'Manoel Eufrásio', 'Juvevê', '80030-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22500, 'Curitiba', 'Manoel Eufrásio', 'Juvevê', '80540-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22501, 'Curitiba', 'Manoel Eugênio Sanzovo Mourão', 'Sítio Cercado', '81920-740', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22502, 'Curitiba', 'Manoel Eurico de Miranda', 'Cidade Industrial', '81450-716', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22503, 'Curitiba', 'Manoel Felipe Daher', 'Fazendinha', '81320-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22504, 'Curitiba', 'Manoel Felipe Rodrigues Moraes', 'Cajuru', '82980-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22505, 'Londrina', 'Manoel Fernandes', 'Portal de Versalhes 3', '86055-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22506, 'Almirante Tamandaré', 'Manoel Fernandes Alves', 'Jardim Giannini', '83511-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22507, 'Curitiba', 'Manoel Ferreira', 'Campo de Santana', '81490-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22508, 'Curitiba', 'Manoel Ferreira da Silva', 'Guaíra', '81010-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22509, 'Ponta Grossa', 'Manoel Ferreira Martins', 'Contorno', '84052-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22510, 'Ponta Grossa', 'Manoel Ferreira Pinto', 'Centro', '84010-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22511, 'Castro', 'Manoel Fidélis do Nascimento', 'Jardim das Araucárias', '84174-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22512, 'Londrina', 'Manoel Floriano', 'Parigot de Souza 2', '86082-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22513, 'Londrina', 'Manoel Francisco Araújo', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22514, 'Curitiba', 'Manoel Freire', 'Prado Velho', '80215-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22515, 'Apucarana', 'Manoel G. Horta', 'Loteamento São João', '86808-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22516, 'Curitiba', 'Manoel Ganz', 'Santo Inácio', '82010-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22517, 'São José dos Pinhais', 'Manoel Gardino Leal', 'Miringuava', '83090-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22518, 'Cambé', 'Manoel Gomes', 'Jardim Santa Adelaide', '86192-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22519, 'Apucarana', 'Manoel Gomes do Nascimento', 'Jardim Cidade Alta', '86803-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22520, 'Paranaguá', 'Manoel Gonçalves Maia Júnior', 'Alvorada', '83206-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22521, 'Curitiba', 'Manoel Guidolin', 'Pilarzinho', '82115-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22522, 'Curitiba', 'Manoel Gustavo Schier', 'Portão', '81070-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22523, 'Paranaguá', 'Manoel Hermógenes Vidal', 'Cruzeiro', '83221-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22524, 'Curitiba', 'Manoel Herrington Wambier', 'Pilarzinho', '82100-777', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22525, 'Curitiba', 'Manoel Hygino dos Santos', 'Guaíra', '80630-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22526, 'Londrina', 'Manoel Inácio da Rocha', 'Santa Joana', '86044-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22527, 'Ponta Grossa', 'Manoel Inácio Martins', 'Cará-cará', '84043-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22528, 'Londrina', 'Manoel Jacinto Correia', 'Santa Rita 1', '86072-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22529, 'Curitiba', 'Manoel Joaquim de Quadros', 'Portão', '81070-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22530, 'Londrina', 'Manoel Joaquim Gregório', 'Bancários', '86062-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22531, 'Londrina', 'Manoel Joaquim Martins', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22532, 'Curitiba', 'Manoel José Ador', 'Vista Alegre', '80810-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22533, 'Castro', 'Manoel José Braga', 'Jardim Colonial', '84178-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22534, 'Londrina', 'Manoel José dos Anjos', 'Jardim Honda', '86076-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22535, 'Curitiba', 'Manoel José Pereira', 'Pilarzinho', '82100-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22536, 'Maringá', 'Manoel Lopes', 'Conjunto João de Barro I', '87053-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22537, 'Londrina', 'Manoel Lopes Martinez', 'Cafezal 1', '86049-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22538, 'Campo Largo', 'Manoel Lopes Vieira', 'Botiatuva', '83602-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22539, 'Londrina', 'Manoel Lourenço Leite', 'Residencial Vila Romana', '86031-819', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22540, 'Pinhais', 'Manoel Lucas Evangelista Neto', 'Vila Carolina', '83326-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22541, 'Apucarana', 'Manoel Luiz da Silva', 'Vila São Carlos', '86800-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22542, 'Ponta Grossa', 'Manoel Machuca', 'Uvaranas', '84020-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22543, 'Curitiba', 'Manoel Manfredini', 'Cidade Industrial', '81260-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22544, 'São José dos Pinhais', 'Manoel Marcílio de Oliveira', 'Miringuava', '83090-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22545, 'Foz do Iguaçu', 'Manoel Maria Carmona', 'Conjunto Residencial Sol de Maio', '85862-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22546, 'Londrina', 'Manoel Marinho', 'Jamile Dequech', '86048-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22547, 'Ponta Grossa', 'Manoel Marques', 'Uvaranas', '84026-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22548, 'Cambé', 'Manoel Marques Cervantes', 'Jardim Imperatriz', '86183-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22549, 'São José dos Pinhais', 'Manoel Martins', 'Costeira', '83015-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22550, 'Curitiba', 'Manoel Martins de Abreu', 'Prado Velho', '80215-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22551, 'Londrina', 'Manoel Martins de Oliveira', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22552, 'Curitiba', 'Manoel Maurício da Silva', 'Uberaba', '81590-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22553, 'Curitiba', 'Manoel Máximo dos Santos', 'Cajuru', '82960-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22554, 'Curitiba', 'Manoel Mendes', 'Pinheirinho', '81820-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22555, 'Guarapuava', 'Manoel Mendes de Camargo', 'São Cristóvão', '85060-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22556, 'Campo Mourão', 'Manoel Mendes de Camargo', 'Centro', '87302-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22557, 'Campo Mourão', 'Manoel Mendes de Camargo', 'Centro', '87303-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22558, 'Curitiba', 'Manoel Miguel Alves Filho', 'Umbará', '81930-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22559, 'Cambé', 'Manoel Monteiro', 'Jardim Josiane', '86188-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22560, 'Foz do Iguaçu', 'Manoel Monteiro de Almeida', 'Jardim das Flores', '85862-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22561, 'Colombo', 'Manoel Moreira', 'Vila Santo Antônio', '83413-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22562, 'Foz do Iguaçu', 'Manoel Moreira Andrion', 'Jardim Panorama', '85856-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22563, 'Toledo', 'Manoel Nogueira', 'Coopagro', '85903-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22564, 'Campo Mourão', 'Manoel Nogueira', 'Jardim Lar Paraná', '87305-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22565, 'Campo Mourão', 'Manoel Nogueira', 'Jardim Lar Paraná', '87306-015', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22566, 'São José dos Pinhais', 'Manoel Nogueira Machado', 'Águas Belas', '83010-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22567, 'Foz do Iguaçu', 'Manoel Orfawaki', 'Jardim Veraneio', '85855-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22568, 'Curitiba', 'Manoel Oyola', 'Abranches', '82130-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22569, 'Campo Largo', 'Manoel Ozorio Portela', 'Vila Solene', '83607-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22570, 'Curitiba', 'Manoel Padilha de Lima', 'Ahú', '82200-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22571, 'Piraquara', 'Manoel Pedro dos Santos', 'Planta Santa Clara', '83306-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22572, 'Londrina', 'Manoel Pedro Macedo', 'Sabará III', '86066-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22573, 'Londrina', 'Manoel Pereira', 'Del Rey', '86045-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22574, 'Paranaguá', 'Manoel Pereira', 'Raia', '83206-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22575, 'Paranaguá', 'Manoel Pereira', '29 de Julho', '83203-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22576, 'Pinhais', 'Manoel Pereira', 'Jardim Guairacá', '83324-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22577, 'Apucarana', 'Manoel Pereira', 'Parque Bela Vista', '86803-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22578, 'Guarapuava', 'Manoel Pereira da Silva', 'Bonsucesso', '85045-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22579, 'Pinhais', 'Manoel Pereira da Silva', 'Jardim Marumby', '83327-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22580, 'Apucarana', 'Manoel Pereira de Luanda', 'Jardim Flamingos', '86811-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22581, 'Londrina', 'Manoel Pereira do Limoeiro', 'Residencial Abussafe', '86037-766', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22582, 'Londrina', 'Manoel Pereira Sobrinho', 'Residencial Portal do Sol', '86082-788', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22583, 'Colombo', 'Manoel Pinheiro', 'Parque Residencial Santa Terezinha', '83408-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22584, 'São José dos Pinhais', 'Manoel Pires Pereira', 'Costeira', '83015-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22585, 'Colombo', 'Manoel Prestes', 'Planta Folloni', '83413-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22586, 'Guarapuava', 'Manoel Preto', 'Primavera', '85050-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22587, 'Telêmaco Borba', 'Manoel Preto', 'Núcleo Bandeirantes', '84269-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22588, 'Colombo', 'Manoel Quinzani', 'Jardim João Paulo II', '83402-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22589, 'Curitiba', 'Manoel Quirino dos Santos', 'Sítio Cercado', '81900-766', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22590, 'Guarapuava', 'Manoel Ramos de Siqueira', 'Industrial', '85045-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22591, 'Laranjeiras do Sul', 'Manoel Ribas', 'Centro', '85301-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22592, 'Guarapuava', 'Manoel Ribas', 'Conradinho', '85055-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22593, 'Guarapuava', 'Manoel Ribas', 'Santana', '85070-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22594, 'Guarapuava', 'Manoel Ribas', 'Centro', '85010-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22595, 'Londrina', 'Manoel Ribas', 'Centro', '86010-140', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22596, 'Francisco Beltrão', 'Manoel Ribas', 'Alvorada', '85601-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22597, 'Maringá', 'Manoel Ribas', 'Zona 04', '87014-120', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22598, 'Maringá', 'Manoel Ribas', 'Jardim Alvorada', '87035-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22599, 'Paranavaí', 'Manoel Ribas', 'Centro', '87701-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22600, 'Paranavaí', 'Manoel Ribas', 'Centro', '87704-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22601, 'Ponta Grossa', 'Manoel Ribas', 'Cará-cará', '84043-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22602, 'Pato Branco', 'Manoel Ribas', 'Brasília', '85504-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22603, 'Toledo', 'Manoel Ribas', 'Walter Fontana', '85909-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22604, 'São José dos Pinhais', 'Manoel Ribas', 'Cruzeiro', '83010-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22605, 'Telêmaco Borba', 'Manoel Ribas', 'Centro', '84261-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22606, 'Cascavel', 'Manoel Ribas', 'Centro', '85810-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22607, 'Cascavel', 'Manoel Ribas', 'Vila Tolentino', '85802-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22608, 'Cascavel', 'Manoel Ribas', 'Centro', '85801-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22609, 'Araucária', 'Manoel Ribas', 'Centro', '83702-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22610, 'Araucária', 'Manoel Ribas', 'Tindiquera', '83708-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22611, 'Colombo', 'Manoel Ribas', 'Jardim Monza', '83406-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22612, 'Castro', 'Manoel Ribas', 'Centro', '84165-510', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22613, 'Campo Largo', 'Manoel Ribas', 'Vila Bancária', '83601-440', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22614, 'Cascavel', 'Manoel Ribas', 'Cancelli', '85811-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22615, 'Curitiba', 'Manoel Ribas', 'Mercês', '80510-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22616, 'Curitiba', 'Manoel Ribas', 'Mercês', '80810-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22617, 'Curitiba', 'Manoel Ribas', 'Cascatinha', '82020-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22618, 'Curitiba', 'Manoel Ribas', 'Santa Felicidade', '82400-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22619, 'Londrina', 'Manoel Ribeiro', 'Jardim São Jorge', '86082-825', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22620, 'Curitiba', 'Manoel Ribeiro de Macedo', 'Pinheirinho', '81825-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22621, 'Londrina', 'Manoel Ricardo de Hollanda', 'Araxá', '86061-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22622, 'Curitiba', 'Manoel Ricardo de Oliveira', 'Sítio Cercado', '81920-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22623, 'São José dos Pinhais', 'Manoel Rio dos Prazeres', 'Centro', '83005-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22624, 'Foz do Iguaçu', 'Manoel Rodrigues Filho', 'Jardim Polo Centro', '85863-758', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22625, 'Araucária', 'Manoel Rosa Pimenta', 'São Miguel', '83706-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22626, 'Curitiba', 'Manoel Rosenmann', 'Cajuru', '82900-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22627, 'Curitiba', 'Manoel Saldanha de Castro', 'São Braz', '82315-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22628, 'Apucarana', 'Manoel Sardinha Pereira', 'Jardim Kiri', '86802-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22629, 'Curitiba', 'Manoel Scliar', 'São Lourenço', '82200-570', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22630, 'Curitiba', 'Manoel Severino da Costa', 'Prado Velho', '80215-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22631, 'Londrina', 'Manoel Silva', 'Indústrias', '86043-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22632, 'Curitiba', 'Manoel Silvério dos Santos', 'Butiatuvinha', '82400-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22633, 'Campo Mourão', 'Manoel Silvério Pereira', 'Jardim Alvorada', '87308-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22634, 'Telêmaco Borba', 'Manoel Simeão de Souza', 'Jardim Bom Jesus', '84262-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22635, 'Colombo', 'Manoel Soares de Almeida', 'Santa Rita', '83412-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22636, 'Ponta Grossa', 'Manoel Soares dos Santos', 'Orfãs', '84015-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22637, 'Curitiba', 'Manoel Soares Gomes', 'Uberaba', '81560-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22638, 'Apucarana', 'Manoel Sorpili', 'Núcleo Habitacional Djalma Mendes de Oliveira', '86806-546', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22639, 'Curitiba', 'Manoel Taborda Ribas', 'Cidade Industrial', '81315-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22640, 'Curitiba', 'Manoel Tambosi', 'Portão', '81320-550', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22641, 'Maringá', 'Manoel Tavares', 'Vila Santa Izabel', '87080-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22642, 'São José dos Pinhais', 'Manoel Teixeira Cardoso', 'São Sebastião', '83075-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22643, 'Curitiba', 'Manoel Teixeira de Andrade', 'Pinheirinho', '81880-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22644, 'Almirante Tamandaré', 'Manoel Teixeira de Lara', 'Jardim Santa Rita de Cássia', '83506-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22645, 'São José dos Pinhais', 'Manoel Tibúrcio Machado', 'São Sebastião', '83075-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22646, 'Araucária', 'Manoel Torquato da Rocha Reis', 'Costeira', '83708-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22647, 'Curitiba', 'Manoel Valdomiro de Macedo', 'Cidade Industrial', '81170-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22648, 'Curitiba', 'Manoel Vicente de Oliveira Mello', 'Tarumã', '82530-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22649, 'Colombo', 'Manoel Vicente Machado', 'Jardim dos Eucaliptos', '83408-537', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22650, 'Foz do Iguaçu', 'Manoel Vicente Pereira', 'Parque Presidente', '85863-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22651, 'Guarapuava', 'Manoel Vitorino de Oliveira', 'Boqueirão', '85022-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22652, 'Londrina', 'Manoela Tamarozzi', 'Jardim Burle Marx', '86047-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22653, 'Curitiba', 'Mansueden dos Santos Prudente', 'Capão da Imbuia', '82810-250', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22654, 'Guarapuava', 'Mansueto Maito', 'Boqueirão', '85023-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22655, 'Curitiba', 'Mansur Feres Sphair', 'Pinheirinho', '81820-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22656, 'Curitiba', 'Mansur Galeb Nasser', 'Bacacheri', '82515-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22657, 'Curitiba', 'Mantova', 'Santa Felicidade', '82410-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22658, 'Londrina', 'Manuel Antunes', 'Colúmbia', '86057-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22659, 'Guarapuava', 'Manuel Bandeira', 'Conradinho', '85055-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22660, 'Maringá', 'Manuel Bandeira', 'Vila Esperança', '87020-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22661, 'Umuarama', 'Manuel Bandeira', 'Jardim Vitória', '87509-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22662, 'Almirante Tamandaré', 'Manuel Bandeira', 'Vila Marta', '83508-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22663, 'Curitiba', 'Manuel Bandeira', 'Cidade Industrial', '81250-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22664, 'Paranaguá', 'Manuel Cardoso de Araújo', 'Conjunto Residencial Prefeito Cominese', '83215-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22665, 'Cambé', 'Manuel Ferreira', 'Parque Residencial Ana Rosa', '86183-710', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22666, 'Campo Largo', 'Manuel Pinto Portugal', 'Vila Santa Terezinha', '83602-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22667, 'Maringá', 'Manuel Prudêncio de Brito', 'Parque Industrial Bandeirantes', '87070-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22668, 'Foz do Iguaçu', 'Mapara', 'Conjunto A', '85860-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22669, 'Ponta Grossa', 'Maquelote', 'Jardim Carvalho', '84016-668', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22670, 'Colombo', 'Maquiavel', 'Jardim Campo Alto', '83408-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22671, 'Ponta Grossa', 'Maquinista Eleodoro Jacinto', 'Oficinas', '84045-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22672, 'Curitiba', 'Mar Cáspio', 'Pinheirinho', '81825-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22673, 'Telêmaco Borba', 'Mar da Espanha', 'Vila Rosa', '84272-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22674, 'Londrina', 'Mar Del Plata', 'Vila Guarujá', '86010-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22675, 'Curitiba', 'Mar Egeu', 'Cidade Industrial', '81305-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22676, 'Curitiba', 'Mar Mediterrâneo', 'Cidade Industrial', '81305-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22677, 'Londrina', 'Mar Vermelho', 'Cláudia', '86050-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22678, 'Cambé', 'Mar Vermelho', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22679, 'Curitiba', 'Mar Vermelho', 'Pinheirinho', '81825-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22680, 'Sarandi', 'Mara', 'Jardim Esplanada', '87112-390', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22681, 'Araucária', 'Mara Hitener', 'Boqueirão', '83704-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22682, 'Guarapuava', 'Marabas', 'Boqueirão', '85020-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22683, 'Umuarama', 'Marabas', 'Zona I', '87501-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22684, 'Curitiba', 'Marabas', 'Guabirotuba', '81520-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22685, 'Londrina', 'Marabu', 'Conjunto Habitacional Violim', '86088-215', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22686, 'Arapongas', 'Marabu', 'Centro', '86701-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22687, 'Foz do Iguaçu', 'Maraca', 'Cohapar II', '85857-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22688, 'Apucarana', 'Maracahi', 'Vila Urizzi', '86808-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22689, 'Londrina', 'Maracai', 'Castelo', '86027-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22690, 'Cascavel', 'Maracai', 'Floresta', '85815-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22691, 'Maringá', 'Maracaibo', 'Vila Morangueira', '87040-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22692, 'Foz do Iguaçu', 'Maracajá', 'Conjunto A', '85861-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22693, 'Londrina', 'Maracaju', 'Rodocentro', '86065-005', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22694, 'Maringá', 'Maracanã', 'Vila Morangueira', '87030-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22695, 'Pato Branco', 'Maracanã', 'Planalto', '85509-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22696, 'Ponta Grossa', 'Maracanã', 'Colônia Dona Luiza', '84046-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22697, 'Umuarama', 'Maracanã', 'Jardim Kennedy', '87508-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22698, 'Cascavel', 'Maracanã', 'Periolo', '85817-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22699, 'Arapongas', 'Maracanã', 'Vila Industrial', '86706-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22700, 'Arapongas', 'Maracanã', 'Vila Bernardes', '86705-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22701, 'Araucária', 'Maracanã', 'Capela Velha', '83706-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22702, 'Arapongas', 'Maracanã', 'Vila Araponguinha', '86703-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22703, 'Campo Mourão', 'Maracanã', 'Conjunto Habitacional Milton Luiz Pereira', '87306-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22704, 'Curitiba', 'Maracanã', 'São Braz', '82015-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22705, 'Curitiba', 'Maracatiara', 'Bairro Alto', '82840-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22706, 'Foz do Iguaçu', 'Maracatu', 'Jardim Residencial São Roque', '85853-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22707, 'Telêmaco Borba', 'Maracujá', 'Fazenda Limeira', '84270-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22708, 'Curitiba', 'Maracujás', 'Uberaba', '81560-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22709, 'Londrina', 'Maragogipe', 'Centro', '86020-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22710, 'Maringá', 'Maragogipe', 'Conjunto João de Barro Itaparica', '87043-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22711, 'Cambé', 'Maragogipe', 'Jardim do Café', '86186-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22712, 'Foz do Iguaçu', 'Maraguari', 'Conjunto A', '85866-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22713, 'Foz do Iguaçu', 'Marajó', 'Jardim Bandeirantes', '85862-326', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22714, 'Apucarana', 'Marangatu', 'Vila Formosa', '86802-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22715, 'Francisco Beltrão', 'Maranhão', 'Presidente Kennedy', '85601-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22716, 'Guarapuava', 'Maranhão', 'Bonsucesso', '85035-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22717, 'Foz do Iguaçu', 'Maranhão', 'Centro', '85851-260', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22718, 'Londrina', 'Maranhão', 'Centro', '86010-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22719, 'Piraquara', 'Maranhão', 'Jardim Tropical', '83314-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22720, 'Maringá', 'Maranhão', 'Jardim Alvorada', '87033-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22721, 'Paranaguá', 'Maranhão', 'Vila do Povo', '83209-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22722, 'Paranavaí', 'Maranhão', 'Jardim Progresso', '87709-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22723, 'São José dos Pinhais', 'Maranhão', 'Boneca do Iguaçu', '83040-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22724, 'Umuarama', 'Maranhão', 'Zona II', '87501-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22725, 'Toledo', 'Maranhão', 'Jardim Canaã', '85914-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22726, 'Telêmaco Borba', 'Maranhão', 'Macopa', '84263-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22727, 'Campo Largo', 'Maranhão', 'Vila Itaqui', '83604-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22728, 'Cascavel', 'Maranhão', 'Centro', '85801-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22729, 'Cascavel', 'Maranhão', 'Centro', '85801-051', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22730, 'Cascavel', 'Maranhão', 'Alto Alegre', '85805-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22731, 'Colombo', 'Maranhão', 'Jardim Jalisco', '83404-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22732, 'Apucarana', 'Maranhão', 'Jardim Apucarana', '86804-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22733, 'Almirante Tamandaré', 'Maranhão', 'Vila Dolores', '83514-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22734, 'Araucária', 'Maranhão', 'Cachoeira', '83709-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22735, 'Curitiba', 'Maranhão', 'Água Verde', '80610-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22736, 'Curitiba', 'Maranhão', 'Portão', '80610-001', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22737, 'Piraquara', 'Mararupa', 'Planta Tamoyo', '83312-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22738, 'Francisco Beltrão', 'Marau', 'Pinheirinho', '85603-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22739, 'Londrina', 'Marauás', 'Vila Galvão', '86026-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22740, 'Ponta Grossa', 'Marcassita', 'Colônia Dona Luiza', '84021-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22741, 'Maringá', 'Marcassita', 'Jardim Real', '87083-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22742, 'Apucarana', 'Marcel Cassandre', 'Vila Formosa', '86802-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22743, 'Foz do Iguaçu', 'Marcela Dotto', 'Jardim Florença', '85867-367', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22744, 'Curitiba', 'Marcelina Wykrota', 'Bacacheri', '82600-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22745, 'Almirante Tamandaré', 'Marcelino Champagnat', 'Jardim do Norte', '83511-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22746, 'Curitiba', 'Marcelino Champagnat', 'Mercês', '80710-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22747, 'Cambé', 'Marcelino Gonzales', 'Parque Residencial Ana Rosa', '86183-580', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22748, 'Curitiba', 'Marcelino Iachinski', 'Portão', '81070-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22749, 'Araucária', 'Marcelino Jasinski', 'Tindiquera', '83708-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22750, 'Cascavel', 'Marcelino Meneguzzi', 'Alto Alegre', '85805-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22751, 'Ponta Grossa', 'Marcelino Nogueira', 'Ronda', '84051-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22752, 'Curitiba', 'Marcelino Nogueira', 'Bacacheri', '82510-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22753, 'Araucária', 'Marcelino Rodrigues de Andrade', 'Costeira', '83708-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22754, 'Maringá', 'Marcelino Zequim', 'Jardim Santa Rosa', '87060-029', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22755, 'Londrina', 'Marcelo Accorci', 'Vânia', '86025-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22756, 'Apucarana', 'Marcelo Alexandre Felipe', 'Núcleo Habitacional João Goulart', '86807-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22757, 'Londrina', 'Marcelo Augusto Pereira Tolentino', 'Ernani de Moura Lima', '86037-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22758, 'Curitiba', 'Marcelo Forte Maiolino', 'Alto Boqueirão', '81850-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22759, 'Londrina', 'Marcelo Gama', 'Jardim Tatiani', '86070-410', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22760, 'Curitiba', 'Marcelo José Iohn', 'Cidade Industrial', '81330-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22761, 'Maringá', 'Marcelo Messias Busiquia', 'Zona 34', '87065-006', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22762, 'Curitiba', 'Marcelo Monaro', 'Sítio Cercado', '81935-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22763, 'Foz do Iguaçu', 'Marcelo Risden', 'Vila Yolanda', '85853-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22764, 'Curitiba', 'Marchanjo Bianchini', 'Santa Felicidade', '82020-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22765, 'Cascavel', 'Márcia Cristina Galvão Nascimento', 'Nova Cidade', '85803-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22766, 'Foz do Iguaçu', 'Márcia de Windsor', 'Jardim Dom Pedro I', '85856-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22767, 'Londrina', 'Márcia Lopes Trindade', 'Giovani Lunardelli', '86037-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22768, 'Londrina', 'Márcia Mendes', 'Conjunto Vivi Xavier', '86082-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22769, 'Maringá', 'Márcia Mendes', 'Jardim América', '87045-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22770, 'Cascavel', 'Márcia Regina', 'Alto Alegre', '85805-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22771, 'Curitiba', 'Marciano Dombeck', 'Seminário', '80240-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22772, 'Maringá', 'Marciano Halchuk', 'Zona 02', '87005-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22773, 'Curitiba', 'Marcília Vaz Carneiro', 'Pilarzinho', '82100-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22774, 'Curitiba', 'Marciliano Ferreira dos Santos', 'Santa Cândida', '82640-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22775, 'São José dos Pinhais', 'Marcílio Bianchetti', 'Cruzeiro', '83065-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22776, 'Guarapuava', 'Marcílio Dias', 'Vila Carli', '85040-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22777, 'Londrina', 'Marcílio Dias', 'Cambesa', '86015-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22778, 'Paranavaí', 'Marcílio Dias', 'Jardim Santos Dumont', '87706-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22779, 'Paranavaí', 'Marcílio Dias', 'Jardim Panorama', '87707-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22780, 'Ponta Grossa', 'Marcílio Dias', 'Nova Rússia', '84071-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22781, 'Ponta Grossa', 'Marcílio Dias', 'Nova Rússia', '84070-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22782, 'Maringá', 'Marcílio Dias', 'Zona 03', '87050-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22783, 'Toledo', 'Marcílio Dias', 'Jardim Paulista', '85909-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22784, 'Apucarana', 'Marcílio Dias', 'Jardim Paraíso', '86812-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22785, 'Cascavel', 'Marcílio Dias', 'Região do Lago 1', '85812-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22786, 'Colombo', 'Marcílio Dias', 'Planta Santo Agostinho', '83404-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22787, 'Curitiba', 'Marcílio Dias', 'Bairro Alto', '82820-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22788, 'Londrina', 'Marcílio Lucas', 'Jardim Vale Verde', '86040-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22789, 'Ponta Grossa', 'Marcílio Luiz Mezzomo', 'Boa Vista', '84072-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22790, 'Paranaguá', 'Marcílio Manoel de Jesus', 'Vila do Caic', '83215-695', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22791, 'Maringá', 'Marcílio Zequim', 'Jardim Santa Rosa', '87060-028', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22792, 'Apucarana', 'Márcio Fábio Viana', 'Jardim Flamingos', '86811-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22793, 'Curitiba', 'Márcio José Aboniski', 'Cidade Industrial', '81450-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22794, 'Curitiba', 'Márcio José Reche Pinhelli', 'Fazendinha', '81330-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22795, 'Paranaguá', 'Márcio N. Gonçalves', 'Ponta do Caju', '83206-466', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22796, 'Maringá', 'Márcio Pacífico', 'Jardim Novo Oásis', '87043-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22797, 'Paranaguá', 'Márcio Rauscher', 'Vila São Vicente', '83209-155', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22798, 'Curitiba', 'Márcio Santos', 'Cidade Industrial', '81460-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22799, 'Araucária', 'Márcio Ubaldino', 'Centro', '83702-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22800, 'Ponta Grossa', 'Marco Antônio Pereira', 'Contorno', '84060-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22801, 'Curitiba', 'Marco Aurélio Malucelli', 'Santo Inácio', '82300-285', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22802, 'São José dos Pinhais', 'Marco Aurélio Rosa', 'São Sebastião', '83075-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22803, 'Curitiba', 'Marco Bigarella', 'Tarumã', '82530-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22804, 'Curitiba', 'Marco Campos', 'Cidade Industrial', '81460-187', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22805, 'Londrina', 'Marco Fertonani', 'Mediterrâneo', '86047-085', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22806, 'Pato Branco', 'Marco Penso', 'Vila Esperança', '85503-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22807, 'Londrina', 'Marco Polo', 'Aeroporto', '86039-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22808, 'Curitiba', 'Marco Polo', 'Bairro Alto', '82820-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22809, 'Curitiba', 'Marcolina Caetana Chaves', 'Sítio Cercado', '81925-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22810, 'Campo Largo', 'Marcolino Domingues', 'Conjunto Águas Claras', '83602-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22811, 'Apucarana', 'Marcon', 'Vila Vitória Régia', '86801-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22812, 'Londrina', 'Marcondes de Oliveira', 'Colonial', '86047-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22813, 'Guarapuava', 'Marcondes Sobrinho', 'Bonsucesso', '85055-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22814, 'Maringá', 'Marconi', 'Parque Residencial Aeroporto (2ª Parte)', '87055-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22815, 'Araucária', 'Marcos André Huttener', 'Tindiquera', '83708-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22816, 'Curitiba', 'Marcos Andreatta', 'Mossunguê', '81200-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22817, 'Maringá', 'Marcos Antônio', 'Jardim Mandacaru', '87080-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22818, 'Curitiba', 'Marcos Antônio Malucelli', 'Cidade Industrial', '81260-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22819, 'São José dos Pinhais', 'Marcos Aurélio Tozzo', 'Braga', '83020-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22820, 'Curitiba', 'Marcos Baggio', 'Fazendinha', '81330-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22821, 'Colombo', 'Marcos Cardoso', 'Jardim Bela Vista', '83411-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22822, 'Apucarana', 'Marcos Eduardo Bovo', 'Loteamento Sol Nascente', '86801-268', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22823, 'Maringá', 'Marcos Just', 'Jardim Bela Vista', '87060-516', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22824, 'Londrina', 'Marcos Luiz Passucci', 'Conjunto Habitacional Bronzzetti', '86037-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22825, 'Curitiba', 'Marcos Luiz Trevisan', 'Cidade Industrial', '81450-759', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22826, 'Curitiba', 'Marcos Mocellin', 'Santa Felicidade', '82020-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22827, 'Umuarama', 'Marcos Moreno dos Santos Cabeção', 'Jardim Alto da Boa Vista', '87506-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22828, 'Curitiba', 'Marcos Moro', 'São Francisco', '80530-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22829, 'Francisco Beltrão', 'Marcos Rey', 'Jardim Novo Mundo', '85602-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22830, 'Cascavel', 'Marcos Schuster', 'Nova Cidade', '85803-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22831, 'Curitiba', 'Marcos Smanhotto', 'Jardim das Américas', '81530-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22832, 'Londrina', 'Marcos Tomazini', 'Colúmbia', '86057-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22833, 'Colombo', 'Marcos Wosch', 'Jardim Santa Cândida', '83402-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22834, 'Foz do Iguaçu', 'Marcus Pereira', 'Jardim Central', '85864-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22835, 'Paranaguá', 'Marechal Alberto de Abreu', 'Centro Histórico', '83203-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22836, 'Curitiba', 'Marechal Alberto Ferreira de Abreu', 'Batel', '80420-020', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22837, 'Curitiba', 'Marechal Althayr Roszanniy', 'Capão Raso', '81110-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22838, 'Curitiba', 'Marechal Anor Teixeira dos Santos', 'Boa Vista', '82650-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22839, 'Curitiba', 'Marechal Bittencourt', 'Bairro Alto', '82820-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22840, 'Ponta Grossa', 'Marechal Bormann', 'Ronda', '84051-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22841, 'Foz do Iguaçu', 'Marechal Cândido Rondon', 'Jardim Lancaster', '85869-698', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22842, 'Laranjeiras do Sul', 'Marechal Cândido Rondon', 'Água Verde', '85302-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22843, 'Guarapuava', 'Marechal Cândido Rondon', 'Jardim das Américas', '85030-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22844, 'Laranjeiras do Sul', 'Marechal Cândido Rondon', 'Centro', '85301-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22845, 'Maringá', 'Marechal Cândido Rondon', 'Vila Santo Antônio', '87030-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22846, 'Paranavaí', 'Marechal Cândido Rondon', 'Centro', '87703-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22847, 'Paranaguá', 'Marechal Cândido Rondon', 'Cruzeiro', '83221-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22848, 'Paranavaí', 'Marechal Cândido Rondon', 'Centro', '87704-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22849, 'Paranavaí', 'Marechal Cândido Rondon', 'Centro', '87705-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22850, 'Umuarama', 'Marechal Cândido Rondon', 'Zona VI', '87503-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22851, 'São José dos Pinhais', 'Marechal Cândido Rondon', 'Bom Jesus', '83025-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22852, 'Cambé', 'Marechal Cândido Rondon', 'Parque Residencial Manela', '86185-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22853, 'Cascavel', 'Marechal Cândido Rondon', 'Vila Tolentino', '85802-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22854, 'Cascavel', 'Marechal Cândido Rondon', 'Centro', '85801-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22855, 'Cascavel', 'Marechal Cândido Rondon', 'Centro', '85810-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22856, 'Cascavel', 'Marechal Cândido Rondon', 'Cancelli', '85811-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22857, 'Cascavel', 'Marechal Cândido Rondon', 'Canadá', '85813-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22858, 'Curitiba', 'Marechal Cardoso Júnior', 'Jardim das Américas', '81530-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22859, 'Pato Branco', 'Marechal Costa e Silva', 'Trevo da Guarany', '85501-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22860, 'Almirante Tamandaré', 'Marechal Costa e Silva', 'Jardim Marambaia', '83506-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22861, 'Foz do Iguaçu', 'Marechal Deodoro', 'Centro', '85851-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22862, 'Guarapuava', 'Marechal Deodoro', 'Boqueirão', '85020-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22863, 'Laranjeiras do Sul', 'Marechal Deodoro', 'Getúlio Vargas', '85304-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22864, 'Ponta Grossa', 'Marechal Deodoro', 'Centro', '84010-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22865, 'Pinhais', 'Marechal Deodoro', 'Vila Amélia', '83330-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22866, 'Pato Branco', 'Marechal Deodoro', 'Cristo Rei', '85507-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22867, 'Paranaguá', 'Marechal Deodoro', 'Centro Histórico', '83203-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22868, 'Maringá', 'Marechal Deodoro', 'Zona 07', '87030-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22869, 'Sarandi', 'Marechal Deodoro', 'Jardim Panorama', '87113-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22870, 'Sarandi', 'Marechal Deodoro', 'Jardim Independência I', '87114-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22871, 'Cascavel', 'Marechal Deodoro', 'Claudete', '85811-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22872, 'Apucarana', 'Marechal Deodoro', 'Vila Santa Rosa', '86811-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22873, 'Cascavel', 'Marechal Deodoro', 'Centro', '85810-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22874, 'Cascavel', 'Marechal Deodoro', 'Vila Tolentino', '85802-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22875, 'Cascavel', 'Marechal Deodoro', 'Centro', '85801-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22876, 'Castro', 'Marechal Deodoro', 'Vila Rio Branco', '84172-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22877, 'Campo Largo', 'Marechal Deodoro', 'Centro', '83601-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22878, 'Curitiba', 'Marechal Deodoro', 'Centro', '80020-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22879, 'Curitiba', 'Marechal Deodoro', 'Alto da Rua XV', '80050-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22880, 'Curitiba', 'Marechal Deodoro', 'Centro', '80010-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22881, 'Curitiba', 'Marechal Deodoro', 'Centro', '80060-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22882, 'Piraquara', 'Marechal Deodoro da Fonseca', 'Planta Araçatuba', '83301-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22883, 'Telêmaco Borba', 'Marechal Deodoro da Fonseca', 'Alto das Oliveiras', '84266-470', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22884, 'Telêmaco Borba', 'Marechal Deodoro da Fonseca', 'Nossa Senhora do Perpétuo Socorro', '84265-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22885, 'São José dos Pinhais', 'Marechal Deodoro da Fonseca', 'Centro', '83005-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22886, 'Cambé', 'Marechal Deodoro da Fonseca', 'Novo Bandeirantes', '86187-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22887, 'Almirante Tamandaré', 'Marechal Deodoro da Fonseca', 'Jardim São Carlos', '83507-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22888, 'Guarapuava', 'Marechal Dutra', 'Boqueirão', '85020-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22889, 'Londrina', 'Marechal Eduardo Gomes', 'Aeroporto', '86039-105', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22890, 'Colombo', 'Marechal Eduardo Gomes', 'Vila Maria do Rosário', '83413-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22891, 'Cambé', 'Marechal Eurico Gaspar Dutra', 'Jardim Silvino', '86188-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22892, 'Foz do Iguaçu', 'Marechal Floriano', 'Centro', '85851-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22893, 'Paranaguá', 'Marechal Floriano', 'Oceania', '83203-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22894, 'Toledo', 'Marechal Floriano', 'Conjunto Residencial Rossani', '85901-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22895, 'Toledo', 'Marechal Floriano', 'Centro', '85900-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22896, 'Cascavel', 'Marechal Floriano', 'Vila Tolentino', '85802-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22897, 'Cascavel', 'Marechal Floriano', 'Centro', '85810-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22898, 'Cascavel', 'Marechal Floriano', 'Claudete', '85811-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22899, 'Apucarana', 'Marechal Floriano', 'Vila Santa Terezinha', '86802-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22900, 'Castro', 'Marechal Floriano', 'Vila Rio Branco', '84172-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22901, 'Cascavel', 'Marechal Floriano', 'Centro', '85801-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22902, 'Guarapuava', 'Marechal Floriano Peixoto', 'Vila Carli', '85040-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22903, 'Guarapuava', 'Marechal Floriano Peixoto', 'Trianon', '85012-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22904, 'Guarapuava', 'Marechal Floriano Peixoto', 'Centro', '85010-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22905, 'Guarapuava', 'Marechal Floriano Peixoto', 'Bonsucesso', '85035-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22906, 'Francisco Beltrão', 'Marechal Floriano Peixoto', 'São Miguel', '85602-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22907, 'Londrina', 'Marechal Floriano Peixoto', 'Centro', '86010-130', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22908, 'Laranjeiras do Sul', 'Marechal Floriano Peixoto', 'Getúlio Vargas', '85304-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22909, 'Maringá', 'Marechal Floriano Peixoto', 'Zona 07', '87030-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22910, 'Pinhais', 'Marechal Floriano Peixoto', 'Vila Amélia', '83330-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22911, 'Ponta Grossa', 'Marechal Floriano Peixoto', 'Centro', '84010-680', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22912, 'Telêmaco Borba', 'Marechal Floriano Peixoto', 'Socomim', '84269-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22913, 'Telêmaco Borba', 'Marechal Floriano Peixoto', 'Alto das Oliveiras', '84266-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22914, 'Cambé', 'Marechal Floriano Peixoto', 'Novo Bandeirantes', '86187-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22915, 'Campo Largo', 'Marechal Floriano Peixoto', 'Loteamento Ouro Verde I', '83606-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22916, 'Araucária', 'Marechal Floriano Peixoto', 'Centro', '83702-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22917, 'Almirante Tamandaré', 'Marechal Floriano Peixoto', 'Jardim São Carlos', '83507-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22918, 'Colombo', 'Marechal Floriano Peixoto', 'Centro', '83414-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22919, 'Curitiba', 'Marechal Floriano Peixoto', 'Boqueirão', '81650-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22920, 'Curitiba', 'Marechal Floriano Peixoto', 'Parolin', '80220-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22921, 'Curitiba', 'Marechal Floriano Peixoto', 'Boqueirão', '81670-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22922, 'Curitiba', 'Marechal Floriano Peixoto', 'Boqueirão', '81730-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22923, 'Curitiba', 'Marechal Floriano Peixoto', 'Rebouças', '80230-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22924, 'Curitiba', 'Marechal Floriano Peixoto', 'Centro', '80010-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22925, 'Curitiba', 'Marechal Floriano Peixoto', 'Centro', '80020-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22926, 'Curitiba', 'Marechal Floriano Peixoto', 'Hauer', '81610-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22927, 'Curitiba', 'Marechal Floriano Peixoto', 'Hauer', '81630-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22928, 'Curitiba', 'Marechal Floriano Peixoto', 'Rebouças', '80220-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22929, 'Foz do Iguaçu', 'Marechal Francisco Solano Lopes', 'Vila Paraguaia', '85864-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22930, 'Piraquara', 'Marechal Hermes', 'Jardim Bela Vista', '83301-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22931, 'Ponta Grossa', 'Marechal Hermes', 'Ronda', '84051-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22932, 'Telêmaco Borba', 'Marechal Hermes', 'Nossa Senhora do Perpétuo Socorro', '84265-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22933, 'São José dos Pinhais', 'Marechal Hermes', 'Afonso Pena', '83045-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22934, 'São José dos Pinhais', 'Marechal Hermes', 'Afonso Pena', '83065-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22935, 'Curitiba', 'Marechal Hermes', 'Ahú', '80540-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22936, 'Curitiba', 'Marechal Hermes', 'Centro Cívico', '80530-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22937, 'Francisco Beltrão', 'Marechal Hermes da Fonseca', 'São Miguel', '85602-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22938, 'Londrina', 'Marechal Hermes da Fonseca', 'Hedy', '86062-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22939, 'Cambé', 'Marechal Hermes da Fonseca', 'Novo Bandeirantes', '86188-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22940, 'Curitiba', 'Marechal Hugo Panasco Alvim', 'Alto Boqueirão', '81850-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22941, 'Curitiba', 'Marechal Humberto de Alencar Castelo Branco', 'Cristo Rei', '82530-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22942, 'Curitiba', 'Marechal José Agostinho dos Santos', 'Capão da Imbuia', '82810-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22943, 'Curitiba', 'Marechal José Bernardino Bormann', 'Bigorrilho', '80710-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22944, 'Curitiba', 'Marechal José Bernardino Bormann', 'Batel', '80730-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22945, 'Araucária', 'Marechal Juarez Távora', 'Boqueirão', '83704-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22946, 'Foz do Iguaçu', 'Marechal Lott', 'Jardim Alvorada', '85859-696', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22947, 'Curitiba', 'Marechal Lott', 'Santa Felicidade', '82410-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22948, 'Foz do Iguaçu', 'Marechal Mallet', 'Centro', '85851-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22949, 'Ponta Grossa', 'Marechal Mallet', 'Oficinas', '84036-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22950, 'São José dos Pinhais', 'Marechal Mallet', 'São Pedro', '83005-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22951, 'Curitiba', 'Marechal Mallet', 'Juvevê', '80540-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22952, 'Maringá', 'Marechal Mascarenhas de Moraes', 'Jardim Alvorada', '87033-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22953, 'Cambé', 'Marechal Mascarenhas de Moraes', 'Centro', '86181-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22954, 'Curitiba', 'Marechal Mascarenhas de Morais', 'Santa Cândida', '82620-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22955, 'Curitiba', 'Marechal Otávio Saldanha Mazza', 'Capão Raso', '81150-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22956, 'Curitiba', 'Marechal Otávio Saldanha Mazza', 'Capão Raso', '81130-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22957, 'Pato Branco', 'Marechal Rondon', 'Jardim Primavera', '85502-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22958, 'Curitiba', 'Marechal Rondon', 'Capão Raso', '81130-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22959, 'Francisco Beltrão', 'Marechal Rúbens Paiva', 'São Miguel', '85602-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22960, 'Curitiba', 'Marechal Trompowski', 'Bacacheri', '82515-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22961, 'Foz do Iguaçu', 'Marejaras', 'Jardim Tarobá', '85856-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22962, 'Londrina', 'Marfim', 'Leonor', '86071-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22963, 'Guarapuava', 'Marfim', 'Industrial', '85053-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22964, 'Maringá', 'Marfim', 'Jardim Veredas', '87060-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22965, 'Ponta Grossa', 'Marfim', 'Neves', '84021-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22966, 'Maringá', 'Marfim', 'Jardim Vitória', '87023-710', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22967, 'Cascavel', 'Marfim', 'Brasmadeira', '85814-127', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22968, 'Apucarana', 'Marfim', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22969, 'Cambé', 'Marfim', 'Vila Salomé', '86192-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22970, 'Ponta Grossa', 'Margarida', 'Contorno', '84060-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22971, 'Apucarana', 'Margarida', 'Jardim das Flores I', '86810-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22972, 'Araucária', 'Margarida', 'Campina da Barra', '83709-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22973, 'Curitiba', 'Margarida Andrade Weber', 'Cidade Industrial', '81460-297', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22974, 'Curitiba', 'Margarida Ângela Zardo Miranda', 'Santa Felicidade', '82320-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22975, 'Curitiba', 'Margarida Dallarmi', 'Santa Felicidade', '82015-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22976, 'São José dos Pinhais', 'Margarida de Araújo Franco', 'Carioca', '83005-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22977, 'Curitiba', 'Margarida do Conto Gava', 'Pilarzinho', '82115-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22978, 'Curitiba', 'Margarida Fogiatto Cavagnari', 'Tingui', '82620-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22979, 'Ponta Grossa', 'Margarida Kubinski Vaz', 'Boa Vista', '84073-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22980, 'Ponta Grossa', 'Margarida Malucelli Moro', 'Estrela', '84050-210', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22981, 'Curitiba', 'Margarida Meirelles', 'Abranches', '82220-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22982, 'Londrina', 'Margarida Moreira da Silva', 'Recanto Pitanguá', '86055-577', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22983, 'São José dos Pinhais', 'Margarida Negrelli Moletta', 'Águas Belas', '83040-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22984, 'São José dos Pinhais', 'Margarida Petrelli Foggiatto', 'Braga', '83020-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22985, 'São José dos Pinhais', 'Margarida Pianaro Moro', 'Cruzeiro', '83010-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22986, 'São José dos Pinhais', 'Margarida Possebon da Cruz', 'Colônia Rio Grande', '83020-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22987, 'Curitiba', 'Margarida Ribas de Mello', 'Boa Vista', '82560-415', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22988, 'Paranaguá', 'Marginal', 'Alboitt', '83221-585', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22989, 'Paranaguá', 'Marginal', 'Emboguaçu', '83209-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22990, 'Ponta Grossa', 'Marginal', 'Uvaranas', '84025-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22991, 'Pato Branco', 'Marginal', 'Vila Esperança', '85503-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22992, 'Umuarama', 'Marginal', 'Parque 1º de Maio', '87509-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22993, 'Cascavel', 'Marginal', 'Santos Dumont', '85804-720', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22994, 'Almirante Tamandaré', 'Marginal', 'Jardim Roma', '83504-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22995, 'Cascavel', 'Marginal B', 'Guarujá', '85804-560', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22996, 'Maringá', 'Marginal B - Contorno Norte', 'Jardim Novo Alvorada', '87035-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22997, 'Ponta Grossa', 'Marginal da Linha', 'Uvaranas', '84020-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22998, 'Colombo', 'Marginal Direita', 'Parque Residencial Santa Terezinha', '83408-600', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (22999, 'Colombo', 'Marginal Jalisco', 'Jardim Jalisco', '83404-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23000, 'Colombo', 'Marginal José de Anchieta', 'Vila Guarani', '83408-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23001, 'São José dos Pinhais', 'Marginal Norte', 'Roseira', '83070-005', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23002, 'Colombo', 'Marginal Paraguai', 'Jardim Rio Verde', '83405-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23003, 'Ponta Grossa', 'Margonita', 'Neves', '84021-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23004, 'Curitiba', 'Maria A. Zaramella Grande', 'Santa Felicidade', '82030-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23005, 'Londrina', 'Maria Abucarub Autoun', 'Conjunto Habitacional  Alexandre Urbanas', '86037-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23006, 'Curitiba', 'Maria Adriano de Miranda', 'Cidade Industrial', '81450-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23007, 'São José dos Pinhais', 'Maria Alexandrina Borges', 'Rio Pequeno', '83065-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23008, 'Apucarana', 'Maria Alice M. Miotta', 'Núcleo Habitacional das Indústrias', '86806-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23009, 'São José dos Pinhais', 'Maria Alice Sademberg', 'Guatupê', '83065-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23010, 'Londrina', 'Maria Alves Miranda', 'Ernani de Moura Lima', '86038-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23011, 'Almirante Tamandaré', 'Maria Amazília Carvalhaes', 'Vila Guilhermina', '83506-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23012, 'Londrina', 'Maria Ameris da Silva', 'Portal de Versalhes 3', '86055-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23013, 'Londrina', 'Maria Ana Caramori', 'Conjunto Residencial Marajoara', '86080-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23014, 'Londrina', 'Maria Ana de Lurdes', 'Dom Pedro II', '86073-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23015, 'Colombo', 'Maria Ana Strapasson Busta', 'Centro', '83414-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23016, 'Curitiba', 'Maria Ângela Pachaly', 'Atuba', '82860-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23017, 'São José dos Pinhais', 'Maria Antônia Chinda', 'Rio Pequeno', '83070-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23018, 'Londrina', 'Maria Antônia Dias', 'Conjunto Habitacional Bronzzetti', '86037-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23019, 'São José dos Pinhais', 'Maria Antônia Franco Dombrowski', 'Silveira da Motta', '83030-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23020, 'Curitiba', 'Maria Antônia Silva', 'Abranches', '82130-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23021, 'Castro', 'Maria Antônia Vileski', 'Jardim Social Arapongas', '84174-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23022, 'Pinhais', 'Maria Antonieta dos Santos', 'Vila Maria Antonieta', '83331-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23023, 'Curitiba', 'Maria Aparecida Beruski', 'Barreirinha', '82700-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23024, 'Curitiba', 'Maria Aparecida Marins', 'Cidade Industrial', '81280-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23025, 'Londrina', 'Maria Aparecida Silveira', 'Cafezal', '86045-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23026, 'Colombo', 'Maria Appel', 'Jardim João Paulo II', '83402-240', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23027, 'Curitiba', 'Maria Augusta da Silva', 'Atuba', '82630-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23028, 'Curitiba', 'Maria Augusta Soares', 'Sítio Cercado', '81900-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23029, 'Colombo', 'Maria Aurora Budel Alberti', 'Parque Industrial Guaraituba', '83411-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23030, 'Ponta Grossa', 'Maria Auxiliadora', 'Neves', '84020-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23031, 'Cambé', 'Maria Auxiliadora Romaniolo', 'Jardim Santa Adelaide', '86192-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23032, 'Ponta Grossa', 'Maria Avelina Martins Braga', 'Contorno', '84052-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23033, 'Curitiba', 'Maria B. Chanoski', 'Orleans', '82310-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23034, 'Curitiba', 'Maria Balaban', 'Umbará', '81930-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23035, 'Almirante Tamandaré', 'Maria Balbina Rodrigues Dias', 'Jardim Primavera', '83506-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23036, 'Curitiba', 'Maria Ballin Baroni', 'Pilarzinho', '80520-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23037, 'Curitiba', 'Maria Banzatto Erthal', 'Barreirinha', '82710-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23038, 'Curitiba', 'Maria Bauer Siegmund', 'Pilarzinho', '82120-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23039, 'Curitiba', 'Maria Beatriz Rotta', 'Bacacheri', '82520-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23040, 'Guarapuava', 'Maria Becker Noriller', 'Jardim das Américas', '85030-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23041, 'Curitiba', 'Maria Benato Volpi', 'Butiatuvinha', '82320-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23042, 'Curitiba', 'Maria Benedita de Lima', 'Capão Raso', '81130-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23043, 'Curitiba', 'Maria Bergamin Andretta', 'Água Verde', '80620-260', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23044, 'Ponta Grossa', 'Maria Bernadete Oliveira Silveira', 'Uvaranas', '84025-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23045, 'Campo Largo', 'Maria Bertoja Rivabem', 'Vila Ferrari', '83606-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23046, 'Piraquara', 'Maria Bevervanso', 'Planta São Tiago', '83306-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23047, 'Curitiba', 'Maria Bizinelli', 'Campo Comprido', '81210-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23048, 'São José dos Pinhais', 'Maria Bonatto Marenda', 'Afonso Pena', '83045-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23049, 'Almirante Tamandaré', 'Maria Bonfim Alcântara', 'Jardim Santa Rita de Cássia', '83506-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23050, 'Londrina', 'Maria Bordon Ticianelli', 'Nova Olinda', '86073-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23051, 'Pinhais', 'Maria Borssuk', 'Moradias Perdizes', '83326-707', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23052, 'Curitiba', 'Maria Breda', 'Tatuquara', '81470-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23053, 'Londrina', 'Maria Brugin Palharini', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23054, 'Araucária', 'Maria Brunatto Cantador', 'Boqueirão', '83704-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23055, 'Pato Branco', 'Maria Bueno', 'Trevo da Guarany', '85501-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23056, 'Curitiba', 'Maria Bueno', 'Novo Mundo', '81020-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23057, 'Curitiba', 'Maria Bunik', 'Tatuquara', '81470-267', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23058, 'Curitiba', 'Maria Cacilda de Azevedo', 'Atuba', '82860-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23059, 'Londrina', 'Maria Calsavara Gallo', 'Vale dos Tucanos', '86046-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23060, 'Paranaguá', 'Maria Cândida de Souza Lobo', 'Costeira', '83203-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23061, 'Cambé', 'Maria Carla', 'Planta São Francisco', '86182-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23062, 'Curitiba', 'Maria Carlota de Abreu Hansen', 'Guabirotuba', '81510-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23063, 'Curitiba', 'Maria Carmelina Loper Macanhão', 'Cidade Industrial', '81170-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23064, 'Curitiba', 'Maria Carmelina Nenon', 'Boa Vista', '82560-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23065, 'Londrina', 'Maria Carmelita Vilela Magalhães', 'Milton Gavetti', '86046-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23066, 'São José dos Pinhais', 'Maria Carmem Follador Helpa', 'Planta Quississana', '83085-196', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23067, 'Piraquara', 'Maria Carolina Wilk', 'Vila Juliana', '83306-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23068, 'Curitiba', 'Maria Cecília Aguiar T. Piza', 'Cidade Industrial', '81315-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23069, 'Londrina', 'Maria Celeste de Souza', 'Limoeiro', '86037-265', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23070, 'Curitiba', 'Maria Celestina Monteiro dos Santos', 'Cidade Industrial', '81230-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23071, 'Curitiba', 'Maria Clara', 'Alto da Glória', '80030-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23072, 'Curitiba', 'Maria Clara de Jesus', 'Ganchinho', '81935-386', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23073, 'Arapongas', 'Maria Coelho Aguiar', 'Centro', '86701-730', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23074, 'Piraquara', 'Maria Conceição da Cruz', 'Planta Santa Lúcia', '83311-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23075, 'Londrina', 'Maria Conceição Moreira', 'Residencial José B Almeida', '86041-829', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23076, 'Londrina', 'Maria Constantino Esperança', 'Residencial Vila Romana', '86031-828', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23077, 'Londrina', 'Maria Contrera', 'Conjunto Habitacional José Belinatti', '86088-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23078, 'Almirante Tamandaré', 'Maria Conzatti Quintana', 'Vila Cachoeira', '83504-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23079, 'Curitiba', 'Maria Coradin Garib', 'Cidade Industrial', '81450-758', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23080, 'São José dos Pinhais', 'Maria Corona Scherner', 'Braga', '83020-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23081, 'Londrina', 'Maria Corrêa', 'Colúmbia', '86057-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23082, 'Curitiba', 'Maria Corrêa Godoy', 'Pilarzinho', '82100-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23083, 'Curitiba', 'Maria Cristina Gaudêncio', 'Santa Cândida', '82720-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23084, 'Apucarana', 'Maria Curie', 'Jardim Albino Biachi', '86802-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23085, 'São José dos Pinhais', 'Maria da Conceição Bastos Zen', 'Rio Pequeno', '83070-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23086, 'Curitiba', 'Maria da Conceição Nogueira de Lima', 'Campo de Santana', '81490-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23087, 'Paranaguá', 'Maria da Conceição Teixeira de Souza', 'Divinéia', '83212-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23088, 'Apucarana', 'Maria da Conceição Vieira', 'Jardim Diamantina', '86804-145', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23089, 'Apucarana', 'Maria da Costa L. Mazargão', 'Jardim Trabalhista', '86807-396', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23090, 'Apucarana', 'Maria da Glória', 'Jardim Independência', '86811-390', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23091, 'Londrina', 'Maria da Glória Barroso Casarin', 'Del Rey', '86045-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23092, 'São José dos Pinhais', 'Maria da Glória Silveira', 'Ipê', '83055-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23093, 'Curitiba', 'Maria da Luz Cordeiro Xavier', 'Santo Inácio', '82010-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23094, 'Curitiba', 'Maria da Luz Laynes de Andrade', 'Campo Comprido', '81220-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23095, 'Curitiba', 'Maria da Luz Rocha Belão', 'Xaxim', '81710-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23096, 'Curitiba', 'Maria da Luz Roquembauer', 'Sítio Cercado', '81900-737', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23097, 'São José dos Pinhais', 'Maria da Luz S. Camargo', 'Cruzeiro', '83010-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23098, 'Curitiba', 'Maria da Luz Weinert de Lima', 'Atuba', '82860-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23099, 'Curitiba', 'Maria da Paixão Brandão Reis', 'Seminário', '80240-650', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23100, 'Colombo', 'Maria Dal''Pra Berlesi', 'Castelo Branco', '83412-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23101, 'Curitiba', 'Maria das Neves Storrer', 'Campina do Siqueira', '80740-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23102, 'Curitiba', 'Maria de Campos', 'Portão', '80330-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23103, 'Maringá', 'Maria de Fátima Contessoto', 'Conjunto Habitacional Sol Nascente', '87055-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23104, 'Maringá', 'Maria de Freitas Marangoni', 'Jardim Higienópolis', '87060-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23105, 'Londrina', 'Maria de Jesus', 'Conjunto Novo Amparo', '86087-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23106, 'Londrina', 'Maria de Jesus Araújo', 'Jardim Piza', '86073-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23107, 'Campo Largo', 'Maria de Jesus Ferreira', 'Vila Ferrari', '83606-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23108, 'Almirante Tamandaré', 'Maria de Jesus Leal', 'Jardim Giannini', '83511-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23109, 'Londrina', 'Maria de Jesus Teixeira', 'Portal de Versalhes 3', '86055-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23110, 'São José dos Pinhais', 'Maria de Lima Almeida', 'Colônia Rio Grande', '83025-326', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23111, 'Londrina', 'Maria de Lourdes Cardoso de Lima', 'Conjunto Residencial Vale do Arvoredo', '86047-536', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23112, 'Almirante Tamandaré', 'Maria de Lourdes Domakoski', 'Jardim Dona Belizaria', '83513-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23113, 'Araucária', 'Maria de Lourdes Grabowski Kampa', 'Centro', '83702-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23114, 'Curitiba', 'Maria de Lourdes Hamann Petrelli', 'Cajuru', '82940-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23115, 'Paranaguá', 'Maria de Lourdes Kossatz', 'Padre Jackson', '83221-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23116, 'Curitiba', 'Maria de Lourdes Kudri', 'Barreirinha', '82700-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23117, 'Curitiba', 'Maria de Lourdes Mickosz', 'Taboão', '82130-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23118, 'Paranaguá', 'Maria de Lourdes Morozowski', '29 de Julho', '83203-775', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23119, 'Londrina', 'Maria de Lourdes Oliveira', 'Lagoa Dourada', '86041-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23120, 'Apucarana', 'Maria de Lourdes Pereira', 'Jardim Aeroporto', '86812-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23121, 'Curitiba', 'Maria de Lourdes Perico Kozoski', 'Pinheirinho', '81825-256', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23122, 'Londrina', 'Maria de Lourdes Ribeiro Ferraro', 'Novo Antares', '86036-420', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23123, 'Londrina', 'Maria de Lourdes Ribeiro Souza', 'Jardim São Jorge', '86082-815', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23124, 'Araucária', 'Maria de Lourdes Skraba Ophis', 'Cachoeira', '83701-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23125, 'Colombo', 'Maria de Lurdes dos Santos', 'Jardim Campo Alto', '83408-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23126, 'Colombo', 'Maria de Lurdes Pereira de Faria', 'Jardim Nova Esperança', '83413-136', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23127, 'Apucarana', 'Maria de Macedo', 'Jardim Residencial Garcia', '86807-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23128, 'Apucarana', 'Maria de Marchi Miranda', 'Jardim Santos Dumont III', '86812-536', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23129, 'Sarandi', 'Maria de Nazaré', 'Parque Residencial Bom Pastor', '87114-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23130, 'Curitiba', 'Maria de Nazareth Athayde', 'Umbará', '81930-658', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23131, 'Londrina', 'Maria de Oliveira Melo', 'San Izidro', '86040-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23132, 'Apucarana', 'Maria de Paula Batista', 'Jardim Figueira', '86801-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23133, 'Curitiba', 'Maria de Souza Coelho', 'Cidade Industrial', '81450-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23134, 'Curitiba', 'Maria Dina das Chagas Zelinski', 'Uberaba', '81590-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23135, 'Curitiba', 'Maria Dissenha Bonato', 'Uberaba', '81930-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23136, 'Toledo', 'Maria do Carmo Gozzo', 'Jardim Maria do Carmo', '85906-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23137, 'Londrina', 'Maria do Carmo Marinho', 'Parque Industrial José Belinati', '86039-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23138, 'Londrina', 'Maria do Carmo Tramontini', 'Conjunto Semiramis Barros Braga', '86088-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23139, 'Arapongas', 'Maria do Rocio Pugliesi', 'Centro', '86701-720', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23140, 'Cascavel', 'Maria Dolores da Motta', 'Claudete', '85811-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23141, 'Londrina', 'Maria Dolores Euzébio de Aquino', 'Jardim Neman Sahyun', '86041-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23142, 'Londrina', 'Maria Dolores Lopes', 'Conjunto Semiramis Barros Braga', '86088-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23143, 'Londrina', 'Maria Doniak', 'Jardim Tropical', '86087-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23144, 'Curitiba', 'Maria dos Prazeres Alves de Oliveira', 'Tatuquara', '81940-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23145, 'Curitiba', 'Maria dos Santos Cantarino', 'Sítio Cercado', '81925-266', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23146, 'Araucária', 'Maria Druszcz Grebos', 'Capela Velha', '83706-720', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23147, 'Araucária', 'Maria Edith de Franca Trauczynski', 'Boqueirão', '83704-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23148, 'São José dos Pinhais', 'Maria Efigênia Souza Cortes', 'Colônia Rio Grande', '83025-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23149, 'Curitiba', 'Maria Efigênio Inácio', 'Pinheirinho', '81825-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23150, 'Curitiba', 'Maria Elisabete Herrera', 'Uberaba', '81560-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23151, 'Curitiba', 'Maria Emiliano de Moraes', 'Cidade Industrial', '81315-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23152, 'São José dos Pinhais', 'Maria Estela Prestes', 'Ipê', '83055-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23153, 'Curitiba', 'Maria Etelvina Antunes de Sá', 'Cidade Industrial', '81460-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23154, 'Curitiba', 'Maria Eudóxia Cortiano', 'Tatuquara', '81940-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23155, 'Curitiba', 'Maria Fatuch', 'Jardim Social', '82520-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23156, 'São José dos Pinhais', 'Maria Ferreira de Lima', 'Braga', '83020-665', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23157, 'Curitiba', 'Maria Ficinska', 'Tarumã', '82530-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23158, 'Londrina', 'Maria Flauzina de Jesus', 'Residencial Portal do Sol', '86082-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23159, 'Curitiba', 'Maria Fortunata Tosin', 'Cidade Industrial', '81230-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23160, 'Colombo', 'Maria Francelina da Silva', 'Parque Residencial Santa Terezinha II', '83408-808', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23161, 'Araucária', 'Maria Fressato Basso', 'Campina da Barra', '83709-829', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23162, 'Foz do Iguaçu', 'Maria Fretertag', 'Jardim Panorama', '85856-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23163, 'Londrina', 'Maria Furlan Franciscato', 'Jardim Pacaembu', '86079-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23164, 'Curitiba', 'Maria Gabardo Mendes', 'Portão', '81070-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23165, 'Londrina', 'Maria Gama da Silva', 'Parigot de Souza 2', '86082-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23166, 'Londrina', 'Maria Garcia Lopes', 'Conjunto Novo Amparo', '86087-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23167, 'Londrina', 'Maria Gaspari Piconi', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23168, 'Foz do Iguaçu', 'Maria Geltrudes Ribeiro', 'Loteamento Universitário das Américas', '85870-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23169, 'Colombo', 'Maria Geronasso do Rosário', 'Vila Maria do Rosário', '83413-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23170, 'Curitiba', 'Maria Geronasso do Rosário', 'Boa Vista', '82560-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23171, 'Curitiba', 'Maria Gomes', 'Novo Mundo', '81020-070', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23172, 'Curitiba', 'Maria Gonçalves Alexandre', 'Cajuru', '82940-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23173, 'Pinhais', 'Maria Gonçalves Garcia', 'Moradias Santa Clara', '83325-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23174, 'Curitiba', 'Maria Goza', 'Tatuquara', '81470-066', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23175, 'Curitiba', 'Maria Grodz', 'Campina do Siqueira', '80730-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23176, 'Curitiba', 'Maria Gronovicz', 'Cidade Industrial', '81250-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23177, 'Curitiba', 'Maria Guebur', 'Santo Inácio', '82300-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23178, 'Curitiba', 'Maria Gusso Sforza', 'Pilarzinho', '82115-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23179, 'Cambé', 'Maria Hauser', 'Residencial Elizabeth', '86188-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23180, 'São José dos Pinhais', 'Maria Helena', 'São Pedro', '83005-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23181, 'Curitiba', 'Maria Helena Brandão', 'Cidade Industrial', '81260-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23182, 'Londrina', 'Maria Helena Neves da Silva', 'Jardim Piza', '86073-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23183, 'Curitiba', 'Maria Homan Wisniewski', 'Cidade Industrial', '81270-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23184, 'Umuarama', 'Maria Ignácia da Silva', 'Jardim Colibri', '87506-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23185, 'Londrina', 'Maria Imaculada Belloti', 'Lagoa Dourada', '86041-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23186, 'Londrina', 'Maria Inácia de Almeida Campos', 'San Fernando', '86040-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23187, 'Londrina', 'Maria Inês Leonel Oliveira', 'Jardim São Jorge', '86082-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23188, 'Curitiba', 'Maria Inês Xavier Mendonça', 'Orleans', '81200-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23189, 'Pinhais', 'Maria Ione G. de Oliveira', 'Jardim Triângulo', '83331-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23190, 'Londrina', 'Maria Irene Vicentini Theodoro', 'Santa Mônica', '86079-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23191, 'São José dos Pinhais', 'Maria Isabel Zen Zagonel', 'Afonso Pena', '83045-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23192, 'Colombo', 'Maria Itália Fidélis', 'Jardim Florença', '83414-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23193, 'Londrina', 'Maria Izabel Conceição', 'Parigot de Souza 2', '86082-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23194, 'Colombo', 'Maria Izabel Tosin', 'Jardim Monza', '83406-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23195, 'Almirante Tamandaré', 'Maria Jacobina', 'São Miguel', '83511-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23196, 'Cambé', 'Maria Jacomel Paccola', 'Parque Residencial Ana Rosa', '86183-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23197, 'Maringá', 'Maria Joana Bueno de Souza', 'Parque Residencial Aeroporto (3ª Parte)', '87055-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23198, 'Curitiba', 'Maria Joana Farias', 'Pilarzinho', '82115-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23199, 'Campo Largo', 'Maria Joana Marochi', 'Loteamento Itaboa', '83605-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23200, 'Curitiba', 'Maria Joana Mulhmann', 'Boa Vista', '82650-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23201, 'Londrina', 'Maria Joana Scatolin', 'Cafezal', '86045-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23202, 'Toledo', 'Maria José', 'Jardim Santa Maria', '85903-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23203, 'Londrina', 'Maria José Balzanelo Aguilera', 'Conjunto Farid Libos', '86087-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23204, 'Apucarana', 'Maria José Bonilha Milano', 'Jardim Santos Dumont I', '86812-567', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23205, 'Londrina', 'Maria José Carneiro', 'Monte Carlo', '86040-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23206, 'Londrina', 'Maria José da Silva', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23207, 'Paranavaí', 'Maria José de Castro Consalter', 'Jardim Monções', '87707-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23208, 'Curitiba', 'Maria José de Souza', 'Tatuquara', '81880-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23209, 'Toledo', 'Maria José Mendes', 'Jardim Paulista', '85910-056', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23210, 'Toledo', 'Maria José Nogueira', 'Jardim Planalto', '85903-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23211, 'Londrina', 'Maria José Vieira da Silva', 'Residencial Verona', '86038-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23212, 'Londrina', 'Maria Josepha de Carvalho', 'Jardim Nova Esperança', '86044-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23213, 'Curitiba', 'Maria Júlia Corrêa da Silva', 'São Braz', '82015-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23214, 'Londrina', 'Maria Júlia Marroni', 'Jardim Vale Verde', '86040-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23215, 'Curitiba', 'Maria Justina Miranda', 'Atuba', '82860-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23216, 'Curitiba', 'Maria Juvita Cruz', 'Campo de Santana', '81490-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23217, 'Araucária', 'Maria Kaminski Moll', 'Iguaçu', '83701-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23218, 'Curitiba', 'Maria Karam Joaquim', 'Novo Mundo', '81050-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23219, 'Araucária', 'Maria Karas', 'Centro', '83702-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23220, 'Londrina', 'Maria Kozan Pialarissi', 'Santa Mônica', '86079-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23221, 'Curitiba', 'Maria Kuchinar Kloss', 'Orleans', '81200-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23222, 'Curitiba', 'Maria Kustumack', 'Cidade Industrial', '81310-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23223, 'Curitiba', 'Maria L. Rossa', 'Augusta', '81290-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23224, 'Londrina', 'Maria Leite Faria', 'Dom Pedro I', '86089-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23225, 'Pinhais', 'Maria Leni Barbosa', 'Vale da Boa Esperança', '83320-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23226, 'São José dos Pinhais', 'Maria Leni Haluch de Bastos', 'Planta Quississana', '83085-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23227, 'Curitiba', 'Maria Lenira G. de Toledo Piza', 'Santa Quitéria', '80310-145', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23228, 'Curitiba', 'Maria Lícia Barauce', 'Boqueirão', '81610-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23229, 'São José dos Pinhais', 'Maria Licodiedoff', 'Costeira', '83015-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23230, 'Colombo', 'Maria Lisboa Schroeder', 'Jardim Parque Verde', '83409-417', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23231, 'Piraquara', 'Maria Lobato Amaral', 'Planta Guarituba II', '83310-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23232, 'Cambé', 'Maria Loni Leandro', 'Jardim Santa Adelaide', '86192-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23233, 'Pato Branco', 'Maria Lora', 'Menino Deus', '85502-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23234, 'Londrina', 'Maria Lúcia da Paz', 'Gleba Fazenda Palhano', '86050-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23235, 'Araucária', 'Maria Lúcia Dutra', 'Campina da Barra', '83709-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23236, 'Colombo', 'Maria Lúcia Gueno de Andrade', 'Parque Industrial Guaraituba', '83411-118', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23237, 'Curitiba', 'Maria Lúcia Locher de Athayde', 'Cidade Industrial', '81450-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23238, 'Londrina', 'Maria Lúcia Moreno', 'Jardim Paris', '86082-087', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23239, 'Colombo', 'Maria Ludwig Müller', 'Jardim dos Eucaliptos', '83408-549', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23240, 'Piraquara', 'Maria Luiza', 'Jardim Veneza', '83310-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23241, 'São José dos Pinhais', 'Maria Luiza', 'Afonso Pena', '83050-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23242, 'Curitiba', 'Maria Luiza Alves de Moraes', 'Cidade Industrial', '81460-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23243, 'Londrina', 'Maria Luiza Bagio Fagion', 'Jardim Imagawa', '86080-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23244, 'Curitiba', 'Maria Luiza Bazzani Natal', 'Cajuru', '82900-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23245, 'Pinhais', 'Maria Luiza Borba', 'Vila Tarumã', '83323-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23246, 'Curitiba', 'Maria Luiza Bruel', 'Cajuru', '82950-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23247, 'Curitiba', 'Maria Luiza Curial dos Santos', 'Boqueirão', '81750-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23248, 'Curitiba', 'Maria Luiza Dantolini Gênero', 'Cidade Industrial', '81230-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23249, 'Curitiba', 'Maria Luiza dos Anjos Mayer', 'Barreirinha', '82700-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23250, 'Curitiba', 'Maria Luiza Puchalski', 'Cajuru', '82960-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23251, 'Cascavel', 'Maria Luiza Saraiva', 'Santos Dumont', '85804-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23252, 'Curitiba', 'Maria Luiza Sbalqueiro Deconto', 'Vista Alegre', '80820-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23253, 'Londrina', 'Maria Luiza Zambelo', 'Esperança', '86046-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23254, 'São José dos Pinhais', 'Maria Machado', 'Braga', '83020-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23255, 'Curitiba', 'Maria Maciel Farias', 'Novo Mundo', '81050-649', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23256, 'Londrina', 'Maria Madalena', 'Gayon', '86039-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23257, 'Almirante Tamandaré', 'Maria Madalena', 'Jardim Arco Íris', '83504-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23258, 'Ponta Grossa', 'Maria Madalena Branco Martins', 'Chapada', '84064-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23259, 'Londrina', 'Maria Madalena de Jesus', 'Assis', '86085-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23260, 'Curitiba', 'Maria Madalena de Miranda Wolfart', 'Boa Vista', '82650-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23261, 'Castro', 'Maria Magadalena Vassão', 'Vila Rio Branco', '84172-405', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23262, 'Pinhais', 'Maria Maia Duarte', 'Vila Maria Antonieta', '83331-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23263, 'Curitiba', 'Maria Marchiori Fantinato', 'Atuba', '82840-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23264, 'Londrina', 'Maria Marcionila da Conceição', 'Dom Pedro I', '86089-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23265, 'Guarapuava', 'Maria Marcondes Ribas', 'Santana', '85070-696', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23266, 'Ponta Grossa', 'Maria Margarida Zagonel Slaviero', 'Boa Vista', '84071-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23267, 'São José dos Pinhais', 'Maria Martins Scalise', 'Braga', '83020-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23268, 'Londrina', 'Maria Maura Rielli Victorelli', 'Conjunto Residencial Marajoara', '86080-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23269, 'São José dos Pinhais', 'Maria Max', 'Braga', '83020-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23270, 'Curitiba', 'Maria Mazuroski', 'Cidade Industrial', '81250-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23271, 'Curitiba', 'Maria Medeiros Damas', 'Uberaba', '81590-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23272, 'Pinhais', 'Maria Melk Cordeiro', 'Conjunto Residencial Inocoop', '83326-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23273, 'Curitiba', 'Maria Mendes Elias', 'Cidade Industrial', '81350-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23274, 'Curitiba', 'Maria Meurer de Matos', 'Xaxim', '81830-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23275, 'Curitiba', 'Maria Milchin', 'Cidade Industrial', '81310-430', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23277, 'Apucarana', 'Maria Montessori', 'Jardim Albino Biachi', '86802-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23278, 'Piraquara', 'Maria Moreira da Silva', 'Jardim Itiberê', '83314-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23279, 'Curitiba', 'Maria Morizaki', 'Cidade Industrial', '81170-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23280, 'Curitiba', 'Maria Moscardi Fanini', 'Guaíra', '80220-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23281, 'Londrina', 'Maria Munaretto Mathias', 'Vale das Araucárias', '86047-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23282, 'Pato Branco', 'Maria Naura Camargo Rigon', 'La Salle', '85505-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23283, 'Paranaguá', 'Maria Nely Picanço', 'Vila do Caic', '83215-696', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23284, 'Curitiba', 'Maria Nicolas', 'Sítio Cercado', '81925-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23285, 'Curitiba', 'Maria Noemia dos Santos', 'Santa Cândida', '82640-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23286, 'Londrina', 'Maria Oliveira Souza Mello', 'Portal de Versalhes 3', '86055-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23287, 'Curitiba', 'Maria Orso Pereira', 'Campo de Santana', '81490-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23288, 'São José dos Pinhais', 'Maria Pasqualim Vaccari', 'Cruzeiro', '83010-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23289, 'São José dos Pinhais', 'Maria Paula Martins de Oliveira', 'Guatupê', '83060-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23290, 'Maringá', 'Maria Paulina Palma', 'Conjunto Habitacional Requião', '87047-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23291, 'São José dos Pinhais', 'Maria Paulina Pereira', 'Ouro Fino', '83015-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23292, 'Francisco Beltrão', 'Maria Pedro Celuppi', 'Antônio de Paiva Cantelmo', '85603-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23293, 'Curitiba', 'Maria Petroski', 'Bacacheri', '82600-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23294, 'Curitiba', 'Maria Philomena de Luca Mondrone', 'Hugo Lange', '80040-410', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23295, 'Curitiba', 'Maria Polenta', 'Água Verde', '80240-250', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23296, 'Araucária', 'Maria Prosdócimo Franceschi', 'Vila Nova', '83703-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23297, 'Foz do Iguaçu', 'Maria Quitéria', 'Jardim Cláudia', '85852-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23298, 'Londrina', 'Maria Quitéria', 'Brasília', '86039-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23299, 'Ponta Grossa', 'Maria Quitéria', 'Uvaranas', '84032-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23300, 'Curitiba', 'Maria Quitéria', 'Fazendinha', '81330-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23301, 'Almirante Tamandaré', 'Maria Rainha da Paz', 'Loteamento Chico Mendes', '83505-768', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23302, 'Cambé', 'Maria Raminelli Dezoti', 'Jardim José Favaro', '86183-785', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23303, 'Colombo', 'Maria Razoto Alberti', 'Jardim Esperança', '83402-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23304, 'Almirante Tamandaré', 'Maria Regina Ferreira dos Santos', 'Jardim Alvorada II', '83505-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23305, 'Curitiba', 'Maria Regina Predebon Vanzo', 'Portão', '81070-480', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23306, 'Curitiba', 'Maria Rieke de Sá', 'Boa Vista', '82210-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23307, 'Curitiba', 'Maria Rita das Chagas Lima', 'São Braz', '82300-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23308, 'Ponta Grossa', 'Maria Rita Perpétuo da Cruz', 'Oficinas', '84035-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23309, 'Apucarana', 'Maria Rocha dos Santos', 'Núcleo Habitacional Mathias Hoffman', '86805-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23310, 'Londrina', 'Maria Rodrigues Alves', 'Jardim Ouro Preto', '86035-186', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23311, 'Piraquara', 'Maria Rodrigues Assumpção', 'Guarituba', '83311-327', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23312, 'Curitiba', 'Maria Rosa Crevelin', 'Pinheirinho', '81870-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23313, 'Londrina', 'Maria Rosa Malher', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23314, 'Colombo', 'Maria Rosa Soares de Chaves', 'Capivari', '83415-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23315, 'Londrina', 'Maria Rúbio Lopes', 'São Cristóvão', '86025-765', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23316, 'Araucária', 'Maria Saad Ohpis', 'Costeira', '83709-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23317, 'Foz do Iguaçu', 'Maria Salete L. Gonçalves', 'Jardim Porto Belo', '85867-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23318, 'Almirante Tamandaré', 'Maria Selvani Nascimento', 'Jardim Paraíso', '83512-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23319, 'Curitiba', 'Maria Sena da Mota', 'São Miguel', '81450-767', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23320, 'Londrina', 'Maria Serrato Batista', 'Milton Gavetti', '86046-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23321, 'Londrina', 'Maria Serrato Batista', 'Conjunto Novo Amparo 2', '86056-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23322, 'Foz do Iguaçu', 'Maria Shinneider Britto', 'Jardim N Horizonte', '85855-746', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23323, 'Curitiba', 'Maria Silka Couston', 'Boqueirão', '81750-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23324, 'Curitiba', 'Maria Simão Campos', 'Uberaba', '81550-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23325, 'Curitiba', 'Maria Simeão Bettega', 'Novo Mundo', '81010-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23326, 'Londrina', 'Maria Sinopoli Francovig', 'Conjunto Semiramis Barros Braga', '86088-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23327, 'Araucária', 'Maria Sobania', 'Tindiquera', '83708-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23328, 'Colombo', 'Maria Solange Lira Rosa', 'Parque Residencial Santa Terezinha II', '83408-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23329, 'Londrina', 'Maria Sorgi Cereda', 'Jardim Neman Sahyun', '86041-276', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23330, 'Curitiba', 'Maria Stacheki de Oliveira', 'Pilarzinho', '82120-570', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23331, 'Araucária', 'Maria Stigar Rybinski', 'Boqueirão', '83704-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23332, 'São José dos Pinhais', 'Maria Tacília Pereira', 'Guatupê', '83060-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23333, 'Londrina', 'Maria Teixeira Coutinho', 'Gaion', '86039-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23334, 'Curitiba', 'Maria Teixeira de Mello', 'Santa Cândida', '82630-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23335, 'Curitiba', 'Maria Teodoro Vilalva', 'Cidade Industrial', '81315-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23336, 'Cascavel', 'Maria Tereza Figueiredo', 'Interlagos', '85814-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23337, 'Colombo', 'Maria Tereza Graboski', 'Jardim Guarujá', '83407-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23338, 'Curitiba', 'Maria Tereza Princival', 'Sítio Cercado', '81900-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23339, 'Londrina', 'Maria Tereza Vieira', 'Igapó', '86046-335', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23340, 'Londrina', 'Maria Terezinha da Costa', 'Jardim São Jorge', '86082-829', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23341, 'Curitiba', 'Maria Terezinha Nunes Silva', 'Mercês', '80710-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23342, 'Curitiba', 'Maria Theodora de Paula Costa', 'Jardim das Américas', '81530-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23343, 'Maringá', 'Maria Thereza Bergamasco', 'Cidade Jardim', '87020-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23344, 'Curitiba', 'Maria Thereza Gonçalves', 'Umbará', '81930-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23345, 'Londrina', 'Maria Tito da Motta Mendes', 'Jardim Império do Sol', '86073-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23346, 'Curitiba', 'Maria Todesco', 'São Lourenço', '82210-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23347, 'Curitiba', 'Maria Trevisan Tortato', 'Novo Mundo', '81020-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23348, 'Ponta Grossa', 'Maria Úrsula de Abreu', 'Cará-cará', '84032-436', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23349, 'São José dos Pinhais', 'Maria Vaccari Bortolan', 'Ouro Fino', '83015-068', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23350, 'Piraquara', 'Maria Valenga', 'Vila Franca', '83305-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23351, 'Londrina', 'Maria Ventura da Conceição', 'Jardim Vale Azul', '86041-840', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23352, 'Colombo', 'Maria Verginia Alves Souza', 'Jardim dos Eucaliptos', '83408-508', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23353, 'Curitiba', 'Maria Verônica Stroparo', 'São Braz', '82310-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23354, 'Londrina', 'Maria Vidal da Silva', 'Jardim Acapulco', '86045-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23355, 'Telêmaco Borba', 'Maria Vieira', 'Jardim Alegre', '84268-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23356, 'Londrina', 'Maria Vieira Lopes', 'Conjunto Habitacional Alexandre Urbanas', '86037-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23357, 'Curitiba', 'Maria Visnievski', 'Cidade Industrial', '81170-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23358, 'Almirante Tamandaré', 'Maria Vitória Achoa', 'Jardim Giannini', '83511-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23359, 'Londrina', 'Maria Zancarli', 'Portal de Versalhes 3', '86055-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23360, 'São José dos Pinhais', 'Maria Zeneide da Silva', 'Rio Pequeno', '83065-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23361, 'Pinhais', 'Maria Ziloá Dipp', 'Planta Núcleo Colonial de Pinhais', '83321-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23362, 'Guarapuava', 'Marialva', 'Alto da XV', '85065-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23363, 'Maringá', 'Marialva', 'Zona 08', '87050-580', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23364, 'Pinhais', 'Marialva', 'Jardim Pedro Demeterco', '83324-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23365, 'Ponta Grossa', 'Marialva', 'Boa Vista', '84071-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23366, 'Umuarama', 'Marialva', 'Zona III', '87502-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23367, 'São José dos Pinhais', 'Marialva', 'Ouro Fino', '83015-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23368, 'Colombo', 'Marialva', 'Jardim Guilhermina', '83410-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23369, 'Apucarana', 'Marialva', 'Loteamento São Sebastião', '86808-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23370, 'Curitiba', 'Marialva', 'Pinheirinho', '81880-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23371, 'Curitiba', 'Marialva', 'Sítio Cercado', '81900-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23372, 'Foz do Iguaçu', 'Mariam Osman', 'Jardim Dona Fátima Osman', '85856-677', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23373, 'Curitiba', 'Marian Tadeuzs Laslowski', 'Cajuru', '82920-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23374, 'Curitiba', 'Mariana', 'Santa Felicidade', '82320-260', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23375, 'Londrina', 'Mariana Cabral Estigarríbia', 'Parque Residencial Michael Licha', '86078-666', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23376, 'Londrina', 'Mariana Fernandes de Brito', 'Jardim Ouro Preto', '86035-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23377, 'Curitiba', 'Mariana Lima Silva', 'Cidade Industrial', '81250-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23378, 'Castro', 'Mariana Marques', 'Centro', '84165-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23379, 'Piraquara', 'Mariana Montoya Saes', 'Planta Guarituba II', '83310-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23380, 'Toledo', 'Mariana Zanetti', 'Panorama', '85911-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23381, 'Londrina', 'Mariane Accioly Baccaro', 'Conjunto Residencial Marajoara', '86080-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23382, 'Curitiba', 'Mariano A. da Luz', 'Uberaba', '81590-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23383, 'Campo Largo', 'Mariano A. Torres', 'Jardim Santa Nely', '83608-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23384, 'Curitiba', 'Mariano Alves do Nascimento', 'Tingui', '82620-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23385, 'Foz do Iguaçu', 'Mariano Camilo Paganotto', 'Loteamento Witt', '85862-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23386, 'Paranavaí', 'Mariano de Souza Morangueira', 'Jardim Maringá', '87709-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23387, 'Curitiba', 'Mariano Gardolinski', 'Santa Cândida', '82640-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23388, 'Maringá', 'Mariano Ives de Oliveira Alves', 'Conjunto Habitacional João de Barro Thaís', '87075-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23389, 'Colombo', 'Mariano Jambinski', 'Prado', '83414-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23390, 'Ponta Grossa', 'Mariano Leal', 'Uvaranas', '84025-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23391, 'Piraquara', 'Mariano Oliveira da Silva', 'Planta Pontoni Filho', '83314-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23392, 'Londrina', 'Mariano Ravali', 'Residencial Vila Romana', '86031-826', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23393, 'Curitiba', 'Mariano Snak', 'Pinheirinho', '81880-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23394, 'Guarapuava', 'Mariano Torres', 'Boqueirão', '85023-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23395, 'Curitiba', 'Mariano Torres', 'Centro', '80060-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23396, 'Arapongas', 'Mariazinha', 'Jardim Aeroporto', '86702-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23397, 'Cascavel', 'Marico Batista', 'Cascavel Velho', '85818-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23398, 'Foz do Iguaçu', 'Marie Curie', 'Jardim Cláudia', '85852-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23399, 'Araucária', 'Marie Roxane Charvet', 'Boqueirão', '83704-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23400, 'Foz do Iguaçu', 'Marieta Shink', 'Jardim das Flores', '85862-488', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23401, 'Pinhais', 'Marilândia', 'Chácaras Atuba', '83325-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23402, 'Telêmaco Borba', 'Marilândia', 'Macopa', '84263-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23403, 'Apucarana', 'Marilândia do Sul', 'Núcleo Habitacional Nossa Senhora Aparecida', '86801-396', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23404, 'Curitiba', 'Marilândia do Sul', 'Alto Boqueirão', '81770-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23405, 'Maringá', 'Marileide Martinelli', 'Jardim São Silvestre', '87055-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23406, 'Londrina', 'Marilena', 'Lindóia', '86031-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23407, 'Francisco Beltrão', 'Marilena', 'Pinheirinho', '85603-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23408, 'Araucária', 'Marilene Tikler Torres', 'Iguaçu', '83701-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23409, 'Colombo', 'Marili Senhorinha da Silva', 'Jardim dos Eucaliptos', '83408-538', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23410, 'Francisco Beltrão', 'Marília', 'Luther King', '85605-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23411, 'Francisco Beltrão', 'Marília', 'Padre Eurico', '85604-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23412, 'Londrina', 'Marília', 'Veraliz', '86062-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23413, 'Maringá', 'Marília', 'Jardim Betty', '87060-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23414, 'Pato Branco', 'Marília', 'São Roque', '85507-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23415, 'Umuarama', 'Marília', 'Jardim América', '87502-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23416, 'Toledo', 'Marília', 'Jardim Paulista', '85909-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23417, 'Londrina', 'Marília Barbosa', 'Conjunto Residencial Vale do Arvoredo', '86047-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23418, 'Cascavel', 'Marilu Pazzinatto', 'Brasília', '85815-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23419, 'Foz do Iguaçu', 'Mariluz', 'Jardim Paraná', '85867-210', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23420, 'Pinhais', 'Mariluz', 'Planta Portal da Serra', '83325-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23421, 'Umuarama', 'Mariluz', 'Zona IV', '87504-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23422, 'Colombo', 'Mariluz', 'Jardim Amazonas', '83410-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23423, 'Curitiba', 'Mariluz', 'Alto Boqueirão', '81770-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23424, 'Piraquara', 'Marina Camargo', 'Planta Urucanga', '83311-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23425, 'São José dos Pinhais', 'Marina Coelho', 'São Sebastião', '83075-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23426, 'Curitiba', 'Marina de Souza Board', 'Cidade Industrial', '81315-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23427, 'Curitiba', 'Marina Teixeira da Cunha', 'Umbará', '81930-548', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23428, 'Francisco Beltrão', 'Maringá', 'Vila Nova', '85605-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23429, 'Francisco Beltrão', 'Maringá', 'Vila Nova', '85601-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23430, 'Londrina', 'Maringá', 'Vitória', '86060-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23431, 'Guarapuava', 'Maringá', 'Bonsucesso', '85045-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23432, 'Laranjeiras do Sul', 'Maringá', 'São Francisco', '85303-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23433, 'Foz do Iguaçu', 'Maringá', 'Jardim Paraná', '85867-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23434, 'Paranaguá', 'Maringá', 'Jardim Paranaguá', '83218-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23435, 'Maringá', 'Maringá', 'Jardim Aclimação', '87050-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23436, 'Piraquara', 'Maringá', 'Planta Araçatuba', '83301-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23437, 'Pato Branco', 'Maringá', 'Cristo Rei', '85507-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23438, 'Pinhais', 'Maringá', 'Chácaras Atuba', '83325-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23439, 'Ponta Grossa', 'Maringá', 'Boa Vista', '84071-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23440, 'Pinhais', 'Maringá', 'Vila Emiliano Perneta', '83324-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23441, 'Pinhais', 'Maringá', 'Jardim Atuba I', '83326-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23442, 'Sarandi', 'Maringá', 'Jardim Europa', '87111-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23443, 'Sarandi', 'Maringá', 'Novo Panorama', '87113-196', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23444, 'Sarandi', 'Maringá', 'Jardim Nova Paulista', '87111-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23445, 'São José dos Pinhais', 'Maringá', 'São Cristóvão', '83040-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23446, 'Umuarama', 'Maringá', 'Zona III', '87502-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23447, 'Toledo', 'Maringá', 'Jardim La Salle', '85902-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23448, 'Telêmaco Borba', 'Maringá', 'Nossa Senhora do Perpétuo Socorro', '84265-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23449, 'Toledo', 'Maringá', 'Jardim La Salle', '85903-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23450, 'Campo Mourão', 'Maringá', 'Conjunto Residencial Antilhas', '87308-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23451, 'Cambé', 'Maringá', 'Jardim Ana Eliza', '86187-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23452, 'Almirante Tamandaré', 'Maringá', 'Jardim Taíza', '83505-128', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23453, 'Apucarana', 'Maringá', 'Vila Formosa', '86802-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23454, 'Colombo', 'Maringá', 'Jardim Guilhermina', '83410-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23455, 'Cascavel', 'Maringá', 'São Cristóvão', '85816-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23456, 'Campo Largo', 'Maringá', 'Vila Rivabem', '83605-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23457, 'Araucária', 'Maringá', 'Iguaçu', '83701-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23458, 'Curitiba', 'Maringá', 'Sítio Cercado', '81900-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23459, 'Curitiba', 'Maringá', 'Pinheirinho', '81880-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23460, 'Maringá', 'Marino Paulichi', 'Jardim Universo', '87060-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23461, 'Curitiba', 'Marino Pereira Júnior', 'Atuba', '82860-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23462, 'Londrina', 'Marinósio Trigueiros Filho', 'Alto da Boa Vista', '86083-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23463, 'Londrina', 'Marinosio Trigueiros Neto', 'Conjunto Semiramis Barros Braga', '86088-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23464, 'Campo Mourão', 'Marins C. Pereira', 'Jardim Vitória', '87303-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23465, 'Pato Branco', 'Marins Camargo', 'Centro', '85501-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23466, 'Curitiba', 'Marins Tavares de Andrade', 'Guabirotuba', '81520-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23467, 'Apucarana', 'Mário Alves Carlos', 'Jardim Marissol II', '86807-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23468, 'Curitiba', 'Mário Alves de Menezes', 'Santa Cândida', '82720-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23469, 'São José dos Pinhais', 'Mário Andriguetto', 'Costeira', '83015-727', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23470, 'Sarandi', 'Mário Antônio Farkas', 'Parque Alvamar II', '87113-510', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23471, 'Curitiba', 'Mário Bandeira Rocha', 'Juvevê', '80030-415', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23472, 'Londrina', 'Mário Barbosa Júnior', 'Conjunto Habitacional  Alexandre Urbanas', '86037-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23473, 'Curitiba', 'Mário Beraldi', 'Santa Cândida', '82650-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23474, 'Castro', 'Mário Bertolini', 'Morada do Sol', '84172-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23475, 'Curitiba', 'Mário Bialli', 'Mercês', '80710-670', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23476, 'Curitiba', 'Mário Bittencourt', 'Santa Cândida', '82640-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23477, 'Londrina', 'Mário Bonalumi', 'Leste Oeste', '86037-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23478, 'Londrina', 'Mário Bottura', 'Jardim Alphaville', '86084-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23479, 'Curitiba', 'Mário Brandalise', 'Uberaba', '81510-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23480, 'Curitiba', 'Mário Bueno Sobrinho', 'Uberaba', '81530-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23481, 'Curitiba', 'Mário Burigo', 'Bigorrilho', '80730-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23482, 'Cascavel', 'Mário C. Martini', 'Claudete', '85811-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23483, 'Londrina', 'Mário Cansian', 'Jardim Imagawa', '86080-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23484, 'Ponta Grossa', 'Mário Carvalho Guimarães', 'Boa Vista', '84070-565', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23485, 'Ponta Grossa', 'Mário Carvalho Guimarães', 'Nova Rússia', '84070-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23486, 'Campo Mourão', 'Mário Castaldelli', 'Jardim Lar Paraná', '87305-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23487, 'Apucarana', 'Mário Cazangi', 'Vila Regina', '86801-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23488, 'Londrina', 'Mário Cecarelli', 'Parque Residencial Alcântara', '86047-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23489, 'Curitiba', 'Mário Chaubald Biscaia', 'Novo Mundo', '81050-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23490, 'Londrina', 'Mário Clivatti', 'Alto da Boa Vista', '86083-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23491, 'Sarandi', 'Mário Consentino', 'Jardim Esperança I', '87112-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23492, 'São José dos Pinhais', 'Mário Covas', 'Afonso Pena', '83045-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23493, 'Araucária', 'Mário Czaikoski', 'Barigui', '83707-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23494, 'Ponta Grossa', 'Mário de Alencar', 'Uvaranas', '84025-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23495, 'Londrina', 'Mário de Andrade', 'Universitário', '86050-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23496, 'Foz do Iguaçu', 'Mário de Andrade', 'Jardim Jupira', '85865-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23497, 'Guarapuava', 'Mário de Andrade', 'Boqueirão', '85020-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23498, 'Cascavel', 'Mário de Andrade', 'Nova Cidade', '85803-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23499, 'Campo Largo', 'Mário de Andrade', 'São Marcos', '83602-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23500, 'Curitiba', 'Mário de Andrade', 'Fazendinha', '81330-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23501, 'Londrina', 'Mário de Barros', 'Santa Izabel', '86031-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23502, 'Curitiba', 'Mário de Menezes Dória', 'Bom Retiro', '80520-180', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23503, 'Campo Largo', 'Mário de Pieri', 'Jardim das Américas', '83601-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23504, 'Maringá', 'Mário de Souza', 'Conjunto João de Barro Porto Seguro II', '87055-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23505, 'Londrina', 'Mário Diniz de Oliveira', 'Parque Residencial Alcântara', '86047-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23506, 'Curitiba', 'Mário do Amaral', 'Bairro Alto', '82820-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23507, 'Piraquara', 'Mário Domingues', 'Guarituba', '83311-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23508, 'Guarapuava', 'Mário Edmundo Xavier de Barros', 'Vila Bela', '85027-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23509, 'Curitiba', 'Mário Edson Afonso Valente', 'Capão Raso', '81050-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23510, 'Curitiba', 'Mário Ferreira', 'Cidade Industrial', '81280-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23511, 'Foz do Iguaçu', 'Mário Filho', 'Parque Morumbi', '85858-440', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23512, 'Foz do Iguaçu', 'Mário Filho', 'Parque Morumbi II', '85859-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23513, 'Guarapuava', 'Mário Fontoura', 'Jardim das Américas', '85030-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23514, 'Apucarana', 'Mário Francisco Macedo', 'Loteamento Sanches dos Santos', '86806-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23515, 'Londrina', 'Mário Garcia Theodoro', 'Jamile Dequech', '86048-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23516, 'Curitiba', 'Mário Gasparin', 'Sítio Cercado', '81925-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23517, 'Curitiba', 'Mário Gasparin', 'Sítio Cercado', '81920-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23518, 'Maringá', 'Mário Gealh', 'Residencial Ibirapuera', '87045-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23519, 'Londrina', 'Mário Giovannetti', 'Roseira', '86041-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23520, 'Londrina', 'Mário Giublin', 'Santiago', '86071-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23521, 'Apucarana', 'Mário Giublin', 'Parque Residencial Milani', '86811-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23522, 'Londrina', 'Mário Gobo', 'Eucaliptos', '86031-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23523, 'Ponta Grossa', 'Mário Godói', 'Colônia Dona Luiza', '84043-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23524, 'Curitiba', 'Mário Gomes', 'São Braz', '82300-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23525, 'Curitiba', 'Mário Gomes Cezar', 'Pinheirinho', '81150-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23526, 'Paranaguá', 'Mário Gonçalves dos Santos', 'Jardim Araçá', '83221-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23527, 'Foz do Iguaçu', 'Mário Gradella', 'Parque Presidente II', '85863-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23528, 'Colombo', 'Mário Guarise', 'Vila Vale Verde', '83406-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23529, 'Londrina', 'Mário Hyoichi Sugahara', 'Colinas', '86056-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23530, 'Curitiba', 'Mário João Scaramuzza', 'Seminário', '80740-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23531, 'Curitiba', 'Mário Jordão Affonso da Costa', 'Seminário', '80740-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23532, 'Maringá', 'Mário José de Faria Ferraz', 'Zona 38', '87055-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23533, 'Londrina', 'Mário José Romagnolli', 'Estados', '86083-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23534, 'Cascavel', 'Mário Katuo Kato', 'Presidente', '85818-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23535, 'Ponta Grossa', 'Mário Kowalski', 'Boa Vista', '84073-247', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23536, 'Foz do Iguaçu', 'Mário Lamarque', 'Centro', '85851-017', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23537, 'Toledo', 'Mário Lenz', 'Sachini', '85903-717', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23538, 'Curitiba', 'Mário Lopes Farinha', 'Uberaba', '81540-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23539, 'Londrina', 'Mário Luzel Cauduro', 'Parque Residencial Alcântara', '86047-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23540, 'Curitiba', 'Mário Marchesini', 'Santo Inácio', '82300-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23541, 'Toledo', 'Mário Marchiori', 'Jardim Anápolis', '85905-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23542, 'Pinhais', 'Mário Marques Guimarães', 'Vale da Boa Esperança', '83320-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23543, 'Ponta Grossa', 'Mário Martins', 'Jardim Carvalho', '84016-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23544, 'Colombo', 'Mário Mendes', 'Jardim Florença', '83414-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23545, 'Curitiba', 'Mário Mendes de Lara', 'Uberaba', '81570-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23546, 'Apucarana', 'Mário Mendes Marques', 'Núcleo Popular', '86812-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23547, 'Foz do Iguaçu', 'Mário Miguel de Mello', 'Jardim Niterói', '85853-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23548, 'Curitiba', 'Mário Miro', 'Cajuru', '82950-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23549, 'Apucarana', 'Mário Mitsuo Tamiya', 'Jardim Catuaí', '86802-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23550, 'Maringá', 'Mário Monteschio', 'Vila Morangueira', '87030-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23551, 'Cambé', 'Mário Moretim', 'Parque Residencial Manela', '86185-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23552, 'Colombo', 'Mário Müller', 'Sapopema', '83407-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23553, 'Maringá', 'Mário Nogarotto', 'Parque Tarumã', '87053-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23554, 'Ponta Grossa', 'Mário Nogueira', 'Uvaranas', '84031-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23555, 'Londrina', 'Mário Nogueira Monteiro', 'São Pedro', '86036-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23556, 'Londrina', 'Mário Novaes', 'Jardim Pacaembu', '86079-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23557, 'Londrina', 'Mário Oncken', 'Jardim das Américas', '86076-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23558, 'Paranavaí', 'Mário Palo', 'Jardim Nakamura', '87701-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23559, 'Apucarana', 'Mário Panont', 'Jardim Independência', '86811-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23560, 'Apucarana', 'Mário Panont', 'Jardim Morada do Sol', '86811-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23561, 'Foz do Iguaçu', 'Mário Paulo Alves', 'Jardim Residencial Bela Vista', '85856-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23562, 'Colombo', 'Mário Pederneiras', 'Jardim Loanda', '83409-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23563, 'Londrina', 'Mário Pereira de Mello', 'Conjunto Professora Hilda Mandarino', '86080-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23564, 'Guarapuava', 'Mário Pereira de Oliveira', 'Dos Estados', '85035-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23565, 'Londrina', 'Mário Pezarini', 'Parque Residencial Alcântara', '86047-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23566, 'Curitiba', 'Mário Pinheiro', 'Cidade Industrial', '81310-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23567, 'Curitiba', 'Mário Pizzato', 'Cidade Industrial', '81460-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23568, 'Toledo', 'Mário Pudell', 'Walter Fontana', '85909-446', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23569, 'Cascavel', 'Mário Quintana', 'Interlagos', '85814-278', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23570, 'Almirante Tamandaré', 'Mário Quintana', 'Vila Marta', '83508-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23571, 'Colombo', 'Mário Quintana', 'Vila Luiz Baron', '83412-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23572, 'Curitiba', 'Mário Ribeiro Chimelli', 'Sítio Cercado', '81910-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23573, 'Londrina', 'Mário Roberto Gneco', 'Jardim Tropical', '86087-647', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23574, 'Curitiba', 'Mário Romagnolli', 'Prado Velho', '80215-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23575, 'São José dos Pinhais', 'Mário Santos', 'Planta Quississana', '83085-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23576, 'Curitiba', 'Mário Semokoviski', 'Cidade Industrial', '81310-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23577, 'Londrina', 'Mário Sérgio Carmagnani', 'Conjunto Habitacional Bronzzetti', '86037-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23578, 'Apucarana', 'Mário Sérgio Pereira', 'Jardim Monções', '86807-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23579, 'Curitiba', 'Mário Spyra', 'Santo Inácio', '82010-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23580, 'Colombo', 'Mário Strapasson', 'Imbuial', '83415-256', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23581, 'São José dos Pinhais', 'Mário Tomelim', 'Guatupê', '83060-386', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23582, 'Laranjeiras do Sul', 'Mário Uniate', 'São Francisco', '85303-348', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23583, 'Curitiba', 'Mário Vendramel', 'Prado Velho', '80215-435', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23584, 'Ponta Grossa', 'Mário Victor Pont', 'Centro', '84010-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23585, 'Londrina', 'Mário Vidotti', 'Jardim Alphaville', '86084-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23586, 'Guarapuava', 'Mário Virmond', 'Industrial', '85045-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23587, 'Curitiba', 'Mário Wilson Ribas', 'Guabirotuba', '81510-505', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23588, 'São José dos Pinhais', 'Mário Wilson Soares', 'Planta Quississana', '83085-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23589, 'Foz do Iguaçu', 'Mário Winkert', 'Jardim Itaipu', '85867-286', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23590, 'Curitiba', 'Mário Yassumoto Seita', 'Ganchinho', '81935-316', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23591, 'Curitiba', 'Mário Zanlorenzi', 'Cidade Industrial', '81230-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23592, 'Foz do Iguaçu', 'Mariópolis', 'Jardim Ipê II', '85869-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23593, 'Foz do Iguaçu', 'Mariópolis', 'Jardim Alvorada', '85859-697', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23594, 'Guarapuava', 'Mariópolis', 'Jardim das Américas', '85031-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23595, 'Curitiba', 'Mariópolis', 'Boqueirão', '81750-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23596, 'Toledo', 'Maripa', 'Jardim La Salle', '85902-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23597, 'Toledo', 'Maripa', 'Centro', '85901-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23598, 'Toledo', 'Maripa', 'Jardim América', '85908-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23599, 'Toledo', 'Maripa', 'Vila Brasil', '85909-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23600, 'Arapongas', 'Mariquita', 'Jardim Baroneza', '86706-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23601, 'Arapongas', 'Mariquita-dos-rios', 'Jardim dos Pássaros', '86702-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23602, 'Curitiba', 'Marisa de Fátima Fosquerau Furman', 'Pinheirinho', '81870-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23603, 'Foz do Iguaçu', 'Marisco', 'Parque Ouro Verde', '85855-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23604, 'Apucarana', 'Marissol', 'Vila Narciso', '86804-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23605, 'Umuarama', 'Maristela', 'Zona V', '87504-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23606, 'Francisco Beltrão', 'Maritaca', 'Padre Ulrico', '85604-456', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23607, 'Araucária', 'Maritacas', 'Estação', '83705-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23608, 'São José dos Pinhais', 'Mark Twain', 'Aristocrata', '83030-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23609, 'Curitiba', 'Marlene Terezinha Moro', 'Abranches', '82220-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23610, 'São José dos Pinhais', 'Marlene Veiga da Rosa', 'Miringuava', '83090-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23611, 'Curitiba', 'Marlus Chesneau Lens César', 'Umbará', '81930-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23612, 'Castro', 'Marly Rolim', 'Vila Rio Branco', '84172-340', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23613, 'Francisco Beltrão', 'Marmeleiro', 'Marrecas', '85601-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23614, 'Ponta Grossa', 'Marmeleiro', 'Uvaranas', '84033-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23615, 'Cascavel', 'Marmeleiro', 'Brasmadeira', '85814-146', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23616, 'Curitiba', 'Marmelo', 'Uberaba', '81550-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23617, 'Londrina', 'Mármore', 'Waldemar Hauer', '86030-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23618, 'Apucarana', 'Mármore', 'Parque Industrial Zona Norte', '86806-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23619, 'Foz do Iguaçu', 'Marmota', 'Conjunto A', '85861-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23620, 'Francisco Beltrão', 'Marquês de Abrantes', 'Guanabara', '85604-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23621, 'Maringá', 'Marquês de Abrantes', 'Zona 07', '87020-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23622, 'Ponta Grossa', 'Marquês de Abrantes', 'Uvaranas', '84025-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23623, 'Curitiba', 'Marquês de Abrantes', 'Bairro Alto', '82820-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23624, 'Curitiba', 'Marquês de Barbacena', 'Cidade Industrial', '81250-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23625, 'Curitiba', 'Marquês de Beccaria', 'Pinheirinho', '81880-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23626, 'Ponta Grossa', 'Marquês de Caravelas', 'Uvaranas', '84032-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23627, 'Ponta Grossa', 'Marquês de Maceió', 'Oficinas', '84036-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23628, 'Ponta Grossa', 'Marquês de Maricá', 'Orfãs', '84015-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23629, 'Ponta Grossa', 'Marquês de Olinda', 'Orfãs', '84070-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23630, 'Curitiba', 'Marquês de Olinda', 'Fazendinha', '81330-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23631, 'Toledo', 'Marquês de Pombal', 'Jardim Europa', '85908-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23632, 'Colombo', 'Marquês de Pombal', 'Jardim das Perdizes', '83409-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23633, 'Ponta Grossa', 'Marquês de Sapucaí', 'Uvaranas', '84032-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23634, 'Ponta Grossa', 'Marques de Souza', 'Oficinas', '84035-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23635, 'Guarapuava', 'Marquês do Herval', 'Alto Cascavel', '85031-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23636, 'Almirante Tamandaré', 'Marquês do Herval', 'Vila Grécia', '83502-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23637, 'Ponta Grossa', 'Marquês do Paraná', 'Ronda', '84051-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23638, 'Curitiba', 'Marquês do Paraná', 'Água Verde', '80620-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23639, 'Umuarama', 'Marques dos Reis', 'Zona VII', '87503-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23640, 'Londrina', 'Marques Valença', 'Jardim Bandeirantes', '86061-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23641, 'Apucarana', 'Marquesa de Santos', 'Jardim Independência', '86811-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23642, 'Arapongas', 'Marreca', 'Vila Estrela', '86708-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23643, 'Arapongas', 'Marreca-ca-ca', 'Parque Veneza', '86701-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23644, 'Arapongas', 'Marreca-caneleira', 'Conjunto Flamingos III', '86703-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23645, 'Arapongas', 'Marreca-de-coleira', 'Jardim São Bento', '86706-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23646, 'Arapongas', 'Marrecão', 'Vila Sampaio', '86705-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23647, 'Arapongas', 'Marreca-parda', 'Jardim Portal das Flores', '86701-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23648, 'Arapongas', 'Marreca-pintada', 'Jardim São Bento', '86706-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23649, 'Foz do Iguaçu', 'Marreco', 'Portal da Foz', '85859-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23650, 'Maringá', 'Marreco', 'Parque Hortência', '87075-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23651, 'Arapongas', 'Marrequito-do-brejo', 'Conjunto Palmares', '86706-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23652, 'Londrina', 'Marrocos', 'Ouro Verde', '86080-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23653, 'Guarapuava', 'Marrocos', 'São Cristóvão', '85063-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23654, 'Pinhais', 'Marrocos', 'Vl Dona Guiomar', '83320-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23655, 'Colombo', 'Marrocos', 'Vila Alto da Cruz III', '83405-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23656, 'Almirante Tamandaré', 'Marrocos', 'Vila Graziela', '83505-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23657, 'Londrina', 'Marselha', 'Parque Residencial João Piza', '86041-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23658, 'Curitiba', 'Marta Kateiva de Oliveira', 'Pilarzinho', '82120-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23659, 'Pinhais', 'Marta Rodrigues', 'Loteamento Pineville', '83325-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23660, 'Campo Largo', 'Marta S. Dering', 'Vila Ferrari', '83606-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23661, 'Almirante Tamandaré', 'Marta Scholochoski', 'Loteamento Recanto dos Papagaios', '83512-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23662, 'Curitiba', 'Marte', 'Sítio Cercado', '81910-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23663, 'Curitiba', 'Marte', 'Sítio Cercado', '81900-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23664, 'Francisco Beltrão', 'Marte', 'Pinheirinho', '85606-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23666, 'Foz do Iguaçu', 'Marte', 'Parque Residencial Três Fronteiras', '85859-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23667, 'Ponta Grossa', 'Marte', 'Uvaranas', '84031-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23668, 'Maringá', 'Marte', 'Jardim Universo', '87060-520', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23669, 'Sarandi', 'Marte', 'Jardim Universal', '87114-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23670, 'Telêmaco Borba', 'Marte', 'Nossa Senhora de Fátima', '84264-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23671, 'Cascavel', 'Marte', 'Universitário', '85819-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23672, 'Cambé', 'Marte', 'Parque Maracanã', '86185-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23673, 'Apucarana', 'Marte', 'Jardim Vale do Sol', '86803-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23674, 'Curitiba', 'Martha Cruz Lima Ratton', 'Campina do Siqueira', '80740-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23675, 'Curitiba', 'Martha Gembaroski Tuleski', 'Cidade Industrial', '81460-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23676, 'Curitiba', 'Martha Zanlorenzi', 'Campo Comprido', '81270-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23677, 'Maringá', 'Martim Afonso', 'Zona 02', '87010-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23678, 'Piraquara', 'Martim Afonso', 'Jardim Bela Vista', '83301-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23679, 'Ponta Grossa', 'Martim Afonso', 'Uvaranas', '84032-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23680, 'Maringá', 'Martim Afonso', 'Jardim Novo Horizonte', '87010-411', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23681, 'Curitiba', 'Martim Afonso', 'Bigorrilho', '80730-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23682, 'Curitiba', 'Martim Afonso', 'São Francisco', '80410-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23683, 'Curitiba', 'Martim Afonso', 'Mercês', '80430-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23684, 'Londrina', 'Martim Afonso de Souza', 'Aeroporto', '86036-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23685, 'Pato Branco', 'Martim Afonso de Souza', 'Aeroporto', '85503-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23686, 'Piraquara', 'Martimiano Sabino da Silva', 'Vila São Cristóvão', '83305-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23687, 'Foz do Iguaçu', 'Martim-pescador', 'Portal da Foz', '85859-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23688, 'Londrina', 'Martim-Pescador', 'Jacomo Violin', '86088-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23689, 'Guarapuava', 'Martin Afonso', 'Alto Cascavel', '85031-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23690, 'Sarandi', 'Martin Afonso', 'Parque Residencial Nova Aliança', '87111-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23691, 'Cascavel', 'Martin Afonso de Souza', 'Pacaembu', '85816-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23692, 'Cascavel', 'Martin Fardoski', 'Santos Dumont', '85804-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23693, 'Araucária', 'Martin Habinoski', 'Barigui', '83707-650', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23694, 'Toledo', 'Martin Heck', 'Vila Bom Jesus', '85909-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23695, 'Curitiba', 'Martin Kaiser', 'Abranches', '82130-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23696, 'Londrina', 'Martin Luther King', 'Lago Parque', '86015-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23697, 'Paranavaí', 'Martin Luther King', 'Jardim Farropilha', '87708-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23698, 'Curitiba', 'Martin Pena', 'Bigorrilho', '80730-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23699, 'Francisco Beltrão', 'Martin Pescador', 'Padre Ulrico', '85604-457', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23700, 'Curitiba', 'Martin Varela', 'Jardim Botânico', '80210-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23701, 'Curitiba', 'Martin Wendrychowski', 'Capão Raso', '81110-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23702, 'Curitiba', 'Martinho Diogo Teixeira', 'Jardim Botânico', '80210-340', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23703, 'Londrina', 'Martinho Lutero', 'Gleba Fazenda Palhano', '86055-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23704, 'Ponta Grossa', 'Martinho Luthero', 'Uvaranas', '84026-490', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23705, 'Apucarana', 'Martinho Pedrosa', 'Jardim Ponta Grossa', '86804-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23706, 'Curitiba', 'Martiniano Ceccon Parolin', 'Xaxim', '81820-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23707, 'Arapongas', 'Martin-pescador', 'Parque Siomara', '86705-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23708, 'Apucarana', 'Martins', 'Vila Martins', '86800-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23709, 'Londrina', 'Martins Balero Saes', 'Cafezal 1', '86049-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23710, 'Araucária', 'Martins Deda', 'Capela Velha', '83706-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23711, 'Curitiba', 'Martins Fontes', 'Fazendinha', '81330-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23712, 'Ponta Grossa', 'Martins Francisco', 'Nova Rússia', '84053-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23713, 'Guarapuava', 'Martins Pena', 'Vila Bela', '85025-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23714, 'Foz do Iguaçu', 'Martins Pena', 'Jardim Festugato', '85864-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23715, 'Ponta Grossa', 'Martins Pena', 'Nova Rússia', '84053-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23716, 'Paranavaí', 'Martins Silvério do Nascimento', 'Jardim Ipê', '87707-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23717, 'Colombo', 'Maruba', 'Parque Monte Castelo', '83411-650', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23718, 'Arapongas', 'Marulo', 'Parque Siomara', '86705-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23719, 'Guarapuava', 'Marumbi', 'Vila Bela', '85027-280', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23720, 'Foz do Iguaçu', 'Marumbi', 'Vila Carima', '85855-719', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23721, 'São José dos Pinhais', 'Marumbi', 'Silveira da Motta', '83030-520', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23722, 'Toledo', 'Marumbi', 'Parque Residencial Gisela', '85905-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23723, 'Umuarama', 'Marumbi', 'Zona VII', '87503-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23724, 'Cascavel', 'Marumbi', 'Universitário', '85819-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23725, 'Pinhais', 'Marumby', 'Planta Bairro Weissópolis', '83322-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23726, 'Curitiba', 'Marumby', 'Campo Comprido', '81220-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23727, 'Londrina', 'Marupa', 'Leonor', '86071-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23728, 'Guarapuava', 'Mary Thompson Milazzo', 'Jardim das Américas', '85030-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23729, 'Londrina', 'Masaki Kawabata', 'Itapoã', '86043-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23730, 'Curitiba', 'Masao Ishii', 'Uberaba', '81540-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23731, 'Curitiba', 'Mascagni', 'São Braz', '82300-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23732, 'Umuarama', 'Mascarenha de Moraes', 'Zona III', '87502-210', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23733, 'Cascavel', 'Mascarenhas de Moraes', 'Maria Luiza', '85819-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23734, 'Araucária', 'Massafumi Sekene', 'Boqueirão', '83704-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23735, 'Apucarana', 'Massaharu Tatesugi', 'Jardim Tarobá', '86812-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23736, 'Apucarana', 'Massaharu Tatesugi', 'Jardim Tarobá', '86813-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23737, 'Londrina', 'Massahiko Tomita', 'Vila Simões', '86020-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23738, 'Londrina', 'Massao Ouya', 'Eucaliptos', '86031-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23739, 'Ponta Grossa', 'Massaranduba', 'Uvaranas', '84033-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23740, 'Curitiba', 'Massaranduba', 'Pinheirinho', '81870-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23741, 'Londrina', 'Massaru Yasuda', 'Cilo 2', '86067-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23742, 'Araucária', 'Massatochi Nozu', 'Costeira', '83709-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23743, 'Campo Largo', 'Matadouro', 'Vila Bancária', '83601-700', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23744, 'Apucarana', 'Matão', 'Jardim Menegazzo', '86802-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23745, 'Cambé', 'Matão', 'Jardim São Paulo', '86191-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23746, 'Toledo', 'Mate Laranjeira', 'Jardim Europa', '85907-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23747, 'Arapongas', 'Mateiro', 'Jardim Santo Antônio', '86705-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23748, 'Foz do Iguaçu', 'Matelândia', 'Jardim Veneza', '85870-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23749, 'Guarapuava', 'Matelândia', 'Jardim das Américas', '85030-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23750, 'Laranjeiras do Sul', 'Matelândia', 'Água Verde', '85302-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23751, 'Toledo', 'Matelândia', 'Jardim Santa Maria', '85903-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23752, 'Cascavel', 'Matelândia', 'Pacaembu', '85816-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23753, 'Cambé', 'Matelândia', 'Jardim Ana Eliza', '86188-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23754, 'Colombo', 'Matelândia', 'Jardim Cristina II', '83410-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23755, 'Curitiba', 'Matelândia', 'Boqueirão', '81750-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23756, 'Arapongas', 'Matelião', 'Vila Sampaio', '86705-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23757, 'Londrina', 'Mateote Zanine', 'Jardim Quebequinho', '86045-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23758, 'Paranavaí', 'Mateus', 'Jardim Iguaçu', '87705-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23759, 'Paranavaí', 'Mateus', 'Jardim Ouro Branco', '87704-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23760, 'Londrina', 'Mateus Guerreiro Filho', 'Jardim Marissol', '86030-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23761, 'Pato Branco', 'Mateus Leme', 'Industrial', '85506-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23762, 'Paranavaí', 'Mateus Leme', 'Jardim Panorama', '87707-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23763, 'Curitiba', 'Mateus Leme', 'Abranches', '82130-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23764, 'Curitiba', 'Mateus Leme', 'São Francisco', '80510-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23765, 'Curitiba', 'Mateus Leme', 'Centro Cívico', '80530-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23766, 'Curitiba', 'Mateus Leme', 'São Lourenço', '82200-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23767, 'Curitiba', 'Mateus Leme', 'São Lourenço', '82210-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23768, 'Cambé', 'Mateus Lemes', 'Jardim Silvino', '86188-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23769, 'Ponta Grossa', 'Matheus Hugo Carneiro Martins', 'Contorno', '84052-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23770, 'Castro', 'Matheus Langendick', 'Núcleo Habitacional Padre Piva', '84178-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23771, 'Londrina', 'Matheus Leme', 'Paulista', '86079-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23772, 'Curitiba', 'Matheus Luiz Dalagassa', 'Tatuquara', '81480-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23773, 'Piraquara', 'Matheus Moscatelli', 'Jardim Guarani', '83311-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23774, 'Pinhais', 'Matheus Pereira de Camargo', 'Vila Tarumã', '83323-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23775, 'Laranjeiras do Sul', 'Matheus Piovesan', 'Centro', '85301-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23776, 'Maringá', 'Mathias Alonso', 'Jardim Novo Oásis', '87043-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23777, 'Ponta Grossa', 'Mathias de Albuquerque', 'Oficinas', '84036-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23778, 'Maringá', 'Mathias de Albuquerque', 'Zona 03', '87050-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23779, 'Curitiba', 'Mathias de Andrade Rocha', 'Alto Boqueirão', '81770-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23780, 'Piraquara', 'Mathias Gaio', 'Vila Susi', '83304-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23781, 'Guarapuava', 'Mathias Galan', 'Morro Alto', '85067-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23782, 'Ponta Grossa', 'Mathias Grani', 'Cará-cará', '84070-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23783, 'Cambé', 'Mathias Hein', 'Jardim Santo Antônio', '86182-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23784, 'Piraquara', 'Mathias Jacomel', 'Jardim Esmeralda', '83301-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23785, 'Piraquara', 'Mathias Jacomel', 'Chácara Águas Claras', '83308-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23786, 'Piraquara', 'Mathias Jacomel Júnior', 'Vila Fuck', '83305-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23787, 'Curitiba', 'Mathias Valesco', 'Santa Cândida', '82720-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23788, 'Curitiba', 'Mathilde da Silva Wolff', 'Pilarzinho', '82110-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23789, 'Curitiba', 'Matias Alenor Martins', 'Cidade Industrial', '81260-070', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23790, 'Curitiba', 'Matias Cadori', 'Uberaba', '81590-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23791, 'Curitiba', 'Matias Camienski', 'Barreirinha', '82700-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23792, 'Pato Branco', 'Matias de Albuquerque', 'Pinheirinho', '85506-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23793, 'Curitiba', 'Matias de Albuquerque', 'Fazendinha', '81330-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23794, 'Foz do Iguaçu', 'Matias Peters', 'Centro', '85851-480', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23795, 'Londrina', 'Matilde Alves Sposito', 'Assis', '86085-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23796, 'Castro', 'Matilde Baer', 'Jardim das Nações', '84172-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23797, 'Londrina', 'Matilde Benicio Pinto', 'Nova Olinda', '86073-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23798, 'Foz do Iguaçu', 'Matilde Bez', 'Jardim Califórnia', '85867-509', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23799, 'Piraquara', 'Matilde Montibeller', 'Jardim Santa Helena', '83308-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23800, 'Londrina', 'Matilde Yoshiko Honda', 'Residencial Loris Sahyun', '86040-658', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23801, 'São José dos Pinhais', 'Matinal', 'Guatupê', '83060-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23802, 'Guarapuava', 'Matinhos', 'Jardim das Américas', '85031-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23803, 'Foz do Iguaçu', 'Matinhos', 'Jardim Lancaster V', '85869-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23804, 'Maringá', 'Matinhos', 'Vila Ruth', '87045-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23805, 'Umuarama', 'Matinhos', 'Jardim San Rafael', '87508-147', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23806, 'Telêmaco Borba', 'Matinhos', 'Vila Arcina', '84268-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23807, 'Cambé', 'Matinhos', 'Chácara Santa Maria', '86189-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23808, 'Cascavel', 'Matinhos', 'Periolo', '85817-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23809, 'Almirante Tamandaré', 'Matinhos', 'Jardim Tamboara', '83505-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23810, 'Colombo', 'Matinhos', 'Jardim Cristina', '83410-630', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23811, 'Curitiba', 'Matinhos', 'Alto Boqueirão', '81720-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23812, 'Arapongas', 'Matirão', 'Conjunto Ulisses Guimarães', '86706-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23813, 'Londrina', 'Mato Grosso', 'Centro', '86010-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23814, 'Foz do Iguaçu', 'Mato Grosso', 'Vila Maracanã', '85852-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23815, 'Francisco Beltrão', 'Mato Grosso', 'Presidente Kennedy', '85605-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23816, 'Guarapuava', 'Mato Grosso', 'Dos Estados', '85035-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23817, 'Piraquara', 'Mato Grosso', 'Jardim dos Estados 2', '83308-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23818, 'Piraquara', 'Mato Grosso', 'Jardim dos Estados 1', '83308-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23819, 'Ponta Grossa', 'Mato Grosso', 'Uvaranas', '84025-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23820, 'Piraquara', 'Mato Grosso', 'Jardim dos Estados 3', '83307-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23821, 'Paranaguá', 'Mato Grosso', 'Vila do Povo', '83209-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23822, 'Pato Branco', 'Mato Grosso', 'Baixada', '85501-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23823, 'Paranavaí', 'Mato Grosso', 'Centro', '87702-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23824, 'Maringá', 'Mato Grosso', 'Jardim Alvorada', '87033-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23825, 'Paranavaí', 'Mato Grosso', 'Jardim São João', '87709-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23826, 'Umuarama', 'Mato Grosso', 'Zona II', '87501-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23827, 'São José dos Pinhais', 'Mato Grosso', 'São Domingos', '83030-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23828, 'Apucarana', 'Mato Grosso', 'Jardim Apucarana', '86804-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23829, 'Campo Largo', 'Mato Grosso', 'Ferraria', '83609-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23830, 'Cascavel', 'Mato Grosso', 'São Cristóvão', '85813-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23831, 'Cascavel', 'Mato Grosso', 'Centro', '85812-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23832, 'Campo Mourão', 'Mato Grosso', 'Centro', '87303-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23833, 'Apucarana', 'Mato Grosso', 'Jardim Ponta Grossa', '86805-240', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23834, 'Colombo', 'Mato Grosso', 'Vila Guaraci', '83404-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23835, 'Campo Largo', 'Mato Grosso', 'Ferraria', '83608-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23836, 'Campo Mourão', 'Mato Grosso', 'Jardim Gutierres', '87300-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23837, 'Araucária', 'Mato Grosso', 'Iguaçu', '83701-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23838, 'Curitiba', 'Mato Grosso', 'Água Verde', '80610-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23839, 'Curitiba', 'Mato Grosso', 'Água Verde', '80620-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23840, 'Curitiba', 'Mato Grosso', 'Guaíra', '80630-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23841, 'Guarapuava', 'Mato Grosso do Sul', 'Dos Estados', '85035-550', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23842, 'Campo Largo', 'Mato Preto', 'Ferraria', '83608-670', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23843, 'Arapongas', 'Matraca', 'Jardim Coroados', '86707-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23844, 'Foz do Iguaçu', 'Matrinchã', 'Conjunto A', '85860-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23845, 'Pinhais', 'Matrinchã', 'Loteamento Alphaville Graciosa', '83327-099', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23846, 'Apucarana', 'Matsujiro Takagui', 'Parque Bela Vista', '86803-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23847, 'São José dos Pinhais', 'Matutina', 'Guatupê', '83060-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23848, 'Foz do Iguaçu', 'Mauá', 'Vila Carima', '85855-716', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23849, 'Guarapuava', 'Mauá', 'Boqueirão', '85023-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23850, 'Francisco Beltrão', 'Mauá', 'Pinheirinho', '85603-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23851, 'Maringá', 'Mauá', 'Zona 01', '87013-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23852, 'Paranavaí', 'Mauá', 'Parque Morumbi', '87703-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23853, 'Pato Branco', 'Mauá', 'São Roque', '85507-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23854, 'Maringá', 'Mauá', 'Zona 03', '87050-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23855, 'Toledo', 'Mauá', 'Jardim Paraná', '85904-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23856, 'Telêmaco Borba', 'Mauá', 'Área 02', '84267-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23857, 'Arapongas', 'Mauá', 'Centro', '86701-165', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23858, 'Curitiba', 'Mauá', 'Alto da Glória', '80030-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23859, 'Londrina', 'Mauri Strini', 'Conjunto Novo Amparo 2', '86056-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23860, 'Londrina', 'Maurício Alves da Silva', 'Conjunto Residencial Vale do Arvoredo', '86047-538', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23861, 'Curitiba', 'Maurício Antoniassi', 'Santo Inácio', '82010-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23862, 'Curitiba', 'Maurício Caillet', 'Água Verde', '80250-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23863, 'Foz do Iguaçu', 'Maurício Caneca', 'Vila São Sebastião', '85870-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23864, 'Londrina', 'Maurício César de Oliveira', 'Portal de Versalhes 3', '86055-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23865, 'Londrina', 'Maurício Coelho Lima', 'Santa Rita 3', '86072-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23866, 'Londrina', 'Maurício de Nassau', 'Jardim Europa', '86015-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23867, 'Ponta Grossa', 'Maurício de Nassau', 'Nova Rússia', '84071-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23868, 'Ponta Grossa', 'Maurício de Nassau', 'Nova Rússia', '84070-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23869, 'Londrina', 'Maurício de Paula', 'Residencial Portal do Sol', '86082-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23870, 'Maringá', 'Maurício Donaldo Girardello', 'Jardim Monte Carlo', '87080-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23871, 'Curitiba', 'Maurício Erzirio dos Santos', 'Ganchinho', '81935-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23872, 'Curitiba', 'Maurício Nunes Garcia', 'Jardim Botânico', '80210-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23873, 'Foz do Iguaçu', 'Maurício Resende Rodrigues', 'Condomínio Izadora Parque', '85863-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23874, 'Curitiba', 'Maurício Ricardo dos Santos', 'Cachoeira', '82710-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23875, 'Almirante Tamandaré', 'Maurício Rosemann', 'Jardim Santo Antônio', '83504-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23876, 'São José dos Pinhais', 'Maurício Roslindo Fruet', 'Guatupê', '83060-376', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23877, 'São José dos Pinhais', 'Maurício Scolaro', 'Miringuava', '83090-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23878, 'Curitiba', 'Maurício Thá', 'Uberaba', '81560-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23879, 'Maringá', 'Maurício Venâncio da Silva', 'Conjunto Habitacional Hermann Moraes Barros', '87023-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23880, 'Curitiba', 'Maurilho da Silva', 'Fazendinha', '81330-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23881, 'São José dos Pinhais', 'Maurílio da Cruz', 'Afonso Pena', '83065-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23882, 'Londrina', 'Maurílio Mazzer', 'Ernani de Moura Lima', '86037-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23883, 'Londrina', 'Mauríllio Strini', 'Conjunto Novo Amparo 2', '86056-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23884, 'Londrina', 'Mauritânia', 'Ouro Verde', '86080-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23885, 'Pinhais', 'Mauritânia', 'Vl Dona Guiomar', '83320-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23886, 'Londrina', 'Mauro Bergonse', 'Conjunto Cafezal 3', '86045-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23887, 'Foz do Iguaçu', 'Mauro Dotto', 'Jardim Porto Belo', '85867-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23888, 'Londrina', 'Mauro Ferreira', 'Jardim Portal de Bianca', '86075-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23889, 'Curitiba', 'Mauro Ferreira', 'Cidade Industrial', '81305-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23890, 'Curitiba', 'Mauro Ferreira', 'Cajuru', '82900-280', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23891, 'Londrina', 'Mauro Feu Filgueiras', 'Colinas', '86056-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23892, 'Curitiba', 'Mauro Gonçalves', 'Tatuquara', '81470-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23893, 'Cascavel', 'Mauro Gonçalves', 'Nucleo de Produção III', '85811-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23894, 'Curitiba', 'Mauro Luiz de Matos', 'Cidade Industrial', '81310-437', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23895, 'Curitiba', 'Mauro Martins de Freitas', 'Tatuquara', '81480-166', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23896, 'Curitiba', 'Mauro Orlei Hoffmann', 'Capão da Imbuia', '82810-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23897, 'Campo Largo', 'Mauro Portugal', 'Vila Bancária', '83601-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23898, 'Castro', 'Mauro Rolin de Moura', 'Cantagalo', '84178-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23899, 'Apucarana', 'Mauro Santos', 'Núcleo Habitacional Heitor S Pinheiro', '86806-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23900, 'Castro', 'Mauro Simão', 'Vila Santa Cruz', '84168-028', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23901, 'Cascavel', 'Mauro Tolentino', 'Nova Cidade', '85803-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23902, 'Sarandi', 'Mauro Trindade', 'Jardim Nova Independência', '87114-624', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23903, 'Curitiba', 'Maury de Jesus da Silva', 'Santo Inácio', '82010-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23904, 'Cascavel', 'Mawes', 'Santo Onofre', '85806-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23905, 'Almirante Tamandaré', 'Max Alberto Tiemann', 'Jardim Paris', '83508-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23906, 'Guarapuava', 'Max Buch', 'Conradinho', '85035-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23907, 'Curitiba', 'Max Francisco Stolz Neves', 'Atuba', '82600-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23908, 'Ponta Grossa', 'Max Jacob', 'Cará-cará', '84043-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23909, 'Pinhais', 'Max Oleksissiyn', 'Moradias Perdizes', '83326-716', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23910, 'Maringá', 'Max Richard Curt Philipp', 'Vila Santa Izabel', '87080-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23911, 'Curitiba', 'Max Rosenmann', 'Tingui', '82600-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23912, 'Pinhais', 'Max S. Aichener', 'Vila Tarumã', '83323-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23913, 'Curitiba', 'Max Schrappe', 'Xaxim', '81710-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23914, 'Curitiba', 'Max Schubert', 'Alto Boqueirão', '81720-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23915, 'Curitiba', 'Max Sesselmeir', 'Bairro Alto', '82820-570', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23916, 'Telêmaco Borba', 'Max Staudacher', 'Centro', '84262-340', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23917, 'Ponta Grossa', 'Max Stolz', 'Olarias', '84035-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23918, 'Cascavel', 'Maxakalis', 'Santa Cruz', '85806-006', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23919, 'Colombo', 'Maximiano Fontoura da Silva', 'Jardim Central', '83409-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23920, 'Cambé', 'Maximiano Goes', 'Jardim Vila Rica', '86192-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23921, 'Curitiba', 'Maximiliano Boscardin', 'Fazendinha', '81330-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23922, 'Piraquara', 'Maximiliano Favoretto', 'Suburbana', '83304-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23923, 'Francisco Beltrão', 'Maximiliano Folador', 'Antônio de Paiva Cantelmo', '85603-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23924, 'Telêmaco Borba', 'Maximiliano José Chaves', 'Socomim', '84266-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23925, 'Pinhais', 'Maximiliano Rohrsetzer', 'Vila Emiliano Perneta', '83324-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23926, 'Londrina', 'Maximina Pereira de Souza', 'Conjunto Cafezal 3', '86045-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23927, 'Colombo', 'Maximiniano Betinardi', 'Roseira', '83415-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23928, 'Curitiba', 'Maximinio Baggio', 'Cidade Industrial', '81270-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23929, 'Foz do Iguaçu', 'Maximino Tosi', 'Jardim Festugato', '85864-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23930, 'Curitiba', 'Maximino Zanon', 'Bacacheri', '82510-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23931, 'Curitiba', 'Maximo Asinelli', 'Uberaba', '81560-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23932, 'Araucária', 'Máximo Cantador', 'Centro', '83702-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23933, 'Curitiba', 'Máximo João Kopp', 'Santa Cândida', '82630-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23934, 'Apucarana', 'Máximo Leone Giavarina', 'Vila Shangri-La', '86812-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23935, 'Foz do Iguaçu', 'Máximo Martins', 'Vila Shalon', '85853-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23936, 'Londrina', 'Máximo Menghini', 'Parigot de Souza 2', '86082-245', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23937, 'Curitiba', 'Máximo Pinheiro Lima', 'Vista Alegre', '80820-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23938, 'Londrina', 'Maysa', 'Conjunto Vivi Xavier', '86082-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23939, 'Curitiba', 'Maysa', 'Tatuquara', '81470-247', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23940, 'Pinhais', 'Maysa Matarazzo', 'Vila Maria Antonieta', '83331-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23941, 'Apucarana', 'Maysa Mon Jardim', 'Núcleo Habitacional Castelo Branco', '86812-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23942, 'Foz do Iguaçu', 'M''boicy', 'Jardim Amazonas', '85857-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23943, 'Ponta Grossa', 'Medeiros de Albuquerque', 'Oficinas', '84035-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23944, 'Guarapuava', 'Medeiros e Albuquerque', 'São Cristóvão', '85060-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23945, 'Francisco Beltrão', 'Medelin', 'Aeroporto', '85603-844', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23946, 'Laranjeiras do Sul', 'Medianeira', 'Água Verde', '85302-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23947, 'Foz do Iguaçu', 'Medianeira', 'Parque Residencial Três Fronteiras', '85859-686', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23948, 'Guarapuava', 'Medianeira', 'Jardim das Américas', '85030-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23949, 'Pinhais', 'Medianeira', 'Jardim Alto Tarumã', '83325-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23950, 'São José dos Pinhais', 'Medianeira', 'Afonso Pena', '83045-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23951, 'Toledo', 'Medianeira', 'Jardim Carelli', '85906-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23952, 'Campo Largo', 'Medianeira', 'Vila Rivabem', '83605-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23953, 'Cascavel', 'Medianeira', 'Cataratas', '85816-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23954, 'Cascavel', 'Medianeira', 'Cataratas', '85817-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23955, 'Curitiba', 'Medianeira', 'Boa Vista', '82210-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23956, 'Curitiba', 'Medianeira', 'Sítio Cercado', '81900-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23957, 'Cascavel', 'Medicina', 'Universitário', '85819-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23958, 'Telêmaco Borba', 'Medina', 'Área 06', '84271-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23959, 'Arapongas', 'Megaluro', 'Jardim Baroneza', '86706-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23960, 'Maringá', 'Megumu Tanaka', 'Parque das Grevíleas', '87025-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23962, 'Curitiba', 'Melancias', 'Uberaba', '81560-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23963, 'Ponta Grossa', 'Melanita', 'Neves', '84021-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23964, 'Curitiba', 'Melão', 'Uberaba', '81560-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23965, 'Curitiba', 'Melchíades Fangueiro', 'Juvevê', '80030-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23966, 'Curitiba', 'Melchíades Silveira do Valle', 'São João', '82030-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23967, 'Ponta Grossa', 'Mello de Moraes', 'Jardim Carvalho', '84016-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23968, 'Cambé', 'Mello Peixoto', 'Jardim Tarobá', '86191-410', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23969, 'Arapongas', 'Mello Peixoto', 'Parque Industrial II', '86703-730', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23970, 'Arapongas', 'Mello Peixoto', 'Aricanduva', '86706-420', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23971, 'Cambé', 'Mello Peixoto', 'Jardim União', '86185-700', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23972, 'Cambé', 'Mello Peixoto', 'Jardim Santa Adelaide', '86192-170', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23973, 'Foz do Iguaçu', 'Melro', 'Conjunto A', '85866-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23974, 'Arapongas', 'Melro', 'Vila Nova', '86707-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23975, 'Maringá', 'Melvim Jones', 'Parque Industrial Bandeirantes', '87070-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23976, 'São José dos Pinhais', 'Melvin J. Lions', 'Centro', '83030-510', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23977, 'Ponta Grossa', 'Melvin Jones', 'Chapada', '84062-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23978, 'Cascavel', 'Melvin Jones', 'Periolo', '85817-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23979, 'Apucarana', 'Melvin Jones', 'Vila Nova', '86812-120', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23980, 'Curitiba', 'Melvin Jones', 'Centro Cívico', '80530-220', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23981, 'Londrina', 'Mem de Sá', 'Oguido', '86025-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23982, 'Maringá', 'Mem de Sá', 'Zona 02', '87010-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23983, 'Maringá', 'Mem de Sá', 'Vila Bosque', '87005-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23984, 'Pato Branco', 'Mem de Sá', 'Bortot', '85504-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23985, 'Piraquara', 'Mem de Sá', 'Jardim Bela Vista', '83301-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23986, 'Ponta Grossa', 'Mem de Sá', 'Uvaranas', '84032-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23987, 'Toledo', 'Mem de Sá', 'Jardim Paulista', '85910-216', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23988, 'Telêmaco Borba', 'Mem de Sá', 'Centro', '84261-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23989, 'Guarapuava', 'Men de Sá', 'Alto Cascavel', '85031-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23990, 'Foz do Iguaçu', 'Men de Sá', 'Jardim Festugato', '85864-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23991, 'Colombo', 'Men de Sá', 'Vila Carrano Júnior', '83409-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23992, 'Cascavel', 'Men de Sá', 'Presidente', '85818-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23993, 'Curitiba', 'Men de Sá', 'Lindóia', '81010-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23994, 'Foz do Iguaçu', 'Mena Barreto', 'Parque Presidente', '85863-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23995, 'Colombo', 'Mendel', 'Jardim Campo Alto', '83408-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23996, 'Curitiba', 'Mendelssohn', 'Vista Alegre', '80820-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23997, 'Curitiba', 'Mendes Gonçalves', 'Uberaba', '81580-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23998, 'Ponta Grossa', 'Mendes Leal', 'Colônia Dona Luiza', '84045-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (23999, 'São José dos Pinhais', 'Mendes Leitão', 'Centro', '83005-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24000, 'Ponta Grossa', 'Mendes Timóteo', 'Ronda', '84051-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24001, 'Cambé', 'Mendonça', 'Parque Residencial Ana Rosa', '86183-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24002, 'Maringá', 'Mendonza', 'Vila Morangueira', '87040-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24003, 'Curitiba', 'Menezes Dória', 'Hugo Lange', '80040-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24004, 'Sarandi', 'Menino Jesus', 'Parque Residencial Bom Pastor', '87114-541', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24005, 'Umuarama', 'Menino Jesus', 'Conjunto Residencial Independência', '87508-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24006, 'Curitiba', 'Menino Jesus', 'Xaxim', '81710-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24007, 'Campo Mourão', 'Menon Lapezaki', 'Jardim Izabel', '87309-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24008, 'São José dos Pinhais', 'Menoquina Marochi Pissaia', 'Ipê', '83055-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24009, 'Curitiba', 'Menotti Caprilhone', 'Mercês', '80710-260', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24010, 'Foz do Iguaçu', 'Menotti Del Picchia', 'Jardim Dom Pedro I', '85856-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24011, 'Maringá', 'Menotti Del Picchia', 'Vila Esperança', '87020-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24012, 'Foz do Iguaçu', 'Mercedes', 'Jardim Vale do Sol', '85862-459', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24013, 'Curitiba', 'Mercedes Seiler Rocha', 'Bacacheri', '82520-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24014, 'Curitiba', 'Mercedes Strano Vieira', 'Capão da Imbuia', '82810-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24015, 'Curitiba', 'Mercedes Stresser', 'Bairro Alto', '82820-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24016, 'Ponta Grossa', 'Mercedez Vaz Stanislawczuk', 'Uvaranas', '84025-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24017, 'Foz do Iguaçu', 'Mercês', 'Chácara Dom Emílio', '85853-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24018, 'Londrina', 'Merchet Nassif', 'Indusville', '86031-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24019, 'Curitiba', 'Merchid Belich', 'Bom Retiro', '80520-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24020, 'Foz do Iguaçu', 'Mercosul', 'Jardim Veraneio', '85855-650', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24021, 'Foz do Iguaçu', 'Mercúrio', 'Parque Residencial Três Fronteiras', '85859-675', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24022, 'Londrina', 'Mercúrio', 'Sol', '86070-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24023, 'Maringá', 'Mercúrio', 'Jardim Universo', '87060-570', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24024, 'Ponta Grossa', 'Mercúrio', 'Uvaranas', '84031-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24025, 'Sarandi', 'Mercúrio', 'Jardim Universal', '87114-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24026, 'Telêmaco Borba', 'Mercúrio', 'Nossa Senhora de Fátima', '84264-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24027, 'Apucarana', 'Mercúrio', 'Jardim Vale do Sol', '86803-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24028, 'Cambé', 'Mercúrio', 'Parque Maracanã', '86185-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24029, 'Curitiba', 'Mercúrio', 'Sítio Cercado', '81910-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24030, 'Arapongas', 'Mergulhador', 'Jardim Bandeirantes', '86703-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24031, 'Foz do Iguaçu', 'Mergulhão', 'Conjunto A', '85866-370', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24032, 'Arapongas', 'Mergulhão', 'Centro', '86701-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24033, 'Arapongas', 'Mergulhão-caçador', 'Jardim dos Pássaros', '86702-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24034, 'Arapongas', 'Mesia', 'Jardim Aeroporto', '86702-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24035, 'Londrina', 'Messias de Oliveira', 'Conjunto Habitacional Bronzzetti', '86037-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24036, 'Curitiba', 'Messias de Paula Prestes', 'Xaxim', '81830-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24037, 'Londrina', 'Messias Natal Macarini', 'Tarobá', '86042-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24038, 'Londrina', 'Messias Wilmar de Souza', 'Guaporé', '86025-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24039, 'Ponta Grossa', 'Mestre Balduíno', 'Oficinas', '84045-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24040, 'Sarandi', 'Mestre da Justiça', 'Parque Residencial Bom Pastor', '87114-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24041, 'Sarandi', 'Mestre da Vida', 'Parque Residencial Bom Pastor', '87114-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24042, 'Londrina', 'Mestre Estevam', 'Maria Lúcia', '86072-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24043, 'Paranaguá', 'Mestre Leopoldino', 'Centro Histórico', '83203-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24044, 'Campo Largo', 'Mestre Tucuruvu', 'Vila David Antônio', '83609-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24045, 'Foz do Iguaçu', 'Metais', 'Parque Ouro Verde', '85854-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24046, 'Arapongas', 'Mexeriqueira', 'Jardim Colúmbia IV', '86707-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24047, 'Guarapuava', 'México', 'Morro Alto', '85065-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24048, 'Paranaguá', 'México', 'Jardim América', '83209-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24049, 'Maringá', 'México', 'Vila Morangueira', '87040-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24050, 'Ponta Grossa', 'México', 'Centro', '84040-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24051, 'Paranaguá', 'México', 'Parque Agari', '83215-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24052, 'Pinhais', 'México', 'Vila Progresso', '83320-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24053, 'Paranavaí', 'México', 'Vila São Vicente', '87709-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24054, 'Toledo', 'México', 'Parque Residencial Gisela', '85905-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24055, 'Telêmaco Borba', 'México', 'Alto das Oliveiras', '84266-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24056, 'Cambé', 'México', 'Jardim Primavera', '86181-336', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24057, 'Apucarana', 'México', 'Recanto Mundo Novo', '86805-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24058, 'Cascavel', 'México', 'Periolo', '85817-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24059, 'Apucarana', 'México', 'Jardim Diamantina', '86804-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24060, 'Colombo', 'México', 'Parque São Domingos', '83404-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24061, 'Almirante Tamandaré', 'México', 'Jardim São Francisco', '83501-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24062, 'Almirante Tamandaré', 'México', 'Vila Graziela', '83505-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24063, 'Curitiba', 'México', 'Bacacheri', '82520-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24064, 'Curitiba', 'México', 'Bacacheri', '82510-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24065, 'Londrina', 'Meyer', 'Jardim Higienópolis', '86015-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24066, 'Francisco Beltrão', 'Miami', 'Antônio de Paiva Cantelmo', '85603-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24067, 'Cambé', 'Miami', 'Jardim Flórida II', '86182-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24068, 'Sarandi', 'Miamy', 'Jardim Califórnia', '87112-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24069, 'Apucarana', 'Michael Cernescu', 'Jardim Espanha', '86802-026', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24070, 'Londrina', 'Michael Faraday', 'Industrial', '86063-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24071, 'Castro', 'Michael Kulpa', 'Vila Santa Cruz', '84168-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24072, 'Curitiba', 'Michajlo Pantschenko', 'Cidade Industrial', '81250-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24073, 'Ponta Grossa', 'Michel Elias Farhat', 'Uvaranas', '84031-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24074, 'Guarapuava', 'Michel Feres Mishalany', 'Vila Carli', '85040-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24075, 'Ponta Grossa', 'Michel Laidane', 'Chapada', '84062-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24076, 'Araucária', 'Michel Nahum Saliba', 'Thomaz Coelho', '83707-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24077, 'Pinhais', 'Michel Romaniow', 'Planta Vila Bordignon', '83325-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24078, 'Cambé', 'Michelangelo', 'Jardim Montecatini', '86186-240', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24079, 'Colombo', 'Michelângelo', 'Jardim Campo Alto', '83408-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24080, 'Curitiba', 'Michelângelo', 'Santa Felicidade', '82020-740', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24081, 'Londrina', 'Michigan', 'Iguaçu', '86060-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24082, 'Foz do Iguaçu', 'Mico-leão', 'Conjunto A', '85861-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24083, 'Londrina', 'Midori Koga', 'Maria Lúcia', '86072-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24084, 'Araucária', 'Mieceslau Jasiocha', 'Thomaz Coelho', '83707-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24085, 'São José dos Pinhais', 'Mieczylau Gumiela', 'Guatupê', '83060-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24086, 'Maringá', 'Mieko Imai da Silva', 'Jardim Licce', '87025-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24087, 'São José dos Pinhais', 'Miescelau Grabias', 'Guatupê', '83060-449', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24088, 'Curitiba', 'Miguel Abrão', 'Portão', '81070-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24089, 'São José dos Pinhais', 'Miguel Acsenty Vodonis', 'Afonso Pena', '83050-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24090, 'Castro', 'Miguel Aicar de Sus', 'Jardim Colonial', '84178-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24091, 'Cambé', 'Miguel Aidar', 'Chácara Cambé Londrina', '86189-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24092, 'Araucária', 'Miguel Airton Ribeiro', 'Boqueirão', '83704-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24093, 'Araucária', 'Miguel Aloísio Choinski', 'Costeira', '83708-727', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24094, 'São José dos Pinhais', 'Miguel Alves da Rocha', 'Costeira', '83015-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24095, 'Curitiba', 'Miguel Ângelo Pelanda', 'Umbará', '81930-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24096, 'Umuarama', 'Miguel Ângelo Remor', 'Parque Cidade Jardim', '87506-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24097, 'Cambé', 'Miguel Arraial', 'Jardim Silvino', '86188-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24098, 'Apucarana', 'Miguel Bailak', 'Vila Vitória', '86802-715', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24099, 'Curitiba', 'Miguel Bakum', 'Guabirotuba', '81510-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24100, 'Cascavel', 'Miguel Bakun', 'Independência', '85811-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24101, 'Paranaguá', 'Miguel Baleche', 'Jardim Araçá', '83221-156', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24102, 'Guarapuava', 'Miguel Banhack', 'Industrial', '85045-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24103, 'São José dos Pinhais', 'Miguel Bassa', 'Colônia Murici', '83085-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24104, 'Londrina', 'Miguel Batista', 'Parigot de Souza 2', '86082-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24105, 'Araucária', 'Miguel Bertolino Pizatto', 'Centro', '83702-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24106, 'Araucária', 'Miguel Bertolino Pizatto', 'Iguaçu', '83701-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24107, 'Londrina', 'Miguel Bespalhok', 'Franciscato II', '86078-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24108, 'Piraquara', 'Miguel Bischibich', 'Planta Tamoyo', '83312-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24109, 'Londrina', 'Miguel Blasi', 'Centro', '86010-070', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24110, 'Paranaguá', 'Miguel Brenaz', 'Divinéia', '83212-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24111, 'Curitiba', 'Miguel Brenner', 'Seminário', '80440-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24112, 'Paranaguá', 'Miguel Buffara', 'Costeira', '83203-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24113, 'Ponta Grossa', 'Miguel Calmon', 'Uvaranas', '84025-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24114, 'Curitiba', 'Miguel Caluf', 'Cajuru', '82900-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24115, 'Curitiba', 'Miguel Caluf', 'Cajuru', '82940-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24116, 'Foz do Iguaçu', 'Miguel Carvalho', 'Mutirão', '85858-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24117, 'Curitiba', 'Miguel Chapula', 'Pinheirinho', '81820-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24118, 'Londrina', 'Miguel Chaves Gouvea', 'Arpoador', '86046-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24119, 'Apucarana', 'Miguel Cláudio Moreno', 'Vila São José Bassa', '86809-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24120, 'Londrina', 'Miguel Couto', 'Jardim Tatiani', '86070-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24121, 'Guarapuava', 'Miguel Couto', 'Alto Cascavel', '85031-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24122, 'Maringá', 'Miguel Couto', 'Zona 06', '87015-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24123, 'Ponta Grossa', 'Miguel Couto', 'Orfãs', '84070-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24124, 'Piraquara', 'Miguel Couto', 'Jardim Bela Vista', '83301-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24125, 'Paranavaí', 'Miguel Couto', 'Jardim São Jorge', '87710-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24126, 'Castro', 'Miguel Couto', 'Centro', '84172-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24127, 'Curitiba', 'Miguel Couto', 'Batel', '80440-090', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24128, 'Curitiba', 'Miguel Couto dos Santos', 'Pinheirinho', '81870-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24129, 'Curitiba', 'Miguel de Lazzari', 'Pilarzinho', '82110-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24130, 'Castro', 'Miguel Dias de Macedo', 'Jardim Colonial', '84178-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24131, 'Ponta Grossa', 'Miguel Dropa', 'Cará-cará', '84032-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24132, 'Araucária', 'Miguel Durau', 'Thomaz Coelho', '83707-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24133, 'Curitiba', 'Miguel Felipe Daher', 'Orleans', '82310-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24134, 'Curitiba', 'Miguel Feliz', 'Capão Raso', '81130-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24135, 'Curitiba', 'Miguel Fiori', 'Pilarzinho', '82120-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24136, 'São José dos Pinhais', 'Miguel Foggiatto Sobrinho', 'Cruzeiro', '83010-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24137, 'Londrina', 'Miguel Francisco de Campos', 'Jardim Maracanã', '86056-868', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24138, 'Curitiba', 'Miguel Gaska', 'Capão Raso', '81020-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24139, 'Curitiba', 'Miguel Gasparin', 'Barreirinha', '82560-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24140, 'Guarapuava', 'Miguel Gavanski', 'Vila Bela', '85025-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24141, 'Araucária', 'Miguel Gavleta', 'Costeira', '83709-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24142, 'Guarapuava', 'Miguel Gelinski', 'Boqueirão', '85020-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24143, 'Campo Mourão', 'Miguel Giani', 'Jardim Francisco Ferreira Albuquerque', '87309-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24144, 'Londrina', 'Miguel Gil Ortega', 'Tarobá', '86042-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24145, 'Paranavaí', 'Miguel Gomar', 'Jardim Santos Dumont', '87706-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24146, 'Colombo', 'Miguel Graboski', 'Jardim Guarujá', '83407-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24147, 'Araucária', 'Miguel Grabowski', 'Boqueirão', '83704-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24148, 'São José dos Pinhais', 'Miguel Grassi', 'Guatupê', '83060-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24149, 'Ponta Grossa', 'Miguel Gustavo Schluberg', 'Uvaranas', '84031-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24150, 'São José dos Pinhais', 'Miguel Haluch', 'Rio Pequeno', '83070-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24151, 'Apucarana', 'Miguel Ignacio Souza', 'Vila Social', '86804-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24152, 'Curitiba', 'Miguel Isaacson', 'Jardim Social', '82520-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24153, 'Araucária', 'Miguel Jaraminski', 'São Miguel', '83706-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24154, 'São José dos Pinhais', 'Miguel Jarek', 'Planta Quississana', '83085-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24155, 'Curitiba', 'Miguel Jorge Nasser', 'Tingui', '82620-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24156, 'Londrina', 'Miguel José Alves', 'Avelino A Vieira', '86056-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24157, 'Curitiba', 'Miguel José Grein', 'Xaxim', '81720-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24158, 'Campo Largo', 'Miguel Júlio', 'Jardim Bela Vista', '83605-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24159, 'Curitiba', 'Miguel Júlio', 'Sítio Cercado', '81900-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24160, 'Londrina', 'Miguel Karaksoff', 'Jardim Tókio', '86063-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24161, 'Curitiba', 'Miguel Karam', 'Tarumã', '82800-015', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24162, 'Guarapuava', 'Miguel Kich', 'Primavera', '85050-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24163, 'Guarapuava', 'Miguel Klassar', 'Primavera', '85050-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24164, 'Curitiba', 'Miguel Klutchkovski', 'Pinheirinho', '81870-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24165, 'Curitiba', 'Miguel Laudecir de Oliveira', 'Ganchinho', '81935-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24166, 'Francisco Beltrão', 'Miguel Liston', 'Nossa Senhora Aparecida', '85601-770', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24167, 'São José dos Pinhais', 'Miguel Lopes Filho', 'Guatupê', '83060-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24168, 'Guarapuava', 'Miguel Losso', 'Industrial', '85053-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24169, 'Curitiba', 'Miguel Losso', 'Sítio Cercado', '81920-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24170, 'Piraquara', 'Miguel Lucas Barbetta', 'Planta Campo Largo', '83310-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24171, 'Campo Mourão', 'Miguel Luiz Pereira', 'Jardim Lar Paraná', '87305-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24172, 'Curitiba', 'Miguel Mafuz', 'Abranches', '82220-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24173, 'Cambé', 'Miguel Marana', 'Jardim Santa Adelaide', '86192-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24174, 'Foz do Iguaçu', 'Miguel Matte', 'Jardim Santa Rita', '85862-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24175, 'Curitiba', 'Miguel Metnek', 'Pinheirinho', '81150-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24176, 'Almirante Tamandaré', 'Miguel Muraski', 'Loteamento Recanto dos Papagaios', '83512-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24177, 'Paranaguá', 'Miguel Nicolau Anastácio', 'Raia', '83206-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24178, 'Curitiba', 'Miguel Novicki', 'São Braz', '82315-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24179, 'Curitiba', 'Miguel Odia Fagundes', 'Fazendinha', '81320-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24180, 'Curitiba', 'Miguel Oleskowicz', 'Sítio Cercado', '81910-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24181, 'Pinhais', 'Miguel Ostrufka', 'Moradias Palmital', '83325-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24182, 'Curitiba', 'Miguel Ozório de Almeida', 'Fazendinha', '81330-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24183, 'Curitiba', 'Miguel Parra', 'Mercês', '80710-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24184, 'Pato Branco', 'Miguel Parzianello', 'Pinheirinho', '85506-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24185, 'Londrina', 'Miguel Perez', 'Aquilles Sthengel', '86086-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24186, 'Curitiba', 'Miguel Piekarski', 'Boa Vista', '82540-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24187, 'Curitiba', 'Miguel Piekarski', 'Boa Vista', '82560-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24188, 'Colombo', 'Miguel Piekarz', 'Jardim Ana Rosa I', '83401-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24189, 'Curitiba', 'Miguel Pitaki Júnior', 'Guabirotuba', '81520-615', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24190, 'Araucária', 'Miguel Poenc', 'Tindiquera', '83708-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24191, 'Curitiba', 'Miguel Poholink', 'Hauer', '81610-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24192, 'Almirante Tamandaré', 'Miguel Poppia', 'Pacotuba', '83514-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24193, 'Apucarana', 'Miguel Raduy', 'Jardim São Pedro', '86809-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24194, 'Curitiba', 'Miguel Raicoski Sobrinho', 'Pinheirinho', '81825-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24195, 'Paranaguá', 'Miguel Ribeiro de Araújo', 'Vila São Vicente', '83209-157', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24196, 'Curitiba', 'Miguel Romanel', 'Água Verde', '80620-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24197, 'Umuarama', 'Miguel Rossafa', 'Zona III', '87502-240', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24198, 'Curitiba', 'Miguel Rybinski', 'Uberaba', '81560-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24199, 'Ponta Grossa', 'Miguel Sallum', 'Uvaranas', '84031-525', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24200, 'Almirante Tamandaré', 'Miguel Sarott', 'Vila Grécia', '83502-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24201, 'Campo Mourão', 'Miguel Scharan', 'Jardim Capricórnio', '87301-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24202, 'Apucarana', 'Miguel Shiskovitz', 'Jardim Tibagi', '86813-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24203, 'Apucarana', 'Miguel Simião', 'Centro', '86800-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24204, 'Foz do Iguaçu', 'Miguel Smack', 'Centro', '85851-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24205, 'Curitiba', 'Miguel Spodaryk', 'Pilarzinho', '82100-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24206, 'Castro', 'Miguel Strazzer', 'Jardim das Araucárias', '84174-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24207, 'Curitiba', 'Miguel Suchevicz', 'Barreirinha', '82710-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24208, 'São José dos Pinhais', 'Miguel Sucla', 'Colônia Rio Grande', '83020-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24209, 'Paranaguá', 'Miguel Taufic Name', 'Vila Guadalupe', '83221-558', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24210, 'São José dos Pinhais', 'Miguel Teixeira Franco', 'Guatupê', '83060-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24211, 'Curitiba', 'Miguel Tschannerl', 'Vista Alegre', '80820-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24212, 'Castro', 'Miguel Urso', 'Jardim das Araucárias', '84174-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24213, 'Paranaguá', 'Miguel Veiga', 'Vila do Caic', '83215-690', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24214, 'Pinhais', 'Miguel Victor da Silva Pinto', 'Vila Tarumã', '83323-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24215, 'Piraquara', 'Miguel Vítor da Silva Pinto', 'Vila San Remo I', '83301-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24216, 'Castro', 'Miguel Zahdi', 'Jardim Social Arapongas', '84174-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24217, 'Colombo', 'Miguel Zanon', 'Vila São Paulo', '83411-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24218, 'Araucária', 'Miguel Zdaniak', 'Thomaz Coelho', '83707-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24219, 'Almirante Tamandaré', 'Miguel Zinher', 'Jardim Colonial', '83501-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24220, 'Curitiba', 'Milano', 'São Braz', '82320-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24221, 'Francisco Beltrão', 'Milão', 'Jardim Floresta', '85603-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24222, 'Londrina', 'Milão', 'Parque Residencial João Piza', '86041-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24223, 'Londrina', 'Milão', 'Parque Residencial João Piza', '86041-185', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24224, 'Cambé', 'Milão', 'Residencial Monte Castelo', '86186-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24225, 'Colombo', 'Milão', 'Planta Boros', '83413-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24226, 'Cascavel', 'Milão', 'Cascavel Velho', '85818-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24227, 'Curitiba', 'Milena Costa', 'Pilarzinho', '82100-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24228, 'Arapongas', 'Milhafre', 'Vila Edio', '86705-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24229, 'Paranavaí', 'Miljutin Cogei', 'Jardim Curitiba', '87701-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24230, 'Paranavaí', 'Miljutin Cogei', 'Jardim Nossa Senhora de Fátima', '87708-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24231, 'Pinhais', 'Milton Anselmo da Silva', 'Jardim Cláudia', '83326-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24232, 'Curitiba', 'Milton Camargo Amorim', 'Tatuquara', '81480-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24233, 'Curitiba', 'Milton Camargo de Oliveira', 'São Braz', '82315-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24234, 'Londrina', 'Milton Campos', 'Sebastião de Melo César', '86084-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24235, 'Apucarana', 'Milton Carlos', 'Núcleo Habitacional Castelo Branco', '86812-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24236, 'Curitiba', 'Mílton Carlos', 'Tatuquara', '81470-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24237, 'Curitiba', 'Milton César da Silva', 'Cidade Industrial', '81305-100', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24238, 'Foz do Iguaçu', 'Milton da Costa', 'Parque Residencial Três Bandeiras', '85862-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24239, 'Curitiba', 'Milton Derviche', 'Tatuquara', '81470-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24240, 'Maringá', 'Milton Eduardo Luders', 'Conjunto João de Barro Itaparica', '87043-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24241, 'Foz do Iguaçu', 'Milton Ferreira Souza', 'Porto Belo', '85867-636', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24242, 'Londrina', 'Milton Gavetti', 'Universitário', '86050-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24243, 'Paranavaí', 'Milton Gonçalves', 'Jardim Campo Grande', '87709-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24244, 'Umuarama', 'Milton Henrique Pizzaia', 'Jardim Canadá', '87505-185', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24245, 'Ponta Grossa', 'Milton Hilgemberg', 'Ronda', '84051-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24246, 'Curitiba', 'Milton Machado', 'Uberaba', '81590-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24247, 'Curitiba', 'Milton Miramir Visinoni', 'Sítio Cercado', '81920-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24248, 'Paranaguá', 'Milton Miro Vernalha', 'Vila dos Comerciários', '83215-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24249, 'Curitiba', 'Milton Portugal Lobato', 'Santa Cândida', '82640-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24250, 'Foz do Iguaçu', 'Milton Ramos', 'Parque Presidente II', '85863-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24251, 'Guarapuava', 'Milton Ribeiro da Silva', 'Industrial Xarquinho', '85053-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24252, 'Paranaguá', 'Milton Rodrigues dos Santos', 'Eldorado', '83206-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24253, 'Apucarana', 'Milton Sence', 'Loteamento Marília', '86812-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24254, 'Londrina', 'Milton Solci', 'Estados', '86083-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24255, 'Sarandi', 'Milton Tavares Paes', 'Parque Alvamar', '87113-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24256, 'Colombo', 'Milton Tosin', 'Jardim Arapongas', '83402-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24257, 'Umuarama', 'Mimosa', 'Jardim Tangará', '87501-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24258, 'Ponta Grossa', 'Mimosas', 'Chapada', '84064-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24259, 'Telêmaco Borba', 'Mina de Carvão', 'Área 02', '84267-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24260, 'Telêmaco Borba', 'Mina de Prata', 'Área 03', '84271-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24261, 'Guarapuava', 'Minas Gerais', 'Dos Estados', '85035-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24262, 'Foz do Iguaçu', 'Minas Gerais', 'Vila Maracanã', '85852-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24263, 'Londrina', 'Minas Gerais', 'Centro', '86010-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24264, 'Laranjeiras do Sul', 'Minas Gerais', 'Água Verde', '85302-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24265, 'Francisco Beltrão', 'Minas Gerais', 'Alvorada', '85601-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24266, 'Piraquara', 'Minas Gerais', 'Jardim dos Estados 2', '83308-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24267, 'Piraquara', 'Minas Gerais', 'Jardim dos Estados 3', '83307-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24268, 'Piraquara', 'Minas Gerais', 'Jardim dos Estados 1', '83308-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24269, 'Paranaguá', 'Minas Gerais', 'Vila do Povo', '83209-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24270, 'Paranavaí', 'Minas Gerais', 'Centro', '87702-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24271, 'Paranavaí', 'Minas Gerais', 'Centro', '87701-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24272, 'Pato Branco', 'Minas Gerais', 'Anchieta', '85501-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24273, 'Ponta Grossa', 'Minas Gerais', 'Boa Vista', '84070-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24274, 'Maringá', 'Minas Gerais', 'Vila Emília', '87010-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24275, 'Toledo', 'Minas Gerais', 'Jardim Porto Alegre', '85906-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24276, 'Umuarama', 'Minas Gerais', 'Zona II', '87501-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24277, 'Telêmaco Borba', 'Minas Gerais', 'Nossa Senhora de Fátima', '84264-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24278, 'São José dos Pinhais', 'Minas Gerais', 'São Domingos', '83030-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24279, 'Cascavel', 'Minas Gerais', 'Centro', '85812-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24280, 'Cascavel', 'Minas Gerais', 'São Cristóvão', '85813-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24281, 'Campo Largo', 'Minas Gerais', 'Vila Itaqui', '83604-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24282, 'Araucária', 'Minas Gerais', 'Costeira', '83709-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24283, 'Apucarana', 'Minas Gerais', 'Jardim Governador Lupion', '86808-015', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24284, 'Colombo', 'Minas Gerais', 'Vila Guaraci', '83404-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24285, 'Apucarana', 'Minas Gerais', 'Vila São Miguel', '86812-490', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24286, 'Apucarana', 'Minas Gerais', 'Núcleo Habitacional Adriano Correia', '86813-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24287, 'Apucarana', 'Minas Gerais', 'Jardim Apucarana', '86804-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24288, 'Curitiba', 'Minas Gerais', 'Guaíra', '80630-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24289, 'Almirante Tamandaré', 'Minas Nova', 'Jardim Ipê', '83505-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24290, 'Foz do Iguaçu', 'Mineirão', 'Portal da Foz', '85859-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24291, 'Arapongas', 'Mineirinho', 'Conjunto Ulisses Guimarães', '86706-658', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24292, 'Foz do Iguaçu', 'Mineiros', 'Jardim Lancaster V', '85869-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24293, 'Piraquara', 'Minervino de Oliveira e Souza', 'Borda do Campo', '83304-426', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24294, 'Londrina', 'Minervino Luiz de Oliveira', 'Jardim dos Alpes III', '86045-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24295, 'Londrina', 'Minezo Matsudo', 'Jardim Pioneiros', '86036-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24296, 'Francisco Beltrão', 'Miniguaçu', 'Luther King', '85605-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24297, 'Maringá', 'Ministro Antônio Oliveira Salazar', 'Zona 02', '87010-510', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24298, 'São José dos Pinhais', 'Ministro Aramis Athayde', 'Guatupê', '83065-280', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24299, 'Curitiba', 'Ministro Flávio Suplicy de Lacerda', 'Sítio Cercado', '81925-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24300, 'Curitiba', 'Ministro Gabriel Passos', 'Jardim das Américas', '81530-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24301, 'Curitiba', 'Ministro Gabriel Passos', 'Guabirotuba', '81520-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24302, 'Curitiba', 'Ministro José Linhares', 'Bairro Alto', '82820-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24303, 'Toledo', 'Ministro Lima Cirne', 'Conjunto Habitacional Britânia', '85904-460', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24304, 'Toledo', 'Ministro Lima Cirne', 'Coopagro', '85903-590', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24305, 'Toledo', 'Ministro Lima Cirne', 'Coopagro', '85902-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24306, 'Toledo', 'Ministro Marcos Freire', 'Conjunto Residencial Tocantins', '85903-366', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24307, 'Curitiba', 'Ministro Marcos Freire', 'São Braz', '82015-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24308, 'Paranavaí', 'Ministro Nelson Hungria', 'Jardim Iguaçu', '87705-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24309, 'Umuarama', 'Ministro Oliveira Salazar', 'Zona III', '87502-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24310, 'Umuarama', 'Ministro Oliveira Salazar', 'Zona II', '87501-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24311, 'Toledo', 'Ministro Petrônio Portela', 'Panorama', '85911-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24312, 'Londrina', 'Minneapolis', 'Lima Azevedo', '86060-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24313, 'Ponta Grossa', 'Minuano', 'Cará-cará', '84043-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24314, 'Arapongas', 'Miolinho', 'Conjunto Centauro', '86709-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24315, 'Araucária', 'Miosótis', 'Campina da Barra', '83709-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24316, 'Telêmaco Borba', 'Mira Cete', 'Fazenda Limeira', '84271-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24317, 'Colombo', 'Miracema', 'Vila Campo Alto', '83408-319', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24318, 'São José dos Pinhais', 'Mirador', 'São Cristóvão', '83040-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24319, 'Colombo', 'Mirador', 'Planta Rio Negro', '83410-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24320, 'Curitiba', 'Mirador', 'Alto Boqueirão', '81770-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24321, 'Toledo', 'Miraldo Pedro Zibetti', 'Jardim Santa Maria', '85903-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24322, 'Telêmaco Borba', 'Miranda', 'Área 02', '84267-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24323, 'Foz do Iguaçu', 'Mirandópolis', 'Jardim Ipê III', '85869-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24324, 'Londrina', 'Miraselva', 'Lindóia', '86031-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24325, 'Colombo', 'Miraselva', 'Jardim São José', '83410-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24326, 'Curitiba', 'Miraselva', 'Alto Boqueirão', '81720-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24327, 'Cambé', 'Mirasol', 'Jardim São Paulo', '86191-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24328, 'Sarandi', 'Miriam Satimi Ilda', 'Parque São Pedro', '87112-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24329, 'Foz do Iguaçu', 'Mirim', 'Vila São João', '85862-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24330, 'Telêmaco Borba', 'Mirim', 'Vila Santa Rita', '84263-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24331, 'Araucária', 'Mirtes Costa Trauczynski', 'Estação', '83705-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24332, 'Londrina', 'Mirtes Martins Moraes Rego', 'Portal de Versalhes 3', '86055-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24333, 'Cascavel', 'Misael Mendonça', 'Santa Felicidade', '85803-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24334, 'Maringá', 'Miss Maria Marta Mantovani', 'Jardim Ouro Cola', '87070-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24335, 'Campo Mourão', 'Miss Yolanda Pereira', 'Jardim Lar Paraná', '87305-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24336, 'Guarapuava', 'Missal', 'Vila Carli', '85040-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24337, 'Foz do Iguaçu', 'Missal', 'Jardim Ipê', '85869-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24338, 'São José dos Pinhais', 'Missionários do Verbo Divino', 'Três Marias', '83030-705', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24339, 'São José dos Pinhais', 'Mitcheslau Magnuskei', 'Guatupê', '83060-209', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24340, 'Londrina', 'Mitomu Simamura', 'Novo Amparo', '86043-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24341, 'Londrina', 'Mitsuge Ohara', 'Conjunto Café', '86038-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24342, 'Toledo', 'Mitsugoro Tanaka', 'Coopagro', '85903-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24343, 'Londrina', 'Mitsuko Kikuta', 'Colinas', '86056-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24344, 'Apucarana', 'Mitsuo Hayashi', 'Centro', '86800-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24345, 'Londrina', 'Mitsuo Takahara', 'Jardim Itatiaia 2', '86047-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24346, 'Maringá', 'Mitsuzo Taguchi', 'Vila Nova', '87045-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24347, 'Londrina', 'Mituo Morita', 'Conjunto Habitacional  Alexandre Urbanas', '86037-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24348, 'Londrina', 'Miyake Takemi', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24349, 'Arapongas', 'Moa', 'Vila Bernardes', '86705-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24350, 'Ponta Grossa', 'Moabe', 'Jardim Carvalho', '84016-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24351, 'Cascavel', 'Moacir Bordignon', 'Periolo', '85817-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24352, 'Umuarama', 'Moacir Colognesi', 'Jardim Petrópolis', '87506-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24353, 'Pato Branco', 'Moacir de Jesus Martins', 'Aeroporto', '85503-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24354, 'Londrina', 'Moacir Duin', 'Tucano', '86047-156', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24355, 'Curitiba', 'Moacir Edison Ferreira', 'Cidade Industrial', '81450-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24356, 'Castro', 'Moacir Elias Fadel', 'Jardim das Araucárias', '84172-590', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24357, 'Ponta Grossa', 'Moacir Lazzarotto de Oliveira', 'Chapada', '84063-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24358, 'Londrina', 'Moacir Nabor Leonel', 'Avelino A Vieira', '86056-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24359, 'Curitiba', 'Moacir Potier', 'Xaxim', '81710-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24360, 'Londrina', 'Moacir Silveira Vallin', 'Santiago', '86071-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24361, 'São José dos Pinhais', 'Moacir Tomelin', 'Colônia Rio Grande', '83025-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24362, 'Curitiba', 'Moacir Vieira Gomes', 'Campo Comprido', '81270-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24363, 'Almirante Tamandaré', 'Moacyr de Mello', 'Jardim Josiane', '83504-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24364, 'Londrina', 'Moacyr Teixeira', 'Terra de Santana (I E II)', '86055-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24365, 'Guarapuava', 'Moara', 'São Cristóvão', '85063-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24366, 'Cascavel', 'Mobral', 'Maria Luiza', '85819-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24367, 'Curitiba', 'Mobral', 'Santa Cândida', '82720-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24368, 'Londrina', 'Moçambique', 'São Lourenço', '86026-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24369, 'Pinhais', 'Moçambique', 'Vila Varginha', '83320-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24370, 'Colombo', 'Moçambique', 'Vila Alto da Cruz II', '83405-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24371, 'Telêmaco Borba', 'Mocidade Alegre', 'Vila Cristina', '84272-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24372, 'Arapongas', 'Mocinha-branca', 'Conjunto Águias', '86704-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24373, 'Cambé', 'Modena', 'Jardim Montecatini', '86186-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24374, 'Guarapuava', 'Moderno', 'Morro Alto', '85065-487', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24375, 'Curitiba', 'Modesto Piccoli', 'Tingui', '82600-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24376, 'Pato Branco', 'Modesto Vigano', 'Bortot', '85504-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24377, 'Guarapuava', 'Moema', 'São Cristóvão', '85063-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24378, 'Paranavaí', 'Moema', 'Jardim Santos Dumont', '87706-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24379, 'Telêmaco Borba', 'Moema', 'Centro', '84261-700', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24380, 'Guarapuava', 'Mogi das Cruzes', 'Primavera', '85050-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24381, 'Umuarama', 'Mogi das Cruzes', 'Parque Tarumã', '87508-226', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24382, 'Londrina', 'Mogno', 'Leonor', '86071-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24383, 'Foz do Iguaçu', 'Mogno', 'Jardim Ipanema', '85862-317', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24384, 'Ponta Grossa', 'Mogno', 'Uvaranas', '84033-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24385, 'Maringá', 'Mogno', 'Jardim Pinheiros III', '87043-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24386, 'Umuarama', 'Mogno', 'Jardim Paineiras', '87503-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24387, 'Cascavel', 'Mogno', 'Recanto Tropical', '85807-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24388, 'Colombo', 'Mogno', 'Parque do Embu', '83414-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24389, 'Foz do Iguaçu', 'Mohamad Ali El Fakih', 'Jardim Dona Leila', '85856-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24390, 'Paranaguá', 'Mohamad Hamud Hamud', 'Vila dos Comerciários', '83215-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24391, 'Foz do Iguaçu', 'Mohamad M. Osman', 'Jardim Dom Miguel Osman', '85856-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24392, 'Telêmaco Borba', 'Moinho Velho', 'Área 02', '84267-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24393, 'Umuarama', 'Moisés', 'Parque Dom Pedro II', '87508-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24394, 'Curitiba', 'Moisés Amaro da Luz', 'Tatuquara', '81480-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24395, 'Almirante Tamandaré', 'Moisés Dalazuana', 'Loteamento Formoso', '83514-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24396, 'Castro', 'Moisés de Oliveira Mello', 'Jardim das Araucárias', '84174-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24397, 'Curitiba', 'Moisés Ferreira', 'Pinheirinho', '81880-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24398, 'Araucária', 'Moisés Fialla', 'Costeira', '83708-747', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24399, 'Foz do Iguaçu', 'Moisés Lucareli', 'Parque Morumbi', '85858-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24400, 'Foz do Iguaçu', 'Moisés Lupion', 'Conjunto Residencial Apora', '85869-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24401, 'Maringá', 'Moisés Marcondes', 'Zona 02', '87010-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24402, 'Piraquara', 'Moisés Marcondes de Albuquerque', 'Jardim dos Estados 2', '83308-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24403, 'Foz do Iguaçu', 'Moisés Marquard', 'Jardim Eldorado', '85853-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24404, 'Curitiba', 'Moisés Pereira dos Santos', 'Santa Cândida', '82720-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24405, 'Curitiba', 'Moisés Saif', 'Pilarzinho', '82100-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24406, 'Londrina', 'Mokichi Nezen', 'Residencial Loris Sahyun', '86040-607', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24407, 'Ponta Grossa', 'Moldavita', 'Neves', '84021-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24408, 'Guarapuava', 'Mombiara', 'São Cristóvão', '85063-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24409, 'Arapongas', 'Momota', 'Vila Aparecida', '86707-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24410, 'Londrina', 'Mônaco', 'Jardim Adriana II', '86046-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24411, 'Umuarama', 'Mônaco', 'Parque Bonfim', '87507-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24412, 'Telêmaco Borba', 'Mônaco', 'Nossa Senhora do Perpétuo Socorro', '84265-140', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24413, 'Toledo', 'Mônaco', 'Jardim Piccinin', '85904-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24414, 'Cascavel', 'Mônaco', 'Interlagos', '85814-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24415, 'Londrina', 'Monções', 'Larsen', '86010-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24416, 'Foz do Iguaçu', 'Mondai', 'Chácara Dom Emílio', '85853-725', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24417, 'Colombo', 'Monge Guido de Azevedo', 'Jardim Planalto', '83409-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24418, 'Cambé', 'Monge Mariana', 'Planta São Francisco', '86182-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24419, 'Piraquara', 'Monjoleiro', 'Vila Santa Maria', '83306-316', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24420, 'Telêmaco Borba', 'Monjoleiro', 'Área 01', '84268-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24421, 'Cascavel', 'Monjoleiro', 'Recanto Tropical', '85807-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24422, 'Telêmaco Borba', 'Monjolinho', 'Área 02', '84267-430', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24423, 'Foz do Iguaçu', 'Monjolo', 'Loteamento Campos do Iguaçu', '85857-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24424, 'Maringá', 'Monlevade', 'Zona 10', '87030-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24425, 'Curitiba', 'Monsenhor Alfredo de Arruda Câmara', 'Tatuquara', '81480-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24426, 'Campo Largo', 'Monsenhor Aluísio Domanski', 'Centro', '83601-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24427, 'Maringá', 'Monsenhor Bernardo Cnudde', 'Zona 07', '87030-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24428, 'Curitiba', 'Monsenhor Boleslau Falarz', 'Cidade Industrial', '81280-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24429, 'Curitiba', 'Monsenhor Celso', 'Centro', '80010-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24430, 'Guarapuava', 'Monsenhor Celso Itiberê da Cunha', 'Conradinho', '85045-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24431, 'Curitiba', 'Monsenhor Dunand', 'Uberaba', '81590-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24432, 'Curitiba', 'Monsenhor Francisco Gorski', 'Água Verde', '80240-225', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24433, 'Maringá', 'Monsenhor Fritz', 'Conjunto Habitacional Requião', '87047-449', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24434, 'Foz do Iguaçu', 'Monsenhor Guilherme', 'Jardim São Paulo II', '85856-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24435, 'Cascavel', 'Monsenhor Guilherme N. Thiletzek', 'Periolo', '85817-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24436, 'Curitiba', 'Monsenhor Isidoro Mikosz', 'Cachoeira', '82220-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24437, 'Curitiba', 'Monsenhor Ivo Zanlorenzi', 'Mossunguê', '81210-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24438, 'Curitiba', 'Monsenhor Ivo Zanlorenzi', 'Campina do Siqueira', '80740-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24439, 'Curitiba', 'Monsenhor Ivo Zanlorenzi', 'Cidade Industrial', '81280-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24440, 'Curitiba', 'Monsenhor José Maria Escrivá de Balaguer', 'Tatuquara', '81480-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24441, 'Araucária', 'Monsenhor José Nock', 'Thomaz Coelho', '83706-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24442, 'Maringá', 'Monsenhor Kimura', 'Vila Cleópatra', '87010-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24443, 'Curitiba', 'Monsenhor Lamartine', 'Jardim das Américas', '81540-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24444, 'Curitiba', 'Monsenhor Manoel Vicente', 'Água Verde', '80620-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24445, 'Curitiba', 'Monsenhor Scalabrini', 'Santa Felicidade', '82410-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24446, 'Maringá', 'Monsenhor Tanaka', 'Jardim Itapuã', '87010-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24447, 'Maringá', 'Monsueto', 'Conjunto Residencial Cidade Alta', '87053-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24448, 'Foz do Iguaçu', 'Montaha Osman', 'Jardim Dona Fátima Osman', '85856-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24449, 'Francisco Beltrão', 'Monte Alegre', 'São Cristóvão', '85601-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24450, 'Telêmaco Borba', 'Monte Alegre', 'Centro', '84261-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24451, 'Toledo', 'Monte Alegre', 'Boa Esperança', '85909-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24452, 'Almirante Tamandaré', 'Monte Alegre', 'Jardim Ipê', '83505-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24453, 'Ponta Grossa', 'Monte Alverne', 'Jardim Carvalho', '84016-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24454, 'Telêmaco Borba', 'Monte Belo', 'Jardim Bonavila', '84264-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24455, 'Maringá', 'Monte Caceros', 'Zona 03', '87050-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24456, 'Londrina', 'Monte Carlo', 'Conjunto Oscavo Gomes Santos', '86046-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24457, 'Maringá', 'Monte Carlo', 'Jardim Novo Horizonte', '87010-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24458, 'Toledo', 'Monte Carlo', 'Boa Esperança', '85909-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24459, 'Curitiba', 'Monte Carmelo', 'Pinheirinho', '81825-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24460, 'Foz do Iguaçu', 'Monte Castelo', 'Jardim Itamaraty', '85863-080', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24461, 'Londrina', 'Monte Castelo', 'Jardim Higienópolis', '86015-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24462, 'Laranjeiras do Sul', 'Monte Castelo', 'São Francisco', '85303-370', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24463, 'Piraquara', 'Monte Castelo', 'Jardim Bela Vista', '83301-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24464, 'Toledo', 'Monte Castelo', 'Boa Esperança', '85909-196', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24465, 'Telêmaco Borba', 'Monte Castelo', 'Centro', '84261-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24466, 'Cambé', 'Monte Castelo', 'Jardim Alvorada', '86191-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24467, 'Cascavel', 'Monte Castelo', 'Maria Luiza', '85819-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24468, 'Curitiba', 'Monte Castelo', 'Tarumã', '82530-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24469, 'Sarandi', 'Monte das Oliveiras', 'Parque Residencial Bom Pastor', '87114-542', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24470, 'Curitiba', 'Monte das Oliveiras', 'Pinheirinho', '81825-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24471, 'Maringá', 'Monte Everest', 'Residencial Regente', '87045-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24472, 'Curitiba', 'Monte Hermom', 'Pinheirinho', '81825-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24473, 'Curitiba', 'Monte Nebo', 'Pinheirinho', '81825-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24474, 'Cascavel', 'Monte Negro', 'Morumbi', '85817-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24475, 'Maringá', 'Monte Pascoal', 'Zona 02', '87010-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24476, 'Foz do Iguaçu', 'Monte Roraima', 'Jardim Eldorado', '85853-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24477, 'Almirante Tamandaré', 'Monte Sião', 'Jardim Miragem', '83505-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24478, 'Curitiba', 'Monte Sião', 'Pinheirinho', '81825-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24479, 'Curitiba', 'Monte Sinai', 'Pinheirinho', '81825-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24480, 'Laranjeiras do Sul', 'Monteiro Lobato', 'Getúlio Vargas', '85304-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24481, 'Londrina', 'Monteiro Lobato', 'Jardim Tatiani', '86070-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24482, 'Guarapuava', 'Monteiro Lobato', 'Boqueirão', '85020-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24483, 'Foz do Iguaçu', 'Monteiro Lobato', 'Vila Portes', '85865-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24484, 'Francisco Beltrão', 'Monteiro Lobato', 'São Miguel', '85602-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24485, 'Ponta Grossa', 'Monteiro Lobato', 'Jardim Carvalho', '84015-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24486, 'Pato Branco', 'Monteiro Lobato', 'Jardim Primavera', '85502-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24487, 'Paranavaí', 'Monteiro Lobato', 'Jardim André Luiz', '87708-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24488, 'Maringá', 'Monteiro Lobato', 'Zona 08', '87050-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24489, 'Ponta Grossa', 'Monteiro Lobato', 'Jardim Carvalho', '84016-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24490, 'Pinhais', 'Monteiro Lobato', 'Núcleo Colonial de Pinhais', '83321-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24491, 'Paranavaí', 'Monteiro Lobato', 'Jardim São Jorge', '87711-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24492, 'Paranavaí', 'Monteiro Lobato', 'Jardim São Jorge', '87710-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24493, 'São José dos Pinhais', 'Monteiro Lobato', 'Colônia Rio Grande', '83025-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24494, 'Umuarama', 'Monteiro Lobato', 'Zona I-A', '87504-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24495, 'Telêmaco Borba', 'Monteiro Lobato', 'Socomim', '84265-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24496, 'Toledo', 'Monteiro Lobato', 'Jardim Bela Vista', '85908-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24497, 'Almirante Tamandaré', 'Monteiro Lobato', 'Vila Marta', '83508-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24498, 'Colombo', 'Monteiro Lobato', 'Planta Teixeira de Lara', '83409-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24499, 'Apucarana', 'Monteiro Lobato', 'Jardim Marabá', '86808-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24500, 'Curitiba', 'Monteiro Lobato', 'Centro', '80430-130', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24501, 'Curitiba', 'Monteiro Tourinho', 'Bacacheri', '82600-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24502, 'Colombo', 'Montemor', 'Parque Residencial Santa Terezinha', '83408-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24503, 'São José dos Pinhais', 'Montemor-o-velho', 'São Pedro', '83005-475', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24504, 'Telêmaco Borba', 'Montes Claros', 'Área 06', '84271-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24505, 'Umuarama', 'Montes Claros', 'Jardim Cidade Alta', '87502-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24506, 'Umuarama', 'Montes Claros', 'Jardim Tamoio', '87505-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24507, 'Almirante Tamandaré', 'Montes Claros', 'Vila Feliz', '83505-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24508, 'Guarapuava', 'Montes de Oca', 'Boqueirão', '85023-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24509, 'Londrina', 'Montese', 'Jardim Higienópolis', '86015-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24510, 'Curitiba', 'Montese', 'Parolin', '80220-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24511, 'Curitiba', 'Montesquieu', 'Barreirinha', '82700-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24512, 'Maringá', 'Montevidéo', 'Vila Morangueira', '87030-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24513, 'Paranaguá', 'Montevidéo', 'Parque Agari', '83215-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24514, 'Guarapuava', 'Montevidéu', 'Santana', '85070-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24515, 'Londrina', 'Montevidéu', 'Guanabara', '86050-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24516, 'Francisco Beltrão', 'Montevidéu', 'Miniguaçu', '85605-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24517, 'Foz do Iguaçu', 'Montevidéu', 'Jardim Alice II', '85858-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24518, 'Sarandi', 'Montevidéu', 'Jardim Castelo', '87112-580', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24519, 'Telêmaco Borba', 'Montevidéu', 'Nossa Senhora de Fátima', '84264-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24520, 'Umuarama', 'Montevidéu', 'Jardim Los Angeles', '87509-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24521, 'Colombo', 'Montevidéu', 'Planta Cristóvão Colombo', '83404-510', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24522, 'Curitiba', 'Montezuma', 'Santa Cândida', '82630-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24523, 'Foz do Iguaçu', 'Montreal', 'Jardim Alice II', '85858-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24524, 'Maringá', 'Montreal', 'Jardim Canadá', '87080-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24525, 'Sarandi', 'Montreal', 'Jardim Panorama', '87113-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24526, 'Cascavel', 'Monza', 'Interlagos', '85814-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24527, 'Maringá', 'Mooca', 'Zona 07', '87020-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24528, 'Sarandi', 'Mooca', 'Parque Residencial Nova Aliança', '87111-718', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24529, 'Apucarana', 'Mooca', 'Jardim América', '86807-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24530, 'Maringá', 'Morangueira', 'Jardim Alvorada', '87033-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24531, 'Maringá', 'Morangueira', 'Jardim Alvorada', '87035-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24532, 'Maringá', 'Morangueira', 'Parque Industrial 200', '87035-570', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24533, 'Maringá', 'Morangueira', 'Zona 07', '87030-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24534, 'Sarandi', 'Morangueira', 'Jardim Universal', '87114-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24535, 'Londrina', 'Moreira Cabral', 'Jardim Londrilar', '86010-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24536, 'Guarapuava', 'Moreira Sales', 'Boqueirão', '85022-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24537, 'Pinhais', 'Moreira Sales', 'Planta Portal da Serra', '83325-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24538, 'Curitiba', 'Moreira Sales', 'Sítio Cercado', '81910-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24539, 'Toledo', 'Moreira Salles', 'Jardim Laranjeiras', '85909-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24540, 'Guarapuava', 'Morel Roseira Ribas', 'Jardim das Américas', '85031-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24541, 'Foz do Iguaçu', 'Morenitas', 'Jardim das Flores', '85855-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24542, 'Curitiba', 'Moreno Roseira Penteado de Almeida', 'Bacacheri', '82600-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24543, 'Pinhais', 'Morlei Manoel da Rosa', 'Moradias Palmital', '83325-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24544, 'Guarapuava', 'Morretes', 'Boqueirão', '85022-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24545, 'Laranjeiras do Sul', 'Morretes', 'Água Verde', '85302-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24546, 'Londrina', 'Morretes', 'Vitória', '86060-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24547, 'Foz do Iguaçu', 'Morretes', 'Vila Carima', '85855-718', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24548, 'Piraquara', 'Morretes', 'Planta Araçatuba', '83301-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24549, 'São José dos Pinhais', 'Morretes', 'Braga', '83020-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24550, 'Telêmaco Borba', 'Morretes', 'Nossa Senhora do Perpétuo Socorro', '84265-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24551, 'Toledo', 'Morretes', 'Jardim Bressan', '85913-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24552, 'Colombo', 'Morretes', 'Vila São José', '83410-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24553, 'Cascavel', 'Morretes', 'Universitário', '85819-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24554, 'Curitiba', 'Morretes', 'Portão', '80610-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24555, 'Foz do Iguaçu', 'Morrinhos', 'Loteamento Witt', '85862-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24556, 'Umuarama', 'Morro Bonito', 'Jardim San Martim', '87508-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24557, 'Umuarama', 'Morumbi', 'Jardim Kennedy', '87508-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24558, 'Maringá', 'Moscados', 'Vila Marumby', '87005-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24559, 'Arapongas', 'Moscareira', 'Vila Bernardes', '86705-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24560, 'Guarapuava', 'Moscou', 'Santana', '85070-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24561, 'Ponta Grossa', 'Moserote', 'Jardim Carvalho', '84016-717', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24562, 'Cascavel', 'Mosport', 'Interlagos', '85814-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24563, 'Arapongas', 'Mosqueteirinho', 'Conjunto Flamingos III', '86703-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24564, 'Arapongas', 'Mosqueteiro', 'Conjunto Tropical', '86702-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24565, 'Arapongas', 'Mosqueteiro-de-topete-vermelho', 'Jardim Astúrias', '86705-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24566, 'Foz do Iguaçu', 'Mosquitinho', 'Jardim Oriente', '85855-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24567, 'Londrina', 'Mossoró', 'Centro', '86020-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24568, 'Piraquara', 'Mossoró', 'Jardim Primavera', '83302-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24569, 'Curitiba', 'Mounif Tacla', 'Ahú', '82200-400', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24570, 'Maringá', 'Mourão', 'Parque das Grevíleas', '87025-230', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24571, 'Curitiba', 'Moyses de Oliveira', 'Guabirotuba', '81510-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24572, 'Curitiba', 'Moyses Guelmann', 'Novo Mundo', '81050-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24573, 'Curitiba', 'Moyses Gutztein', 'Sítio Cercado', '81925-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24574, 'Curitiba', 'Moyses Marcondes', 'Juvevê', '80030-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24575, 'Curitiba', 'Moyses Marcondes', 'Juvevê', '80530-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24576, 'Curitiba', 'Moyses Martins', 'Guabirotuba', '81510-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24577, 'Londrina', 'Moyzes Betoni', 'Jardim Paris', '86082-098', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24578, 'Curitiba', 'Mozart Correia de Souza Pinto', 'Santa Felicidade', '82410-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24579, 'Arapongas', 'Mucho', 'Jardim Morumbi', '86708-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24580, 'Maringá', 'Múcio Leão', 'Vila Esperança', '87020-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24581, 'Foz do Iguaçu', 'Mucuripe', 'Jardim Manaus', '85857-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24582, 'Foz do Iguaçu', 'Mundau', 'Três Lagoas', '85862-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24583, 'Pato Branco', 'Munhoz da Rocha', 'Menino Deus', '85502-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24584, 'Ponta Grossa', 'Munhoz da Rocha', 'Centro', '84010-130', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24585, 'Curitiba', 'Munhoz da Rocha', 'Cabral', '80035-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24586, 'Ponta Grossa', 'Munhoz de Mello', 'Jardim Carvalho', '84016-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24587, 'Arapongas', 'Municipal', 'Jardim Baroneza', '86706-320', 'Estádio', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24588, 'Apucarana', 'Municipal Corifeu de Azevedo Marques', 'Centro', '86800-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24589, 'Curitiba', 'Município de Campo Novo', 'Cidade Industrial', '81250-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24590, 'Curitiba', 'Município de Colorado', 'Cidade Industrial', '81250-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24591, 'Curitiba', 'Município de Enéas Marques', 'Cidade Industrial', '81250-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24592, 'Curitiba', 'Município de Floresta', 'Cidade Industrial', '81250-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24593, 'Cascavel', 'Munique', 'Cascavel Velho', '85818-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24594, 'Almirante Tamandaré', 'Munir Habib Achoa', 'Jardim Giannini', '83511-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24595, 'Foz do Iguaçu', 'Muri', 'Loteameto Jardim Colombelli', '85862-466', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24596, 'Curitiba', 'Murillo Lupion de Quadros', 'Cidade Industrial', '81350-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24597, 'Londrina', 'Murilo Alvarenga', 'Conjunto Vivi Xavier', '86082-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24598, 'Curitiba', 'Murilo do Amaral Ferreira', 'Água Verde', '80620-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24599, 'Curitiba', 'Murilo Lemos', 'Cidade Industrial', '81460-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24600, 'Guarapuava', 'Murilo Mendes', 'São Cristóvão', '85060-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24601, 'Foz do Iguaçu', 'Murilo Mendes', 'Parque Residencial Três Bandeiras', '85862-268', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24602, 'Ponta Grossa', 'Murilo Monteiro Mendes', 'Cará-cará', '84043-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24603, 'Foz do Iguaçu', 'Muriqui', 'Conjunto A', '85860-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24604, 'Colombo', 'Murtede', 'Parque Residencial Santa Terezinha', '83408-660', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24605, 'Curitiba', 'Músico Antero G. da Silva', 'Sítio Cercado', '81935-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24606, 'Arapongas', 'Musofago', 'Jardim Bandeirantes', '86703-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24607, 'Foz do Iguaçu', 'Mussum', 'Conjunto A', '85860-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24608, 'Curitiba', 'Mustapha Francisco Lemes', 'Barreirinha', '82220-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24609, 'Curitiba', 'Mustapha Kaiel', 'Guabirotuba', '81510-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24610, 'Foz do Iguaçu', 'Mutum', 'Conjunto A', '85866-470', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24611, 'Arapongas', 'Mutum', 'Centro', '86701-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24612, 'Arapongas', 'Mutum-açu', 'Conjunto Flamingos', '86703-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24613, 'Arapongas', 'Mutumporanga', 'Conjunto Centauro', '86709-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24614, 'Cascavel', 'Mutun', 'Floresta', '85814-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24615, 'Arapongas', 'Mutupinima', 'Vila Edio', '86705-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24616, 'Curitiba', 'Muzambinho', 'Santa Felicidade', '82410-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24617, 'Cascavel', 'Mylla', 'Pioneiros Catarinenses', '85805-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24618, 'Curitiba', 'Myltho Anselmo da Silva', 'Mercês', '80510-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24619, 'Curitiba', 'Myltho Anselmo da Silva', 'Mercês', '80810-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24620, 'Curitiba', 'Myriam de Lourdes Neves', 'Mossunguê', '81200-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24621, 'Foz do Iguaçu', 'N', 'Conjunto C', '85870-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24622, 'Umuarama', 'N', 'Parque das Jaboticabeiras', '87509-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24623, 'Campo Mourão', 'N', 'Jardim Paulino', '87306-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24624, 'Campo Largo', 'N', 'Popular Nova', '83602-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24625, 'Campo Largo', 'N', 'Vila Torres II', '83609-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24626, 'Campo Largo', 'N', 'Jardim Três Rios', '83603-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24627, 'Arapongas', 'N-1', 'Conjunto Palmares', '86702-667', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24628, 'Arapongas', 'N-14', 'Conjunto Padre Bernardo Merckel', '86706-437', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24629, 'Arapongas', 'N-15', 'Parque Industrial IV', '86706-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24630, 'Arapongas', 'N-16', 'Conjunto Padre Bernardo Merckel', '86706-436', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24631, 'Arapongas', 'N-23', 'Parque Industrial II', '86703-077', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24632, 'Arapongas', 'N-24', 'Parque Industrial II', '86703-078', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24633, 'Arapongas', 'N-25', 'Parque Industrial II', '86703-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24634, 'Arapongas', 'N-26', 'Parque Industrial II', '86703-076', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24635, 'Ponta Grossa', 'Naaliel', 'Jardim Carvalho', '84016-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24636, 'Curitiba', 'Nabal Guimarães Barreto', 'Orleans', '82310-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24637, 'Ponta Grossa', 'Nabuco de Araújo', 'Uvaranas', '84031-510', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24638, 'Foz do Iguaçu', 'Nacional', 'Parque Presidente', '85863-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24639, 'Cambé', 'Nacional', 'Jardim Alvorada', '86191-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24640, 'Maringá', 'Nações Unidas', 'Zona 01', '87013-215', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24641, 'Piraquara', 'Nações Unidas', 'Jardim Bela Vista', '83301-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24642, 'Telêmaco Borba', 'Nações Unidas', 'Centro', '84265-410', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24643, 'Telêmaco Borba', 'Nações Unidas', 'Centro', '84262-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24644, 'Apucarana', 'Nações Unidas', 'Vila Country Club', '86808-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24645, 'Maringá', 'Nadalina Beloto', 'Cidade Jardim', '87020-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24646, 'Curitiba', 'Nadia Leuch Rymanski', 'Cajuru', '82970-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24647, 'Curitiba', 'Nadim Caluf', 'Santo Inácio', '82300-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24648, 'Colombo', 'Nadir Outeiro Alves', 'Jardim dos Eucaliptos', '83408-546', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24649, 'Toledo', 'Nadir Somenzi', 'Jardim Carelli', '85906-719', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24650, 'Ponta Grossa', 'Nael Nunes Rocha', 'Estrela', '84050-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24651, 'Curitiba', 'Naftali Reiss', 'Bacacheri', '82510-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24652, 'Curitiba', 'Nagib da Silva', 'Cajuru', '82960-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24653, 'Curitiba', 'Nagib Daher', 'Tarumã', '82530-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24654, 'Guarapuava', 'Nagib Fagundes Schier', 'Santana', '85070-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24655, 'Curitiba', 'Nagib Guérios', 'Água Verde', '80620-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24656, 'Curitiba', 'Nagib José Fatuch', 'Tatuquara', '81470-185', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24657, 'Pinhais', 'Nagib Moussi Fatouch', 'Vila Palmital', '83320-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24658, 'Curitiba', 'Nagib Nakle Mitri', 'Cidade Industrial', '81315-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24659, 'Guarapuava', 'Nagib Nassar', 'Vila Bela', '85027-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24660, 'Cambé', 'Nagib Racy', 'Parque Residencial Ana Rosa', '86183-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24661, 'Maringá', 'Nagoia', 'Jardim Imperial II', '87023-017', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24662, 'Araucária', 'Nahum Pedro Saliba', 'Iguaçu', '83701-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24663, 'Curitiba', 'Nahyr Costa Lima Padilha', 'Novo Mundo', '81050-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24664, 'Maringá', 'Naihma Name', 'Jardim Olímpico', '87070-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24665, 'Foz do Iguaçu', 'Naipi', 'Centro', '85851-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24666, 'Toledo', 'Naipi', 'Boa Esperança', '85909-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24667, 'Cascavel', 'Naipi', 'Claudete', '85811-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24668, 'Colombo', 'Nair Antunes da Silva', 'Centro Industrial Mauá', '83413-677', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24669, 'Curitiba', 'Nair Cordeiro Ribeiro', 'Cidade Industrial', '81310-440', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24670, 'Curitiba', 'Nair Cravo Westphalen', 'Umbará', '81930-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24671, 'Londrina', 'Nair Dias da Silva', 'Conjunto Habitacional João Turquino', '86056-856', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24672, 'Curitiba', 'Nair Ferraz Cazellato', 'Alto Boqueirão', '81770-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24673, 'Maringá', 'Nair Jandira Pereira da Silva Luiz', 'Vila Vardelina', '87080-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24674, 'Cascavel', 'Nair Mendes Ferreira', 'Santos Dumont', '85804-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24675, 'Curitiba', 'Nair Rosa Mendes', 'Cidade Industrial', '81310-417', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24676, 'Curitiba', 'Nair Schultz Helvig', 'Cachoeira', '82710-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24677, 'Curitiba', 'Nair Silvestre Ribas', 'São Braz', '82315-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24678, 'Londrina', 'Nair Ventura Pegoraro', 'Los Angeles', '86060-365', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24679, 'Colombo', 'Nair Vieira Moreira', 'Parque Residencial Santa Terezinha II', '83408-806', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24680, 'Londrina', 'Nairto Onofo Barion', 'Jardim Santa Fé', '86035-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24681, 'Francisco Beltrão', 'Nambu', 'Padre Eurico', '85604-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24682, 'Londrina', 'Nancy', 'Parque Residencial João Piza', '86041-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24683, 'Curitiba', 'Nancy Maria Anad', 'Santa Felicidade', '82410-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24684, 'Curitiba', 'Napoleão Bartachevits', 'Fazendinha', '81070-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24685, 'Campo Mourão', 'Napoleão Bonaparte', 'Jardim Lar Paraná', '87305-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24686, 'Curitiba', 'Napoleão Bonaparte', 'Tarumã', '82820-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24687, 'Pato Branco', 'Napoleão Corrêa Lobo', 'Pinheirinho', '85506-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24688, 'Curitiba', 'Napoleão Laureano', 'Boqueirão', '81650-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24689, 'Curitiba', 'Napoleão Lopes', 'São Francisco', '80530-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24690, 'Curitiba', 'Napoleão Lyrio Teixeira', 'Tatuquara', '81940-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24691, 'Curitiba', 'Napoleão Manosso', 'Butiatuvinha', '82400-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24692, 'Maringá', 'Napoleão Moreira da Silva', 'Zona 01', '87013-330', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24693, 'Francisco Beltrão', 'Napoleão Vieira', 'Pinheirinho', '85606-070', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24694, 'Londrina', 'Nápoles', 'Parque Residencial João Piza', '86041-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24695, 'Francisco Beltrão', 'Nápoles', 'Jardim Floresta', '85603-346', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24696, 'Colombo', 'Nápoles', 'Walfrido do Rosário', '83413-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24697, 'Cascavel', 'Napoli', 'Cascavel Velho', '85818-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24698, 'Curitiba', 'Napoli', 'São João', '82030-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24699, 'Cambé', 'Nápolis', 'Residencial Monte Castelo', '86186-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24700, 'Cambé', 'Naposeano Pedro Alves', 'Jardim Tarobá', '86191-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24701, 'Londrina', 'Nara Leão', 'Conjunto Vivi Xavier', '86082-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24702, 'Foz do Iguaçu', 'Narceja', 'Conjunto A', '85866-300', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24703, 'Arapongas', 'Narceja-americana', 'Jardim Bandeirantes', '86703-696', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24704, 'Arapongas', 'Narcejão', 'Vila Castelo', '86708-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24705, 'Piraquara', 'Narciso Gomes', 'Vila São Cristóvão', '83305-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24706, 'Colombo', 'Narciso Negro', 'Vila Ana Maria', '83413-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24707, 'Londrina', 'Narciso Spoladore', 'Monte Carlo', '86073-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24708, 'Apucarana', 'Narciso Vicente de Castro', 'Vila Residencial Malibu', '86812-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24709, 'Londrina', 'Narciza do Carmo Chagas', 'Colúmbia', '86057-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24710, 'Curitiba', 'Nardy Müller da Costa', 'Campo Comprido', '81220-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24711, 'Apucarana', 'Nassau', 'Núcleo Habitacional Vale Verde', '86805-259', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24712, 'Curitiba', 'Nassib Abdo Abage', 'São Francisco', '80510-390', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24713, 'Maringá', 'Nassib Haddad', 'Zona 04', '87015-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24714, 'Londrina', 'Nassim Jabur', 'Paulista', '86079-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24715, 'Curitiba', 'Nassim Sado', 'Sítio Cercado', '81920-777', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24716, 'Londrina', 'Natal', 'Jardim Agari', '86020-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24717, 'Foz do Iguaçu', 'Natal', 'Jardim das Palmeiras', '85869-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24718, 'Foz do Iguaçu', 'Natal', 'Conjunto C', '85870-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24719, 'Guarapuava', 'Natal', 'São Cristóvão', '85060-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24720, 'Piraquara', 'Natal', 'Vila Vicente Macedo', '83303-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24721, 'Maringá', 'Natal', 'Parque Residencial Cidade Nova', '87023-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24722, 'São José dos Pinhais', 'Natal', 'Costeira', '83015-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24723, 'Telêmaco Borba', 'Natal', 'Macopa', '84263-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24724, 'Sarandi', 'Natal', 'Parque Residencial Nova Aliança', '87111-719', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24725, 'Umuarama', 'Natal', 'Zona V', '87504-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24726, 'Cambé', 'Natal', 'Jardim Dona Catarina', '86182-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24727, 'Cascavel', 'Natal', 'Recanto Tropical', '85807-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24728, 'Cascavel', 'Natal', 'Centro', '85810-061', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24729, 'Cascavel', 'Natal', 'Centro', '85810-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24730, 'Curitiba', 'Natal', 'Cajuru', '82930-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24731, 'Curitiba', 'Natal', 'Cajuru', '82920-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24732, 'Curitiba', 'Natal Bim', 'Sítio Cercado', '81925-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24733, 'Curitiba', 'Natal Cecone', 'Mossunguê', '81200-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24734, 'Londrina', 'Natal Cereda', 'Jardim Neman Sahyun', '86041-259', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24735, 'Londrina', 'Natal Delalibera', 'Jardim Alphaville', '86084-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24736, 'Pinhais', 'Natal Fabri', 'Conjunto Residencial Áquila', '83326-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24737, 'Curitiba', 'Natal Garib', 'Pilarzinho', '82115-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24738, 'Foz do Iguaçu', 'Natal Graciotin', 'Vila Shalon', '85853-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24739, 'Curitiba', 'Natal Pedro Dalla Stella', 'Santa Felicidade', '82030-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24740, 'Cascavel', 'Natal Zanetti', 'Presidente', '85818-167', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24741, 'Campo Largo', 'Natália Camargo Pereira', 'Jardim Rondinha', '83607-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24742, 'Araucária', 'Natália Campanholo', 'Estação', '83705-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24743, 'Almirante Tamandaré', 'Natália de Souza Pereira', 'Jardim Gerhusa', '83502-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24744, 'Curitiba', 'Natália Ivanczyszyn', 'Cidade Industrial', '81450-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24745, 'Pato Branco', 'Natália Vicente Pereira', 'Vila Esperança', '85503-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24746, 'Londrina', 'Natalício Euzébio', 'Jardim Imagawa', '86080-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24747, 'Cascavel', 'Natalício Florentino Alves', 'Claudete', '85811-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24748, 'Curitiba', 'Natalina Cordeiro', 'Uberaba', '81580-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24749, 'Umuarama', 'Natalina Giroto Spina', 'Jardim União', '87508-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24750, 'São José dos Pinhais', 'Natalina Pinto de Franca', 'São Sebastião', '83075-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24751, 'Londrina', 'Natalino Frouti', 'Parque Residencial Alcântara', '86047-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24752, 'Colombo', 'Natálio Canestraro', 'Jardim Paraná', '83412-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24753, 'Curitiba', 'Natálio Fagundes', 'Pinheirinho', '81870-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24754, 'Curitiba', 'Natálio Santos', 'Alto da Rua XV', '80050-640', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24755, 'Curitiba', 'Natálio Scussiato', 'Campo Comprido', '81220-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24756, 'Curitiba', 'Natálio Scussiato', 'Campo Comprido', '81230-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24757, 'Colombo', 'Natálio Zanon', 'Vila Santo Antônio', '83413-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24758, 'Paranavaí', 'Natan Moreira Barbosa', 'Vila Prudêncio', '87702-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24759, 'Londrina', 'Natanael César Camargo', 'Jardim Itamarati', '86061-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24760, 'Paranaguá', 'Natanael F. dos Santos Júnior', 'Vila Guarani', '83221-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24761, 'Curitiba', 'Nathalia Bozza', 'Umbará', '81930-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24762, 'Maringá', 'Nathalino Carniel', 'Jardim Hanover', '87065-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24763, 'Apucarana', 'Natividade', 'Vila Regina', '86801-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24764, 'Foz do Iguaçu', 'Natsuko Mertz', 'Jardim Irmã', '85867-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24765, 'São José dos Pinhais', 'Nauher Bortolotti', 'Afonso Pena', '83050-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24766, 'Pinhais', 'Nauza Alves', 'Jardim Triângulo', '83331-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24767, 'Ponta Grossa', 'Navajo', 'Cará-cará', '84043-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24768, 'Maringá', 'Navarra', 'Loteamento Madrid', '87053-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24769, 'Foz do Iguaçu', 'Navegantes', 'Jardim das Palmeiras', '85869-737', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24770, 'Sarandi', 'Navirai', 'Jardim Gralha Azul', '87112-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24771, 'São José dos Pinhais', 'Nayme Nasser', 'Costeira', '83015-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24772, 'Toledo', 'Nayoro', 'Parque Residencial Cosmos', '85903-697', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24773, 'Maringá', 'Nazaré', 'Zona 06', '87015-590', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24774, 'Ponta Grossa', 'Nazaré', 'Jardim Carvalho', '84016-698', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24775, 'Londrina', 'Nazaré Cândida de Jesus', 'Jardim Paracatu', '86081-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24776, 'Curitiba', 'Nazareno Collini', 'Barreirinha', '82650-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24777, 'Londrina', 'Nazareth Virgínia Pereira Dias', 'Aragarça', '86038-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24778, 'Curitiba', 'Nazilde Guimarães Paixão', 'Cidade Industrial', '81450-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24779, 'Almirante Tamandaré', 'Nazílio Camargo', 'Planta São Venâncio', '83504-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24780, 'Curitiba', 'Nazir Ribeiro de Souza', 'Santa Cândida', '82630-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24781, 'Londrina', 'Necesio Silva Filho', 'Jardim dos Alpes II', '86075-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24782, 'Arapongas', 'Negaça', 'Jardim Aeroporto', '86702-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24783, 'Londrina', 'Neid Macluf Feres', 'Catuaí Parque Residence', '86047-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24784, 'Curitiba', 'Neide Darif Palhano', 'Mossunguê', '81200-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24785, 'Colombo', 'Neide Freire', 'Vila Carrano Júnior', '83409-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24786, 'Sarandi', 'Neil Armstrong', 'Jardim Universal', '87114-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24787, 'Londrina', 'Neila Ribeiro', 'Parque Residencial Alcântara', '86047-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24788, 'Curitiba', 'Neivo José Scotti', 'Tatuquara', '81940-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24789, 'Londrina', 'Nelino Silva Pereira', 'Parque Residencial João Piza', '86041-315', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24790, 'Londrina', 'Nello Thomaz Lainetti', 'Leste Oeste', '86037-817', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24791, 'São José dos Pinhais', 'Nelso Comin', 'Rio Pequeno', '83070-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24792, 'Curitiba', 'Nelso José Lauthart', 'Alto Boqueirão', '81860-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24793, 'Curitiba', 'Nelson Antonini', 'Capão da Imbuia', '82810-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24794, 'Curitiba', 'Nelson Antônio Farias', 'Fanny', '81030-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24795, 'Curitiba', 'Nelson Antônio Zamprogna', 'Tatuquara', '81470-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24796, 'Colombo', 'Nelson Argenta', 'Jardim João Paulo II', '83402-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24797, 'Ponta Grossa', 'Nelson Barreto', 'Uvaranas', '84031-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24798, 'São José dos Pinhais', 'Nelson Basso', 'Bom Jesus', '83025-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24799, 'Curitiba', 'Nelson Batista Ribas', 'Bigorrilho', '80430-260', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24800, 'Apucarana', 'Nelson Beckedorf', 'Loteamento São João', '86808-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24801, 'Campo Mourão', 'Nelson Behrens', 'Jardim Silvana', '87309-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24802, 'Apucarana', 'Nelson Bisso', 'Parque Industrial Zona Oeste II', '86800-766', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24803, 'Campo Mourão', 'Nelson Bittencourt Prado', 'Jardim Lar Paraná', '87305-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24804, 'Campo Mourão', 'Nelson Bittencourt Prado', 'Jardim Pio XII', '87306-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24805, 'Curitiba', 'Nelson Borba', 'Cidade Industrial', '81350-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24806, 'Londrina', 'Nelson Brunelli', 'Conjunto Habitacional  Alexandre Urbanas', '86037-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24807, 'São José dos Pinhais', 'Nelson de Britto', 'Colônia Rio Grande', '83020-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24808, 'Londrina', 'Nelson de Godoy Pereira', 'Residencial Veneza', '86038-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24809, 'Apucarana', 'Nelson de Souza', 'Loteamento Sanches dos Santos', '86806-606', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24810, 'Curitiba', 'Nelson Deip', 'Cidade Industrial', '81170-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24811, 'Cascavel', 'Nelson do Cavaquinho', 'Brasília', '85815-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24812, 'Londrina', 'Nelson do Valle Rego', 'Conjunto Semiramis Barros Braga', '86088-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24813, 'Curitiba', 'Nelson dos Santos', 'Santa Quitéria', '80310-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24814, 'Londrina', 'Nelson Eggas', 'Parque Residencial Alcântara', '86047-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24815, 'Paranavaí', 'Nelson Ernesto Buchner', 'Jardim Videira', '87711-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24816, 'Londrina', 'Nelson Ferracini', 'Roseira', '86041-445', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24817, 'São José dos Pinhais', 'Nelson Ferreira da Luz', 'Guatupê', '83065-456', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24818, 'Curitiba', 'Nelson Ferreira da Luz', 'Campo Comprido', '81220-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24819, 'São José dos Pinhais', 'Nelson Foggiatto', 'Costeira', '83015-728', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24820, 'São José dos Pinhais', 'Nelson Franca', 'Miringuava', '83090-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24821, 'Curitiba', 'Nelson Gonçalves de Lima', 'Alto da Rua XV', '80040-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24822, 'Campo Mourão', 'Nelson Guimarães Monteiro', 'Jardim Paulista', '87310-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24823, 'Castro', 'Nelson Iwanoski', 'Jardim Social Primavera', '84174-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24824, 'Toledo', 'Nelson Lorens', 'Jardim Concórdia', '85906-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24825, 'Londrina', 'Nelson Lotz', 'Eucaliptos', '86031-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24826, 'Ponta Grossa', 'Nelson Marcondes da Cunha', 'Uvaranas', '84030-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24827, 'Colombo', 'Nelson Mocelin', 'Centro', '83414-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24828, 'Apucarana', 'Nelson Moraes', 'Núcleo Habitacional Osmar G Freire', '86801-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24829, 'Londrina', 'Nelson Morguetti', 'Cafezal', '86045-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24830, 'Maringá', 'Nelson Movio', 'Jardim Universo', '87060-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24831, 'Almirante Tamandaré', 'Nelson P. de Lara', 'Vila Otília', '83506-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24832, 'Araucária', 'Nelson Pereira de Souza', 'Boqueirão', '83704-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24833, 'Ponta Grossa', 'Nelson Pereira Dias Júnior', 'Olarias', '84026-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24834, 'Ponta Grossa', 'Nelson Pereira Jorge', 'Boa Vista', '84072-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24835, 'Paranaguá', 'Nelson Pereira Neves', 'Conjunto Residencial Prefeito Cominese', '83215-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24836, 'Curitiba', 'Nelson Pizzani', 'Cidade Industrial', '81170-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24837, 'São José dos Pinhais', 'Nelson Portes de Brito', 'Guatupê', '83060-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24838, 'Curitiba', 'Nelson Prevedello', 'Abranches', '82220-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24839, 'Curitiba', 'Nelson Rieke', 'Cidade Industrial', '81450-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24840, 'Guarapuava', 'Nelson Rocha Marcondes', 'Industrial', '85045-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24841, 'Curitiba', 'Nelson Rocha Wendling', 'Santa Cândida', '82650-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24842, 'Londrina', 'Nelson Rodrigues', 'Conjunto Vivi Xavier', '86082-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24843, 'Foz do Iguaçu', 'Nelson Rodrigues', 'Jardim Comercial das Bandeiras', '85864-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24844, 'Londrina', 'Nelson Roversi Forattini', 'Conjunto Cafezal 3', '86045-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24845, 'Londrina', 'Nelson Sambatti', 'Jardim Continental', '86081-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24846, 'Curitiba', 'Nelson Satenarski Monteiro', 'Xaxim', '81810-015', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24847, 'Curitiba', 'Nelson Thomaz', 'São Braz', '82315-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24848, 'Londrina', 'Nelson Vicentini', 'Condomínio Royal Golf Residence', '86055-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24849, 'Curitiba', 'Nely Conceição Liss', 'Barreirinha', '82700-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24850, 'Londrina', 'Neman Sayun', 'Jardim Portal de Bianca', '86075-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24851, 'Curitiba', 'Nemésio Araújo Moritz', 'Santa Felicidade', '82015-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24852, 'Araucária', 'Nenufar', 'Campina da Barra', '83709-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24853, 'Maringá', 'Neo Alves Martins', 'Zona 03', '87050-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24854, 'Maringá', 'Neo Alves Martins', 'Zona 01', '87013-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24855, 'Londrina', 'Neo Martins', 'Novo Amparo', '86043-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24856, 'Guarapuava', 'Neoclássica', 'Morro Alto', '85065-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24857, 'Foz do Iguaçu', 'Neópolis', 'Jardim Paraná', '85867-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24858, 'Londrina', 'Nepal', 'Cláudia', '86050-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24859, 'Maringá', 'Nepal', 'Jardim Imperial II', '87023-028', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24860, 'Londrina', 'Nereu Mendes', 'Mediterrâneo', '86047-086', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24861, 'Londrina', 'Nereu Mendes', 'Ernani de Moura Lima', '86037-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24862, 'Cambé', 'Nereu Pizzaia', 'Jardim Riviera', '86187-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24863, 'Foz do Iguaçu', 'Nereu Ramos', 'Parque Presidente', '85863-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24864, 'Laranjeiras do Sul', 'Nereu Ramos', 'São Francisco', '85303-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24865, 'Pato Branco', 'Nereu Ramos', 'Trevo da Guarany', '85501-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24866, 'Pinhais', 'Nereu Ramos', 'Vila Amélia', '83330-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24867, 'Pato Branco', 'Nereu Ramos', 'Vila Isabel', '85504-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24868, 'Umuarama', 'Nereu Ramos', 'Jardim Tangará', '87501-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24869, 'Telêmaco Borba', 'Nereu Ramos', 'Alto das Oliveiras', '84266-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24870, 'Cascavel', 'Nereu Ramos', 'Claudete', '85811-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24871, 'Cascavel', 'Nereu Ramos', 'Centro', '85810-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24872, 'Cascavel', 'Nereu Ramos', 'Centro', '85801-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24873, 'Cascavel', 'Nereu Ramos', 'Vila Tolentino', '85802-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24874, 'Francisco Beltrão', 'Nereu Schelikmann', 'Pinheirinho', '85603-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24875, 'Colombo', 'Neriman Nezetli', 'Vila Guaraci', '83404-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24876, 'Sarandi', 'Nerio Broglia', 'Parque São Pedro', '87112-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24877, 'Londrina', 'Nerivaldo Floriano Silva', 'Armindo Guazzi', '86037-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24878, 'São José dos Pinhais', 'Nery Soares', 'Guatupê', '83060-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24879, 'Ponta Grossa', 'Nestor Alves de Campos', 'Uvaranas', '84030-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24880, 'Apucarana', 'Nestor Balan', 'Jardim Ouro Verde', '86805-225', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24881, 'Ponta Grossa', 'Nestor Borba', 'Ronda', '84051-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24882, 'Pato Branco', 'Nestor Cardoso', 'Vila Esperança', '85503-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24883, 'Ponta Grossa', 'Nestor de Castro', 'Oficinas', '84040-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24884, 'Curitiba', 'Nestor de Castro', 'Centro', '80020-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24885, 'Ponta Grossa', 'Nestor Guimarães', 'Estrela', '84040-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24886, 'Curitiba', 'Nestor Lopes da Silva', 'Mercês', '80710-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24887, 'Araucária', 'Nestor Padilha de Lima', 'Tindiquera', '83708-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24888, 'São José dos Pinhais', 'Nestor Pereira da Rocha Júnior', 'Braga', '83020-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24889, 'São José dos Pinhais', 'Nestor Pereira de Castro', 'Zaniolo', '83025-615', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24890, 'Araucária', 'Nestor Pereira Habkost', 'Barigui', '83707-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24891, 'Paranaguá', 'Nestor Victor', 'João Gualberto', '83203-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24892, 'Ponta Grossa', 'Nestor Victor', 'Ronda', '84051-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24893, 'Curitiba', 'Nestor Victor', 'Água Verde', '80620-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24894, 'Foz do Iguaçu', 'Netuno', 'Parque Residencial Três Fronteiras', '85859-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24895, 'Londrina', 'Netuno', 'Sol', '86070-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24896, 'Maringá', 'Netuno', 'Jardim Imperial II', '87023-009', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24897, 'Telêmaco Borba', 'Netuno', 'Nossa Senhora de Fátima', '84264-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24898, 'Sarandi', 'Netuno', 'Jardim Universal', '87114-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24899, 'Apucarana', 'Netuno', 'Vila Martins', '86800-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24900, 'Cambé', 'Netuno', 'Parque Maracanã', '86185-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24901, 'Curitiba', 'Netuno', 'Sítio Cercado', '81910-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24902, 'Curitiba', 'Neuma Cortes Monclaro', 'São Braz', '82015-575', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24903, 'Curitiba', 'Neuraci Neves do Nascimento', 'Santa Felicidade', '82020-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24904, 'Curitiba', 'Neusa Maria de Moura', 'Umbará', '81930-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24905, 'Curitiba', 'Neusa Maria Lorenzini', 'Novo Mundo', '81050-658', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24906, 'Curitiba', 'Neusa Vieira Bet', 'Cajuru', '82960-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24907, 'Apucarana', 'Neusa Xavier Maia', 'Residencial Parque da Raposa', '86812-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24908, 'Curitiba', 'Neuza Brizola', 'Sítio Cercado', '81910-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24909, 'São José dos Pinhais', 'Neuza Pallu Stankevecz', 'Braga', '83020-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24910, 'Ponta Grossa', 'Neuza Rodrigues de Oliveira', 'Neves', '84020-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24911, 'Curitiba', 'Neuzo Benedito Alberti', 'Boa Vista', '82540-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24912, 'Londrina', 'Nevada', 'Iguaçu', '86060-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24913, 'Cambé', 'Nevada', 'Jardim Golden Park', '86186-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24914, 'Londrina', 'Névio Soriani Júnior', 'Jardim São Paulo', '86046-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24915, 'Colombo', 'Newton', 'Vila Guarani', '83408-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24916, 'Curitiba', 'Newton Amarante', 'Santa Felicidade', '82015-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24917, 'Londrina', 'Newton Braga', 'Santos Dumont', '86039-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24918, 'Londrina', 'Newton de Abreu Sodré', 'Residence Catuai Parque', '86047-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24919, 'Curitiba', 'Newton de Luca', 'Cidade Industrial', '81315-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24920, 'Curitiba', 'Newton de Souza e Silva', 'Uberaba', '81570-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24921, 'Curitiba', 'Newton Franca Bittencourt', 'Ahú', '82200-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24922, 'Curitiba', 'Newton Ivan Buskei', 'Campina do Siqueira', '80740-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24923, 'Curitiba', 'Newton Laporte', 'Lamenha Pequena', '82410-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24924, 'Ponta Grossa', 'Newton Prado', 'Nova Rússia', '84053-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24925, 'São José dos Pinhais', 'Newton Sampaio', 'São Sebastião', '83075-478', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24926, 'Ponta Grossa', 'Newton Slaviero', 'Cará-cará', '84043-560', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24927, 'Maringá', 'Ney Aminthas Barros Braga', 'Jardim Alvorada', '87033-040', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24928, 'Apucarana', 'Ney Aminthas de Barros Braga', 'Jardim Morumbi', '86802-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24929, 'Curitiba', 'Ney Azevedo', 'Novo Mundo', '81050-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24930, 'Campo Mourão', 'Ney Braga', 'Jardim Izabel', '87309-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24931, 'Curitiba', 'Ney Itiberê Pia de Andrade', 'Santo Inácio', '82010-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24932, 'Londrina', 'Ney José de Oliveira Machado', 'Parque Industrial Buena Vista', '86032-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24933, 'Piraquara', 'Ney Leprevost', 'Recreio da Serra', '83305-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24934, 'Curitiba', 'Ney Pacheco', 'Cidade Industrial', '81460-176', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24935, 'Londrina', 'Ney Pimenta', 'Barbeta', '86078-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24936, 'Curitiba', 'Ney Rebello Tourinho', 'Cidade Industrial', '81230-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24937, 'Curitiba', 'Ney Romano', 'São Braz', '82310-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24938, 'Curitiba', 'Neylor Vasconcellos de Andrade', 'Santa Quitéria', '80330-195', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24939, 'Cascavel', 'Nhambiquaras', 'Santa Cruz', '85806-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24940, 'Arapongas', 'Nhambu', 'Centro', '86701-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24941, 'Arapongas', 'Nhambuguaçu', 'Conjunto Flamingos', '86703-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24942, 'Arapongas', 'Nhambuxintã', 'Jardim Caravelle', '86702-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24943, 'Arapongas', 'Nhambuxororó', 'Jardim Bononi', '86703-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24944, 'Paranaguá', 'Nhundiaquara', 'Jardim Guaraituba', '83209-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24945, 'Cascavel', 'Nhundiaquara', 'Brasmadeira', '85814-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24946, 'Curitiba', 'Nhundiaquara', 'Cajuru', '82960-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24947, 'Guarapuava', 'Niagara', 'Vila Bela', '85025-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24948, 'Curitiba', 'Nibet Deucher', 'Cidade Industrial', '81170-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24949, 'Curitiba', 'Nicacio Riquelme', 'Capão da Imbuia', '82810-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24950, 'Curitiba', 'Nicanor Acyr Milano', 'Uberaba', '81580-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24951, 'São José dos Pinhais', 'Nicanor Dias', 'Ipê', '83055-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24952, 'Curitiba', 'Nicanor do Rosário', 'Pinheirinho', '81870-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24953, 'Umuarama', 'Nicanor dos Santos Silva', 'Zona I', '87501-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24954, 'Umuarama', 'Nicanor dos Santos Silva', 'Zona V', '87504-005', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24955, 'Curitiba', 'Nicanor Rivas', 'São Braz', '82320-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24956, 'Londrina', 'Nicarágua', 'Vila Rodrigues', '86010-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24957, 'Francisco Beltrão', 'Nicarágua', 'Antônio de Paiva Cantelmo', '85603-542', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24958, 'Guarapuava', 'Nicarágua', 'Morro Alto', '85065-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24959, 'Ponta Grossa', 'Nicarágua', 'Ronda', '84051-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24960, 'Pinhais', 'Nicarágua', 'Vila Progresso', '83320-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24961, 'Maringá', 'Nicarágua', 'Vila Morangueira', '87040-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24962, 'Apucarana', 'Nicarágua', 'Núcleo Habitacional Vale Verde', '86805-248', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24963, 'Colombo', 'Nicarágua', 'Jardim São Gabriel', '83404-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24964, 'Cascavel', 'Nicarágua', 'Periolo', '85817-370', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24965, 'Curitiba', 'Nicarágua', 'Bacacheri', '82515-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24966, 'Curitiba', 'Nicarágua', 'Bacacheri', '82510-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24967, 'São José dos Pinhais', 'Niccolo Maquiavel', 'Aristocrata', '83030-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24968, 'Curitiba', 'Niccolo Paganini', 'Vista Alegre', '80820-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24969, 'Colombo', 'Nico Mello', 'Centro', '83414-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24970, 'Paranaguá', 'Nicodemos Ribeiro Camargo', 'Conjunto Residencial Prefeito Cominese', '83215-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24971, 'Curitiba', 'Nicodemus Zeglin', 'Uberaba', '81590-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24972, 'Cambé', 'Nicola Disparo', 'Jardim Planalto Verde', '86192-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24973, 'Londrina', 'Nícola Figliano', 'Antônio M Nogueira Cafezal 4', '86089-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24974, 'Paranavaí', 'Nicola Francisco', 'Jardim América', '87705-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24975, 'Curitiba', 'Nicola Pellanda', 'Pinheirinho', '81880-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24976, 'Curitiba', 'Nicola Pellanda', 'Tatuquara', '81940-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24977, 'Curitiba', 'Nicola Pellanda', 'Umbará', '81930-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24978, 'Foz do Iguaçu', 'Nícolas Ibraim Nasser', 'Distrito Industrial', '85862-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24979, 'Arapongas', 'Nicolau', 'Conjunto Ulisses Guimarães', '86706-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24980, 'Campo Mourão', 'Nicolau Assad', 'Jardim Capricórnio', '87301-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24981, 'Londrina', 'Nicolau Barra Rosa', 'Jardim dos Alpes III', '86045-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24982, 'Foz do Iguaçu', 'Nicolau Barreto', 'Jardim Florença', '85867-368', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24983, 'Curitiba', 'Nicolau Boscardin', 'São Braz', '82015-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24984, 'Londrina', 'Nicolau Chirnev Filho', 'Jardim Atlânta', '86042-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24985, 'Curitiba', 'Nicolau Chupil', 'Pinheirinho', '81825-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24986, 'Londrina', 'Nicolau Copérnico', 'Universitário', '86050-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24987, 'Curitiba', 'Nicolau Copérnico', 'Jardim das Américas', '81540-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24988, 'Londrina', 'Nicolau d''Andrea', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24989, 'Paranaguá', 'Nicolau Farah', 'Costeira', '83203-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24990, 'Toledo', 'Nicolau Finkler', 'Sachini', '85903-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24991, 'Ponta Grossa', 'Nicolau Florenski', 'Ronda', '84010-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24992, 'Ponta Grossa', 'Nicolau Florenzano', 'Uvaranas', '84031-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24993, 'Curitiba', 'Nicolau Gulbino', 'Capão da Imbuia', '82800-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24994, 'Castro', 'Nicolau Jacob Filho', 'Vila Santa Cruz', '84168-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24995, 'Curitiba', 'Nicolau Jorge', 'Bacacheri', '82515-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24996, 'Curitiba', 'Nicolau José Gravina', 'Cascatinha', '82010-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24997, 'Curitiba', 'Nicolau José Gravina', 'Cascatinha', '82015-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24998, 'Ponta Grossa', 'Nicolau Kluppel Netto', 'Contorno', '84061-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (24999, 'Apucarana', 'Nicolau Kowalski', 'Barra Funda', '86800-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25000, 'Curitiba', 'Nicolau Kresko', 'Hauer', '81630-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25001, 'Curitiba', 'Nicolau Latchoc', 'Campo Comprido', '81220-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25002, 'Paranaguá', 'Nicolau Mader', 'Itiberê', '83206-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25003, 'Curitiba', 'Nicolau Maeder', 'Alto da Glória', '80030-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25004, 'Araucária', 'Nicolau Merhy', 'Boqueirão', '83704-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25005, 'Cambé', 'Nicolau Nasser', 'Jardim Riviera', '86187-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25006, 'Cambé', 'Nicolau Nasser', 'Conjunto Residencial Roberto Conceição', '86183-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25007, 'São José dos Pinhais', 'Nicolau Pampuch', 'Afonso Pena', '83045-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25008, 'Curitiba', 'Nicolau Salomão', 'Tingui', '82620-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25009, 'Curitiba', 'Nicolau Scheffer', 'Santa Cândida', '82640-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25010, 'Colombo', 'Nicolau Schleder do Carmo', 'Jardim Guaraituba', '83410-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25011, 'Curitiba', 'Nicolau Serrato Sobrinho', 'Novo Mundo', '81020-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25012, 'Curitiba', 'Nicolau Serrato Sobrinho', 'Novo Mundo', '81010-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25013, 'Londrina', 'Nicolau Soares da Silva', 'Parque Residencial Campos Elísios', '86044-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25014, 'Foz do Iguaçu', 'Nicolau Stapiuck', 'Loteamento Witt', '85862-549', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25015, 'Castro', 'Nicolau Valenga', 'Loteamento Jardim Pandorf', '84182-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25016, 'Curitiba', 'Nicolau Vieira', 'São Braz', '82310-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25017, 'Curitiba', 'Nicolau Vorobi', 'Cidade Industrial', '81250-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25018, 'Londrina', 'Nicomedes Estigarribia', 'Jardim Alphaville', '86084-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25019, 'Foz do Iguaçu', 'Nidan Barretos', 'Vila Matilde', '85856-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25020, 'Francisco Beltrão', 'Nigéria', 'Seminário', '85605-657', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25021, 'Pinhais', 'Nigéria', 'Vl Dona Guiomar', '83320-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25022, 'Colombo', 'Nigéria', 'Planta Vila Nova', '83404-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25023, 'Londrina', 'Nikita Polskikh', 'Esperança', '86046-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25024, 'São José dos Pinhais', 'Nikolai Cicilovic', 'Miringuava', '83090-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25025, 'Guarapuava', 'Nikon Tembil', 'Boqueirão', '85015-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25026, 'Maringá', 'Nilo Alves dos Santos', 'Loteamento Madrid', '87053-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25027, 'Londrina', 'Nilo Bettoni', 'Jardim Delta', '86065-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25028, 'Londrina', 'Nilo Cairo', 'Paulista', '86079-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25029, 'Maringá', 'Nilo Cairo', 'Jardim Alvorada', '87035-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25030, 'Paranaguá', 'Nilo Cairo', 'Vila Guadalupe', '83221-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25031, 'Toledo', 'Nilo Cairo', 'Jardim Alto Alegre', '85910-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25032, 'Curitiba', 'Nilo Cairo', 'Centro', '80060-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25033, 'Almirante Tamandaré', 'Nilo Cropocato Matias', 'Jardim Areias', '83514-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25034, 'Ponta Grossa', 'Nilo Gasparetto', 'Boa Vista', '84072-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25035, 'Londrina', 'Nilo Gonzales Vicente', 'Jardim dos Alpes III', '86045-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25036, 'Curitiba', 'Nilo José Casarin', 'Cidade Industrial', '81250-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25037, 'Paranaguá', 'Nilo Lázaro Abud', 'Vila dos Comerciários', '83215-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25038, 'Foz do Iguaçu', 'Nilo Peçanha', 'Parque Presidente', '85863-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25039, 'Londrina', 'Nilo Peçanha', 'Hedy', '86062-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25040, 'Pinhais', 'Nilo Peçanha', 'Vila Amélia', '83330-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25041, 'Ponta Grossa', 'Nilo Peçanha', 'Estrela', '84040-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25042, 'Maringá', 'Nilo Peçanha', 'Zona 04', '87014-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25043, 'Pato Branco', 'Nilo Peçanha', 'Vila Esperança', '85503-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25044, 'Telêmaco Borba', 'Nilo Peçanha', 'Alto das Oliveiras', '84266-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25045, 'Cascavel', 'Nilo Peçanha', 'Parque São Paulo', '85803-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25046, 'Colombo', 'Nilo Peçanha', 'Jardim das Perdizes', '83409-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25047, 'Apucarana', 'Nilo Peçanha', 'Jardim Monções', '86807-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25048, 'Curitiba', 'Nilo Peçanha', 'São Francisco', '80520-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25049, 'Curitiba', 'Nilo Peçanha', 'Bom Retiro', '82120-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25050, 'Curitiba', 'Nilo Zanier', 'Cidade Industrial', '81450-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25051, 'Francisco Beltrão', 'Nilópolis', 'Pinheirinho', '85603-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25052, 'Foz do Iguaçu', 'Nilópolis', 'Jardim Lancaster I', '85869-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25053, 'Curitiba', 'Nilseu Brock', 'Cabral', '80035-320', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25054, 'Foz do Iguaçu', 'Nilson Gottlieb', 'Jardim Mônaco', '85862-408', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25055, 'Apucarana', 'Nilson Menezes Dias', 'Vila Nova II', '86812-056', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25056, 'Curitiba', 'Nilson Neves Filho', 'Mercês', '80810-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25057, 'Paranaguá', 'Nilson Pereira Neves', 'Conjunto Residencial Prefeito Cominese', '83215-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25058, 'Paranaguá', 'Nilson Pereira Neves Filho', 'Costeira', '83203-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25059, 'Curitiba', 'Nilson Trinkel', 'Alto Boqueirão', '81720-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25060, 'São José dos Pinhais', 'Nilto Jacob', 'Afonso Pena', '83050-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25061, 'Paranaguá', 'Nilton Abel de Lima', 'Vila dos Comerciários', '83215-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25062, 'Curitiba', 'Nilton João Marchesini', 'Cajuru', '82950-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25063, 'Ponta Grossa', 'Nilton Luiz de Castro', 'Colônia Dona Luiza', '84046-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25064, 'Londrina', 'Nilton Saconatto', 'Indusville', '86031-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25065, 'Ponta Grossa', 'Nilton Sales Rosa', 'Uvaranas', '84031-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25066, 'Colombo', 'Nilza Bandeira', 'Jardim Nova Esperança', '83413-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25067, 'Londrina', 'Nilza edite Rossi Lakoski', 'Jardim Maracanã', '86056-869', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25068, 'Piraquara', 'Nilza Gelinsky de Faria', 'Planta Deodoro', '83304-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25069, 'Ponta Grossa', 'Nilza Marques Leme', 'Boa Vista', '84073-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25070, 'Araucária', 'Nilza Rosina Sgrot da Silva', 'Estação', '83705-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25071, 'Curitiba', 'Nimer Madi Sobrinho', 'Cidade Industrial', '81315-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25072, 'Ponta Grossa', 'Nina Rodrigues', 'Ronda', '84051-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25073, 'Guarapuava', 'Nincia Maciel Ribas', 'Morro Alto', '85065-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25074, 'Curitiba', 'Ninon Muller Piske', 'Cajuru', '82950-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25075, 'Londrina', 'Niquel', 'Jardim São Francisco de Assis', '86067-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25076, 'Foz do Iguaçu', 'Niquel', 'Parque Ouro Verde', '85854-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25077, 'Pinhais', 'Nirisco', 'Planta Walde Rosi Galvão', '83328-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25078, 'Londrina', 'Nisa Maria Lopes do Carmo', 'Jardim Maria Celina', '86081-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25079, 'Foz do Iguaçu', 'Niseto Braga', 'Jardim Iara', '85854-175', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25080, 'Londrina', 'Nishinomiya', 'Aeroporto', '86039-265', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25081, 'Curitiba', 'Nita Hubel', 'Pinheirinho', '81150-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25082, 'Foz do Iguaçu', 'Niteroi', 'Jardim Karla', '85868-175', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25083, 'São José dos Pinhais', 'Niteroi', 'Águas Belas', '83010-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25084, 'Telêmaco Borba', 'Niteroi', 'Vila Santa Rita', '84263-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25085, 'Francisco Beltrão', 'Niterói', 'Nossa Senhora Aparecida', '85601-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25086, 'Londrina', 'Niterói', 'Centro', '86026-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25087, 'Paranavaí', 'Niterói', 'Jardim Novo Horizonte', '87711-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25088, 'Campo Largo', 'Niterói', 'Jardim Rivabem', '83605-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25089, 'Cambé', 'Niterói', 'Vila Guarani', '86182-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25090, 'Curitiba', 'Niterói', 'Cajuru', '82930-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25091, 'Curitiba', 'Niterói', 'Cajuru', '82940-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25092, 'Maringá', 'Nivaldo Aparecido Lopes', 'Parque Residencial Patrícia', '87040-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25093, 'Foz do Iguaçu', 'Nivaldo do Amaral', 'Parque Morumbi II', '85859-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25094, 'Curitiba', 'Nivaldo Medvid', 'Cidade Industrial', '81460-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25095, 'Curitiba', 'Nivaldo Pereira', 'Sítio Cercado', '81925-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25096, 'Piraquara', 'Nivaldo Rodrigues', 'Planta Granjas Eldorado', '83309-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25097, 'Colombo', 'Nivaldo Socher', 'Jardim Magnópolis', '83403-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25098, 'Londrina', 'Nivardo Sposito', 'Jardim Barcelona', '86073-366', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25099, 'Cascavel', 'Nivelles', 'Interlagos', '85814-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25100, 'Curitiba', 'Niwaldo Alberto Baro', 'Alto Boqueirão', '81770-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25101, 'Apucarana', 'Noboru Fukuchima', 'Vila São Carlos', '86800-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25102, 'Maringá', 'Nóbrega', 'Zona 04', '87014-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25103, 'Londrina', 'Nobuiti Sakamoto', 'Residencial Verona', '86038-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25104, 'Curitiba', 'Nodiran Gonçalves Cordeiro', 'Uberaba', '81550-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25105, 'Castro', 'Noel Clodoval Cunninghann', 'Jardim das Araucárias', '84174-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25106, 'Londrina', 'Noel Porfírio de Andrade', 'Dom Pedro I', '86089-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25107, 'Foz do Iguaçu', 'Noel Rosa', 'Jardim Naipi', '85853-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25108, 'Londrina', 'Noel Rosa', 'Meton', '86035-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25109, 'Pato Branco', 'Noel Rosa', 'Menino Deus', '85502-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25110, 'Maringá', 'Noel Rosa', 'Conjunto Residencial Cidade Alta', '87053-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25111, 'Toledo', 'Noel Rosa', 'Jardim Panambi', '85904-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25112, 'Toledo', 'Noel Rosa', 'Pacaembu', '85910-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25113, 'Cascavel', 'Noel Rosa', 'Periolo', '85815-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25114, 'Apucarana', 'Noel Rosa', 'Núcleo Habitacional Castelo Branco', '86812-346', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25115, 'Curitiba', 'Noel Rosa', 'Bigorrilho', '80710-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25116, 'Londrina', 'Noêmia Barroso Machado', 'Lagoa Dourada', '86041-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25117, 'Curitiba', 'Noêmia Corrêa Negrão Schier', 'Boqueirão', '81670-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25118, 'Colombo', 'Noêmia de Oliveira Silva', 'Jardim Modelo', '83405-186', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25119, 'Guarapuava', 'Noêmia Teixeira Silvério', 'Vila Carli', '85040-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25120, 'Foz do Iguaçu', 'Nogueira', 'Jardim Tropical', '85855-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25121, 'Ponta Grossa', 'Nogueira', 'Contorno', '84061-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25122, 'Telêmaco Borba', 'Nogueira', 'Área 01', '84268-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25123, 'Cascavel', 'Nogueira', 'Brasmadeira', '85814-128', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25124, 'Apucarana', 'Nogueira', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25125, 'Laranjeiras do Sul', 'Nogueira do Amaral', 'Centro', '85301-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25126, 'Guarapuava', 'Nogueira Pecam', 'São Cristóvão', '85060-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25127, 'Londrina', 'Noitibo', 'Yara', '86027-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25128, 'Arapongas', 'Noitimbo', 'Centro', '86701-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25129, 'Foz do Iguaçu', 'Nonoai', 'Jardim Ipê II', '85869-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25130, 'Cambé', 'Nora Wydenbuck', 'Residencial Elizabeth', '86188-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25131, 'Campo Mourão', 'Norberto Alcântara Padilha', 'Parque Industrial I', '87306-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25132, 'Curitiba', 'Norberto Alves Cardoso', 'Cidade Industrial', '81260-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25133, 'Curitiba', 'Norberto Antônio Calliari', 'Água Verde', '80240-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25134, 'Londrina', 'Norberto Cestari Moreira', 'Antares', '86036-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25135, 'São José dos Pinhais', 'Norberto de Brito', 'Centro', '83005-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25136, 'São José dos Pinhais', 'Norberto Gapski', 'Águas Belas', '83040-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25137, 'Curitiba', 'Norberto Germano Heller', 'Boqueirão', '81750-395', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25138, 'Londrina', 'Norberto Kemmer', 'Jardim Maracanã', '86056-875', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25139, 'Guarapuava', 'Norberto Marcondes', 'Cascavel', '85025-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25140, 'Curitiba', 'Norberto Marques Ferreira', 'Campo Comprido', '81220-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25141, 'Cascavel', 'Norberto Staim da Rocha', 'Brasília', '85815-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25142, 'Curitiba', 'Norberto Tramujas Decker', 'Santo Inácio', '82010-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25143, 'Londrina', 'Nordeste', 'Leste Oeste', '86072-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25144, 'Londrina', 'Norma de Pauli Salton', 'Loteamento Terra Bonita', '86047-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25145, 'Foz do Iguaçu', 'Norma Lakus', 'Jardim Norma', '85869-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25146, 'Londrina', 'Norma Lazarin Camuci', 'Jardim Marízia II', '86079-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25147, 'Londrina', 'Norman Prochet', 'Centro', '86010-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25148, 'Londrina', 'Normando Camargo da Silva', 'Parigot de Souza 2', '86082-155', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25149, 'Londrina', 'Noroeste', 'Santa Rita 1', '86072-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25150, 'Ponta Grossa', 'Noroeste', 'Chapada', '84064-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25151, 'Londrina', 'Norte', 'Leste Oeste', '86072-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25152, 'Sarandi', 'Norte', 'Jardim Perimetral', '87111-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25153, 'Arapongas', 'Norte 1', 'Jardim do Carmo', '86703-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25154, 'Guarapuava', 'Noruega', 'São Cristóvão', '85063-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25155, 'Londrina', 'Noruega', 'Jardim Adriana I', '86046-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25156, 'Cambé', 'Noruega', 'Centro', '86182-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25157, 'Colombo', 'Noruega', 'Vila Santa Helena', '83406-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25158, 'Apucarana', 'Noruega', 'Vila Isabel', '86808-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25159, 'Laranjeiras do Sul', 'Nossa Senhora Aparecida', 'São Francisco', '85303-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25160, 'Londrina', 'Nossa Senhora Aparecida', 'Recreio', '86025-425', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25161, 'Maringá', 'Nossa Senhora Aparecida', 'Vila Esperança', '87020-790', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25162, 'Telêmaco Borba', 'Nossa Senhora Aparecida', 'Nossa Senhora de Fátima', '84264-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25163, 'São José dos Pinhais', 'Nossa Senhora Aparecida', 'Zaniolo', '83025-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25164, 'Umuarama', 'Nossa Senhora Aparecida', 'Conjunto Residencial Independência', '87508-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25165, 'Araucária', 'Nossa Senhora Aparecida', 'Iguaçu', '83701-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25166, 'Almirante Tamandaré', 'Nossa Senhora Aparecida', 'Parque São Jorge', '83503-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25167, 'Campo Mourão', 'Nossa Senhora Aparecida', 'Jardim Pio XII', '87306-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25168, 'Cascavel', 'Nossa Senhora Aparecida', 'Brasília', '85815-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25169, 'Campo Mourão', 'Nossa Senhora Aparecida', 'Jardim Lar Paraná', '87305-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25170, 'Curitiba', 'Nossa Senhora Aparecida', 'Seminário', '80440-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25171, 'Curitiba', 'Nossa Senhora Aparecida', 'Seminário', '80310-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25172, 'Cambé', 'Nossa Senhora Auxiliadora', 'Jardim Santa Izabel', '86183-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25173, 'Curitiba', 'Nossa Senhora Consolada', 'Santa Felicidade', '82030-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25174, 'Campo Largo', 'Nossa Senhora da Aparecida', 'Vila Santa Terezinha', '83602-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25175, 'Curitiba', 'Nossa Senhora da Cabeça', 'Cidade Industrial', '81310-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25176, 'Apucarana', 'Nossa Senhora da Conceição', 'Jardim Presidente Kennedy', '86809-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25177, 'Colombo', 'Nossa Senhora da Conceição', 'Jardim Central', '83409-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25178, 'Almirante Tamandaré', 'Nossa Senhora da Conceição', 'Jardim São José', '83501-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25179, 'Francisco Beltrão', 'Nossa Senhora da Glória', 'Cango', '85604-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25180, 'Maringá', 'Nossa Senhora da Glória', 'Jardim São Jorge', '87080-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25181, 'Umuarama', 'Nossa Senhora da Glória', 'Parque Dom Pedro II', '87508-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25182, 'Curitiba', 'Nossa Senhora da Glória', 'Alto da Glória', '80530-200', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25183, 'Londrina', 'Nossa Senhora da Guia', 'Gaion', '86071-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25184, 'Toledo', 'Nossa Senhora da Luz', 'Jardim Santa Maria', '85903-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25185, 'São José dos Pinhais', 'Nossa Senhora da Luz', 'Cidade Jardim', '83035-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25186, 'Telêmaco Borba', 'Nossa Senhora da Luz', 'Centro', '84261-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25187, 'Almirante Tamandaré', 'Nossa Senhora da Luz', 'Vila Alto Pinheiros', '83503-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25188, 'Curitiba', 'Nossa Senhora da Luz', 'Bacacheri', '82510-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25189, 'Curitiba', 'Nossa Senhora da Luz', 'Hugo Lange', '82520-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25190, 'Curitiba', 'Nossa Senhora da Luz', 'Hugo Lange', '82530-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25191, 'Curitiba', 'Nossa Senhora da Paz', 'Boqueirão', '81730-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25192, 'Cascavel', 'Nossa Senhora da Penha', 'Santos Dumont', '85804-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25193, 'Curitiba', 'Nossa Senhora da Penha', 'Cristo Rei', '80050-550', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25194, 'Colombo', 'Nossa Senhora da Saúde', 'Colônia Faria', '83412-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25195, 'Londrina', 'Nossa Senhora das Graças', 'Gaion', '86071-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25196, 'Londrina', 'Nossa Senhora das Graças', 'Petrópolis', '86015-515', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25197, 'Francisco Beltrão', 'Nossa Senhora das Graças', 'Cango', '85604-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25198, 'Umuarama', 'Nossa Senhora das Graças', 'Conjunto Residencial Vinte e Seis de Junho', '87508-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25199, 'Almirante Tamandaré', 'Nossa Senhora das Graças', 'Vila Alto Pinheiros', '83503-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25200, 'Curitiba', 'Nossa Senhora das Graças', 'Mercês', '80430-230', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25201, 'Foz do Iguaçu', 'Nossa Senhora de Caacupe', 'Vila Paraguaia', '85864-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25202, 'Londrina', 'Nossa Senhora de Fátima', 'Lago Parque', '86015-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25203, 'Piraquara', 'Nossa Senhora de Fátima', 'Centro', '83301-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25204, 'Telêmaco Borba', 'Nossa Senhora de Fátima', 'Centro', '84261-500', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25205, 'Toledo', 'Nossa Senhora de Fátima', 'Jardim Porto Alegre', '85906-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25206, 'Colombo', 'Nossa Senhora de Fátima', 'Jardim La Paloma', '83412-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25207, 'Araucária', 'Nossa Senhora de Fátima', 'Costeira', '83709-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25208, 'Almirante Tamandaré', 'Nossa Senhora de Fátima', 'Parque São Jorge', '83503-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25209, 'Curitiba', 'Nossa Senhora de Fátima', 'Capão da Imbuia', '82800-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25210, 'Umuarama', 'Nossa Senhora de Guadalupe', 'Conjunto Residencial Independência', '87508-096', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25211, 'Curitiba', 'Nossa Senhora de Guadalupe', 'Santa Cândida', '82630-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25212, 'Londrina', 'Nossa Senhora de Lourdes', 'Amaral', '86027-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25213, 'Almirante Tamandaré', 'Nossa Senhora de Lourdes', 'Parque São Jorge', '83503-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25214, 'Curitiba', 'Nossa Senhora de Lourdes', 'Jardim das Américas', '81530-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25215, 'Londrina', 'Nossa Senhora de Nazaré', 'Jardim São Jorge', '86082-805', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25216, 'Curitiba', 'Nossa Senhora de Nazaré', 'Boa Vista', '82540-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25217, 'Curitiba', 'Nossa Senhora de Nazaré', 'Boa Vista', '82560-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25218, 'Francisco Beltrão', 'Nossa Senhora de Salete', 'Cango', '85604-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25219, 'Curitiba', 'Nossa Senhora de Salette', 'Centro Cívico', '80530-180', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25220, 'Ponta Grossa', 'Nossa Senhora de Vila Velha', 'Cará-cará', '84033-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25221, 'Umuarama', 'Nossa Senhora do Caminho', 'Jardim San Fernando', '87508-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25222, 'Londrina', 'Nossa Senhora do Carmo', 'Gaion', '86071-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25223, 'Colombo', 'Nossa Senhora do Carmo', 'Jardim São Gabriel', '83407-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25224, 'Castro', 'Nossa Senhora do Carmo', 'Centro', '84165-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25225, 'Curitiba', 'Nossa Senhora do Carmo', 'Boqueirão', '81650-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25226, 'Londrina', 'Nossa Senhora do Perpétuo Socorro', 'Avelino A Vieira', '86056-145', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25227, 'Araucária', 'Nossa Senhora do Perpétuo Socorro', 'Costeira', '83709-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25228, 'Curitiba', 'Nossa Senhora do Perpétuo Socorro', 'Capão Raso', '81130-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25229, 'Guarapuava', 'Nossa Senhora do Rocio', 'São Cristóvão', '85060-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25230, 'Ponta Grossa', 'Nossa Senhora do Rocio', 'Olarias', '84035-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25231, 'Londrina', 'Nossa Senhora do Rocio', 'Santa Terezinha', '86027-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25232, 'Paranaguá', 'Nossa Senhora do Rocio', 'Rocio', '83221-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25233, 'Toledo', 'Nossa Senhora do Rocio', 'Centro', '85900-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25234, 'Telêmaco Borba', 'Nossa Senhora do Rocio', 'Centro', '84261-430', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25235, 'Toledo', 'Nossa Senhora do Rocio', 'Jardim La Salle', '85902-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25236, 'Arapongas', 'Nossa Senhora do Rocio', 'Centro', '86701-005', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25237, 'Cambé', 'Nossa Senhora do Rocio', 'Centro', '86181-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25238, 'Almirante Tamandaré', 'Nossa Senhora do Rocio', 'Vila Alto Pinheiros', '83503-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25239, 'Curitiba', 'Nossa Senhora do Rocio', 'Santa Cândida', '82720-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25240, 'Castro', 'Nossa Senhora do Rosário', 'Vila Rio Branco', '84172-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25241, 'Colombo', 'Nossa Senhora do Rosário', 'Centro', '83414-280', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25242, 'Curitiba', 'Nossa Senhora do Rosário de Fátima', 'Portão', '81070-380', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25243, 'Curitiba', 'Nossa Senhora do Sagrado Coração', 'Pinheirinho', '81870-010', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25244, 'Londrina', 'Nossa Senhora do Socorro', 'Gaion', '86071-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25245, 'Araucária', 'Nossa Senhora dos Remédios', 'Boqueirão', '83704-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25246, 'Londrina', 'Nossa Senhora Imaculada Conceição', 'Avelino A Vieira', '86056-015', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25247, 'Umuarama', 'Nossa Senhora Pastora', 'Jardim San Martim', '87508-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25248, 'Londrina', 'Nosso Senhor dos Passos', 'Petrópolis', '86015-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25249, 'Almirante Tamandaré', 'Nostradamus', 'Jardim Campos Elísios', '83508-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25250, 'Castro', 'Nova', 'Jardim Social Arapongas', '84174-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25251, 'Curitiba', 'Nova América', 'Campo Comprido', '81240-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25252, 'Sarandi', 'Nova Andradina', 'Jardim Gralha Azul', '87112-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25253, 'Laranjeiras do Sul', 'Nova Aurora', 'Água Verde', '85302-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25254, 'Sarandi', 'Nova Aurora', 'Jardim Nova Independência', '87114-623', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25255, 'Curitiba', 'Nova Aurora', 'Sítio Cercado', '81925-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25256, 'Curitiba', 'Nova Aurora', 'Sítio Cercado', '81920-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25257, 'Curitiba', 'Nova Barigui', 'Cidade Industrial', '81350-300', 'Conjunto', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25258, 'Umuarama', 'Nova Canaã', 'Parque Tarumã', '87508-216', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25259, 'Foz do Iguaçu', 'Nova Cantu', 'Jardim Alvorada', '85859-698', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25260, 'Curitiba', 'Nova Cantu', 'Sítio Cercado', '81925-366', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25261, 'Curitiba', 'Nova de Colombo', 'Santa Cândida', '82720-010', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25262, 'Londrina', 'Nova Delhi', 'Cláudia', '86050-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25263, 'Telêmaco Borba', 'Nova Era', 'Área 06', '84271-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25264, 'Almirante Tamandaré', 'Nova Era', 'Jardim Ipê', '83505-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25265, 'Londrina', 'Nova Esperança', 'Lindóia', '86031-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25266, 'Pinhais', 'Nova Esperança', 'Planta Portal da Serra', '83325-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25267, 'Maringá', 'Nova Esperança', 'Zona 08', '87050-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25268, 'Ponta Grossa', 'Nova Esperança', 'Contorno', '84052-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25269, 'Pinhais', 'Nova Esperança', 'Jardim Atuba I', '83326-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25270, 'Pinhais', 'Nova Esperança', 'Jardim Pedro Demeterco', '83324-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25271, 'Campo Mourão', 'Nova Esperança', 'Jardim Ana Eliza', '87303-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25272, 'Curitiba', 'Nova Esperança', 'Sítio Cercado', '81900-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25273, 'Curitiba', 'Nova Esperança', 'Sítio Cercado', '81925-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25274, 'Ponta Grossa', 'Nova Fátima', 'Contorno', '84052-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25275, 'Curitiba', 'Nova Fátima', 'Xaxim', '81820-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25276, 'Guarapuava', 'Nova Fronteira', 'Vila Bela', '85027-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25277, 'Francisco Beltrão', 'Nova Iguaçu', 'Cristo Rei', '85602-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25278, 'Foz do Iguaçu', 'Nova Iguaçu', 'Jardim Canadá', '85869-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25279, 'Sarandi', 'Nova Iguaçu', 'Parque Residencial Santana', '87112-575', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25280, 'Piraquara', 'Nova Jerusalém', 'Planta Deodoro', '83304-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25281, 'Almirante Tamandaré', 'Nova Jerusalém', 'Jardim Santa Fé', '83511-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25282, 'Laranjeiras do Sul', 'Nova Laranjeiras', 'São Francisco', '85303-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25283, 'Foz do Iguaçu', 'Nova Lima', 'Jardim Vitória', '85853-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25284, 'Telêmaco Borba', 'Nova Lombardia', 'Fazenda Limeira', '84272-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25285, 'Londrina', 'Nova Londrina', 'Lindóia', '86031-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25286, 'Guarapuava', 'Nova Londrina', 'Santana', '85070-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25287, 'Ponta Grossa', 'Nova Londrina', 'Contorno', '84052-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25288, 'Piraquara', 'Nova Londrina', 'Centro', '83301-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25289, 'Sarandi', 'Nova Londrina', 'Jardim Esperança IV', '87112-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25290, 'Curitiba', 'Nova Londrina', 'Augusta', '81290-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25291, 'Londrina', 'Nova Orleans', 'Lima Azevedo', '86060-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25292, 'Curitiba', 'Nova República', 'Capão Raso', '81110-380', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25293, 'Cascavel', 'Nova Santa Rosa', 'Pacaembu', '85816-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25294, 'Almirante Tamandaré', 'Nova Serrana', 'Vila Feliz', '83505-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25295, 'Piraquara', 'Nova Tirol', 'Planta São Tiago', '83306-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25296, 'Apucarana', 'Nova Ucrânia', 'Vila Nossa Senhora da Conceição', '86810-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25297, 'Apucarana', 'Nova Ucrânia', 'Vila Nossa Senhora da Conceição', '86802-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25298, 'Foz do Iguaçu', 'Nova União', 'Jardim Vale do Sol', '85862-458', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25299, 'Foz do Iguaçu', 'Nova Veneza', 'Jardim Veneza', '85870-577', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25300, 'Cambé', 'Nova York', 'Jardim Flórida II', '86182-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25301, 'Francisco Beltrão', 'Nova Zelândia', 'Pinheirinho', '85606-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25302, 'Londrina', 'Novarino Geraldo da Silva', 'Jardim Paris', '86082-086', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25303, 'Ponta Grossa', 'Nove', 'Chapada', '84063-426', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25304, 'Paranavaí', 'Nove', 'Parque Morumbi', '87703-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25305, 'Ponta Grossa', 'Nove', 'Uvaranas', '84022-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25306, 'Ponta Grossa', 'Nove', 'Jardim Carvalho', '84016-518', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25307, 'Ponta Grossa', 'Nove', 'Boa Vista', '84073-248', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25308, 'Ponta Grossa', 'Nove', 'Chapada', '84064-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25309, 'Ponta Grossa', 'Nove', 'Contorno', '84060-597', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25310, 'Piraquara', 'Nove', 'Chácara Águas Claras', '83309-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25311, 'Ponta Grossa', 'Nove', 'Uvaranas', '84032-467', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25312, 'Ponta Grossa', 'Nove', 'Uvaranas', '84026-597', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25313, 'Ponta Grossa', 'Nove', 'Uvaranas', '84030-747', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25314, 'Ponta Grossa', 'Nove', 'Uvaranas', '84030-489', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25315, 'Ponta Grossa', 'Nove', 'Contorno', '84060-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25316, 'Paranaguá', 'Nove', 'Jardim Paraná', '83215-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25317, 'Umuarama', 'Nove', 'Jardim São Cristóvão', '87507-368', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25318, 'Umuarama', 'Nove', 'Jardim Beira Rio', '87507-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25319, 'Sarandi', 'Nove', 'Jardim Independência I', '87114-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25320, 'Umuarama', 'Nove', 'Parque Danielle', '87506-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25321, 'Umuarama', 'Nove', 'Jardim Maria Lúcia', '87501-666', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25322, 'Campo Largo', 'Nove', 'Jardim das Acácias', '83603-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25323, 'Campo Largo', 'Nove', 'Vila Pompéia', '83608-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25324, 'Almirante Tamandaré', 'Nove', 'Jardim Novo Horizonte da Cachoeira', '83502-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25325, 'Campo Largo', 'Nove', 'Loteamento São Gerônimo', '83606-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25326, 'Campo Largo', 'Nove', 'Vila Glória', '83604-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25327, 'Almirante Tamandaré', 'Nove', 'Jardim Tatiana', '83513-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25328, 'Campo Largo', 'Nove', 'Moradias Bom Jesus', '83602-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25329, 'Almirante Tamandaré', 'Nove', 'Jardim Cíntia Mara', '83513-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25330, 'Campo Largo', 'Nove', 'Jardim Keli Cristina', '83609-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25331, 'Almirante Tamandaré', 'Nove', 'Jardim Gineste', '83505-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25332, 'Campo Largo', 'Nove', 'Jardim Lorenzete', '83603-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25333, 'Campo Largo', 'Nove', 'Jardim Guairacá', '83608-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25334, 'Almirante Tamandaré', 'Nove', 'Jardim das Oliveiras', '83502-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25335, 'Almirante Tamandaré', 'Nove', 'Loteamento Marinoni', '83508-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25336, 'Curitiba', 'Nove', 'Cidade Industrial', '81315-300', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25337, 'Guarapuava', 'Nove de Abril', 'Morro Alto', '85065-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25338, 'Paranaguá', 'Nove de Agosto', 'Centro Histórico', '83203-006', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25339, 'Guarapuava', 'Nove de Dezembro', 'Santana', '85070-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25340, 'Guarapuava', 'Nove de Dezembro', 'Centro', '85010-340', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25341, 'Umuarama', 'Nove de Julho', 'Parque Presidente', '87505-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25342, 'Cambé', 'Nove de Julho', 'Vila Atalaia', '86181-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25343, 'Apucarana', 'Nove de Setembro', 'Vila São Jorge', '86800-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25344, 'Umuarama', 'Novo Caminho', 'Parque Caiuá', '87508-237', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25345, 'Francisco Beltrão', 'Novo Hamburgo', 'Pinheirinho', '85603-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25346, 'Foz do Iguaçu', 'Novo Hamburgo', 'Jardim Alvorada', '85859-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25347, 'Foz do Iguaçu', 'Novo Horizonte', 'Loteamento Mata Verde', '85853-687', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25348, 'Maringá', 'Novo Horizonte', 'Jardim Novo Horizonte', '87005-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25349, 'Almirante Tamandaré', 'Novo Horizonte', 'Vila Feliz', '83505-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25350, 'Francisco Beltrão', 'Novo Mundo', 'Jardim Novo Mundo', '85602-766', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25351, 'Umuarama', 'Novo Paraíso', 'Parque Caiuá', '87508-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25352, 'Ponta Grossa', 'Nunes Machado', 'Colônia Dona Luiza', '84045-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25353, 'Curitiba', 'Nunes Machado', 'Centro', '80250-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25354, 'Curitiba', 'Nunes Machado', 'Rebouças', '80220-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25355, 'Curitiba', 'Nunes Machado', 'Parolin', '80220-071', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25356, 'Londrina', 'Nuno Roland', 'Indústrias Leves', '86030-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25357, 'Cascavel', 'Nurburgring', 'Interlagos', '85814-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25358, 'Foz do Iguaçu', 'Nutria', 'Conjunto A', '85861-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25359, 'São José dos Pinhais', 'Nyr Marcílio de Oliveira', 'Bom Jesus', '83025-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25360, 'Foz do Iguaçu', 'O', 'Conjunto C', '85870-396', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25361, 'Umuarama', 'O', 'Conjunto Residencial Porto Belo', '87506-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25362, 'Campo Largo', 'O', 'Vila Torres II', '83609-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25363, 'Campo Largo', 'O', 'Popular Nova', '83602-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25364, 'Campo Largo', 'O', 'Vila Nossa Senhora do Carmo', '83601-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25365, 'Curitiba', 'O Brasil para Cristo', 'Boqueirão', '81650-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25366, 'Curitiba', 'O Brasil para Cristo', 'Boqueirão', '81730-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25367, 'Ponta Grossa', 'O Brasil Pará Cristo', 'Chapada', '84063-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25368, 'Curitiba', 'Oadi Jorge Barbosa', 'Sítio Cercado', '81900-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25369, 'Londrina', 'Oakland', 'Quebec', '86060-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25370, 'Curitiba', 'Oatre Brambilla', 'Capão da Imbuia', '82810-640', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25371, 'Cambé', 'Obatã', 'Jardim do Café', '86186-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25372, 'Curitiba', 'Oberon Floriano Dittert', 'Pinheirinho', '81880-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25373, 'Toledo', 'Ocelino Arrosi', 'Residencial Santa Clara', '85903-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25374, 'Piraquara', 'Octacílio Rodrigues', 'Guarituba', '83311-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25375, 'Curitiba', 'Octacyr Reinaldo Mion', 'Xaxim', '81710-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25376, 'Toledo', 'Octaviano Angeli', 'Residencial Santa Clara', '85903-708', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25377, 'Cascavel', 'Octaviano Daros', 'Santa Cruz', '85806-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25378, 'Ponta Grossa', 'Octaviano Macedo Ribas', 'Boa Vista', '84070-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25379, 'Paranavaí', 'Octaviano Pires de Oliveira', 'Vila City', '87709-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25380, 'Francisco Beltrão', 'Octaviano Teixeira dos Santos', 'Centro', '85601-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25381, 'Guarapuava', 'Octavino B. Martins', 'Primavera', '85050-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25382, 'São José dos Pinhais', 'Octávio Cim', 'Afonso Pena', '83050-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25383, 'Londrina', 'Octávio Clivati', 'Franciscone', '86083-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25384, 'Sarandi', 'Octávio Colli', 'Jardim Itamaraty', '87112-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25385, 'Ponta Grossa', 'Octávio de Carvalho', 'Jardim Carvalho', '84016-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25386, 'Ponta Grossa', 'Octávio de Carvalho', 'Jardim Carvalho', '84015-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25387, 'Curitiba', 'Octávio de Sá Barreto', 'Batel', '80420-230', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25388, 'Curitiba', 'Octávio Girardi', 'Cajuru', '82930-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25389, 'Curitiba', 'Octávio Joppert', 'São João', '82020-255', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25390, 'Castro', 'Octávio Paes de Almeida', 'Invernada do Matadouro', '84174-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25391, 'Castro', 'Octávio Pereira da Silva Júnior', 'Jardim das Araucárias', '84172-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25392, 'Maringá', 'Octávio Perioto', 'Zona 01', '87013-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25393, 'Curitiba', 'Octávio Primo Stocchero', 'Butiatuvinha', '82400-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25394, 'Apucarana', 'Octávio Rechi', 'Jardim Catuaí', '86802-607', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25395, 'Curitiba', 'Octávio Schiavon', 'Capão da Imbuia', '82800-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25396, 'São José dos Pinhais', 'Octávio Secundino', 'São Sebastião', '83075-087', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25397, 'Cascavel', 'Octávio Silvério Siqueira', '14 de Novembro', '85804-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25398, 'Curitiba', 'Octávio Sylvio Nicco', 'Mossunguê', '81200-215', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25399, 'Ponta Grossa', 'Octávio Trindade de Almeida', 'Oficinas', '84045-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25400, 'Cascavel', 'Octávio Vaz', 'Santa Felicidade', '85803-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25401, 'Curitiba', 'Octávio Xavier Rauen', 'Seminário', '80740-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25402, 'Londrina', 'Octávio Zanetti', 'Cambesa', '86015-666', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25403, 'Foz do Iguaçu', 'Ocui', 'Loteamento João Paulo II', '85857-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25404, 'Curitiba', 'Odacir Schilipak', 'Santa Cândida', '82640-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25405, 'Apucarana', 'Odair Luiz Pupo', 'Jardim Santos Dumont I', '86812-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25406, 'Curitiba', 'Odair Pazello', 'Capão Raso', '81130-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25407, 'Curitiba', 'Odalea Costa Águas', 'Cajuru', '82930-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25408, 'Londrina', 'Odalfe Sapia', 'Assis', '86085-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25409, 'Londrina', 'Odécio Simino', 'Recanto Nobre', '86050-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25410, 'Curitiba', 'Odenir Dissenha', 'Uberaba', '81590-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25411, 'Curitiba', 'Odenir Silveira', 'Xaxim', '81810-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25412, 'Londrina', 'Odete Dias de Santana', 'Jardim São Jorge', '86082-818', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25413, 'Curitiba', 'Odete Fatuch', 'Bacacheri', '82600-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25414, 'Curitiba', 'Odete Laura Foggiato', 'Atuba', '82630-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25415, 'São José dos Pinhais', 'Odete Maximiano de Sousa', 'São Sebastião', '83075-086', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25416, 'Umuarama', 'Odete Mossurunga', 'Zona VII', '87503-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25417, 'Almirante Tamandaré', 'Odete Pereira', 'Jardim Mônica', '83505-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25418, 'Curitiba', 'Odete Tezolin', 'Cidade Industrial', '81315-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25419, 'Curitiba', 'Odijalmas Sabóia Lima', 'Santa Cândida', '82630-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25420, 'Sarandi', 'Odila Toriani Lemuchi', 'Parque Alvamar', '87113-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25421, 'Londrina', 'Odília Alves Pedra', 'Ernani de Moura Lima', '86037-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25422, 'Apucarana', 'Odilio Silva', 'Vila São Jorge', '86802-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25423, 'Telêmaco Borba', 'Odilon Borba', 'Vila Ozorio', '84268-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25424, 'Londrina', 'Odilon Borges de Carvalho', 'Shangri-La', '86070-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25425, 'Londrina', 'Odilon Braga', 'Sebastião de Melo César', '86084-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25426, 'Araucária', 'Odilon Carrano', 'Fazenda Velha', '83703-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25427, 'Cascavel', 'Odilon Cirilo Barbosa', 'Cancelli', '85811-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25428, 'Curitiba', 'Odilon de Santa Rita Borba', 'Bacacheri', '82510-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25429, 'Curitiba', 'Odilon Figueiredo', 'Pinheirinho', '81870-018', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25430, 'Curitiba', 'Odilon Lustosa Ribas', 'Vista Alegre', '80820-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25431, 'Paranaguá', 'Odilon Mader', 'Estradinha', '83206-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25432, 'Paranaguá', 'Odilon Mader', 'Vila Paranaguá', '83221-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25433, 'Curitiba', 'Odilon Mader', 'São Francisco', '80510-060', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25434, 'Londrina', 'Odilon Marcondes das Dores', 'Cilo 3', '86072-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25435, 'Curitiba', 'Odilon Negrão', 'Santa Felicidade', '82020-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25436, 'Curitiba', 'Odilon Ramos', 'Cajuru', '82980-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25437, 'Curitiba', 'Odilon Santana Gomes', 'Pilarzinho', '82110-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25438, 'Curitiba', 'Odin de Oliveira Pacheco', 'Lamenha Pequena', '82410-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25439, 'Curitiba', 'Odin Ferreira do Amaral', 'Batel', '80240-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25440, 'Pinhais', 'Odinei de Lima Godói', 'Vale da Boa Esperança', '83320-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25442, 'Paranavaí', 'Odinot Machado', 'Jardim Ouro Branco', '87704-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25443, 'Paranavaí', 'Odinot Machado', 'Jardim Ouro Branco', '87703-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25444, 'Paranavaí', 'Odinot Machado', 'Centro', '87705-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25445, 'Curitiba', 'Odir Gomes da Rocha', 'Tatuquara', '81470-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25446, 'Curitiba', 'Odir Susin', 'Alto Boqueirão', '81850-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25447, 'Pinhais', 'Odith Mallmann Santos', 'Vila Maria Antonieta', '83331-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25448, 'Foz do Iguaçu', 'Oditon Sottomaior Ramos', 'Jardim das Flores', '85862-486', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25449, 'Londrina', 'Odocas Camilo', 'Parque Residencial Campos Elísios', '86044-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25450, 'Colombo', 'Odonis Bighi', 'Jardim das Flores', '83402-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25451, 'Cascavel', 'Odontologia', 'Universitário', '85819-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25452, 'Castro', 'Odorico Barbosa Bueno', 'Castroville', '84178-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25453, 'Ponta Grossa', 'Odorico Mendes', 'Jardim Carvalho', '84016-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25454, 'Francisco Beltrão', 'Odosio Dalla Maria', 'Pinheirinho', '85603-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25455, 'Almirante Tamandaré', 'Odracir Dias dos Santos', 'Loteamento Nova Morada', '83504-686', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25456, 'Londrina', 'Oduvaldo Viana', 'Novo Amparo', '86043-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25457, 'Foz do Iguaçu', 'Oduvaldo Viana Filho', 'Jardim Comercial das Bandeiras', '85864-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25458, 'Londrina', 'Ody Silveira', 'Alto da Boa Vista', '86083-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25459, 'Londrina', 'Oeste', 'Leste Oeste', '86072-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25460, 'Curitiba', 'Oficinas', 'Cajuru', '82950-390', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25461, 'Curitiba', 'Ogeny Pedro Maia', 'Sítio Cercado', '81910-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25462, 'Londrina', 'Ohio', 'Los Angeles', '86020-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25463, 'Curitiba', 'Ohio', 'Água Verde', '80240-150', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25464, 'Londrina', 'Oiapoque', 'Jardim Agari', '86025-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25465, 'Paranaguá', 'Oiti', 'Vila São Vicente', '83209-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25466, 'Francisco Beltrão', 'Oito', 'Pinheirinho', '85603-172', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25467, 'Piraquara', 'Oito', 'Chácara Águas Claras', '83309-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25468, 'Piraquara', 'Oito', 'Chácara Águas Claras', '83309-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25469, 'Paranaguá', 'Oito', 'Jardim Paraná', '83215-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25470, 'Ponta Grossa', 'Oito', 'Contorno', '84060-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25471, 'Ponta Grossa', 'Oito', 'Uvaranas', '84022-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25472, 'Ponta Grossa', 'Oito', 'Uvaranas', '84032-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25473, 'Ponta Grossa', 'Oito', 'Contorno', '84060-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25474, 'Ponta Grossa', 'Oito', 'Chapada', '84064-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25475, 'Ponta Grossa', 'Oito', 'Uvaranas', '84032-466', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25476, 'Ponta Grossa', 'Oito', 'Uvaranas', '84030-488', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25477, 'Ponta Grossa', 'Oito', 'Uvaranas', '84030-746', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25478, 'Ponta Grossa', 'Oito', 'Jardim Carvalho', '84016-517', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25479, 'Ponta Grossa', 'Oito', 'Uvaranas', '84026-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25480, 'Ponta Grossa', 'Oito', 'Chapada', '84063-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25481, 'Ponta Grossa', 'Oito', 'Chapada', '84063-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25482, 'Paranavaí', 'Oito', 'Conjunto Dona Josefa', '87708-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25483, 'Umuarama', 'Oito', 'Jardim Maria Lúcia', '87501-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25484, 'Umuarama', 'Oito', 'Jardim São Cristóvão', '87507-367', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25485, 'Sarandi', 'Oito', 'Jardim Nova Independência I', '87114-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25486, 'Umuarama', 'Oito', 'Jardim Beira Rio', '87507-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25487, 'Campo Largo', 'Oito', 'Jardim Guairacá', '83608-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25488, 'Campo Largo', 'Oito', 'Jardim Lorenzete', '83603-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25489, 'Campo Largo', 'Oito', 'Vila Pompéia', '83608-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25490, 'Campo Largo', 'Oito', 'Jardim das Acácias', '83603-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25491, 'Almirante Tamandaré', 'Oito', 'Jardim das Oliveiras', '83502-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25492, 'Campo Largo', 'Oito', 'Moradias Bom Jesus', '83602-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25493, 'Almirante Tamandaré', 'Oito', 'Jardim Tatiana', '83513-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25494, 'Almirante Tamandaré', 'Oito', 'Loteamento Marinoni', '83508-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25495, 'Campo Largo', 'Oito', 'Vila São Luiz', '83608-137', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25496, 'Campo Largo', 'Oito', 'Jardim Padre José de Anchieta', '83607-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25497, 'Curitiba', 'Oito', 'Cidade Industrial', '81315-200', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25498, 'Umuarama', 'Oito de Dezembro', 'Mutirão Jardim Alvorada', '87506-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25499, 'São José dos Pinhais', 'Oito de Janeiro', 'Centro', '83005-110', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25500, 'Cascavel', 'Oito de Maio', 'Maria Luiza', '85819-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25501, 'Curitiba', 'Oito de Maio', 'Alto Boqueirão', '81850-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25502, 'Umuarama', 'Oito de Março', 'Mutirão Jardim Alvorada', '87506-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25503, 'Curitiba', 'Oito de Março', 'Cidade Industrial', '81170-490', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25504, 'Maringá', 'Oito de Setembro', 'Jardim Alamar', '87014-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25505, 'Almirante Tamandaré', 'Olaria', 'Jardim Graziele', '83505-695', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25506, 'Almirante Tamandaré', 'Olaria', 'Vila Graziela', '83505-690', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25507, 'Curitiba', 'Olávio Barwik', 'Abranches', '82220-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25508, 'Piraquara', 'Olávio de Souza', 'Vila Santa Maria', '83306-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25509, 'Londrina', 'Olavo Bilac', 'Champagnat', '86062-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25510, 'Laranjeiras do Sul', 'Olavo Bilac', 'Centro', '85301-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25511, 'Guarapuava', 'Olavo Bilac', 'Conradinho', '85055-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25512, 'Foz do Iguaçu', 'Olavo Bilac', 'Vila Portes', '85865-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25513, 'Paranavaí', 'Olavo Bilac', 'Jardim São Jorge', '87710-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25514, 'Ponta Grossa', 'Olavo Bilac', 'Uvaranas', '84026-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25515, 'Pato Branco', 'Olavo Bilac', 'Bortot', '85504-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25516, 'Pinhais', 'Olavo Bilac', 'Núcleo Colonial de Pinhais', '83321-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25517, 'Piraquara', 'Olavo Bilac', 'Jardim Bela Vista', '83301-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25518, 'Toledo', 'Olavo Bilac', 'Jardim Paraná', '85904-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25519, 'São José dos Pinhais', 'Olavo Bilac', 'Colônia Rio Grande', '83025-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25520, 'Apucarana', 'Olavo Bilac', 'Jardim América', '86807-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25521, 'Apucarana', 'Olavo Bilac', 'Jardim Ponta Grossa', '86805-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25522, 'Cascavel', 'Olavo Bilac', 'Centro', '85812-141', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25523, 'Cascavel', 'Olavo Bilac', 'Centro', '85812-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25524, 'Colombo', 'Olavo Bilac', 'Parque Monte Castelo', '83409-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25525, 'Almirante Tamandaré', 'Olavo Bilac', 'Vila Marta', '83508-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25526, 'Campo Largo', 'Olavo Bilac', 'Jardim São Vicente', '83602-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25527, 'Campo Largo', 'Olavo Bilac', 'Jardim Busmayer', '83606-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25528, 'Curitiba', 'Olavo Bilac', 'Batel', '80440-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25529, 'Curitiba', 'Olavo Chagas Correia', 'Novo Mundo', '81010-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25530, 'Ponta Grossa', 'Olavo de Paula Barbosa', 'Neves', '84020-786', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25531, 'Londrina', 'Olavo Garcia Ferreira da Silva', 'Portal de Versalhes 3', '86055-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25532, 'Apucarana', 'Olavo M. Guides', 'Núcleo Habitacional João Goulart', '86807-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25533, 'São José dos Pinhais', 'Olavo Nenes de Almeida', 'Miringuava', '83090-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25534, 'Ponta Grossa', 'Oldimar Cornélio Janser', 'Contorno', '84061-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25535, 'Foz do Iguaçu', 'Olegar da Silva Souza', 'Jardim Florença', '85867-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25536, 'Curitiba', 'Olegário Ayres de Arruda', 'Bom Retiro', '80520-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25537, 'Ponta Grossa', 'Olegário Maciel', 'Nova Rússia', '84070-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25538, 'Curitiba', 'Olegário Maciel', 'Fazendinha', '81330-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25539, 'Ponta Grossa', 'Olegário Mariano', 'Neves', '84020-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25540, 'Toledo', 'Olegário Mariano', 'Panorama', '85911-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25541, 'Curitiba', 'Olegário Reis do Amaral', 'Cidade Industrial', '81350-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25542, 'Londrina', 'Óleo Pardo', 'Leonor', '86071-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25543, 'Campo Mourão', 'Óleo Pardo', 'Jardim Santa Nilce I', '87308-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25544, 'Curitiba', 'Olga Baptista Beviláqua', 'Alto Boqueirão', '81830-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25545, 'Araucária', 'Olga Cantador Incot', 'Boqueirão', '83704-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25546, 'Curitiba', 'Olga de Araújo Espíndola', 'Novo Mundo', '81050-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25547, 'Curitiba', 'Olga Edith de Menezes', 'Centro', '80430-280', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25548, 'Curitiba', 'Olga Graleska de Oliveira Lima', 'Tarumã', '82530-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25549, 'Curitiba', 'Olga Mazepa de Paula', 'Cajuru', '82960-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25550, 'Curitiba', 'Olga Monteiro Cortes', 'Sítio Cercado', '81900-767', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25551, 'Foz do Iguaçu', 'Olga Royer', 'Jardim Porto Belo', '85867-598', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25552, 'Almirante Tamandaré', 'Olho d''água', 'Jardim Ipê', '83505-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25553, 'Arapongas', 'Olho-de-fogo', 'Conjunto Tropical', '86702-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25554, 'Pato Branco', 'Oliden Rotava', 'Menino Deus', '85509-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25555, 'Foz do Iguaçu', 'Olímpia', 'Jardim Lancaster', '85869-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25556, 'Londrina', 'Olímpia', 'Jardim Alvorada', '86062-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25557, 'Foz do Iguaçu', 'Olímpico', 'Parque Morumbi III', '85859-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25558, 'Maringá', 'Olímpico', 'Jardim Kosmos', '87070-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25559, 'Colombo', 'Olímpio Cardoso', 'Vila São Paulo', '83411-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25560, 'Curitiba', 'Olímpio de Paula Xavier', 'Alto Boqueirão', '81850-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25561, 'São José dos Pinhais', 'Olímpio Ferreira da Cruz', 'Miringuava', '83090-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25562, 'Curitiba', 'Olímpio Gomes de Carvalho', 'Alto Boqueirão', '81770-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25563, 'Londrina', 'Olímpio Lopes', 'Lagoa Dourada', '86041-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25564, 'Londrina', 'Olimpio Lopes dos Santos', 'São Lourenço', '86043-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25565, 'Maringá', 'Olímpio Mendes da Rocha', 'Jardim Sol', '87023-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25566, 'Maringá', 'Olímpio Mendes da Rocha', 'Vila Esperança', '87020-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25567, 'Foz do Iguaçu', 'Olímpio Rafagnin', 'Parque Presidente II', '85863-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25568, 'Foz do Iguaçu', 'Olímpio Rafagnin', 'Parque Presidente II', '85862-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25569, 'Curitiba', 'Olímpio Sotto Maior Sobrinho', 'Vista Alegre', '80820-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25570, 'Maringá', 'Olímpio Totti', 'Jardim das Nações', '87060-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25571, 'Telêmaco Borba', 'Olímpio Vieira de Campos', 'Socomim', '84265-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25572, 'Francisco Beltrão', 'Olinda', 'Pinheirinho', '85603-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25573, 'Londrina', 'Olinda', 'Vila Ipiranga', '86010-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25574, 'Foz do Iguaçu', 'Olinda', 'Jardim Duarte', '85861-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25575, 'Guarapuava', 'Olinda', 'Vila Bela', '85027-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25576, 'Maringá', 'Olinda', 'Jardim Alvorada', '87033-090', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25577, 'Umuarama', 'Olinda', 'Jardim Cidade Alta', '87502-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25578, 'Telêmaco Borba', 'Olinda', 'Área 03', '84271-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25579, 'Umuarama', 'Olinda', 'Jardim Tamoio', '87505-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25580, 'Curitiba', 'Olinda', 'Santa Cândida', '82640-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25581, 'Curitiba', 'Olinda Paula Botto de Barros', 'Pilarzinho', '82100-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25582, 'Paranavaí', 'Olindina da Silva', 'Jardim Videira', '87711-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25583, 'Londrina', 'Olindina Evangelista', 'Jardim Maracanã', '86056-870', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25584, 'Curitiba', 'Olindo Baggio', 'Campo Comprido', '81210-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25585, 'Curitiba', 'Olindo Caetani', 'Uberaba', '81590-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25586, 'Curitiba', 'Olindo Caetani', 'Uberaba', '81550-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25587, 'Curitiba', 'Olindo Caetani', 'Uberaba', '81580-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25588, 'Ponta Grossa', 'Olindo Marenda', 'Contorno', '84060-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25589, 'Francisco Beltrão', 'Olindo Massotti', 'Sadia', '85606-396', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25590, 'Cascavel', 'Olindo Periolo', 'Pacaembu', '85816-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25591, 'Curitiba', 'Olindo Sequinel', 'Capão Raso', '81150-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25592, 'Pato Branco', 'Olindo Setti', 'La Salle', '85505-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25593, 'Pato Branco', 'Olindo Setti', 'Parzianello', '85504-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25594, 'Pinhais', 'Olintho Fernandes', 'Prive Bois de Boulogne', '83330-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25595, 'Curitiba', 'Olintho Vidigal', 'Capão Raso', '81110-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25596, 'Araucária', 'Olinto Lemos', 'Capela Velha', '83706-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25597, 'Londrina', 'Olinto Pedriali', 'Jamile Dequech', '86048-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25598, 'Cascavel', 'Oliva', 'Universitário', '85819-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25599, 'Ponta Grossa', 'Olival Baer', 'Uvaranas', '84030-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25600, 'Laranjeiras do Sul', 'Olivar Amaral', 'Centro', '85301-390', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25601, 'Maringá', 'Olivar Freitas Paiva', 'Conjunto João de Barro Cidade Canção', '87053-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25602, 'Ponta Grossa', 'Oliveira', 'Uvaranas', '84033-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25603, 'Telêmaco Borba', 'Oliveira', 'Vila São Francisco de Assis', '84264-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25604, 'Apucarana', 'Oliveira', 'Vila Nossa Senhora da Aparecida', '86810-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25605, 'Curitiba', 'Oliveira', 'Guabirotuba', '81510-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25606, 'Curitiba', 'Oliveira Bello', 'Centro', '80020-030', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25607, 'Ponta Grossa', 'Oliveira Belo', 'Olarias', '84035-750', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25608, 'São José dos Pinhais', 'Oliveira Corrêa Branco', 'Ipê', '83055-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25609, 'Ponta Grossa', 'Oliveira Lima', 'Uvaranas', '84020-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25610, 'Ponta Grossa', 'Oliveira Martins', 'Olarias', '84035-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25611, 'Curitiba', 'Oliveira Viana', 'Hauer', '81630-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25612, 'Curitiba', 'Oliveira Viana', 'Boqueirão', '81670-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25613, 'Campo Mourão', 'Oliveira Zanini', 'Jardim Cidade Nova', '87308-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25614, 'Colombo', 'Olivério Ceccon', 'São João', '83415-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25615, 'Guarapuava', 'Olivério Estaciano dos Santos', 'São Cristóvão', '85063-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25616, 'Curitiba', 'Olívia Bandeira Singer', 'Pinheirinho', '81820-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25617, 'Londrina', 'Olívia Conceição Cândido de Souza', 'Jardim Barcelona', '86073-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25618, 'Colombo', 'Olívia Ferraz', 'Jardim dos Eucaliptos', '83408-539', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25619, 'Curitiba', 'Olívia G. Freitas', 'Orleans', '82310-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25620, 'São José dos Pinhais', 'Olívia Gazola Pissaia', 'Carioca', '83005-130', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25621, 'Cascavel', 'Olívia Kucinski', 'Vila Tolentino', '85802-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25622, 'Toledo', 'Olívia Leonardi', 'Vila Brasil', '85909-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25623, 'Maringá', 'Olívia Lina', 'Zona 07', '87020-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25624, 'Piraquara', 'Olívia Palhares da Silva', 'Jardim Caiçara', '83314-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25625, 'Londrina', 'Olívia Stramandinoli', 'Jardim Bavária', '86082-017', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25626, 'Francisco Beltrão', 'Olívia Tortora', 'Sadia', '85606-397', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25627, 'Foz do Iguaçu', 'Olívia Vieira Dotto', 'Jardim Porto Belo', '85867-597', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25628, 'Pato Branco', 'Olívio Copetti', 'La Salle', '85505-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25629, 'Curitiba', 'Olívio Coraiola', 'Santo Inácio', '82010-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25630, 'Curitiba', 'Olívio Domingos Leonardi', 'Sítio Cercado', '81925-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25631, 'Curitiba', 'Olívio dos Santos', 'Cidade Industrial', '81460-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25632, 'Curitiba', 'Olívio José Rosseti', 'Tatuquara', '81470-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25633, 'Foz do Iguaçu', 'Olívio Mazzarolo', 'Jardim Panorama II', '85856-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25634, 'Londrina', 'Olívio Pedro Benatto', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25635, 'Colombo', 'Olívio Rocha', 'Jardim Bandeirantes', '83408-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25636, 'Campo Mourão', 'Olívio Salvadori', 'Jardim Cidade Nova', '87308-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25637, 'Ponta Grossa', 'Olívio Scorsim', 'Chapada', '84063-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25638, 'São José dos Pinhais', 'Olívio Setim', 'Afonso Pena', '83065-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25639, 'São José dos Pinhais', 'Olívio Tozzo', 'Miringuava', '83090-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25640, 'Curitiba', 'Olívio Zagonel', 'Campo Comprido', '81220-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25641, 'Toledo', 'Olivo Beal', 'Jardim Concórdia', '85906-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25642, 'Curitiba', 'Olivo Carnasciali', 'Cajuru', '82970-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25643, 'Londrina', 'Olver Serra Zanetti', 'Conjunto Habitacional José Garcia Molina', '86080-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25644, 'Londrina', 'Olympio Theodoro', 'Colinas', '86056-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25645, 'Curitiba', 'Olympio Trombini', 'Vista Alegre', '82020-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25646, 'Londrina', 'Olympio Victório Passeio', 'Jardim das Palmeiras', '86083-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25647, 'Curitiba', 'Omar Dutra', 'São Lourenço', '82200-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25648, 'Curitiba', 'Omar Raymundo Picheth', 'Xaxim', '81810-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25649, 'Curitiba', 'Omílio Monteiro Soares', 'Fanny', '81030-001', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25650, 'Curitiba', 'Omílio Monteiro Soares', 'Fanny', '81030-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25651, 'Foz do Iguaçu', 'Onça', 'Conjunto A', '85861-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25652, 'Piraquara', 'Ondina de Souza', 'Vila São Cristóvão', '83305-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25653, 'Guarapuava', 'Onesta Paganini Pacheco', 'Boqueirão', '85020-709', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25654, 'Colombo', 'Onezino Rodrigues da Silva', 'Capivari', '83415-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25655, 'Londrina', 'Onivaldo Davanco', 'Residencial Portal do Sol', '86082-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25656, 'Foz do Iguaçu', 'Ônix', 'Parque Ouro Verde', '85854-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25657, 'Maringá', 'Ônix', 'Jardim Real', '87083-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25658, 'Ponta Grossa', 'Ônix', 'Neves', '84021-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25659, 'Umuarama', 'Ônix', 'Conjunto Residencial Ouro Branco', '87508-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25660, 'Campo Mourão', 'Ônix', 'Jardim Tropical I', '87310-227', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25661, 'Cascavel', 'Ônix', 'Esmeralda', '85806-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25662, 'Cambé', 'Ônix', 'Conjunto Habitacional Cristal', '86182-707', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25663, 'Londrina', 'Onofra Moreira de Moraes', 'Leste Oeste', '86037-809', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25664, 'Maringá', 'Onofre Alves', 'Vila Esperança', '87020-505', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25665, 'São José dos Pinhais', 'Onofre Holthman', 'Rio Pequeno', '83085-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25666, 'Curitiba', 'Onofre Pedro dos Santos', 'São João', '82030-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25667, 'Almirante Tamandaré', 'Onofre Zinherco', 'Jardim Formosa', '83511-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25668, 'Francisco Beltrão', 'Onofrio Ferronato', 'Sadia', '85606-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25669, 'Toledo', 'Onofrio Lemos', 'Panorama', '85911-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25670, 'Ponta Grossa', 'Onze', 'Contorno', '84060-599', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25671, 'Ponta Grossa', 'Onze', 'Uvaranas', '84030-749', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25672, 'Ponta Grossa', 'Onze', 'Jardim Carvalho', '84016-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25673, 'Ponta Grossa', 'Onze', 'Chapada', '84064-578', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25674, 'Ponta Grossa', 'Onze', 'Chapada', '84063-428', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25675, 'Ponta Grossa', 'Onze', 'Contorno', '84060-578', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25676, 'Ponta Grossa', 'Onze', 'Uvaranas', '84022-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25677, 'Ponta Grossa', 'Onze', 'Uvaranas', '84030-506', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25678, 'Ponta Grossa', 'Onze', 'Uvaranas', '84032-469', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25679, 'Ponta Grossa', 'Onze', 'Contorno', '84052-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25680, 'Ponta Grossa', 'Onze', 'Uvaranas', '84026-599', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25681, 'Umuarama', 'Onze', 'Jardim Maria Lúcia', '87501-668', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25682, 'Almirante Tamandaré', 'Onze', 'Loteamento Marinoni', '83508-568', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25683, 'Campo Largo', 'Onze', 'Loteamento São Gerônimo', '83606-247', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25684, 'Campo Largo', 'Onze', 'Jardim Keli Cristina', '83609-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25685, 'Campo Largo', 'Onze', 'Jardim das Acácias', '83603-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25686, 'Campo Largo', 'Onze', 'Jardim Lorenzete', '83603-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25687, 'Almirante Tamandaré', 'Onze', 'Jardim Tatiana', '83513-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25688, 'Almirante Tamandaré', 'Onze', 'Jardim Gerhusa', '83512-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25689, 'Curitiba', 'Onze de Agosto', 'Xaxim', '81830-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25690, 'Araucária', 'Onze de Fevereiro', 'Centro', '83702-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25691, 'Pinhais', 'Onze de Junho', 'Jardim Pinhais', '83323-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25692, 'Maringá', 'Onze de Março', 'Jardim Alamar', '87014-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25693, 'Cambé', 'Onze de Outubro', 'Jardim União', '86185-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25694, 'Maringá', 'Opala', 'Jardim Brasil', '87083-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25695, 'Ponta Grossa', 'Opala', 'Neves', '84021-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25696, 'Cascavel', 'Opala', 'Esmeralda', '85806-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25697, 'Foz do Iguaçu', 'Opalas', 'Parque Ouro Verde', '85854-010', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25698, 'Campo Mourão', 'Operária', 'Jardim Urupês', '87303-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25699, 'Curitiba', 'Operário Santo Dias', 'Alto Boqueirão', '81850-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25700, 'Paranavaí', 'Operários', 'Jardim São Jorge', '87710-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25701, 'Ponta Grossa', 'Operários', 'Olarias', '84035-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25702, 'Curitiba', 'Ophir Ruy Woitowicz', 'Sítio Cercado', '81925-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25703, 'Curitiba', 'Opilio de Mello Pinheiro', 'Novo Mundo', '81050-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25704, 'Foz do Iguaçu', 'Oracildo Pedro Marquioro', 'Jardim Califórnia', '85867-507', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25705, 'Londrina', 'Orácio de Oliveira', 'Alto da Boa Vista', '86083-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25706, 'Curitiba', 'Oracy Gemba', 'Sítio Cercado', '81920-760', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25707, 'Almirante Tamandaré', 'Oraide de Paula Pacheco', 'Vila Alto Pinheiros', '83503-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25708, 'Londrina', 'Oraldo Waldemar Sproger', 'Jardim São Jorge', '86082-819', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25709, 'Guarapuava', 'Orastina de Miranda', 'São Cristóvão', '85015-530', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25710, 'Londrina', 'Orégano', 'Jardim Novo Sabará', '86066-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25711, 'Curitiba', 'Orestes Beltrami', 'Pilarzinho', '82120-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25712, 'Curitiba', 'Orestes Camilli', 'Prado Velho', '80215-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25713, 'Curitiba', 'Orestes Códega', 'Pinheirinho', '81150-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25714, 'Ponta Grossa', 'Orestes de Deus Colecte', 'Uvaranas', '84030-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25715, 'São José dos Pinhais', 'Orestes Foggiatto', 'Costeira', '83015-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25716, 'Cascavel', 'Orestes Kolmann', 'Brasmadeira', '85814-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25717, 'Londrina', 'Orestes Medeiros Pullin', 'Marumbi', '86071-375', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25718, 'Londrina', 'Orestes Medeiros Pullin', 'Conjunto Café', '86038-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25719, 'Cambé', 'Orestes Omodei', 'Jardim Vitória', '86184-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25720, 'Francisco Beltrão', 'Orestes Pavan', 'Luther King', '85605-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25721, 'Colombo', 'Orestes Pavin', 'Jardim Solimões', '83402-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25722, 'São José dos Pinhais', 'Orestes Persegona', 'Afonso Pena', '83050-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25723, 'Curitiba', 'Orestes Romeu Bizzotto', 'Tatuquara', '81480-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25724, 'Curitiba', 'Orestes Thá', 'Cidade Industrial', '81350-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25725, 'Curitiba', 'Orias Ricardo', 'Cajuru', '82950-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25726, 'Colombo', 'Orides Alves Ribeiro', 'Jardim Cristina', '83410-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25727, 'Foz do Iguaçu', 'Orides Camilo Copine', 'Jardim Niterói', '85853-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25728, 'Guarapuava', 'Oriente', 'Dos Estados', '85035-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25729, 'Londrina', 'Oriette Ninno Mignoni', 'Jardim Vale Azul', '86041-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25730, 'Campo Largo', 'Orígenes Lessa', 'São Marcos', '83602-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25731, 'Arapongas', 'Oriol', 'Jardim Aeroporto', '86702-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25732, 'Londrina', 'Orion', 'Sol', '86070-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25733, 'Maringá', 'Orion', 'Jardim Universo', '87060-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25734, 'Curitiba', 'Órion', 'Sítio Cercado', '81910-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25735, 'São José dos Pinhais', 'Oristela Foggiatto', 'Costeira', '83015-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25736, 'Ponta Grossa', 'Orival Carneiro Martins', 'Olarias', '84035-760', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25737, 'Londrina', 'Orivaldo Frois da Mota', 'Jardim Barcelona', '86073-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25738, 'Maringá', 'Orlândia', 'Parque das Laranjeiras', '87083-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25739, 'Curitiba', 'Orlando Albino Von der Ostem', 'Novo Mundo', '81050-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25740, 'Ponta Grossa', 'Orlando Becher', 'Jardim Carvalho', '84016-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25741, 'Curitiba', 'Orlando Bertoldi', 'Bom Retiro', '80520-740', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25742, 'Curitiba', 'Orlando Calil Fadel', 'Boqueirão', '81730-375', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25743, 'Curitiba', 'Orlando Cantarelli', 'Mercês', '80710-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25744, 'Colombo', 'Orlando Ceccon', 'Centro', '83414-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25745, 'Colombo', 'Orlando Ceccon', 'São João', '83415-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25746, 'Londrina', 'Orlando Coser', 'Aritana', '86037-825', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25747, 'Almirante Tamandaré', 'Orlando Custódio', 'Jardim Vitória', '83508-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25748, 'Londrina', 'Orlando de Almeida', 'Conjunto Residencial Cafezal', '86045-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25749, 'Castro', 'Orlando de Biassio', 'Cantagalo', '84178-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25750, 'Curitiba', 'Orlando de Moura Leite', 'Barreirinha', '82700-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25751, 'Araucária', 'Orlando de Paula Souza', 'Costeira', '83708-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25752, 'Curitiba', 'Orlando Destefani', 'São Braz', '82300-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25753, 'Toledo', 'Orlando Dezem', 'Residencial Santa Clara', '85903-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25754, 'Toledo', 'Orlando dos Santos', 'Jardim Porto Alegre', '85906-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25755, 'Curitiba', 'Orlando Duarte Lopes', 'Boa Vista', '82650-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25756, 'Guarapuava', 'Orlando Fernandes', 'Primavera', '85050-060', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25757, 'Londrina', 'Orlando Ferreira Neto', 'Itapoã', '86043-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25758, 'Toledo', 'Orlando Gomes Pereira', 'Centro', '85901-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25759, 'Almirante Tamandaré', 'Orlando Gonçalves da Rosa', 'Jardim Campo Verde', '83502-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25760, 'Ponta Grossa', 'Orlando Henneberg', 'Orfãs', '84015-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25761, 'Curitiba', 'Orlando Luís Lamarca', 'Cidade Industrial', '81315-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25762, 'Londrina', 'Orlando Maimone', 'Vale dos Tucanos', '86046-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25763, 'Curitiba', 'Orlando Maria Martins', 'Cidade Industrial', '81350-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25764, 'São José dos Pinhais', 'Orlando Martins', 'Costeira', '83015-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25765, 'Cambé', 'Orlando Martins Santos', 'Jardim Tarobá', '86191-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25766, 'Colombo', 'Orlando Nascimento', 'Vila Ana Maria', '83413-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25767, 'Umuarama', 'Orlando Navaqui', 'Jardim Alto da Boa Vista', '87506-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25768, 'Curitiba', 'Orlando Padilha dos Santos', 'Portão', '81070-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25769, 'Curitiba', 'Orlando Peruci', 'Butiatuvinha', '82400-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25770, 'Londrina', 'Orlando Pezarine', 'Jardim Piza', '86073-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25771, 'Pinhais', 'Orlando Santander Francisco', 'Vale da Boa Esperança', '83320-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25772, 'Toledo', 'Orlando Savaris', 'Jardim Porto Alegre', '85905-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25773, 'Maringá', 'Orlando Schiavoni', 'Jardim Paris III', '87083-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25774, 'Londrina', 'Orlando Silva', 'Santa Izabel', '86031-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25775, 'Foz do Iguaçu', 'Orlando Silva', 'Jardim Comercial das Bandeiras', '85864-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25776, 'Pato Branco', 'Orlando Silva', 'Chaparral', '85507-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25777, 'Cascavel', 'Orlando Silva', 'Brasília', '85815-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25778, 'Apucarana', 'Orlando Silva', 'Núcleo Habitacional Castelo Branco', '86812-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25779, 'Londrina', 'Orlando Sisti', 'Residencial Abussafe', '86037-789', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25780, 'Cascavel', 'Orlando Vasconcelos', 'Pioneiros Catarinenses', '85805-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25781, 'Foz do Iguaçu', 'Orleans', 'Jardim Vitória', '85853-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25782, 'Curitiba', 'Orlei Kos', 'Água Verde', '80620-430', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25783, 'Curitiba', 'Orlete Antunes de Oliveira', 'Cidade Industrial', '81170-717', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25784, 'Araucária', 'Orlete de R. Metzger Dobjanski', 'Costeira', '83708-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25785, 'Londrina', 'Orlindo Carlos Monteiro', 'Residencial Abussafe', '86037-759', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25786, 'Londrina', 'Ormam Laurindo da Conceição', 'Jardim Tropical', '86087-638', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25787, 'Foz do Iguaçu', 'Orminda Freitas Cezar', 'Vila São Sebastião', '85870-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25788, 'Londrina', 'Orminda Pereira Costa', 'Residencial Portal de Piza', '86041-308', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25789, 'Arapongas', 'Orocoia', 'Jardim Universitário', '86702-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25790, 'Curitiba', 'Orondes dos Santos Costa', 'Cidade Industrial', '81450-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25791, 'Londrina', 'Orozimbo Camilo de Almeida', 'Recanto Pitanguá', '86055-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25792, 'Francisco Beltrão', 'Orquídea', 'Nossa Senhora Aparecida', '85601-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25793, 'Ponta Grossa', 'Orquídea', 'Contorno', '84060-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25794, 'Campo Mourão', 'Orquídea', 'Jardim Paulista', '87310-440', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25795, 'Apucarana', 'Orquídea', 'Jardim das Flores I', '86810-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25796, 'Almirante Tamandaré', 'Orquídeas', 'Vila Santa Edwiges', '83504-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25797, 'Castro', 'Orquídeas', 'Jardim Termas Riviera', '84182-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25798, 'Francisco Beltrão', 'Ortigueira', 'São Cristóvão', '85601-367', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25799, 'Londrina', 'Ortigueira', 'Lindóia', '86031-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25800, 'Foz do Iguaçu', 'Ortigueira', 'Jardim Vitória', '85853-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25801, 'Pinhais', 'Ortigueira', 'Jardim Alto Tarumã', '83325-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25802, 'Ponta Grossa', 'Ortigueira', 'Contorno', '84052-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25803, 'Telêmaco Borba', 'Ortigueira', 'Nossa Senhora do Perpétuo Socorro', '84265-270', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25804, 'Almirante Tamandaré', 'Ortigueira', 'Loteamento Chico Mendes', '83505-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25805, 'Curitiba', 'Ortigueira', 'Uberaba', '81560-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25806, 'Foz do Iguaçu', 'Ortilio Vieira', 'Jardim Evangélico', '85870-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25807, 'Maringá', 'Osaca', 'Jardim Imperial II', '87023-019', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25808, 'Londrina', 'Osaka', 'Cláudia', '86050-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25809, 'Francisco Beltrão', 'Osasco', 'Pinheirinho', '85603-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25810, 'Foz do Iguaçu', 'Osasco', 'Jardim Vasco da Gama', '85862-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25811, 'Guarapuava', 'Osasco', 'Vila Bela', '85027-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25812, 'Londrina', 'Osasco', 'Champagnat', '86062-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25813, 'Telêmaco Borba', 'Osasco', 'Vila Santa Rita', '84263-350', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25814, 'Curitiba', 'Oscar Aisengart', 'Pilarzinho', '82110-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25815, 'Foz do Iguaçu', 'Oscar Alfredo Franco', 'Jardim Santa Rita', '85862-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25816, 'Castro', 'Oscar Ayres', 'Jardim das Araucárias', '84174-570', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25817, 'Guarapuava', 'Oscar Bezerra', 'Vila Carli', '85040-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25818, 'Curitiba', 'Oscar Borges de Macedo Ribas', 'Campo Comprido', '81200-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25819, 'Ponta Grossa', 'Oscar Buturi', 'Uvaranas', '84030-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25820, 'Curitiba', 'Oscar Capeline', 'São Braz', '82300-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25821, 'Curitiba', 'Oscar Chanoski', 'Cidade Industrial', '81280-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25822, 'Ponta Grossa', 'Oscar Clock', 'Nova Rússia', '84053-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25823, 'Curitiba', 'Oscar da Costa Figueiredo', 'Cajuru', '82930-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25824, 'Araucária', 'Oscar da Silva Lisboa', 'Boqueirão', '83704-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25825, 'Curitiba', 'Oscar de Abreu Finkensieper', 'Pilarzinho', '82100-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25826, 'Ponta Grossa', 'Oscar de Paula Soares', 'Olarias', '84026-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25827, 'Curitiba', 'Oscar Dias Negrão', 'Cidade Industrial', '81315-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25828, 'Londrina', 'Oscar Fernandes Filho', 'Conjunto Farid Libos', '86087-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25829, 'Curitiba', 'Oscar Ferreira dos Santos', 'São Braz', '82300-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25830, 'Londrina', 'Oscar Freitas Guimarães', 'Parque Industrial Alicante', '86087-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25831, 'Curitiba', 'Oscar Gomes de Oliveira', 'Santa Cândida', '82720-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25832, 'Curitiba', 'Oscar Hecke', 'Boa Vista', '82210-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25833, 'Telêmaco Borba', 'Oscar Hey', 'Centro', '84261-640', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25834, 'Colombo', 'Oscar Hioschi', 'Jardim Arapongas', '83402-530', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25835, 'Guarapuava', 'Oscar L. Durski Silva', 'Vila Carli', '85040-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25836, 'Castro', 'Oscar Marfurt', 'Vila Santa Cruz', '84168-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25837, 'Foz do Iguaçu', 'Oscar Muxfeldt', 'Centro', '85851-490', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25838, 'Toledo', 'Oscar Pedrini', 'Jardim Alto Alegre', '85910-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25839, 'Foz do Iguaçu', 'Oscar Pereira da Silva', 'Parque Residencial Três Bandeiras', '85862-256', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25840, 'Londrina', 'Oscar Pereira dos Santos', 'Colinas', '86056-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25841, 'Araucária', 'Oscar Renaud', 'Iguaçu', '83701-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25842, 'Curitiba', 'Oscar Schanoski Filho', 'Novo Mundo', '81050-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25843, 'Curitiba', 'Oscar Scharappe Senior', 'Capão da Imbuia', '82810-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25844, 'Curitiba', 'Oscar Spena', 'Atuba', '82860-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25845, 'Umuarama', 'Oscar Thompson Filho', 'Zona I-A', '87501-360', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25846, 'Curitiba', 'Oscar Wilde', 'Lindóia', '81010-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25847, 'Paranavaí', 'Oscarlino Carvalho Duarte', 'Jardim São Jorge', '87710-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25848, 'Paranavaí', 'Oscarlino Carvalho Duarte', 'Jardim São Jorge', '87711-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25849, 'Curitiba', 'Oseas Lazzari Stoterau', 'Sítio Cercado', '81900-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25850, 'Londrina', 'Oséias Furtoso', 'Dom Pedro II', '86073-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25851, 'São José dos Pinhais', 'Osires Broska', 'Zaniolo', '83025-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25852, 'Umuarama', 'Osires Lamenha de Siqueira', 'Jardim San Fernando', '87508-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25853, 'Curitiba', 'Osires Paixão Gonçalves', 'Santa Felicidade', '82410-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25854, 'Paranavaí', 'Osires Ramiro de Assis', 'Jardim Iguaçu', '87705-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25855, 'Maringá', 'Osires Stenghel Guimarães', 'Conjunto Habitacional Karina', '87047-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25856, 'Curitiba', 'Osíris de Brito', 'Prado Velho', '80215-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25857, 'Curitiba', 'Osíris de Oliveira Ribas', 'Santa Quitéria', '80310-460', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25858, 'Umuarama', 'Osmar Capoia', 'Conjunto Residencial Porto Belo', '87506-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25859, 'Curitiba', 'Osmar Carta', 'Bigorrilho', '80730-500', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25860, 'Colombo', 'Osmar Ceccon', 'Vila Maria do Rosário', '83413-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25861, 'Ponta Grossa', 'Osmar Frederico Osanan', 'Estrela', '84050-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25862, 'Curitiba', 'Osmar Hilbert', 'Boqueirão', '81670-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25863, 'Paranaguá', 'Osmar Pereira', 'Ponta do Caju', '83206-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25864, 'Londrina', 'Osmar Pomim', 'Londres', '86081-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25865, 'Curitiba', 'Osmar Razzolini', 'Portão', '81070-130', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25866, 'Curitiba', 'Osmar Rosa', 'Cidade Industrial', '81310-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25867, 'Curitiba', 'Osmar Simões', 'Sítio Cercado', '81900-436', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25868, 'Maringá', 'Osmar Sossai', 'Conjunto Residencial Planalto', '87015-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25869, 'Curitiba', 'Osmário de Lima', 'Capão da Imbuia', '82810-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25870, 'Piraquara', 'Osmário de Oliveira Bastos', 'Vila Fuck', '83305-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25871, 'Ponta Grossa', 'Osmário Gonçalves', 'Neves', '84020-789', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25872, 'Curitiba', 'Osmário Machado', 'Xaxim', '81830-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25873, 'Ponta Grossa', 'Osmário Martins Ribas', 'Nova Rússia', '84053-460', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25874, 'Londrina', 'Osmy Muniz', 'Conjunto Professora Hilda Mandarino', '86080-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25875, 'Londrina', 'Osni Silveira', 'Santo Antônio', '86035-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25876, 'Curitiba', 'Osni Silveira', 'Xaxim', '81720-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25877, 'Curitiba', 'Osnilde de Souza', 'Cidade Industrial', '81460-278', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25878, 'Foz do Iguaçu', 'Osório', 'Jardim Terra e Lar', '85858-486', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25879, 'Curitiba', 'Osório Damas de Oliveira', 'Pinheirinho', '81150-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25880, 'Foz do Iguaçu', 'Osório de Souza', 'Loteamento Witt', '85862-548', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25881, 'Umuarama', 'Osório dos Santos Carvalho', 'Conjunto Residencial Ouro Preto', '87504-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25882, 'Curitiba', 'Osório dos Santos Pacheco', 'Capão Raso', '81110-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25883, 'Pinhais', 'Osório Duque Estrada', 'Núcleo Colonial de Pinhais', '83321-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25884, 'Apucarana', 'Osório Ribas de Paula', 'Centro', '86800-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25885, 'Apucarana', 'Osório Ribas de Paula', 'Vila Vitória', '86802-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25886, 'Cambé', 'Osório Ricieri', 'Parque Residencial Ana Rosa', '86183-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25887, 'Londrina', 'Osório Soares', 'Sebastião de Melo César', '86084-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25888, 'Ponta Grossa', 'Osório Subtil Marçal', 'Contorno', '84060-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25889, 'Arapongas', 'Ostraceiro', 'Vila Zanin', '86705-187', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25890, 'Foz do Iguaçu', 'Osvalda Ferreira', 'Jardim das Flores', '85862-487', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25891, 'Curitiba', 'Osvaldina Granemann Prange', 'Cidade Industrial', '81460-216', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25892, 'Curitiba', 'Osvaldir Antônio Cuman', 'Santa Felicidade', '82015-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25893, 'Apucarana', 'Osvaldir Antônio Rosa', 'Loteamento Central', '86807-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25894, 'São José dos Pinhais', 'Osvaldo Anacleto Bobato', 'Planta Quississana', '83085-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25895, 'Curitiba', 'Osvaldo Andrezejewski', 'Vista Alegre', '80820-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25896, 'Laranjeiras do Sul', 'Osvaldo Aranha', 'São Francisco', '85303-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25897, 'Pato Branco', 'Osvaldo Aranha', 'Centro', '85504-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25898, 'Pato Branco', 'Osvaldo Aranha', 'Centro', '85501-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25899, 'Toledo', 'Osvaldo Aranha', 'Panorama', '85911-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25900, 'Cascavel', 'Osvaldo Aranha', 'Coqueiral', '85807-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25901, 'Londrina', 'Osvaldo Arentan', 'Conjunto Habitacional José Garcia Molina', '86080-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25902, 'Foz do Iguaçu', 'Osvaldo Brandão', 'Parque Residencial Santa Rita', '85858-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25903, 'Paranavaí', 'Osvaldo Brandão', 'Centro', '87702-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25904, 'Curitiba', 'Osvaldo Brandão', 'Guaíra', '80630-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25905, 'Curitiba', 'Osvaldo Campos', 'Capão da Imbuia', '82810-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25906, 'Curitiba', 'Osvaldo Capeline', 'São Braz', '82300-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25907, 'Curitiba', 'Osvaldo Cavalcanti Vida', 'Orleans', '82310-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25908, 'Pato Branco', 'Osvaldo Cruz', 'São Cristóvão', '85508-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25909, 'Maringá', 'Osvaldo Cruz', 'Zona 07', '87020-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25910, 'Ponta Grossa', 'Osvaldo Cruz', 'Uvaranas', '84025-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25911, 'Telêmaco Borba', 'Osvaldo Cruz', 'Nossa Senhora do Perpétuo Socorro', '84265-250', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25912, 'Umuarama', 'Osvaldo Cruz', 'Parque Tarumã', '87508-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25913, 'Cambé', 'Osvaldo Cruz', 'Vila Atalaia', '86181-490', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25914, 'Cascavel', 'Osvaldo Cruz', 'Centro', '85810-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25915, 'Cascavel', 'Osvaldo Cruz', 'Vila Tolentino', '85802-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25916, 'Cascavel', 'Osvaldo Cruz', 'Cancelli', '85811-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25917, 'Cascavel', 'Osvaldo Cruz', 'Centro', '85801-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25918, 'São José dos Pinhais', 'Osvaldo da Silva Bassu', 'Afonso Pena', '83050-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25919, 'Pinhais', 'Osvaldo da Silva Osório', 'Vila Maria Antonieta', '83331-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25920, 'Cascavel', 'Osvaldo Dall Oglio', 'Brasmadeira', '85814-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25921, 'Londrina', 'Osvaldo de Jesus', 'Monte Belo', '86041-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25922, 'Araucária', 'Osvaldo de Lima', 'Estação', '83705-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25923, 'Maringá', 'Osvaldo de Moraes Correia', 'Parque Industrial', '87065-590', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25924, 'Apucarana', 'Osvaldo de Oliveira', 'Jardim Flamingos', '86811-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25925, 'São José dos Pinhais', 'Osvaldo Ferreira', 'Guatupê', '83060-216', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25926, 'Londrina', 'Osvaldo Franco dos Santos', 'Itapoã', '86043-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25927, 'Foz do Iguaçu', 'Osvaldo Friederich', 'Parque Presidente II', '85863-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25928, 'Foz do Iguaçu', 'Osvaldo Goch', 'Jardim Residencial Bela Vista', '85856-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25929, 'Telêmaco Borba', 'Osvaldo Gomes de Lima', 'Centro', '84261-220', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25930, 'Londrina', 'Osvaldo Manoel da Costa', 'Residencial Portal de Piza', '86041-299', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25931, 'Almirante Tamandaré', 'Osvaldo Milek', 'Vila São Bernardo', '83506-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25932, 'Campo Largo', 'Osvaldo Nascimento Ramos', 'Loteamento Itaboa', '83605-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25933, 'Curitiba', 'Osvaldo Novicki', 'Campina do Siqueira', '80740-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25934, 'Apucarana', 'Osvaldo Otávio Pereira', 'Vila Apucaraninha', '86801-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25935, 'Curitiba', 'Osvaldo Pfutzenreuter', 'Pilarzinho', '82115-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25936, 'São José dos Pinhais', 'Osvaldo Pilotto', 'São Sebastião', '83075-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25937, 'Apucarana', 'Osvaldo Pimenta', 'Núcleo Habitacional José Mercadante', '86804-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25938, 'Castro', 'Osvaldo Rebonato', 'Cantagalo', '84178-520', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25939, 'Foz do Iguaçu', 'Osvaldo Requião', 'Jardim Iguaçu', '85853-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25940, 'Londrina', 'Osvaldo S. Campos', 'Conjunto Parigot de Souza 3', '86081-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25941, 'Apucarana', 'Osvaldo Sant''Anna', 'Jardim São Pedro', '86809-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25942, 'Foz do Iguaçu', 'Osvaldo Silva', 'Jardim Princesa Daiana', '85867-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25943, 'Colombo', 'Osvaldo Strapasson Vicentin', 'Jardim Santa Helena', '83407-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25944, 'Cambé', 'Osvaldo Tomeleri', 'Jardim Vitória', '86184-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25945, 'Curitiba', 'Osvaldo Tosato', 'Campo Comprido', '81270-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25946, 'Londrina', 'Osvaldo Vieira', 'Jardim Acapulco', '86045-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25947, 'Colombo', 'Oswald de Andrade', 'Parque Monte Castelo', '83409-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25948, 'Curitiba', 'Oswald de Andrade', 'Boa Vista', '82650-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25949, 'Londrina', 'Oswaldo Américo de Souza', 'Residencial Abussafe', '86037-757', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25950, 'Londrina', 'Oswaldo Aranha', 'Cilo 2', '86067-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25951, 'Londrina', 'Oswaldo Baggio', 'Vale dos Tucanos', '86046-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25952, 'Curitiba', 'Oswaldo Baggio', 'Cidade Industrial', '81460-347', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25953, 'Londrina', 'Oswaldo Caldarelli', 'Nossa Senhora de Lourdes', '86039-415', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25954, 'Londrina', 'Oswaldo Castri', 'Antônio M Nogueira Cafezal 4', '86089-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25955, 'Curitiba', 'Oswaldo Ceccon', 'Tatuquara', '81480-277', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25956, 'Londrina', 'Oswaldo Cruz', 'Kase', '86026-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25957, 'Laranjeiras do Sul', 'Oswaldo Cruz', 'Getúlio Vargas', '85304-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25958, 'Foz do Iguaçu', 'Oswaldo Cruz', 'Vila Portes', '85865-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25959, 'Piraquara', 'Oswaldo Cruz', 'Jardim Primavera', '83302-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25960, 'Toledo', 'Oswaldo Cruz', 'Jardim Europa', '85908-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25961, 'Campo Largo', 'Oswaldo Cruz', 'Centro', '83601-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25962, 'Curitiba', 'Oswaldo Cruz', 'Centro', '80250-230', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25963, 'Curitiba', 'Oswaldo de Abreu Silva', 'Fazendinha', '81330-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25964, 'Londrina', 'Oswaldo de Souza Campos', 'Lindóia', '86031-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25965, 'Londrina', 'Oswaldo dos Santos', 'Jardim Paraty', '86081-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25966, 'Apucarana', 'Oswaldo Francisco de Lima', 'Loteamento Sanches dos Santos', '86806-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25967, 'Curitiba', 'Oswaldo Francisco Goelzer', 'Uberaba', '81590-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25968, 'Curitiba', 'Oswaldo Guimarães', 'Cajuru', '82900-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25969, 'Londrina', 'Oswaldo Leite', 'Conjunto Residencial Marajoara', '86080-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25970, 'Curitiba', 'Oswaldo Maciel', 'Taboão', '82130-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25971, 'Cascavel', 'Oswaldo Marcondes de Campos', 'Claudete', '85811-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25972, 'Curitiba', 'Oswaldo Martin', 'Cidade Industrial', '81280-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25973, 'Londrina', 'Oswaldo Mostaco', 'Antônio M Nogueira Cafezal 4', '86089-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25974, 'São José dos Pinhais', 'Oswaldo Nascimento', 'São Sebastião', '83075-306', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25975, 'Curitiba', 'Oswaldo Novaes', 'Barreirinha', '82700-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25976, 'Londrina', 'Oswaldo Nunes', 'Maria Lúcia', '86072-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25977, 'Londrina', 'Oswaldo Perosa', 'Franciscato II', '86078-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25978, 'Curitiba', 'Oswaldo Portugal Lobato', 'Santa Cândida', '82640-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25979, 'Curitiba', 'Oswaldo Ramos de Souza', 'Umbará', '81930-547', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25980, 'Curitiba', 'Oswaldo Ramos de Souza', 'Augusta', '81260-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25981, 'Paranaguá', 'Oswaldo Rodrigues Branco', 'João Gualberto', '83203-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25982, 'Ponta Grossa', 'Oswaldo Wiechetech', 'Boa Vista', '84070-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25983, 'Ponta Grossa', 'Otacília Hasselmann de Oliveira', 'Jardim Carvalho', '84015-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25984, 'Apucarana', 'Otacílio Barreto do Nascimento', 'Jardim Tibagi', '86813-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25985, 'Paranavaí', 'Otacílio Egger', 'Jardim Farropilha', '87708-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25986, 'Curitiba', 'Otalino Amado de Souza', 'Pilarzinho', '82115-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25987, 'Campo Largo', 'Otalipio Pereira de Andrade', 'Jardim Paraíso Mineral', '83606-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25988, 'Londrina', 'Otávia Mendonça de Carvalho', 'Jacutinga', '86087-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25989, 'Laranjeiras do Sul', 'Otaviano Amaral', 'São Francisco', '85303-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25990, 'Laranjeiras do Sul', 'Otaviano Amaral', 'Centro', '85301-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25991, 'Almirante Tamandaré', 'Otaviano Becker', 'Jardim São Domingos', '83501-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25992, 'Curitiba', 'Otaviano de Almeida Rosa', 'Xaxim', '81810-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25993, 'Londrina', 'Otaviano Félix', 'Nikko', '86047-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25994, 'Londrina', 'Otaviano Gonçalves Ferreira', 'Colonial', '86047-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25995, 'Cambé', 'Otaviano Rodrigues Filho', 'Conjunto Residencial Roberto Conceição', '86183-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25996, 'Curitiba', 'Otávio Afonso da Silva', 'Sítio Cercado', '81925-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25997, 'São José dos Pinhais', 'Otávio Albino da Rosa', 'Cidade Jardim', '83035-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25998, 'Castro', 'Otávio Bannach', 'Jardim das Nações', '84172-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (25999, 'Umuarama', 'Otávio Barbosa da Silva', 'Parque Bandeirantes', '87504-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26000, 'Curitiba', 'Otávio Benevenuto Furlan', 'Pinheirinho', '81870-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26001, 'Paranavaí', 'Otávio Borim', 'Jardim América', '87705-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26002, 'Curitiba', 'Otávio Bressan', 'Santa Felicidade', '82020-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26003, 'Londrina', 'Otávio Cesário Pereira', 'Jardim Acapulco', '86045-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26004, 'São José dos Pinhais', 'Otávio Claudino de Camargo', 'Cruzeiro', '83010-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26005, 'Londrina', 'Otávio Correia', 'Sebastião de Melo César', '86084-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26006, 'Colombo', 'Otávio David', 'Jardim Aurora', '83411-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26007, 'Londrina', 'Otávio de Faveri', 'Jardim São Jorge', '86082-835', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26008, 'São José dos Pinhais', 'Otávio de Sá Barreto', 'São Sebastião', '83075-357', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26009, 'Toledo', 'Otávio Escremim', 'Conjunto Habitacional São Francisco', '85915-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26010, 'Campo Largo', 'Otávio Fabris', 'Loteamento Santa Rita', '83602-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26011, 'Ponta Grossa', 'Otávio Ferreira da Silva', 'Uvaranas', '84031-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26012, 'Foz do Iguaçu', 'Otávio Ferreira Vaz', 'Jardim das Flores', '85862-496', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26013, 'Curitiba', 'Otávio Francisco Dias', 'Água Verde', '80620-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26014, 'Curitiba', 'Otávio Ganz', 'Santo Inácio', '82010-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26015, 'Cambé', 'Otávio Gazoni Gorni', 'Jardim Planalto Verde', '86192-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26016, 'Ponta Grossa', 'Otávio Larocca', 'Contorno', '84061-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26017, 'Londrina', 'Otávio Mangabeira', 'Sebastião de Melo César', '86084-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26018, 'Apucarana', 'Otávio Mareze', 'Jardim Menegazzo', '86802-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26019, 'Colombo', 'Otávio Martins', 'Jardim São Gabriel', '83407-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26020, 'Araucária', 'Otávio Munhoz Santiago', 'Estação', '83705-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26021, 'Ponta Grossa', 'Otávio Palhano', 'Boa Vista', '84072-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26022, 'Londrina', 'Otávio Palhares', 'Santos Dumont', '86039-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26023, 'Londrina', 'Otávio Pedro de Araújo', 'Cafezal', '86045-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26024, 'Curitiba', 'Otávio Pereira', 'Santa Cândida', '82720-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26025, 'Curitiba', 'Otávio Pereira dos Anjos', 'Jardim das Américas', '81530-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26026, 'Apucarana', 'Otávio Pereira Mello', 'Jardim Laranjeiras', '86811-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26027, 'Curitiba', 'Otávio Pinto', 'Uberaba', '81570-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26028, 'Foz do Iguaçu', 'Otávio Portes', 'Parque Morumbi II', '85859-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26029, 'Curitiba', 'Otávio Rechia', 'Bacacheri', '82600-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26030, 'Curitiba', 'Otávio Ribas Guimarães', 'Portão', '80320-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26031, 'Londrina', 'Otávio Salles Almeida Leite', 'Áurea', '86038-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26032, 'Londrina', 'Otávio Tacola', 'Portal de Versalhes 3', '86055-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26033, 'Castro', 'Otávio Torres Pereira', 'Vila Rio Branco', '84172-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26034, 'Cascavel', 'Otelo Celestino de Castilhos', 'Coqueiral', '85807-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26035, 'Curitiba', 'Otelo Queirolo', 'Bigorrilho', '80710-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26036, 'Curitiba', 'Othelo Werneck Lopes', 'Cidade Industrial', '81250-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26037, 'Londrina', 'Othelo Zeloni', 'Vila Ziober', '86026-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26038, 'Campo Largo', 'Othmar Gerster Scotoni', 'Vila Elizabeth', '83607-180', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26039, 'Curitiba', 'Othon Cristóvão Cescato', 'Sítio Cercado', '81900-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26040, 'Foz do Iguaçu', 'Othon Maeder', 'Vila Yolanda', '85853-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26041, 'Curitiba', 'Othoniel Taborda Reinhardt', 'Xaxim', '81810-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26042, 'Ponta Grossa', 'Otília Cunha Guimarães', 'Uvaranas', '84031-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26043, 'Curitiba', 'Otília de Jesus Carlins', 'Sítio Cercado', '81925-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26044, 'Toledo', 'Otília Giaretta', 'Conjunto Habitacional São Francisco', '85915-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26045, 'Pato Branco', 'Otílio Amadori', 'Bancários', '85504-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26046, 'Maringá', 'Ottawa', 'Jardim Canadá', '87080-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26047, 'Curitiba', 'Ottília Reksidler', 'São Lourenço', '82210-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26048, 'Curitiba', 'Ottília Rosenmann', 'Cidade Industrial', '81310-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26049, 'Ponta Grossa', 'Otto Adolfo Justus', 'Contorno', '84061-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26050, 'Curitiba', 'Otto Bracarense Costa', 'Cidade Industrial', '81450-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26051, 'Curitiba', 'Otto Braun', 'Ahú', '80540-090', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26052, 'Campo Largo', 'Otto Busmayer', 'Vila Elizabeth', '83607-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26053, 'Ponta Grossa', 'Otto Cunha', 'Contorno', '84060-176', 'Parque', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26054, 'Londrina', 'Otto Edmundo Riihmann', 'Jardim Império do Sol', '86073-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26055, 'Foz do Iguaçu', 'Otto Ernesto Gottlieb', 'Jardim Eliza I', '85856-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26056, 'Foz do Iguaçu', 'Otto Ernesto Gottlieb', 'Jardim Guarapuava I', '85853-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26057, 'Ponta Grossa', 'Otto Ewy', 'Oficinas', '84035-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26058, 'Cambé', 'Otto Gaertner', 'Centro', '86181-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26059, 'Castro', 'Otto Kugler', 'Centro', '84165-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26060, 'Guarapuava', 'Otto Lara Resende', 'Batel', '85015-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26061, 'Curitiba', 'Otto Mak', 'Sítio Cercado', '81900-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26062, 'Francisco Beltrão', 'Otto Metzler', 'Jardim Santa Fé', '85602-507', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26063, 'Cambé', 'Otto Müller', 'Jardim Santa Adelaide', '86192-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26064, 'Curitiba', 'Otto Oscar Schmeiske', 'Cidade Industrial', '81350-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26065, 'Londrina', 'Otto Sommer', 'Lilian', '86015-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26066, 'Curitiba', 'Otto Urban', 'Tatuquara', '81470-067', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26067, 'Curitiba', 'Otto Willi Michaelis', 'Butiatuvinha', '82315-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26068, 'Cascavel', 'Ottom Mader', 'Santa Felicidade', '85803-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26069, 'Londrina', 'Ouadi José Nakhli', 'Aragarça', '86038-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26070, 'Londrina', 'Oulavo Benato', 'Novo Horizonte', '86075-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26071, 'Guarapuava', 'Ourinhos', 'Vila Bela', '85027-320', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26072, 'Londrina', 'Ourinhos', 'San Remo', '86062-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26073, 'Foz do Iguaçu', 'Ourinhos', 'Jardim Ana Cristina', '85861-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26074, 'Ponta Grossa', 'Ourinhos', 'Nova Rússia', '84053-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26075, 'Umuarama', 'Ourinhos', 'Parque Presidente', '87505-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26076, 'Curitiba', 'Ourizona', 'Sítio Cercado', '81925-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26077, 'Curitiba', 'Ourizona', 'Sítio Cercado', '81920-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26078, 'Londrina', 'Ouro', 'Jardim São Francisco de Assis', '86067-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26079, 'Foz do Iguaçu', 'Ouro', 'Parque Ouro Verde', '85854-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26080, 'Apucarana', 'Ouro', 'Parque Industrial Zona Norte', '86806-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26081, 'Umuarama', 'Ouro Branco', 'Conjunto Residencial Ouro Branco', '87508-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26082, 'Apucarana', 'Ouro Branco', 'Centro', '86808-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26083, 'Foz do Iguaçu', 'Ouro Fino', 'Jardim Vitória', '85853-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26084, 'Apucarana', 'Ouro Fino', 'Vila Agari', '86808-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26085, 'Apucarana', 'Ouro Negro', 'Jardim Ana Maria', '86808-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26086, 'Foz do Iguaçu', 'Ouro Preto', 'Jardim Nacional', '85862-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26087, 'Guarapuava', 'Ouro Preto', 'Morro Alto', '85065-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26088, 'Francisco Beltrão', 'Ouro Preto', 'Pinheirinho', '85603-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26089, 'Londrina', 'Ouro Preto', 'Centro', '86026-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26090, 'Maringá', 'Ouro Preto', 'Jardim Alvorada', '87033-410', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26091, 'Maringá', 'Ouro Preto', 'Jardim Liberdade', '87047-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26092, 'Umuarama', 'Ouro Preto', 'Jardim Panorama', '87501-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26093, 'Sarandi', 'Ouro Preto', 'Parque Residencial Nova Aliança', '87111-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26094, 'Telêmaco Borba', 'Ouro Preto', 'Vila Esperança', '84272-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26095, 'Apucarana', 'Ouro Preto', 'Jardim Adriane', '86807-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26096, 'Cascavel', 'Ouro Preto', 'São Cristóvão', '85816-200', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26097, 'Almirante Tamandaré', 'Ouro Preto', 'Vila Colômbia', '83505-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26098, 'Piraquara', 'Ouro Verde', 'Jardim Santa Mônica', '83302-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26099, 'Maringá', 'Ouro Verde', 'Vila Emília', '87010-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26100, 'Telêmaco Borba', 'Ouro Verde', 'Área 06', '84271-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26101, 'Telêmaco Borba', 'Ouro Verde', 'Fazenda Limeira', '84267-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26102, 'Umuarama', 'Ouro Verde', 'Zona VI', '87503-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26103, 'Apucarana', 'Ouro Verde', 'Jardim América', '86805-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26104, 'Cascavel', 'Ouro Verde', 'Brasmadeira', '85814-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26105, 'Apucarana', 'Ouro Verde', 'Jardim América', '86807-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26106, 'Curitiba', 'Ouro Verde', 'Capão Raso', '81130-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26107, 'Sarandi', 'Outono', 'Jardim Primaverão', '87111-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26108, 'Pato Branco', 'Ouvidor', 'São Cristóvão', '85508-115', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26109, 'Curitiba', 'Ouvidor Pardinho', 'Rebouças', '80250-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26110, 'Curitiba', 'Ovídio Alberto de Carvalho', 'Cidade Industrial', '81170-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26111, 'Guarapuava', 'Ovidio Clock', 'Cascavel', '85025-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26112, 'Curitiba', 'Ovídio Garcez', 'Cachoeira', '82710-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26113, 'Londrina', 'Ovidio Leme Portes', 'Jardim Paraty', '86081-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26114, 'Curitiba', 'Oyapock', 'Cristo Rei', '80050-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26115, 'Piraquara', 'Ozir Schuli de Aguiar', 'Vila Rosa', '83304-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26116, 'Colombo', 'Ozório Alberti', 'Jardim Mediterrâneo', '83401-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26117, 'Campo Mourão', 'Ozório Barnabé Pontes', 'Jardim Cidade Nova', '87308-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26118, 'Ponta Grossa', 'Ozorio de Almeida Taques', 'Estrela', '84050-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26119, 'Telêmaco Borba', 'Ozorio de Almeida Taques', 'Centro', '84261-680', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26120, 'Londrina', 'Ozório Duque Estrada', 'Itamarati', '86061-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26121, 'Curitiba', 'Ozório Duque Estrada', 'Jardim Social', '82520-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26122, 'Ponta Grossa', 'Ozorio Fernandes dos Santos', 'Chapada', '84062-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26123, 'Apucarana', 'Ozorio Gama', 'Núcleo Habitacional Mathias Hoffman', '86805-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26124, 'Ponta Grossa', 'Ozório Guimarães Martins', 'Colônia Dona Luiza', '84046-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26125, 'Colombo', 'Ozório Souza', 'Jardim Mediterrâneo', '83401-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26126, 'Colombo', 'Ozório Strapasson', 'Centro Industrial Mauá', '83413-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26127, 'Foz do Iguaçu', 'P', 'Conjunto C', '85870-397', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26128, 'Ponta Grossa', 'P', 'Boa Vista', '84072-288', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26129, 'Umuarama', 'P', 'Parque San Marino', '87509-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26130, 'Campo Largo', 'P', 'Vila Torres II', '83609-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26131, 'Arapongas', 'P-1', 'Jardim Caravelle', '86702-668', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26132, 'Curitiba', 'P-47', 'Bacacheri', '82515-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26133, 'Maringá', 'Pablo Neruda', 'Jardim Cidade Monções', '87060-556', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26134, 'Cascavel', 'Pablo Neruda', 'Interlagos', '85814-277', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26135, 'Umuarama', 'Pablo Picasso', 'Conjunto Residencial Ouro Preto', '87504-598', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26136, 'Curitiba', 'Pablo Picasso', 'Fazendinha', '81330-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26137, 'Foz do Iguaçu', 'Pacaembu', 'Parque Morumbi II', '85859-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26138, 'Foz do Iguaçu', 'Pacarana', 'Conjunto A', '85861-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26139, 'Londrina', 'Pacífico', 'Jardim Indianápolis', '86010-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26140, 'Toledo', 'Pacífico Dezem', 'Residencial Santa Clara', '85903-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26141, 'Curitiba', 'Pacífico Guimarães Teixeira Filho', 'Uberaba', '81570-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26142, 'Castro', 'Pacífico J. da Conceição', 'Jardim Colonial', '84178-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26143, 'Foz do Iguaçu', 'Paço da Pátria', 'Jardim Itamaraty', '85863-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26144, 'Foz do Iguaçu', 'Pacuguaçu', 'Conjunto A', '85860-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26145, 'Cambé', 'Padova', 'Jardim Montecatini', '86186-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26146, 'Curitiba', 'Padova', 'Santa Felicidade', '82020-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26147, 'Paranaguá', 'Padre Adamo', 'Padre Jackson', '83221-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26148, 'Piraquara', 'Padre Agostinho', 'Jardim Bela Vista', '83301-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26149, 'Curitiba', 'Padre Agostinho', 'Mercês', '80430-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26150, 'Curitiba', 'Padre Agostinho', 'Mercês', '80410-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26151, 'Curitiba', 'Padre Agostinho', 'Mercês', '80710-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26152, 'Curitiba', 'Padre Agostinho Legros', 'Boqueirão', '81750-500', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26153, 'Curitiba', 'Padre Alberto Chmielowski', 'Pinheirinho', '81820-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26154, 'São José dos Pinhais', 'Padre Alberto Müller', 'Cidade Jardim', '83035-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26155, 'Paranaguá', 'Padre Albino', 'Campo Grande', '83203-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26156, 'Curitiba', 'Padre Albino Vico', 'Capão Raso', '81110-020', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26157, 'Londrina', 'Padre Almeida', 'Petrópolis', '86015-450', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26158, 'Toledo', 'Padre Aloísio Baumeister', 'Centro', '85901-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26159, 'Toledo', 'Padre Aloys Mann', 'Conjunto Residencial Rossani', '85901-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26160, 'Campo Mourão', 'Padre Aloysio Jacobi', 'Jardim Capricórnio', '87301-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26161, 'Ponta Grossa', 'Padre Anacleto', 'Nova Rússia', '84070-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26162, 'Laranjeiras do Sul', 'Padre Anchieta', 'Centro', '85301-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26163, 'Guarapuava', 'Padre Anchieta', 'Morro Alto', '85065-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26164, 'Londrina', 'Padre Anchieta', 'Nossa Senhora do Desterro', '86025-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26165, 'Pato Branco', 'Padre Anchieta', 'Anchieta', '85501-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26166, 'Ponta Grossa', 'Padre Anchieta', 'Colônia Dona Luiza', '84045-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26167, 'Piraquara', 'Padre Anchieta', 'Jardim Bela Vista', '83301-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26168, 'Toledo', 'Padre Anchieta', 'Vila Industrial', '85905-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26169, 'São José dos Pinhais', 'Padre Anchieta', 'Afonso Pena', '83050-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26170, 'Cascavel', 'Padre Anchieta', 'Parque São Paulo', '85803-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26171, 'Castro', 'Padre Anchieta', 'Água Suja', '84165-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26172, 'Curitiba', 'Padre Anchieta', 'Mercês', '80410-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26173, 'Curitiba', 'Padre Anchieta', 'Bigorrilho', '80730-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26174, 'Curitiba', 'Padre Anchieta', 'Mercês', '80430-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26175, 'Curitiba', 'Padre Ângelo Baggio', 'Capão Raso', '81110-060', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26176, 'Ponta Grossa', 'Padre Ângelo Bortolini', 'Boa Vista', '84070-640', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26177, 'Ponta Grossa', 'Padre Ângelo Bortolini', 'Cará-cará', '84033-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26178, 'São José dos Pinhais', 'Padre Ângelo Bortolini', 'Cruzeiro', '83010-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26179, 'Ponta Grossa', 'Padre Ângelo Fernandes Caballero', 'Boa Vista', '84072-230', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26180, 'Apucarana', 'Padre Antônio', 'Vila Santa Rosa', '86811-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26181, 'Curitiba', 'Padre Antônio', 'Centro', '80030-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26182, 'Ponta Grossa', 'Padre Antônio Cavanis', 'Cará-cará', '84033-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26183, 'Ponta Grossa', 'Padre Antônio Darius', 'Cará-cará', '84033-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26184, 'São José dos Pinhais', 'Padre Antônio Darius', 'Afonso Pena', '83065-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26185, 'Curitiba', 'Padre Antônio Joaquim Ribeiro', 'Cidade Industrial', '81280-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26186, 'Ponta Grossa', 'Padre Antônio Patui', 'Cará-cará', '84033-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26187, 'Toledo', 'Padre Antônio Patui', 'Jardim Santa Maria', '85903-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26188, 'Guarapuava', 'Padre Antônio Vieira', 'São Cristóvão', '85060-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26274, 'Ponta Grossa', 'Padre João Lux', 'Centro', '84010-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26189, 'Londrina', 'Padre Antônio Vieira', 'Nossa Senhora do Desterro', '86025-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26190, 'Paranavaí', 'Padre Antônio Vieira', 'Jardim São Jorge', '87710-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26191, 'Telêmaco Borba', 'Padre Antônio Vieira', 'Vila Monte Belo', '84262-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26192, 'Ponta Grossa', 'Padre Arnaldo Janssen', 'Cará-cará', '84032-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26193, 'Curitiba', 'Padre Arnaldo Janssen', 'Cajuru', '82980-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26194, 'Cascavel', 'Padre Arrute', 'Interlagos', '85814-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26195, 'Curitiba', 'Padre Arturo Seppi', 'Butiatuvinha', '82320-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26196, 'Curitiba', 'Padre Augusto Kolel', 'Uberaba', '81590-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26197, 'Londrina', 'Padre Bernardo Greiss', 'Centro', '86010-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26198, 'Curitiba', 'Padre Bernardo Peirick', 'São Lourenço', '82210-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26199, 'Foz do Iguaçu', 'Padre Bernardo Plate', 'Jardim Polo Centro', '85863-719', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26200, 'São José dos Pinhais', 'Padre Bittencourt', 'Centro', '83030-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26201, 'Araucária', 'Padre Boleslau Bayer', 'São Miguel', '83706-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26202, 'Curitiba', 'Padre Boleslau Lucas Bayer', 'Cidade Industrial', '81280-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26203, 'Curitiba', 'Padre Bonifácio Kleinpass', 'Juvevê', '80035-310', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26204, 'Curitiba', 'Padre Camargo', 'Alto da Glória', '80060-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26205, 'São José dos Pinhais', 'Padre Carlos Dworaczek', 'Três Marias', '83030-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26206, 'Cascavel', 'Padre Carlos Nitzko', 'Região do Lago 3', '85819-777', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26207, 'Londrina', 'Padre Carlos Weiss', 'Santiago', '86071-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26208, 'Ponta Grossa', 'Padre Carlos Zelesny', 'Nova Rússia', '84053-470', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26209, 'Castro', 'Padre Casimiro', 'Vila Rio Branco', '84172-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26210, 'Cascavel', 'Padre Cassemiro Chichon', 'Maria Luiza', '85819-535', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26211, 'Guarapuava', 'Padre Cassiano Waldner', 'Morro Alto', '85065-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26212, 'Ponta Grossa', 'Padre César de Buss', 'Orfãs', '84015-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26213, 'Guarapuava', 'Padre Chagas', 'Morro Alto', '85065-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26214, 'Guarapuava', 'Padre Chagas', 'Centro', '85010-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26215, 'Guarapuava', 'Padre Chagas', 'Santa Cruz', '85015-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26216, 'Telêmaco Borba', 'Padre Chagas Lima', 'Fazenda Limeira', '84272-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26217, 'Cascavel', 'Padre Champagnat', 'Centro', '85812-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26218, 'Foz do Iguaçu', 'Padre Cícero', 'Jardim Guaíra', '85855-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26219, 'Ponta Grossa', 'Padre Cícero Romão Batista', 'Jardim Carvalho', '84016-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26220, 'Curitiba', 'Padre Cláudio Arenal', 'Uberaba', '81590-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26221, 'Curitiba', 'Padre Colbacchini', 'Santa Felicidade', '82410-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26222, 'Castro', 'Padre Damaso', 'Centro', '84165-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26223, 'Curitiba', 'Padre Damião', 'Jardim das Américas', '81530-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26224, 'São José dos Pinhais', 'Padre Damião de Veuster', 'Costeira', '83015-717', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26225, 'Curitiba', 'Padre Dario Zampiero', 'Portão', '80330-390', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26226, 'Curitiba', 'Padre Dehon', 'Boqueirão', '81670-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26227, 'Curitiba', 'Padre Dehon', 'Hauer', '81630-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26228, 'Ponta Grossa', 'Padre Denis Quilty', 'Orfãs', '84030-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26229, 'Curitiba', 'Padre Denis Quilty', 'Alto Boqueirão', '81860-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26230, 'Telêmaco Borba', 'Padre Diogo Feijó', 'Área 06', '84270-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26231, 'Apucarana', 'Padre Diogo Feijó', 'Jardim Independência', '86811-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26232, 'Colombo', 'Padre Domingos Marine', 'Centro', '83414-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26233, 'Londrina', 'Padre Domingos Rodevatti', 'Castelo', '86027-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26234, 'Cascavel', 'Padre Donizetti', 'Santos Dumont', '85804-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26235, 'Colombo', 'Padre Durval Sechi', 'Vila São Gabriel', '83406-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26236, 'Curitiba', 'Padre Emir Filter', 'Fazendinha', '81330-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26237, 'São José dos Pinhais', 'Padre Ernesto Zaramella', 'Ipê', '83055-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26238, 'Curitiba', 'Padre Estanislau Cebula', 'Cajuru', '82980-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26239, 'Curitiba', 'Padre Estanislau Piasecki', 'Cidade Industrial', '81280-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26240, 'Curitiba', 'Padre Estanislau Trzebiatowski', 'Alto Boqueirão', '81750-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26241, 'Londrina', 'Padre Eugênio Herter', 'Centro', '86010-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26242, 'Curitiba', 'Padre Feijó', 'Tarumã', '82530-240', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26243, 'Curitiba', 'Padre Félix Stefanowicz', 'Santa Cândida', '82650-485', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26244, 'Toledo', 'Padre Francisco', 'Pacaembu', '85910-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26245, 'Curitiba', 'Padre Francisco Auling', 'Bom Retiro', '80520-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26246, 'Ponta Grossa', 'Padre Francisco Biermann', 'Cará-cará', '84033-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26247, 'Colombo', 'Padre Francisco Bonato', 'Centro', '83414-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26248, 'Curitiba', 'Padre Francisco Chylaszek', 'Cidade Industrial', '81280-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26249, 'Curitiba', 'Padre Francisco Corso', 'Sítio Cercado', '81910-620', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26250, 'Curitiba', 'Padre Francisco João Azevedo', 'Jardim Botânico', '80210-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26251, 'Araucária', 'Padre Francisco José Soja', 'Centro', '83702-605', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26252, 'Curitiba', 'Padre Francisco Madej', 'Cidade Industrial', '81280-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26253, 'Araucária', 'Padre Francisco Starczinski', 'Centro', '83702-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26254, 'Curitiba', 'Padre Francisco Van de Water', 'Sítio Cercado', '81920-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26255, 'Ponta Grossa', 'Padre Fredolino Beuren', 'Cará-cará', '84033-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26256, 'Curitiba', 'Padre Gaston', 'Cidade Industrial', '81170-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26257, 'Maringá', 'Padre Germano José Mayer', 'Zona 02', '87010-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26258, 'Curitiba', 'Padre Germano Mayer', 'Cristo Rei', '80050-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26259, 'Curitiba', 'Padre Germano Mayer', 'Alto da Rua XV', '80040-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26260, 'Curitiba', 'Padre Giacomo Cusmano', 'Campina do Siqueira', '80730-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26261, 'Curitiba', 'Padre Giovanni Graceffa', 'Pilarzinho', '82120-240', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26262, 'Guarapuava', 'Padre Henrique Daniels', 'Santana', '85070-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26263, 'São José dos Pinhais', 'Padre Humberto Röbig', 'São Sebastião', '83075-477', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26264, 'Ponta Grossa', 'Padre Ildefonso', 'Centro', '84010-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26265, 'Curitiba', 'Padre Ildefonso', 'Batel', '80240-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26266, 'Curitiba', 'Padre Isaías de Andrade', 'Parolin', '80220-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26267, 'Curitiba', 'Padre Jacinto Miensopust', 'Cidade Industrial', '81280-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26268, 'Ponta Grossa', 'Padre João Antônio', 'Orfãs', '84015-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26269, 'Curitiba', 'Padre João Bagozzi', 'Portão', '80610-270', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26270, 'São José dos Pinhais', 'Padre João da Veiga Coutinho', 'Cidade Jardim', '83035-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26271, 'São José dos Pinhais', 'Padre João Inácio Moreno', 'Costeira', '83015-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26272, 'Curitiba', 'Padre João Kominek', 'Cidade Industrial', '81280-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26273, 'Piraquara', 'Padre João Leconte', 'Centro', '83301-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26275, 'Umuarama', 'Padre João Maria Daniel', 'Jardim Alto da Boa Vista', '87506-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26276, 'Campo Largo', 'Padre João Morelli', 'Rondinha', '83607-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26277, 'Araucária', 'Padre João Palka', 'Capela Velha', '83706-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26278, 'Ponta Grossa', 'Padre João Pedro Medaille', 'Cará-cará', '84033-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26279, 'Ponta Grossa', 'Padre João Piamarta', 'Colônia Dona Luiza', '84046-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26280, 'Curitiba', 'Padre João Rzemelka', 'Cidade Industrial', '81280-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26281, 'Curitiba', 'Padre João Sotto-Maior', 'São Francisco', '80510-230', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26282, 'Campo Mourão', 'Padre João Viecelli', 'Jardim Maia', '87301-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26283, 'Curitiba', 'Padre João Wislinski', 'Santa Cândida', '82630-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26284, 'Curitiba', 'Padre João Zalanczyk', 'Uberaba', '81590-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26285, 'Ponta Grossa', 'Padre José Bugatti', 'Colônia Dona Luiza', '84046-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26286, 'Apucarana', 'Padre José Canale', 'Vila Monte Castelo', '86808-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26287, 'Umuarama', 'Padre José Carlos Parra Pires', 'Parque San Remo III', '87506-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26288, 'Araucária', 'Padre José Damek', 'Vila Nova', '83703-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26289, 'Cambé', 'Padre José de Anchieta', 'Parque Residencial Manela', '86185-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26290, 'Curitiba', 'Padre José Falarz', 'Santo Inácio', '82010-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26291, 'Umuarama', 'Padre José Germano Neto Júnior', 'Zona VI', '87503-650', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26292, 'Curitiba', 'Padre José Joaquim Goral', 'Abranches', '82130-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26293, 'Curitiba', 'Padre José Kentenich', 'Campo Comprido', '81210-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26294, 'Ponta Grossa', 'Padre José Krainski', 'Cará-cará', '84033-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26295, 'Curitiba', 'Padre José Lopacinski', 'Cidade Industrial', '81280-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26296, 'Curitiba', 'Padre José Martini', 'Santa Felicidade', '82410-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26297, 'Cascavel', 'Padre José Maurício', 'Floresta', '85815-177', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26298, 'Almirante Tamandaré', 'Padre José Maurício', 'Jardim João Paulo II', '83508-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26299, 'Foz do Iguaçu', 'Padre José Milbauer', 'Parque Presidente II', '85863-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26300, 'Curitiba', 'Padre José Poliga', 'Cajuru', '82980-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26301, 'Curitiba', 'Padre José Zajac', 'Santa Cândida', '82630-375', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26302, 'Curitiba', 'Padre Júlio de Campos', 'Centro', '80020-160', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26303, 'São José dos Pinhais', 'Padre Júlio Pareda', 'Costeira', '83015-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26304, 'Curitiba', 'Padre Júlio Saavedra', 'Uberaba', '81570-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26305, 'Curitiba', 'Padre Karol Dworaczek', 'Cajuru', '82980-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26306, 'Londrina', 'Padre Ladislau Kula', 'Milton Gavetti', '86078-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26307, 'Curitiba', 'Padre Ladislau Kula', 'Santo Inácio', '82010-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26308, 'Ponta Grossa', 'Padre Ladislau Maibuk', 'Cará-cará', '84033-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26309, 'Curitiba', 'Padre Landell de Moura', 'Cidade Industrial', '81170-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26310, 'São José dos Pinhais', 'Padre Leo Pientka', 'Cidade Jardim', '83035-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26311, 'Curitiba', 'Padre Leonardo Nunes', 'Portão', '80330-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26312, 'Toledo', 'Padre Lino Beal', 'Coopagro', '85903-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26313, 'Toledo', 'Padre Luciano Ambrosini', 'Jardim Laranjeiras', '85909-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26314, 'Curitiba', 'Padre Ludovico Bronny', 'Pilarzinho', '82100-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26315, 'Toledo', 'Padre Luiz Luise', 'Conjunto Residencial Tocantins', '85903-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26316, 'Cascavel', 'Padre Luiz Luyse', 'Nucleo de Produção III', '85811-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26317, 'Cambé', 'Padre Luiz Otton', 'Vila Atalaia', '86181-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26318, 'Londrina', 'Padre Manoel da Nóbrega', 'Nossa Senhora do Desterro', '86025-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26319, 'Laranjeiras do Sul', 'Padre Manoel da Nóbrega', 'Getúlio Vargas', '85304-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26320, 'Francisco Beltrão', 'Padre Manoel da Nóbrega', 'Cristo Rei', '85602-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26321, 'Telêmaco Borba', 'Padre Manoel da Nóbrega', 'Vila Monte Belo', '84262-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26322, 'Cambé', 'Padre Manoel da Nóbrega', 'Parque Residencial Manela', '86185-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26323, 'Colombo', 'Padre Manoel Sparagona', 'Centro', '83414-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26324, 'Curitiba', 'Padre Manuel da Nóbrega', 'Fanny', '81030-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26325, 'Ponta Grossa', 'Padre Marcos Cavanis', 'Cará-cará', '84033-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26326, 'Piraquara', 'Padre Mariano', 'Vila Fuck', '83305-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26327, 'Curitiba', 'Padre Mário Tesio', 'Xaxim', '81710-560', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26328, 'Foz do Iguaçu', 'Padre Montoya', 'Centro', '85851-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26329, 'Foz do Iguaçu', 'Padre Montoya', 'Jardim Eldorado', '85853-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26330, 'Curitiba', 'Padre Natal Pigato', 'Santa Felicidade', '82320-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26331, 'Campo Largo', 'Padre Natal Pigatto', 'Vila Elizabeth', '83607-240', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26332, 'Campo Largo', 'Padre Natal Pigatto', 'Vila Bancária', '83601-630', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26333, 'Castro', 'Padre Nicolau Baltazar', 'Centro', '84165-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26334, 'Ponta Grossa', 'Padre Nóbrega', 'Estrela', '84040-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26335, 'Castro', 'Padre Nóbrega', 'Centro', '84165-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26336, 'Curitiba', 'Padre Olímpio', 'Bigorrilho', '80710-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26337, 'Ponta Grossa', 'Padre Oswaldo Gomes', 'Chapada', '84062-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26338, 'Curitiba', 'Padre Oswaldo Gomes', 'Guabirotuba', '81510-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26339, 'Campo Largo', 'Padre Otávio Júlio dos Santos', 'Loteamento Ouro Verde I', '83606-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26340, 'Foz do Iguaçu', 'Padre Otto Berwanger', 'Centro', '85851-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26341, 'Curitiba', 'Padre Paulo Canelles', 'Santa Cândida', '82720-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26342, 'Cascavel', 'Padre Paulo Englert', 'Interlagos', '85814-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26343, 'Laranjeiras do Sul', 'Padre Paulo Schneider', 'São Francisco', '85303-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26344, 'Guarapuava', 'Padre Paulo Tschorn', 'Vila Bela', '85027-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26345, 'Guarapuava', 'Padre Paulo Tschorn', 'Dos Estados', '85035-400', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26346, 'Curitiba', 'Padre Paulo Warkocz', 'Cidade Industrial', '81280-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26347, 'Curitiba', 'Padre Pedro Fuss', 'Cidade Industrial', '81310-425', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26348, 'Almirante Tamandaré', 'Padre Pedro Fuss', 'Vila Feliz', '83505-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26349, 'São José dos Pinhais', 'Padre Pedro Guerra', 'Rio Pequeno', '83070-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26350, 'Piraquara', 'Padre Phelippe Ledet', 'Planta Laranjeiras', '83307-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26351, 'Castro', 'Padre Piva', 'Jardim das Nações', '84172-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26352, 'Curitiba', 'Padre Rafael José Kalinowski', 'Pinheirinho', '81825-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26353, 'Ponta Grossa', 'Padre Rafael Romão', 'Palmeirinha', '84071-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26354, 'Maringá', 'Padre Raimundo Le Goff', 'Zona 07', '87020-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26355, 'Londrina', 'Padre Reinaldo Semprebom', 'Colonial', '86047-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26356, 'Ponta Grossa', 'Padre Renato Canta', 'Jardim Carvalho', '84015-476', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26357, 'Guarapuava', 'Padre Réus', 'Vila Bela', '85027-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26358, 'Francisco Beltrão', 'Padre Réus', 'Cristo Rei', '85602-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26359, 'Londrina', 'Padre Roberto Peres', 'Ouro Verde', '86080-085', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26360, 'Londrina', 'Padre Rolim', 'Jardim São Francisco de Assis', '86067-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26361, 'Cascavel', 'Padre Roque Gonzales', 'Interlagos', '85814-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26362, 'Apucarana', 'Padre Severino Cerutti', 'Vila São José', '86808-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26363, 'Curitiba', 'Padre Sigismundo Pietrowski', 'Abranches', '82130-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26364, 'Curitiba', 'Padre Silvestre Kandora', 'Cidade Industrial', '81280-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26365, 'Curitiba', 'Padre Sílvio Sattler', 'Guaíra', '80630-110', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26366, 'Curitiba', 'Padre Simão Kalinowski', 'Alto Boqueirão', '81750-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26367, 'Almirante Tamandaré', 'Padre Tadeu Diedezic', 'Vila Feliz', '83505-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26368, 'Apucarana', 'Padre Tadeu Wrobel', 'Loteamento Residencial Cazarin', '86802-428', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26369, 'Curitiba', 'Padre Tiago Alberione', 'Santa Felicidade', '82020-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26370, 'Apucarana', 'Padre Tito Cerasoli', 'Jardim Figueira', '86801-356', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26371, 'Londrina', 'Padre Valentin Rodrigues', 'Ipanema', '86015-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26372, 'Curitiba', 'Padre Victor Dewor', 'Cidade Industrial', '81280-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26373, 'Pato Branco', 'Padre Vieira', 'São Cristóvão', '85508-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26374, 'Maringá', 'Padre Vieira', 'Zona 07', '87020-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26375, 'Curitiba', 'Padre Vieira', 'Guabirotuba', '81510-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26376, 'Ponta Grossa', 'Padre Vitório Maria Dall''Acqua', 'Cará-cará', '84033-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26377, 'Londrina', 'Pádua', 'Parque Residencial João Piza', '86041-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26378, 'Ponta Grossa', 'Paes de Andrade', 'Nova Rússia', '84053-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26379, 'Londrina', 'Paes Leme', 'Jardim das Américas', '86010-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26380, 'Pato Branco', 'Pagnoncelli', 'Bancários', '85504-480', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26381, 'Guarapuava', 'Pahy', 'Primavera', '85050-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26382, 'Ponta Grossa', 'Paia do Leblon', 'Contorno', '84060-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26383, 'Campo Mourão', 'Paiçandu', 'Conjunto Habitacional Parigot de Souza', '87310-607', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26384, 'Guarapuava', 'Paiçandú', 'Santana', '85070-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26385, 'Maringá', 'Paim', 'Parque das Laranjeiras', '87083-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26386, 'Foz do Iguaçu', 'Paineira', 'Conjunto B', '85867-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26387, 'Ponta Grossa', 'Paineira', 'Contorno', '84061-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26388, 'Telêmaco Borba', 'Paineira', 'Área 02', '84268-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26389, 'Umuarama', 'Paineira', 'Jardim Paineiras', '87503-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26390, 'Cascavel', 'Paineira', 'Parque Verde', '85807-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26391, 'Londrina', 'País de Gales', 'Jardim Adriana I', '86046-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26392, 'Maringá', 'Paisagística', 'Parque das Laranjeiras', '87083-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26393, 'Maringá', 'Paissandu', 'Zona 03', '87050-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26394, 'Curitiba', 'Paissandú', 'Sítio Cercado', '81910-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26395, 'Curitiba', 'Paixão da Ascencão Cancela', 'Boa Vista', '82540-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26396, 'Francisco Beltrão', 'Palermo', 'Jardim Floresta', '85603-795', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26397, 'Londrina', 'Palermo', 'Parque Residencial João Piza', '86041-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26398, 'Curitiba', 'Palermo', 'Cascatinha', '82020-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26399, 'Foz do Iguaçu', 'Palestina', 'Jardim Comercial das Bandeiras', '85864-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26400, 'Foz do Iguaçu', 'Palestra Itália', 'Parque Morumbi II', '85859-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26401, 'Londrina', 'Palheta', 'Conjunto Café', '86038-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26402, 'Telêmaco Borba', 'Palma', 'Bela Vista do Paraíso', '84262-320', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26403, 'Apucarana', 'Palma', 'Jardim das Flores I', '86810-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26404, 'Guarapuava', 'Palmares', 'Conradinho', '85045-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26405, 'Foz do Iguaçu', 'Palmares', 'Jardim Ipê II', '85869-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26406, 'Francisco Beltrão', 'Palmas', 'Vila Nova', '85605-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26407, 'Francisco Beltrão', 'Palmas', 'Centro', '85601-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26408, 'Guarapuava', 'Palmas', 'Jardim das Américas', '85031-330', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26409, 'Ponta Grossa', 'Palmas', 'Olarias', '84026-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26410, 'Paranavaí', 'Palmas', 'Jardim Ouro Branco', '87704-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26411, 'Pinhais', 'Palmas', 'Jardim Dona Joaquina I', '83325-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26412, 'Paranavaí', 'Palmas', 'Jardim Ibirapuera', '87705-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26413, 'Piraquara', 'Palmas', 'Planta Araçatuba', '83301-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26414, 'São José dos Pinhais', 'Palmas', 'Cruzeiro', '83010-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26415, 'Campo Mourão', 'Palmas', 'Jardim Paulista', '87310-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26416, 'Cascavel', 'Palmas', 'Cataratas', '85818-790', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26417, 'Curitiba', 'Palmas', 'Sítio Cercado', '81900-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26418, 'Laranjeiras do Sul', 'Palmeira', 'Água Verde', '85302-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26419, 'Foz do Iguaçu', 'Palmeira', 'Jardim Quinta do Sol', '85853-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26420, 'Ponta Grossa', 'Palmeira', 'Contorno', '84061-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26421, 'São José dos Pinhais', 'Palmeira', 'São Pedro', '83020-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26422, 'Pato Branco', 'Palmeiras', 'Industrial', '85506-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26423, 'Ponta Grossa', 'Palmeiras', 'Contorno', '84052-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26424, 'Telêmaco Borba', 'Palmeiras', 'Área 01', '84268-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26425, 'Telêmaco Borba', 'Palmeiras', 'Vila Santa Rita', '84263-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26426, 'Cascavel', 'Palmeiras', 'Parque Verde', '85807-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26427, 'Apucarana', 'Palmeiras', 'Vila São Francisco', '86800-580', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26428, 'Curitiba', 'Palmeiras', 'Água Verde', '80620-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26429, 'Curitiba', 'Palminor Rodrigues Ferreira', 'Uberaba', '81590-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26430, 'Londrina', 'Palmira Bandeira Parizotto', 'Assis', '86085-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26431, 'Curitiba', 'Palmira dos Santos', 'Xaxim', '81710-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26432, 'Guarapuava', 'Palmira Freitas Rocha', 'Boqueirão', '85020-717', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26433, 'Curitiba', 'Palmira Glória de Queiroz', 'Orleans', '82310-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26434, 'Guarapuava', 'Palmira K. Rocha', 'Bonsucesso', '85045-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26435, 'Cambé', 'Palmira Raminelli Pagoti', 'Jardim José Favaro', '86183-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26436, 'Cambé', 'Palmiro Frasson', 'Jardim Silvino', '86187-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26437, 'São José dos Pinhais', 'Palmiro Vaccari', 'Braga', '83020-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26438, 'Curitiba', 'Palmital', 'Cidade Industrial', '81305-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26439, 'Foz do Iguaçu', 'Palmital', 'Jardim Ana Cristina', '85861-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26440, 'Guarapuava', 'Palmital', 'Morro Alto', '85065-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26441, 'Pinhais', 'Palmital', 'Planta Karla', '83328-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26442, 'Maringá', 'Palmital', 'Parque Residencial Quebec', '87023-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26443, 'Toledo', 'Palmital', 'Coopagro', '85904-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26444, 'Telêmaco Borba', 'Palmital', 'Jardim Bonavila', '84264-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26445, 'Francisco Beltrão', 'Palmitos', 'Pinheirinho', '85603-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26446, 'Telêmaco Borba', 'Palomar', 'Vila Ana Mari', '84263-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26447, 'Foz do Iguaçu', 'Palometa', 'Parque Ouro Verde', '85855-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26448, 'Londrina', 'Palotina', 'Indústrias', '86043-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26449, 'Laranjeiras do Sul', 'Palotina', 'Água Verde', '85302-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26450, 'Foz do Iguaçu', 'Palotina', 'Jardim Cedro', '85862-356', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26451, 'Guarapuava', 'Palotina', 'Jardim das Américas', '85030-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26452, 'Pinhais', 'Palotina', 'Jardim Atuba II', '83326-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26453, 'Telêmaco Borba', 'Palotina', 'Jardim Bonavila', '84264-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26454, 'Toledo', 'Palotina', 'Jardim Carelli', '85906-717', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26455, 'Campo Mourão', 'Palotina', 'Conjunto Habitacional Parigot de Souza', '87310-606', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26456, 'Colombo', 'Palotina', 'Jardim Amazonas', '83410-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26457, 'Cascavel', 'Palotina', 'Pacaembu', '85816-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26458, 'Curitiba', 'Palotina', 'Alto Boqueirão', '81720-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26459, 'Maringá', 'Pamplona', 'Loteamento Madrid', '87053-529', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26460, 'Londrina', 'Panamá', 'Vila Rodrigues', '86010-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26461, 'Guarapuava', 'Panamá', 'Santana', '85070-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26462, 'Francisco Beltrão', 'Panamá', 'Antônio de Paiva Cantelmo', '85603-541', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26463, 'Maringá', 'Panamá', 'Vila Morangueira', '87040-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26464, 'Pinhais', 'Panamá', 'Vila Progresso', '83320-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26465, 'Paranaguá', 'Panamá', 'Jardim América', '83209-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26466, 'Paranaguá', 'Panamá', 'Parque Agari', '83215-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26467, 'Telêmaco Borba', 'Panamá', 'Alto das Oliveiras', '84266-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26468, 'Colombo', 'Panamá', 'Vila Marcelina', '83404-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26469, 'Cascavel', 'Panamá', 'Periolo', '85817-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26470, 'Apucarana', 'Panamá', 'Jardim Diamantina', '86804-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26471, 'Curitiba', 'Panamá', 'Bacacheri', '82510-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26472, 'Toledo', 'Panambi', 'Jardim La Salle', '85902-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26473, 'Campo Mourão', 'Panambi', 'Centro', '87303-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26474, 'Campo Mourão', 'Panambi', 'Centro', '87300-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26475, 'Laranjeiras do Sul', 'Pandiá Calógeras', 'Centro', '85301-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26476, 'Londrina', 'Pandiá Calógeras', 'Jardim Tatiani', '86070-510', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26477, 'Ponta Grossa', 'Pandiá Calógeras', 'Uvaranas', '84020-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26478, 'Maringá', 'Pandiá Calógeras', 'Zona 04', '87014-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26479, 'Castro', 'Pandiá Calógeras', 'Centro', '84165-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26480, 'Curitiba', 'Pandiá Calógeras', 'Cajuru', '82900-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26481, 'Londrina', 'Panificadores,dos', 'Jardim União da Vitória', '86044-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26482, 'Cascavel', 'Panorama', 'Universitário', '85819-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26483, 'Pato Branco', 'Pantaleão Telles', 'Trevo Patinhos', '85504-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26484, 'Londrina', 'Pantanal', 'Santiago', '86071-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26485, 'Curitiba', 'Pantanal', 'Cidade Industrial', '81305-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26486, 'Almirante Tamandaré', 'Pântano preto', 'Jardim Valença', '83512-280', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26487, 'Curitiba', 'Pantelis Stergov Zafires', 'Cidade Industrial', '81315-400', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26488, 'Cascavel', 'Pão de Açúcar', 'Periolo', '85817-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26489, 'Ponta Grossa', 'Paola Bosia', 'Estrela', '84050-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26490, 'Curitiba', 'Paolo Battan', 'Boa Vista', '82650-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26491, 'Colombo', 'Papa Calixto II', 'Jardim Loanda', '83409-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26492, 'Guarapuava', 'Papa João Paulo I', 'Morro Alto', '85065-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26493, 'Maringá', 'Papa João Paulo I', 'Parque Residencial Rio Branco', '87060-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26494, 'Telêmaco Borba', 'Papa João Paulo I', 'Centro', '84261-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26495, 'Sarandi', 'Papa João Paulo I', 'Parque Industrial I', '87111-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26496, 'Curitiba', 'Papa João Paulo I', 'Vista Alegre', '82100-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26497, 'Francisco Beltrão', 'Papa João XXIII', 'Pinheirinho', '85603-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26498, 'Pato Branco', 'Papa João XXIII', 'São Cristóvão', '85508-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26499, 'Maringá', 'Papa João XXIII', 'Zona 02', '87010-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26500, 'Ponta Grossa', 'Papa João XXIII', 'Neves', '84020-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26501, 'Telêmaco Borba', 'Papa João XXIII', 'Nossa Senhora de Fátima', '84264-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26502, 'Cambé', 'Papa João XXIII', 'Centro', '86182-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26503, 'Araucária', 'Papa João XXIII', 'Sabiá', '83708-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26504, 'Curitiba', 'Papa João XXIII', 'Centro Cívico', '80530-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26505, 'Piraquara', 'Papa Paulo VI', 'Vila Santa Maria', '83306-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26506, 'Umuarama', 'Papa Paulo VI', 'Zona I', '87503-690', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26507, 'Apucarana', 'Papa Paulo VI', 'Vila Regina', '86801-365', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26508, 'Francisco Beltrão', 'Papa Pio XII', 'Guanabara', '85604-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26509, 'Telêmaco Borba', 'Papa Pio XII', 'Centro', '84261-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26510, 'Curitiba', 'Papa Raphael', 'Jardim Social', '82530-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26511, 'Arapongas', 'Papa-capim', 'Jardim Bandeirantes', '86703-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26512, 'Arapongas', 'Papa-formiga-de-crista', 'Conjunto Águias', '86704-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26513, 'Londrina', 'Papagaio', 'Jacomo Violin', '86088-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26514, 'Arapongas', 'Papagaio', 'Jardim Império', '86709-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26515, 'Arapongas', 'Papagaio', 'Centro', '86701-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26516, 'Araucária', 'Papagaio', 'Capela Velha', '83706-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26517, 'Apucarana', 'Papagaio', 'Núcleo Habitacional Michel Soni', '86813-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26518, 'Arapongas', 'Papagaio-grego', 'Conjunto Novo Centauro', '86709-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26519, 'Foz do Iguaçu', 'Papagaios', 'Parque Morumbi III', '85859-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26521, 'Arapongas', 'Papa-piri', 'Vila Edio', '86705-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26522, 'Colombo', 'Papinhosa da Serra', 'Parque Residencial Santa Terezinha', '83408-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26523, 'Pinhais', 'Papiro', 'Jardim Pio XII', '83328-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26524, 'Ponta Grossa', 'Papoula', 'Contorno', '84060-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26525, 'Apucarana', 'Papoula', 'Jardim das Flores II', '86810-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26526, 'Londrina', 'Paquistão', 'Jerumenha', '86046-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26527, 'Londrina', 'Pará', 'Centro', '86020-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26528, 'Guarapuava', 'Pará', 'Boqueirão', '85023-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26529, 'Francisco Beltrão', 'Pará', 'Centro', '85601-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26530, 'Londrina', 'Pará', 'Centro', '86010-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26531, 'Paranaguá', 'Pará', 'Vila do Povo', '83209-649', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26532, 'Ponta Grossa', 'Pará', 'Olarias', '84035-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26533, 'Maringá', 'Pará', 'Parque Residencial Cidade Nova', '87023-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26534, 'Piraquara', 'Pará', 'Jardim dos Estados 2', '83308-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26535, 'Pato Branco', 'Pará', 'Centro', '85505-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26536, 'Paranavaí', 'Pará', 'Centro', '87701-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26537, 'Paranavaí', 'Pará', 'Jardim São Cristóvão', '87702-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26538, 'Maringá', 'Pará', 'Jardim Alvorada', '87033-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26539, 'Telêmaco Borba', 'Pará', 'Vila Ozorio', '84268-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26540, 'São José dos Pinhais', 'Pará', 'Boneca do Iguaçu', '83040-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26541, 'Umuarama', 'Pará', 'Jardim São Marcos', '87501-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26542, 'Almirante Tamandaré', 'Pará', 'Jardim Formosa', '83511-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26543, 'Campo Largo', 'Pará', 'Vila Itaqui', '83604-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26544, 'Cambé', 'Pará', 'Centro', '86181-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26545, 'Campo Largo', 'Pará', 'Jardim Boa Vista', '83609-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26546, 'Cascavel', 'Pará', 'São Cristóvão', '85813-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26547, 'Apucarana', 'Pará', 'Jardim Apucarana', '86804-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26548, 'Castro', 'Pará', 'Água Suja', '84165-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26549, 'Colombo', 'Pará', 'Jardim Curitiba', '83406-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26550, 'Araucária', 'Pará', 'Iguaçu', '83701-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26551, 'Curitiba', 'Pará', 'Água Verde', '80610-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26552, 'Ponta Grossa', 'Pará Castro', 'Jardim Carvalho', '84016-230', 'Estrada Velha', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26553, 'Almirante Tamandaré', 'Pará de Minas', 'Jardim Ipê', '83505-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26554, 'Maringá', 'Pára de Minas', 'Jardim Alvorada', '87033-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26555, 'Maringá', 'para Paisandú', 'Parque Industrial', '87065-165', 'Estrada Velha', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26556, 'Curitiba', 'para Thomas Coelho', 'São Miguel', '81450-760', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26557, 'Umuarama', 'Paracai', 'Zona VII', '87503-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26558, 'Foz do Iguaçu', 'Paracatú', 'Loteamento Campos do Iguaçu', '85857-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26559, 'Londrina', 'Paraguaçu', 'Jardim Palmares', '86025-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26560, 'Londrina', 'Paraguaçu', 'Jardim Palmares', '86025-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26561, 'Pinhais', 'Paraguaçu', 'Loteamento Alphaville Graciosa', '83327-079', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26562, 'Paranavaí', 'Paraguaçu', 'Jardim Santos Dumont', '87706-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26563, 'Cascavel', 'Paraguaçu', 'Brasmadeira', '85814-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26564, 'Guarapuava', 'Paraguai', 'Morro Alto', '85063-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26565, 'Francisco Beltrão', 'Paraguai', 'Presidente Kennedy', '85605-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26566, 'Londrina', 'Paraguai', 'Larsen', '86010-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26567, 'Ponta Grossa', 'Paraguai', 'Centro', '84051-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26568, 'Pato Branco', 'Paraguai', 'Jardim América', '85502-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26569, 'Maringá', 'Paraguai', 'Jardim Alvorada', '87033-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26570, 'Toledo', 'Paraguai', 'Jardim Porto Alegre', '85906-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26571, 'São José dos Pinhais', 'Paraguai', 'Cidade Jardim', '83035-010', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26572, 'Castro', 'Paraguai', 'Vila do Rosário', '84168-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26573, 'Almirante Tamandaré', 'Paraguai', 'Jardim Itamarati', '83505-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26574, 'Cascavel', 'Paraguai', 'Alto Alegre', '85805-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26575, 'Apucarana', 'Paraguai', 'Jardim Diamantina', '86804-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26576, 'Curitiba', 'Paraguai', 'Bacacheri', '82510-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26577, 'Ponta Grossa', 'Paraguassu', 'Contorno', '84052-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26578, 'Curitiba', 'Paraguassu', 'Alto da Glória', '80030-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26579, 'Francisco Beltrão', 'Paraíba', 'Vila Nova', '85605-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26580, 'Londrina', 'Paraíba', 'Jardim Higienópolis', '86020-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26581, 'Foz do Iguaçu', 'Paraíba', 'Loteamento Campos do Iguaçu', '85857-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26582, 'Guarapuava', 'Paraíba', 'Dos Estados', '85035-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26583, 'Paranaguá', 'Paraíba', 'Vila do Povo', '83209-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26584, 'Paranavaí', 'Paraíba', 'Jardim São Cristóvão', '87702-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26585, 'Piraquara', 'Paraíba', 'Jardim dos Estados 2', '83308-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26586, 'Paranavaí', 'Paraíba', 'Centro', '87701-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26587, 'Paranavaí', 'Paraíba', 'Centro', '87708-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26588, 'Ponta Grossa', 'Paraíba', 'Olarias', '84035-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26589, 'São José dos Pinhais', 'Paraíba', 'Boneca do Iguaçu', '83040-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26590, 'Umuarama', 'Paraíba', 'Zona II', '87501-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26591, 'Telêmaco Borba', 'Paraíba', 'Nossa Senhora de Fátima', '84264-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26592, 'Toledo', 'Paraíba', 'Walter Fontana', '85909-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26593, 'Campo Largo', 'Paraíba', 'Jardim Boa Vista', '83609-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26594, 'Campo Largo', 'Paraíba', 'Vila Itaqui', '83604-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26595, 'Colombo', 'Paraíba', 'Jardim Jalisco', '83404-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26596, 'Araucária', 'Paraíba', 'Iguaçu', '83701-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26597, 'Apucarana', 'Paraíba', 'Jardim Apucarana', '86804-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26598, 'Curitiba', 'Paraíba', 'Portão', '80610-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26599, 'Curitiba', 'Paraíba', 'Guaíra', '80630-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26600, 'Paranaguá', 'Paraíso', 'Jardim Paranaguá', '83218-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26601, 'Maringá', 'Paraíso', 'Vila Marumby', '87005-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26602, 'Maringá', 'Paraíso', 'Parque Residencial Rio Branco', '87060-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26603, 'Sarandi', 'Paraíso', 'Parque Residencial Nova Aliança', '87111-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26604, 'Cascavel', 'Paraíso', 'Cancelli', '85811-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26605, 'Pinhais', 'Paraíso do Norte', 'Jardim Pedro Demeterco', '83324-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26606, 'Ponta Grossa', 'Paraíso do Norte', 'Contorno', '84052-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26607, 'Telêmaco Borba', 'Paraíso do Norte', 'Jardim Bonavila', '84264-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26608, 'Curitiba', 'Paraíso do Norte', 'Boqueirão', '81750-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26609, 'Londrina', 'Paramaribo', 'Santa Rosa', '86050-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26610, 'Colombo', 'Paramaribo', 'Vila Marcelina', '83404-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26611, 'Foz do Iguaçu', 'Paramirim', 'Vila Militar', '85857-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26612, 'Foz do Iguaçu', 'Paraná', 'Jardim Itaipu', '85867-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26613, 'Foz do Iguaçu', 'Paraná', 'Centro', '85852-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26614, 'Foz do Iguaçu', 'Paraná', 'Cr 1', '85863-720', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26615, 'Foz do Iguaçu', 'Paraná', 'Conjunto A', '85860-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26616, 'Guarapuava', 'Paraná', 'Dos Estados', '85035-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26617, 'Francisco Beltrão', 'Paraná', 'Vila Maria Delani', '85605-610', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26618, 'Foz do Iguaçu', 'Paraná', 'Jardim das Laranjeiras', '85868-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26619, 'Laranjeiras do Sul', 'Paraná', 'Água Verde', '85302-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26621, 'Guarapuava', 'Paraná', 'Bonsucesso', '85045-120', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26622, 'Laranjeiras do Sul', 'Paraná', 'Centro', '85301-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26623, 'Maringá', 'Paraná', 'Zona 07', '87020-085', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26624, 'Piraquara', 'Paraná', 'Jardim dos Estados 2', '83308-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26625, 'Paranavaí', 'Paraná', 'Centro', '87704-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26626, 'Pato Branco', 'Paraná', 'Centro', '85501-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26627, 'Paranaguá', 'Paraná', 'Jardim Paranaguá', '83218-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26628, 'Piraquara', 'Paraná', 'Jardim Santa Mônica', '83302-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26629, 'Piraquara', 'Paraná', 'Jardim dos Estados 1', '83308-410', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26630, 'Paranavaí', 'Paraná', 'Jardim América', '87705-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26631, 'Londrina', 'Paraná', 'Centro', '86010-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26632, 'Maringá', 'Paraná', 'Zona 01', '87013-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26633, 'Londrina', 'Paraná', 'Centro', '86020-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26634, 'Umuarama', 'Paraná', 'Zona I', '87501-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26635, 'Telêmaco Borba', 'Paraná', 'Vila Ana Mari', '84263-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26636, 'Umuarama', 'Paraná', 'Zona III', '87502-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26637, 'Toledo', 'Paraná', 'Jardim Porto Alegre', '85906-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26638, 'Telêmaco Borba', 'Paraná', 'Centro', '84261-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26639, 'São José dos Pinhais', 'Paraná', 'São Domingos', '83030-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26640, 'Cascavel', 'Paraná', 'Coqueiral', '85807-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26641, 'Cascavel', 'Paraná', 'Centro', '85810-011', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26642, 'Cascavel', 'Paraná', 'Centro', '85810-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26643, 'Colombo', 'Paraná', 'Vila Guaraci', '83404-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26644, 'Campo Largo', 'Paraná', 'Jardim Boa Vista', '83609-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26645, 'Cascavel', 'Paraná', 'Centro', '85812-011', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26646, 'Cascavel', 'Paraná', 'Centro', '85812-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26647, 'Cascavel', 'Paraná', 'São Cristóvão', '85813-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26648, 'Apucarana', 'Paraná', 'Vila Cassala', '86804-340', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26649, 'Araucária', 'Paraná', 'Iguaçu', '83701-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26650, 'Campo Largo', 'Paraná', 'Jardim Esmeralda', '83604-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26651, 'Campo Mourão', 'Paraná', 'Jardim Nossa Senhora Aparecida', '87309-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26652, 'Almirante Tamandaré', 'Paraná', 'Jardim Dragão Verde', '83507-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26653, 'Curitiba', 'Paraná', 'Santa Cândida', '82620-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26654, 'Curitiba', 'Paraná', 'Boa Vista', '82510-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26655, 'Curitiba', 'Paraná', 'Cabral', '80035-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26656, 'Cambé', 'Paraná Esporte Club', 'Conjunto Habitacional Collor de Melo', '86188-580', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26657, 'Guarapuava', 'Paranacity', 'Boqueirão', '85020-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26658, 'Ponta Grossa', 'Paranacity', 'Cará-cará', '84032-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26659, 'Pinhais', 'Paranacity', 'Jardim Pedro Demeterco', '83324-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26660, 'Curitiba', 'Paranacity', 'Xaxim', '81830-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26661, 'Laranjeiras do Sul', 'Paranaguá', 'Água Verde', '85302-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26662, 'Londrina', 'Paranaguá', 'Centro', '86020-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26663, 'Londrina', 'Paranaguá', 'Centro', '86020-031', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26664, 'Londrina', 'Paranaguá', 'Centro', '86015-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26665, 'Paranaguá', 'Paranaguá', 'Jardim Paranaguá', '83218-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26666, 'Ponta Grossa', 'Paranaguá', 'Estrela', '84050-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26667, 'Piraquara', 'Paranaguá', 'Planta Araçatuba', '83301-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26668, 'Maringá', 'Paranaguá', 'Zona 07', '87020-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26669, 'Umuarama', 'Paranaguá', 'Jardim Paraíso', '87505-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26670, 'São José dos Pinhais', 'Paranaguá', 'Boneca do Iguaçu', '83040-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26671, 'Toledo', 'Paranaguá', 'Jardim Paulista', '85909-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26672, 'Araucária', 'Paranaguá', 'Iguaçu', '83701-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26673, 'Apucarana', 'Paranaguá', 'Jardim Ponta Grossa', '86805-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26674, 'Cascavel', 'Paranaguá', 'São Cristóvão', '85816-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26675, 'Almirante Tamandaré', 'Paranaguá', 'Vila Otília', '83506-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26676, 'Colombo', 'Paranaguá', 'Jardim São José', '83410-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26677, 'Cambé', 'Paranaguá', 'Jardim Ana Eliza', '86187-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26678, 'Curitiba', 'Paranaguá', 'Guaíra', '80610-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26679, 'Guarapuava', 'Paranaiba', 'Santana', '85070-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26680, 'Sarandi', 'Paranaiba', 'Jardim Gralha Azul', '87112-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26681, 'Foz do Iguaçu', 'Paranapanema', 'Jardim Acaray', '85857-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26682, 'Londrina', 'Paranapanema', 'Vila Balarotti', '86025-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26683, 'Guarapuava', 'Paranapanema', 'Alto Cascavel', '85031-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26684, 'Paranaguá', 'Paranapanema', 'Santos Dumont', '83209-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26685, 'Umuarama', 'Paranapanema', 'Zona VI', '87503-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26686, 'Araucária', 'Paranapanema', 'Iguaçu', '83701-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26687, 'Curitiba', 'Paranapoema', 'São Braz', '82300-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26688, 'Londrina', 'Paranavaí', 'Judith', '86061-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26689, 'Guarapuava', 'Paranavaí', 'Alto Cascavel', '85031-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26690, 'Maringá', 'Paranavaí', 'Parque Industrial Bandeirantes', '87070-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26691, 'Pinhais', 'Paranavaí', 'Jardim Atuba I', '83326-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26692, 'Pinhais', 'Paranavaí', 'Planta Portal da Serra', '83325-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26693, 'Maringá', 'Paranavaí', 'Zona 06', '87015-630', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26694, 'Pinhais', 'Paranavaí', 'Jardim Pedro Demeterco', '83324-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26695, 'Ponta Grossa', 'Paranavaí', 'Uvaranas', '84025-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26696, 'São José dos Pinhais', 'Paranavaí', 'Boneca do Iguaçu', '83040-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26697, 'Toledo', 'Paranavaí', 'Jardim Bressan', '85913-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26698, 'Cambé', 'Paranavaí', 'Jardim Silvino', '86187-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26699, 'Cascavel', 'Paranavaí', 'Pacaembu', '85816-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26700, 'Araucária', 'Paranavaí', 'Iguaçu', '83701-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26701, 'Cambé', 'Paranoá', 'Jardim Alvorada', '86191-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26702, 'Foz do Iguaçu', 'Paraopéba', 'Loteamento Campos do Iguaçu', '85857-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26703, 'Campo Mourão', 'Para-piri', 'Jardim Flórida', '87300-530', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26704, 'Foz do Iguaçu', 'Parati', 'Conjunto A', '85860-450', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26705, 'Foz do Iguaçu', 'Parati', 'Conjunto A', '85861-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26706, 'Foz do Iguaçu', 'Parati', 'Jardim Lancaster', '85869-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26707, 'Piraquara', 'Parati', 'Jardim Tropical', '83314-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26708, 'Telêmaco Borba', 'Parati', 'Vila São Francisco de Assis', '84264-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26709, 'Arapongas', 'Parati', 'Jardim Aeroporto', '86702-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26710, 'Foz do Iguaçu', 'Pardais', 'Portal da Foz', '85859-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26711, 'Londrina', 'Pardal', 'Conjunto Habitacional Violim', '86088-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26712, 'Pinhais', 'Pardal', 'Jardim Fênix', '83326-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26713, 'Maringá', 'Pardal', 'Parque Hortência', '87075-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26714, 'Ponta Grossa', 'Pardal', 'Colônia Dona Luiza', '84046-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26715, 'Apucarana', 'Pardal', 'Núcleo Habitacional Michel Soni', '86813-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26716, 'Araucária', 'Pardal', 'Estação', '83705-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26717, 'Cambé', 'Pardal', 'Conjunto Habitacional Waldomiro M Gomes', '86182-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26718, 'Arapongas', 'Pardal', 'Jardim Primavera', '86702-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26719, 'Campo Mourão', 'Pardal', 'Conjunto Habitacional Milton Luiz Pereira', '87306-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26720, 'Cascavel', 'Parecis', '14 de Novembro', '85804-118', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26721, 'Cambé', 'Parecis', 'Jardim Tupi', '86183-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26722, 'Foz do Iguaçu', 'Parigot de Souza', 'Vila Yolanda', '85853-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26723, 'Pato Branco', 'Parigot de Souza', 'Bortot', '85504-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26724, 'Paranavaí', 'Parigot de Souza', 'Jardim Ibirapuera', '87705-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26725, 'Toledo', 'Parigot de Souza', 'Centro', '85905-380', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26726, 'Toledo', 'Parigot de Souza', 'Vila Industrial', '85904-270', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26727, 'Toledo', 'Parigot de Souza', 'Jardim Porto Alegre', '85906-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26728, 'Toledo', 'Parigot de Souza', 'Jardim Santa Maria', '85903-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26729, 'Cascavel', 'Parigot de Souza', 'Country', '85813-065', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26730, 'Cascavel', 'Parigot de Souza', 'Cancelli', '85811-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26731, 'Campo Mourão', 'Parigot de Souza', 'Conjunto Habitacional Parigot de Souza', '87310-600', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26732, 'Curitiba', 'Parintins', 'Vila Izabel', '80320-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26733, 'Foz do Iguaçu', 'Paris', 'Jardim Alice I', '85858-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26734, 'Londrina', 'Paris', 'Parque Residencial João Piza', '86041-120', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26735, 'Francisco Beltrão', 'Paris', 'Seminário', '85605-658', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26736, 'Guarapuava', 'Paris', 'Santana', '85070-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26737, 'Paranaguá', 'Paris', 'Parque Agari', '83215-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26738, 'Toledo', 'Paris', 'Centro', '85900-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26739, 'Telêmaco Borba', 'Paris', 'Nossa Senhora do Perpétuo Socorro', '84265-030', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26740, 'Cascavel', 'Paris', 'Cascavel Velho', '85818-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26741, 'Colombo', 'Paris', 'Vila Alto da Cruz', '83405-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26742, 'Cascavel', 'Parisis', 'Santo Onofre', '85806-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26743, 'Colombo', 'Parma', 'Centro Industrial Mauá', '83413-587', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26744, 'Cambé', 'Parma', 'Jardim Montecatini', '86186-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26745, 'Foz do Iguaçu', 'Parnaiba', 'Conjunto Libra', '85857-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26746, 'Curitiba', 'Parnaíba', 'São Francisco', '80510-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26747, 'Arapongas', 'Parotiba', 'Vila Trinta e Três', '86705-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26748, 'Foz do Iguaçu', 'Parque Antártica', 'Parque Morumbi II', '85859-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26749, 'Maringá', 'Parque do Horto', 'Zona 05', '87060-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26750, 'Londrina', 'Parque Nacional da Amazônia', 'Vila A B Vicentini', '86077-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26751, 'Londrina', 'Parque Nacional do Araguaia', 'Vila A B Vicentini', '86077-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26752, 'Londrina', 'Parque Nacional do Iguaçu', 'Vila A B Vicentini', '86077-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26753, 'Londrina', 'Parque Nacional do Pico da Neblina', 'Vila A B Vicentini', '86077-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26754, 'Londrina', 'Parque Nacional do Rio Branco', 'Vila A B Vicentini', '86077-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26755, 'Guarapuava', 'Parreiras', 'Morro Alto', '85067-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26756, 'Francisco Beltrão', 'Particular', 'Nossa Senhora Aparecida', '85601-845', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26757, 'Pinhais', 'Particular', 'Capoeira Grande', '83329-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26758, 'Telêmaco Borba', 'Particular', 'Nossa Senhora do Perpétuo Socorro', '84265-010', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26759, 'Castro', 'Paschoal Amato', 'Vila Frei Mathias', '84165-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26760, 'Curitiba', 'Paschoal Bordignon', 'Jardim Botânico', '80210-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26761, 'Londrina', 'Paschoal Carlos Magno', 'Conjunto Vivi Xavier', '86082-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26762, 'Ponta Grossa', 'Paschoal Carlos Magno', 'Centro', '84010-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26763, 'Londrina', 'Paschoal Ghelardi', 'Colúmbia', '86057-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26764, 'Colombo', 'Paschoal Lazarotto Toniolo', 'Jardim Nossa Senhora de Fátima', '83405-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26765, 'Guarapuava', 'Paschoal Ranieiri', 'Boqueirão', '85020-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26766, 'Londrina', 'Paschoal Sorace', 'Jardim Graziela', '86036-140', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26767, 'Curitiba', 'Páscoa Maria Ançay', 'Cidade Industrial', '81305-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26768, 'Araucária', 'Pascoal Basso', 'Centro', '83702-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26769, 'Campo Largo', 'Pascoal Carignano', 'Passauna', '83608-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26770, 'Araucária', 'Pascoal Fernandes Leite', 'Thomaz Coelho', '83707-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26771, 'Guarapuava', 'Pascoal Moreira Cabral', 'Primavera', '85050-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26772, 'Telêmaco Borba', 'Pascoal Moreira Cabral', 'Núcleo Bandeirantes', '84269-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26773, 'Cambé', 'Pascoal Moreira Cabral', 'Jardim Riviera', '86187-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26774, 'Cascavel', 'Pascoal Ranieri Mazzille', 'Presidente', '85818-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26775, 'Curitiba', 'Pascoalin Muzica', 'Pilarzinho', '82110-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26776, 'Ponta Grossa', 'Pascoalino Proviseiro', 'Uvaranas', '84030-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26777, 'Cambé', 'Pascual Lupo', 'Jardim Boa Vista', '86191-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26778, 'Campo Mourão', 'Pássaro Lira', 'Conjunto Habitacional Milton Luiz Pereira', '87306-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26779, 'Guarapuava', 'Pássaro-azul', 'São Cristóvão', '85063-050', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26780, 'Arapongas', 'Pássaro-boi', 'Jardim Monte Carlo', '86704-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26781, 'Arapongas', 'Pássaro-preto', 'Parque Industrial II', '86703-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26782, 'Apucarana', 'Pássaro-preto', 'Núcleo Habitacional Michel Soni', '86813-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26783, 'Campo Mourão', 'Pássaro-preto', 'Conjunto Habitacional Milton Luiz Pereira', '87306-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26784, 'Araucária', 'Passaúna', 'Iguaçu', '83701-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26785, 'Foz do Iguaçu', 'Passo da Ilha', 'Jardim Vale do Sol', '85862-457', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26786, 'Pato Branco', 'Passo Fundo', 'Santo Antônio', '85507-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26787, 'Londrina', 'Passos', 'Jardim Alvorada', '86062-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26788, 'Francisco Beltrão', 'Passos', 'Sadia', '85606-370', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26789, 'São José dos Pinhais', 'Passos de Oliveira', 'Centro', '83030-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26790, 'Pinhais', 'Pasteur', 'Núcleo Colonial de Pinhais', '83321-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26791, 'Ponta Grossa', 'Pasteur', 'Centro', '84010-540', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26792, 'Telêmaco Borba', 'Pasteur', 'Nossa Senhora do Perpétuo Socorro', '84265-240', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26793, 'Colombo', 'Pasteur', 'Vila Guarani', '83408-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26794, 'Almirante Tamandaré', 'Pasteur', 'Jardim Campos Elísios', '83508-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26795, 'Curitiba', 'Pasteur', 'Batel', '80250-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26796, 'Piraquara', 'Pastor Adolfo Weidmann', 'Guarituba', '83312-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26797, 'Maringá', 'Pastor Anísio Francisco da Silva', 'Jardim Alvorada', '87033-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26798, 'Curitiba', 'Pastor Antônio Cardona Aguiar', 'Novo Mundo', '81030-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26799, 'Maringá', 'Pastor Antônio Luiz Furlan', 'Parque Tarumã', '87053-598', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26800, 'Curitiba', 'Pastor Antônio Polito', 'Alto Boqueirão', '81770-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26801, 'Curitiba', 'Pastor Antônio Polito', 'Boqueirão', '81730-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26802, 'Francisco Beltrão', 'Pastor Ariel', 'Jardim Santa Fé', '85602-506', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26803, 'Curitiba', 'Pastor Arlindo Antônio Herter', 'Uberaba', '81590-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26804, 'Maringá', 'Pastor Betinho', 'Vila Marumby', '87005-126', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26805, 'São José dos Pinhais', 'Pastor Boleslau Olcha', 'São Sebastião', '83075-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26806, 'Telêmaco Borba', 'Pastor Bráulio José Matheus', 'Fazenda Limeira', '84272-346', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26807, 'Curitiba', 'Pastor Carlos Frank', 'Boqueirão', '81750-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26808, 'Curitiba', 'Pastor Carlos Frank', 'Boqueirão', '81730-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26809, 'Curitiba', 'Pastor David Koop', 'Boqueirão', '81670-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26810, 'Londrina', 'Pastor Elias Abrahão', 'Residencial Vila Romana', '86031-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26811, 'Apucarana', 'Pastor Eufemjusz Mialik', 'Loteamento Residencial Cazarin', '86802-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26812, 'Pinhais', 'Pastor Eurípedes Souza de Oliveira', 'Jardim Guairacá', '83324-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26813, 'Ponta Grossa', 'Pastor Fugmann', 'Centro', '84010-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26814, 'Ponta Grossa', 'Pastor Fugmann', 'Nova Rússia', '84070-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26815, 'Curitiba', 'Pastor Ismael Colucci', 'Xaxim', '81830-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26816, 'Curitiba', 'Pastor João Augusto da Silveira', 'Sítio Cercado', '81900-777', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26817, 'Curitiba', 'Pastor João Batista Clemente', 'Cidade Industrial', '81305-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26818, 'Curitiba', 'Pastor João Boeira de Vargas', 'Pinheirinho', '81825-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26819, 'Curitiba', 'Pastor João Emílio Henck', 'Fanny', '81030-105', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26820, 'Curitiba', 'Pastor João Pereira', 'Cidade Industrial', '81270-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26821, 'Londrina', 'Pastor José Cândido', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26822, 'Curitiba', 'Pastor José Martins da Silva', 'Sítio Cercado', '81925-599', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26823, 'Curitiba', 'Pastor José Pinheiro de Lacerda', 'Xaxim', '81710-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26824, 'Curitiba', 'Pastor Lori Massolin', 'Cidade Industrial', '81170-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26825, 'Curitiba', 'Pastor Lourival Malinoski', 'Portão', '80610-380', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26826, 'Curitiba', 'Pastor Luiz Antônio Alvear Lagos', 'Cidade Industrial', '81170-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26827, 'Curitiba', 'Pastor Manoel Virgínio de Souza', 'Capão da Imbuia', '82810-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26828, 'Maringá', 'Pastor Martin Luther King', 'Zona 05', '87015-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26829, 'Londrina', 'Pastor Nestor do Carmo', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26830, 'Curitiba', 'Pastor Nivaldo Ramos', 'Cidade Industrial', '81240-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26831, 'Ponta Grossa', 'Pastor Noé Fagundes Muniz', 'Contorno', '84061-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26832, 'Curitiba', 'Pastor Osmar Amaral', 'Novo Mundo', '81050-688', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26833, 'Curitiba', 'Pastor Osório de Freitas', 'Pinheirinho', '81825-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26834, 'Ponta Grossa', 'Pastor Pita', 'Uvaranas', '84030-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26835, 'Paranaguá', 'Pastor Rafael Batista de Oliveira', 'Jardim Guaraituba', '83209-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26836, 'Laranjeiras do Sul', 'Pastor Reno Prodosquismiski', 'São Francisco', '85303-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26837, 'Curitiba', 'Pastor Roberto Mendes Rabello', 'Cidade Industrial', '81350-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26838, 'Guarapuava', 'Pastor Roberto Rickli Sobrinho', 'Vila Carli', '85040-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26839, 'Londrina', 'Pastor Vítor Augusto de Oliveira', 'Indústrias', '86043-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26840, 'Curitiba', 'Pastor Waldomiro Bileski', 'Sítio Cercado', '81920-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26841, 'Londrina', 'Patagônia', 'Barbeta', '86078-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26842, 'Arapongas', 'Patão', 'Vila Sampaio', '86705-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26843, 'Foz do Iguaçu', 'Patativa', 'Conjunto A', '85866-070', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26844, 'Maringá', 'Patativa', 'Jardim Olímpico', '87070-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26845, 'Ponta Grossa', 'Patativa', 'Chapada', '84064-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26846, 'Ponta Grossa', 'Patativa', 'Colônia Dona Luiza', '84043-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26847, 'Arapongas', 'Patativa', 'Jardim Bandeirantes', '86703-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26848, 'Araucária', 'Patativa', 'Capela Velha', '83706-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26849, 'Foz do Iguaçu', 'Pati', 'Conjunto A', '85860-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26850, 'Foz do Iguaçu', 'Pato Branco', 'Vila Carima', '85855-689', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26851, 'Laranjeiras do Sul', 'Pato Branco', 'Água Verde', '85302-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26852, 'Guarapuava', 'Pato Branco', 'Jardim das Américas', '85030-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26853, 'Francisco Beltrão', 'Pato Branco', 'São Cristóvão', '85601-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26854, 'Pinhais', 'Pato Branco', 'Jardim Alto Tarumã', '83325-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26855, 'Ponta Grossa', 'Pato Branco', 'Oficinas', '84036-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26856, 'Umuarama', 'Pato Branco', 'Jardim San Martim', '87508-126', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26857, 'Toledo', 'Pato Branco', 'Jardim Bressan', '85913-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26858, 'Telêmaco Borba', 'Pato Branco', 'Bela Vista do Paraíso', '84262-330', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26859, 'São José dos Pinhais', 'Pato Branco', 'Guatupê', '83060-046', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26860, 'Colombo', 'Pato Branco', 'Jardim Cristina III', '83410-850', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26861, 'Cascavel', 'Pato Branco', 'São Cristóvão', '85816-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26862, 'Apucarana', 'Pato Branco', 'Jardim Ponta Grossa', '86805-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26863, 'Curitiba', 'Pato Branco', 'Xaxim', '81820-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26864, 'Arapongas', 'Pato-bravo', 'Jardim Cultura', '86707-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26865, 'Arapongas', 'Pato-bravo-do-mato', 'Jardim Petrópolis', '86709-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26866, 'Arapongas', 'Pato-de-crista', 'Jardim São Rafael', '86703-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26867, 'Arapongas', 'Pato-do-mato', 'Conjunto Palmares', '86706-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26868, 'Arapongas', 'Pato-mergulhador', 'Jardim Petrópolis', '86709-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26869, 'Almirante Tamandaré', 'Patos de Minas', 'Vila Feliz', '83505-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26870, 'Umuarama', 'Patriarca Abraão', 'Conjunto Residencial Vinte e Seis de Junho', '87508-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26871, 'Umuarama', 'Patriarca Isaac', 'Conjunto Residencial Vinte e Seis de Junho', '87508-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26872, 'Umuarama', 'Patriarca Jacó', 'Conjunto Residencial Vinte e Seis de Junho', '87508-086', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26873, 'Umuarama', 'Patriarca José', 'Conjunto Residencial Vinte e Seis de Junho', '87508-087', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26874, 'Maringá', 'Patrícia', 'Parque Residencial Patrícia', '87040-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26875, 'Londrina', 'Patrícia Cruciol Avanço', 'Jardim Ilha do Mel', '86081-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26876, 'Curitiba', 'Patrício Bagolin', 'Cidade Industrial', '81280-056', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26877, 'Foz do Iguaçu', 'Patrício Moleda', 'Jardim das Flores', '85870-608', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26878, 'Paranavaí', 'Patriota Leodegário Gomes', 'Jardim São Jorge', '87710-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26879, 'Cambé', 'Patrocínio Brandão Machado', 'Planta São Francisco', '86182-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26880, 'Foz do Iguaçu', 'Patrulheiro Venanti Otremba', 'Vila Maracanã', '85852-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26881, 'Foz do Iguaçu', 'Paturi', 'Conjunto A', '85866-260', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26882, 'Maringá', 'Paturi', 'Jardim Olímpico', '87070-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26883, 'Arapongas', 'Paturi', 'Vila São João', '86708-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26884, 'Maringá', 'Pau d''Alho', 'Parque Palmeiras', '87023-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26885, 'Foz do Iguaçu', 'Pau-brasil', 'Jardim Tropical', '85855-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26886, 'Guarapuava', 'Pau-brasil', 'Santana', '85070-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26887, 'Londrina', 'Pau-brasil', 'Universitário', '86050-725', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26888, 'Maringá', 'Pau-brasil', 'Jardim Pinheiros', '87043-639', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26889, 'Ponta Grossa', 'Pau-brasil', 'Uvaranas', '84033-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26890, 'Pinhais', 'Pau-brasil', 'Planta Karla', '83328-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26891, 'Sarandi', 'Pau-brasil', 'Jardim Monterey', '87112-799', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26892, 'Apucarana', 'Pau-brasil', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-465', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26893, 'Araucária', 'Pau-brasil', 'Estação', '83705-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26894, 'Cambé', 'Pau-Brasil', 'Vila Salomé', '86192-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26895, 'Cascavel', 'Pau-brasil', 'Recanto Tropical', '85807-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26896, 'Campo Mourão', 'Pau-brasil', 'Conjunto Habitacional Mendes', '87306-387', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26897, 'Londrina', 'Pau-d'' Alho', 'Leonor', '86071-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26898, 'Apucarana', 'Pau-d''alho', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26899, 'Apucarana', 'Pau-ferro', 'Jardim Recanto dos Palmares', '86803-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26900, 'Curitiba', 'Paul Cezanne', 'Guabirotuba', '81510-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26901, 'Ponta Grossa', 'Paul Fort', 'Cará-cará', '84043-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26902, 'Curitiba', 'Paul Garfunkel', 'Cidade Industrial', '81460-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26903, 'Londrina', 'Paul Harris', 'Nossa Senhora de Lourdes', '86039-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26904, 'Ponta Grossa', 'Paul Harris', 'Chapada', '84062-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26905, 'Sarandi', 'Paul Harris', 'Jardim Nova Independência I', '87114-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26906, 'Curitiba', 'Paul Harris', 'Juvevê', '80030-450', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26907, 'Foz do Iguaçu', 'Paul Harrys', 'Centro', '85851-350', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26908, 'Campo Mourão', 'Paul P. Harris', 'Jardim São Sebastião', '87303-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26909, 'Umuarama', 'Paul Percy Harris', 'Zona VII', '87503-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26910, 'Cascavel', 'Paul Ricard', 'Interlagos', '85814-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26911, 'Francisco Beltrão', 'Paula Freitas', 'Nossa Senhora Aparecida', '85601-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26912, 'Telêmaco Borba', 'Paula Freitas', 'Jardim Bonavila', '84264-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26913, 'Curitiba', 'Paula Freitas', 'Alto Boqueirão', '81860-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26914, 'Londrina', 'Paula Gomes', 'Progresso', '86079-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26915, 'Ponta Grossa', 'Paula Gomes', 'Nova Rússia', '84053-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26916, 'Curitiba', 'Paula Gomes', 'São Francisco', '80510-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26917, 'Curitiba', 'Paula Pedroso do Amaral', 'Água Verde', '80240-670', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26918, 'Curitiba', 'Paula Prevedello Gusso', 'Boa Vista', '82540-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26919, 'Curitiba', 'Paula Prevedello Gusso', 'Boa Vista', '82560-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26920, 'Londrina', 'Paula Soares', 'Paulista', '86079-115', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26921, 'Curitiba', 'Paulina Ader', 'Novo Mundo', '81050-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26922, 'Araucária', 'Paulina Condessa Ferreira', 'Costeira', '83709-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26923, 'Curitiba', 'Paulina Kavinski Pontarolla', 'Tatuquara', '81470-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26924, 'Curitiba', 'Paulina Maria da Luz', 'Sítio Cercado', '81920-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26925, 'São José dos Pinhais', 'Paulina Pallu', 'Afonso Pena', '83050-128', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26926, 'Piraquara', 'Paulina Pereira da Luz Sobrinho', 'Jardim Santa Mônica', '83302-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26927, 'Curitiba', 'Paulina Polak', 'Pilarzinho', '82120-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26928, 'Curitiba', 'Paulina Taborda Ribas de Camargo', 'Alto da Rua XV', '80050-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26929, 'Londrina', 'Paulina Vitorino', 'Conjunto Habitacional Jesualdo Garcia Pessoa', '86031-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26930, 'Colombo', 'Paulina Wanke', 'Jardim Magnópolis', '83403-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26931, 'São José dos Pinhais', 'Paulina Wescher', 'Braga', '83020-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26932, 'Apucarana', 'Paulina Zala', 'Centro', '86800-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26933, 'Colombo', 'Paulino Bonato', 'Jardim Solimões', '83402-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26934, 'São José dos Pinhais', 'Paulino Chiuratto', 'Afonso Pena', '83040-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26935, 'São José dos Pinhais', 'Paulino de Siqueira Cortes', 'São Pedro', '83005-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26936, 'São José dos Pinhais', 'Paulino de Siqueira Cortes', 'Silveira da Motta', '83030-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26937, 'Foz do Iguaçu', 'Paulino Ferreira', 'Boa Esperança', '85854-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26938, 'São José dos Pinhais', 'Paulino Ferreira Bello', 'Guatupê', '83060-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26939, 'Curitiba', 'Paulino Franco de Carvalho', 'Santa Cândida', '82630-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26940, 'Colombo', 'Paulino Frazão', 'Jardim Florença', '83414-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26941, 'Araucária', 'Paulino José da Motta', 'Boqueirão', '83704-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26942, 'Curitiba', 'Paulino Leitoles', 'Santa Quitéria', '80310-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26943, 'Almirante Tamandaré', 'Paulino Mendes Gonçalves', 'Jardim Dourados', '83507-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26944, 'São José dos Pinhais', 'Paulino Natal Bonin', 'Centro', '83030-725', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26945, 'Apucarana', 'Paulino Pinto de Macedo', 'Jardim Flamingos', '86811-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26946, 'Paranaguá', 'Paulino Pioli', 'Vila dos Comerciários', '83215-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26947, 'Curitiba', 'Paulino Santana de Oliveira', 'Novo Mundo', '81050-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26948, 'Curitiba', 'Paulino Silva', 'Tatuquara', '81470-316', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26949, 'Toledo', 'Paulista', 'Jardim Paulista', '85909-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26950, 'Cascavel', 'Paulista', 'São Cristóvão', '85816-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26951, 'Francisco Beltrão', 'Paulo Abdala', 'Água Branca', '85601-334', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26952, 'Campo Largo', 'Paulo Abdala', 'Vila Ferrari', '83606-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26953, 'Foz do Iguaçu', 'Paulo Afonso', 'Conjunto Libra II', '85858-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26954, 'São José dos Pinhais', 'Paulo Alberti', 'Silveira da Motta', '83030-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26955, 'Curitiba', 'Paulo Alves de Bastos', 'Sítio Cercado', '81900-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26956, 'Araucária', 'Paulo Alves Pinto', 'Centro', '83702-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26957, 'Londrina', 'Paulo Alvino Teixeira Wiese', 'Jardim dos Alpes II', '86075-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26958, 'Paranavaí', 'Paulo Antônio da Costa', 'Jardim Simara', '87707-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26959, 'Paranavaí', 'Paulo Antônio da Costa', 'Jardim Aeroporto', '87705-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26960, 'Curitiba', 'Paulo Arendarchuk', 'Alto Boqueirão', '81750-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26961, 'Curitiba', 'Paulo Augusto', 'Boqueirão', '81730-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26962, 'Londrina', 'Paulo Augusto dos Santos', 'Jardim São Rafael', '86035-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26963, 'Londrina', 'Paulo Barreto', 'Nova', '86015-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26964, 'Foz do Iguaçu', 'Paulo Baum', 'Jardim N Horizonte', '85855-727', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26965, 'Cambé', 'Paulo Begnini', 'Jardim Santo Antônio', '86182-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26966, 'Curitiba', 'Paulo Bertassoni', 'Campo Comprido', '81220-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26967, 'Curitiba', 'Paulo Bettes', 'Novo Mundo', '81010-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26968, 'Cascavel', 'Paulo Bevilaqua', 'Nova Cidade', '85803-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26969, 'Campo Largo', 'Paulo Bianco', 'Botiatuva', '83602-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26970, 'Almirante Tamandaré', 'Paulo Bini', 'Vila Rachel', '83501-630', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26971, 'Laranjeiras do Sul', 'Paulo Brondani', 'São Francisco', '85303-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26972, 'Curitiba', 'Paulo Brum', 'Alto Boqueirão', '81830-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26973, 'Colombo', 'Paulo Bugaski', 'Jardim Arapongas', '83402-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26974, 'Londrina', 'Paulo Bulik', 'Jamile Dequech', '86048-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26975, 'Araucária', 'Paulo Cantador', 'Costeira', '83709-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26976, 'Curitiba', 'Paulo Caramori', 'Santa Cândida', '82630-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26977, 'Curitiba', 'Paulo César Cordeiro', 'Cidade Industrial', '81280-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26978, 'Curitiba', 'Paulo César de Araújo Kalil', 'Cidade Industrial', '81170-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26979, 'São José dos Pinhais', 'Paulo César de Souza', 'Miringuava', '83090-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26980, 'Curitiba', 'Paulo César Moscardini', 'Santa Felicidade', '82410-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26981, 'Curitiba', 'Paulo César Padilha', 'Cidade Industrial', '81315-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26982, 'Foz do Iguaçu', 'Paulo Colombelli', 'Jardim Don Ricardo', '85862-416', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26983, 'Paranaguá', 'Paulo de Almeida Pires', 'Vila Guadalupe', '83221-557', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26984, 'Colombo', 'Paulo de Andrade', 'Santa Rita', '83412-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26985, 'Curitiba', 'Paulo de Avelar', 'Pinheirinho', '81870-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26986, 'Curitiba', 'Paulo de Deus Bessa', 'Santo Inácio', '82300-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26987, 'Foz do Iguaçu', 'Paulo de Farias', 'Jardim Lancaster I', '85869-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26988, 'Curitiba', 'Paulo de Frontin', 'Cajuru', '82940-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26989, 'Londrina', 'Paulo de Lucca', 'Espírito Santo', '86073-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26990, 'Londrina', 'Paulo de Tarso Gomes', 'Parque Residencial Elizabeth', '86077-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26991, 'Curitiba', 'Paulo de Tarso Montenegro', 'Bairro Alto', '82820-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26992, 'Curitiba', 'Paulo Deconto', 'Umbará', '81940-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26993, 'Curitiba', 'Paulo Dietzsch', 'Portão', '80330-360', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26994, 'Londrina', 'Paulo Elísio de Pinho', 'Jardim Belo Horizonte', '86037-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26995, 'Curitiba', 'Paulo Engel', 'Pinheirinho', '81825-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26996, 'Umuarama', 'Paulo Fábio Pimentel Gonçalves', 'Parque San Remo III', '87506-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26997, 'Curitiba', 'Paulo Fagnani', 'Sítio Cercado', '81935-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26998, 'Colombo', 'Paulo Ferrarini', 'Vila Maria do Rosário', '83413-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (26999, 'Colombo', 'Paulo Fravo', 'Jardim Belo Rincão', '83412-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27000, 'Colombo', 'Paulo Frazon', 'Vila Santa Maria', '83402-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27001, 'São José dos Pinhais', 'Paulo Freire', 'Afonso Pena', '83050-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27002, 'Curitiba', 'Paulo Friebe', 'Bairro Alto', '82820-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27003, 'Londrina', 'Paulo Frontin', 'Itamarati', '86061-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27004, 'Francisco Beltrão', 'Paulo Frontin', 'Guanabara', '85604-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27005, 'Ponta Grossa', 'Paulo Frontin', 'Orfãs', '84015-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27006, 'São José dos Pinhais', 'Paulo Frontin', 'Cidade Jardim', '83035-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27007, 'Apucarana', 'Paulo Frontin', 'Vila Franko', '86802-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27008, 'Campo Mourão', 'Paulo G. Bastos', 'Jardim São Sebastião', '87303-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27009, 'Ponta Grossa', 'Paulo Ganzert', 'Contorno', '84061-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27010, 'Araucária', 'Paulo Gavleta', 'Campina da Barra', '83709-766', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27011, 'Francisco Beltrão', 'Paulo Gomes da Costa', 'São Cristóvão', '85601-346', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27012, 'Araucária', 'Paulo Gomes de Azevedo', 'Boqueirão', '83704-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27013, 'Paranavaí', 'Paulo Gonçalves Rezende', 'Parque Morumbi', '87703-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27014, 'Apucarana', 'Paulo Gorski', 'Núcleo Habitacional Osmar G Freire', '86801-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27015, 'Curitiba', 'Paulo Gorski', 'Mossunguê', '81210-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27016, 'Curitiba', 'Paulo Gorski', 'Mossunguê', '81200-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27017, 'Curitiba', 'Paulo Graeser Sobrinho', 'São Francisco', '80510-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27018, 'Curitiba', 'Paulo Grein', 'Cidade Industrial', '81280-047', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27019, 'Curitiba', 'Paulo Groetzner', 'Cidade Industrial', '81170-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27020, 'Ponta Grossa', 'Paulo Grott', 'Uvaranas', '84030-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27021, 'Colombo', 'Paulo Guebur', 'Jardim Valdívia', '83403-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27022, 'Londrina', 'Paulo Guijarra', 'Jardim Primavera', '86086-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27023, 'Curitiba', 'Paulo Gusso', 'Pilarzinho', '82115-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27024, 'Londrina', 'Paulo Guzzo', 'Ernani de Moura Lima', '86037-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27025, 'Castro', 'Paulo Henning', 'Morada do Sol', '84172-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27026, 'Curitiba', 'Paulo Henrique Andrade Santos', 'Bigorrilho', '80730-510', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27027, 'Curitiba', 'Paulo Henrique Lopes Furtado', 'Cidade Industrial', '81280-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27028, 'Arapongas', 'Paulo Herminio Pennachi', 'Jardim Petrópolis', '86702-620', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27029, 'Castro', 'Paulo Iank', 'Vila Farias', '84178-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27030, 'Curitiba', 'Paulo Ildefonso Assumpção', 'Bacacheri', '82520-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27031, 'Londrina', 'Paulo Izaias Ribeiro', 'Jardim Piza', '86073-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27032, 'Curitiba', 'Paulo J. Buso', 'Santa Felicidade', '82410-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27033, 'Curitiba', 'Paulo Jacomel', 'Uberaba', '81570-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27034, 'Maringá', 'Paulo Jorge Carolino', 'Jardim Paris', '87083-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27035, 'Paranaguá', 'Paulo Jorge da Costa Martins', 'Costeira', '83203-415', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27036, 'Curitiba', 'Paulo Júlio Reksidler', 'São Miguel', '81450-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27037, 'Londrina', 'Paulo Kawassaki', 'Dom Bosco', '86060-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27038, 'Toledo', 'Paulo Kipper', 'Boa Esperança', '85909-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27039, 'Apucarana', 'Paulo Kisner', 'Vila São Carlos', '86800-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27040, 'Curitiba', 'Paulo Kissula', 'Capão da Imbuia', '82810-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27041, 'Curitiba', 'Paulo Klaussner', 'Cidade Industrial', '81460-177', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27042, 'Guarapuava', 'Paulo Kluber', 'Bonsucesso', '85045-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27043, 'São José dos Pinhais', 'Paulo Koloski', 'Afonso Pena', '83045-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27044, 'Ponta Grossa', 'Paulo Kroth', 'Jardim Carvalho', '84016-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27045, 'Curitiba', 'Paulo Kulik', 'Santa Cândida', '82720-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27046, 'Curitiba', 'Paulo Laureano da Costa', 'Cidade Industrial', '81315-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27047, 'São José dos Pinhais', 'Paulo Leme do Prado', 'Aristocrata', '83030-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27048, 'Guarapuava', 'Paulo Leminski', 'Bonsucesso', '85060-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27049, 'Pinhais', 'Paulo Leminski', 'Planta Núcleo Colonial de Pinhais', '83321-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27050, 'São José dos Pinhais', 'Paulo Leminski', 'São Sebastião', '83075-289', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27051, 'Colombo', 'Paulo Leminski', 'Jardim Bela Vista', '83404-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27052, 'Cascavel', 'Paulo Leminski', 'Nucleo de Produção III', '85811-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27053, 'Londrina', 'Paulo Lotz', 'Monte Belo', '86041-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27054, 'Curitiba', 'Paulo Mader Bittencourt', 'Abranches', '82130-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27055, 'Castro', 'Paulo Madureira Novaes', 'Jardim Social Primavera', '84174-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27056, 'São José dos Pinhais', 'Paulo Marcelo Pereira', 'Afonso Pena', '83065-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27057, 'Curitiba', 'Paulo Martins', 'Mercês', '80710-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27058, 'Curitiba', 'Paulo Mass', 'Sítio Cercado', '81920-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27059, 'Curitiba', 'Paulo Maurício Silveira Costa', 'Sítio Cercado', '81925-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27060, 'Guarapuava', 'Paulo Mendes Campos', 'Vila Bela', '85025-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27061, 'Ponta Grossa', 'Paulo Menotti Del Picchia', 'Cará-cará', '84043-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27062, 'Colombo', 'Paulo Milani', 'Vila Ana Maria', '83413-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27063, 'Castro', 'Paulo Milek Sobrinho', 'Vila Santa Cruz', '84168-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27064, 'Foz do Iguaçu', 'Paulo Montanari', 'Conjunto Residencial Sol de Maio', '85862-570', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27065, 'Umuarama', 'Paulo Mulato Netto', 'Parque Bandeirantes', '87504-687', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27066, 'Ponta Grossa', 'Paulo Nadal', 'Orfãs', '84015-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27067, 'Curitiba', 'Paulo Nadolny', 'Bacacheri', '82510-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27068, 'Londrina', 'Paulo Nolli', 'Jardim Higienópolis', '86015-106', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27069, 'Londrina', 'Paulo Novaes da Silveira', 'Sabará', '86066-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27070, 'Curitiba', 'Paulo Paiva', 'Sítio Cercado', '81920-770', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27071, 'Curitiba', 'Paulo Pampuche', 'Campo Comprido', '81220-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27072, 'São José dos Pinhais', 'Paulo Pasqualin', 'Colônia Rio Grande', '83025-660', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27073, 'Curitiba', 'Paulo Pedroso do Amaral', 'Sítio Cercado', '81900-780', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27074, 'Colombo', 'Paulo Pereira', 'Centro Industrial Mauá', '83413-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27075, 'Umuarama', 'Paulo Perussi', 'Parque Bandeirantes', '87504-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27076, 'Pato Branco', 'Paulo Pezarico', 'La Salle', '85505-070', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27077, 'Londrina', 'Paulo Pontes', 'Novo Amparo', '86042-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27078, 'Foz do Iguaçu', 'Paulo Pontes', 'Vila Pérola', '85865-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27079, 'Londrina', 'Paulo Ramos Carvalho', 'Jardim Palmas', '86081-357', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27080, 'Londrina', 'Paulo Renato Giarola', 'Jardim Alphaville', '86084-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27081, 'Curitiba', 'Paulo Ribeiro', 'Sítio Cercado', '81920-759', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27082, 'Curitiba', 'Paulo Rio Branco de Macedo', 'Sítio Cercado', '81925-587', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27083, 'Londrina', 'Paulo Roberto Campana', 'Jardim Barcelona', '86073-358', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27084, 'Pinhais', 'Paulo Roberto Cordeiro', 'Vale da Boa Esperança', '83320-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27085, 'Curitiba', 'Paulo Roberto da Silva', 'Cidade Industrial', '81305-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27086, 'Apucarana', 'Paulo Roberto de Almeida', 'Vila Flamboyant', '86804-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27087, 'Londrina', 'Paulo Roberto Martins', 'Jardim Neman Sahyun', '86041-257', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27088, 'Londrina', 'Paulo Roberto Moita da Silva', 'Ilha Bela', '86036-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27089, 'Curitiba', 'Paulo Roberto Rego Barros Biscaia', 'Cidade Industrial', '81240-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27090, 'Curitiba', 'Paulo Robl', 'Sítio Cercado', '81910-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27091, 'Cascavel', 'Paulo Rocha', 'Floresta', '85814-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27092, 'Curitiba', 'Paulo Rodrigues Simões', 'Barreirinha', '82700-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27093, 'Curitiba', 'Paulo Santi', 'Pilarzinho', '82120-580', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27094, 'São José dos Pinhais', 'Paulo Scherner', 'São Cristóvão', '83040-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27095, 'Foz do Iguaçu', 'Paulo Schertner', 'Jardim Oriente', '85858-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27096, 'Colombo', 'Paulo Scrok', 'Jardim Valdívia', '83403-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27097, 'Maringá', 'Paulo Sérgio de Lima Marasca', 'Parque Industrial Bandeirantes', '87070-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27098, 'Almirante Tamandaré', 'Paulo Sérgio Rodrigues', 'Vila Tefé', '83503-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27099, 'Londrina', 'Paulo Setúbal', 'Jardim Tatiani', '86070-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27100, 'Ponta Grossa', 'Paulo Setúbal', 'Uvaranas', '84031-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27101, 'Apucarana', 'Paulo Setúbal', 'Loteamento São Sebastião', '86808-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27102, 'Curitiba', 'Paulo Setúbal', 'Boqueirão', '81670-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27103, 'Curitiba', 'Paulo Setúbal', 'Boqueirão', '81750-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27104, 'Curitiba', 'Paulo Setúbal', 'Hauer', '81630-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27105, 'Colombo', 'Paulo Sheremeta', 'Jardim Monza', '83406-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27106, 'Londrina', 'Paulo Sorace', 'Monte Belo', '86041-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27107, 'Curitiba', 'Paulo Szpak', 'Uberaba', '81580-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27108, 'Colombo', 'Paulo Torques', 'Imbuial', '83415-257', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27109, 'Curitiba', 'Paulo Turkiewicz', 'Tarumã', '82820-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27110, 'Campo Mourão', 'Paulo V. de Castro', 'Jardim Tropical I', '87310-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27111, 'São José dos Pinhais', 'Paulo Vaccari', 'Cruzeiro', '83010-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27112, 'São José dos Pinhais', 'Paulo Valenga', 'Ipê', '83055-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27113, 'Guarapuava', 'Paulo VI', 'Morro Alto', '85065-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27114, 'Londrina', 'Paulo VI', 'Jardim Albatroz', '86039-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27115, 'Toledo', 'Paulo VI', 'Jardim Concórdia', '85906-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27116, 'Ponta Grossa', 'Paulo Wagner', 'Colônia Dona Luiza', '84046-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27117, 'Ponta Grossa', 'Paulo Wagnitz', 'Boa Vista', '84073-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27118, 'Curitiba', 'Paulo Wasserman', 'Santa Felicidade', '82030-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27119, 'Curitiba', 'Paulo Ziliotto', 'Campina do Siqueira', '80740-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27120, 'Curitiba', 'Paulo Zinher', 'Tatuquara', '81480-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27121, 'Pinhais', 'Pau-marfim', 'Planta Karla', '83328-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27122, 'Sarandi', 'Pau-marfim', 'Jardim Monterey', '87112-798', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27123, 'Arapongas', 'Pauxi', 'Vila São José', '86706-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27124, 'Foz do Iguaçu', 'Pavão', 'Portal da Foz', '85859-397', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27125, 'Guarapuava', 'Pavão', 'Morro Alto', '85067-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27126, 'Francisco Beltrão', 'Pavão', 'Padre Eurico', '85604-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27127, 'Maringá', 'Pavão', 'Jardim Olímpico', '87070-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27128, 'Ponta Grossa', 'Pavão', 'Colônia Dona Luiza', '84046-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27129, 'Campo Mourão', 'Pavão', 'Conjunto Habitacional Milton Luiz Pereira', '87306-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27130, 'Arapongas', 'Pavão', 'Jardim Panorama', '86708-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27131, 'Arapongas', 'Pavão', 'Centro', '86701-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27132, 'Cascavel', 'Pavão', 'Floresta', '85814-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27133, 'Arapongas', 'Pavão', 'Jardim Bandeirantes', '86703-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27134, 'Campo Largo', 'Pavão', 'Vila Gilcy', '83609-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27135, 'Araucária', 'Pavão', 'Capela Velha', '83706-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27136, 'Londrina', 'Pavão-do-Pará', 'Conjunto Habitacional Violim', '86088-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27137, 'Arapongas', 'Pavão-do-pará', 'Jardim Astúrias', '86705-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27138, 'Arapongas', 'Pavãozinho-do-pará', 'Parque Industrial II', '86703-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27139, 'Foz do Iguaçu', 'Pavo', 'Conjunto A', '85866-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27140, 'Cascavel', 'Pavo', 'Floresta', '85814-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27141, 'Arapongas', 'Pavo', 'Vila Aparecida', '86706-195', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27142, 'Arapongas', 'Pavó', 'Vila São José', '86706-186', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27143, 'Curitiba', 'Pavo de Almeida', 'Campo de Santana', '81490-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27144, 'Arapongas', 'Pavoncine', 'Vila Lugrandi', '86705-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27145, 'Guarapuava', 'Paz', 'Vila Carli', '85040-460', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27146, 'Guarapuava', 'Peabiru', 'Boqueirão', '85022-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27147, 'Pinhais', 'Peabiru', 'Vila Emiliano Perneta', '83324-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27148, 'Campo Mourão', 'Peabiru', 'Centro', '87302-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27149, 'Paranaguá', 'Pecêgo Júnior', 'Centro Histórico', '83203-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27150, 'Ponta Grossa', 'Pedestre', 'Contorno', '84061-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27151, 'Maringá', 'Pedestres', 'Vila Morangueira', '87040-185', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27152, 'Cascavel', 'Pedra Branca', 'Morumbi', '85817-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27153, 'Telêmaco Borba', 'Pedra Mina', 'Vila Arcina', '84268-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27154, 'Piraquara', 'Pedra Preta', 'Jardim Veneza', '83310-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27155, 'Londrina', 'Pedra Verde', 'Ideal', '86030-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27156, 'Ponta Grossa', 'Pedra-da-lua', 'Neves', '84021-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27157, 'Londrina', 'Pedregulho', 'Waldemar Hauer', '86030-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27158, 'Foz do Iguaçu', 'Pedreira', 'Loteamento Witt', '85862-519', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27159, 'Francisco Beltrão', 'Pedreira', 'Nova Petrópolis', '85601-148', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27160, 'Curitiba', 'Pedrina Accordes Costa', 'Ganchinho', '81935-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27161, 'São José dos Pinhais', 'Pedrina Costa Viski', 'Campina', '83020-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27162, 'Toledo', 'Pedrini P. Regim', 'Conjunto Habitacional São Francisco', '85915-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27163, 'Londrina', 'Pedro Abelardo', 'Eldorado', '86040-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27164, 'São José dos Pinhais', 'Pedro Aires da Rocha', 'Afonso Pena', '83040-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27165, 'Curitiba', 'Pedro Airton Zimmermann', 'Sítio Cercado', '81925-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27166, 'São José dos Pinhais', 'Pedro Alberti', 'Silveira da Motta', '83030-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27167, 'Londrina', 'Pedro Aleixo', 'Sebastião de Melo César', '86084-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27168, 'Curitiba', 'Pedro Aleixo', 'Cidade Industrial', '81260-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27169, 'Colombo', 'Pedro Alexandre Broto', 'Jardim Abigail', '83409-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27170, 'Curitiba', 'Pedro Alexandre Brotto', 'Ahú', '80540-120', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27171, 'Ponta Grossa', 'Pedro Alfredo Ribas', 'Centro', '84035-730', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27172, 'Foz do Iguaçu', 'Pedro Alliana', 'Jardim São Rafael II', '85858-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27173, 'Curitiba', 'Pedro Aloys Scherer', 'Uberaba', '81580-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27174, 'Laranjeiras do Sul', 'Pedro Álvares Cabral', 'São Francisco', '85303-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27175, 'Ponta Grossa', 'Pedro Álvares Cabral', 'Nova Rússia', '84070-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27176, 'Piraquara', 'Pedro Álvares Cabral', 'Vila Ipanema', '83301-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27177, 'Pato Branco', 'Pedro Álvares Cabral', 'Aeroporto', '85503-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27178, 'Maringá', 'Pedro Álvares Cabral', 'Zona 02', '87010-310', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27179, 'Umuarama', 'Pedro Álvares Cabral', 'Parque San Remo I', '87506-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27180, 'Sarandi', 'Pedro Álvares Cabral', 'Jardim Panorama', '87113-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27181, 'Sarandi', 'Pedro Álvares Cabral', 'Parque Pioneiros', '87114-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27182, 'Toledo', 'Pedro Álvares Cabral', 'Residencial Santa Clara', '85908-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27183, 'Toledo', 'Pedro Álvares Cabral', 'Jardim Concórdia', '85906-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27184, 'Castro', 'Pedro Álvares Cabral', 'Centro', '84165-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27185, 'Apucarana', 'Pedro Álvares Cabral', 'Vila Santa Rosa', '86811-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27186, 'Cascavel', 'Pedro Álvares Cabral', 'Pioneiros Catarinenses', '85805-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27187, 'Cambé', 'Pedro Álvares Cabral', 'Jardim Vila Rica', '86192-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27188, 'Guarapuava', 'Pedro Alves', 'Centro', '85010-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27189, 'Guarapuava', 'Pedro Alves', 'Batel', '85015-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27190, 'São José dos Pinhais', 'Pedro Alves da Rocha', 'Braga', '83020-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27191, 'Laranjeiras do Sul', 'Pedro Alves de Oliveira', 'Vila Industrial', '85303-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27192, 'Ponta Grossa', 'Pedro Alves dos Santos', 'Contorno', '84060-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27193, 'Guarapuava', 'Pedro Américo', 'Alto Cascavel', '85031-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27194, 'Ponta Grossa', 'Pedro Américo', 'Oficinas', '84035-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27195, 'Maringá', 'Pedro Américo', 'Zona 05', '87015-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27196, 'Cascavel', 'Pedro Américo', 'Independência', '85813-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27197, 'Curitiba', 'Pedro Américo', 'Novo Mundo', '81110-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27198, 'Colombo', 'Pedro André', 'Jardim Nossa Senhora de Fátima', '83405-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27199, 'Curitiba', 'Pedro Andretta', 'Cidade Industrial', '81450-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27200, 'Almirante Tamandaré', 'Pedro Antoniacomi', 'Colônia Vila Prado', '83504-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27201, 'Campo Largo', 'Pedro Antoniassi', 'Jardim Florestal', '83602-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27202, 'Francisco Beltrão', 'Pedro Antônio Casaril', 'Sadia', '85606-398', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27203, 'Curitiba', 'Pedro Antônio da Costa', 'Boa Vista', '82650-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27204, 'Londrina', 'Pedro Antônio da Silva', 'Arpoador', '86046-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27205, 'Londrina', 'Pedro Antônio de Souza', 'Eucaliptos', '86031-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27206, 'Maringá', 'Pedro Antônio Urizzi', 'Jardim Botânico', '87060-539', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27207, 'Curitiba', 'Pedro Artur Zanlorenzi', 'Campo Comprido', '81270-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27208, 'Colombo', 'Pedro Baggio', 'Embrapa', '83407-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27209, 'Curitiba', 'Pedro Baggio', 'Água Verde', '80620-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27210, 'Guarapuava', 'Pedro Barbieri', 'Bonsucesso', '85045-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27211, 'Curitiba', 'Pedro Barcik Sobrinho', 'Fazendinha', '81330-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27212, 'Curitiba', 'Pedro Barichelo', 'Abranches', '82220-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27213, 'Foz do Iguaçu', 'Pedro Basso', 'Alto São Francisco', '85863-756', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27214, 'Londrina', 'Pedro Basso', 'Itamarati', '86061-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27215, 'Londrina', 'Pedro Batista de Oliveira', 'Estados', '86083-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27216, 'São José dos Pinhais', 'Pedro Batista Medeiros', 'São Sebastião', '83075-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27217, 'Cascavel', 'Pedro Bau', 'Universitário', '85819-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27218, 'Londrina', 'Pedro Beccati', 'Franciscato II', '86078-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27219, 'Curitiba', 'Pedro Bellon', 'Cajuru', '82920-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27220, 'Ponta Grossa', 'Pedro Beninca', 'Uvaranas', '84031-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27221, 'Foz do Iguaçu', 'Pedro Benitez', 'Jardim das Flores', '85862-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27222, 'Colombo', 'Pedro Berlesi', 'Jardim Paraná', '83412-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27223, 'Cambé', 'Pedro Bertan', 'Jardim Vila Rica', '86192-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27224, 'Londrina', 'Pedro Bertolucci', 'Conjunto Habitacional José Belinati', '86084-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27225, 'Curitiba', 'Pedro Biernaski', 'Campo Comprido', '81220-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27226, 'Curitiba', 'Pedro Bindo', 'Guabirotuba', '81530-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27227, 'Araucária', 'Pedro Bini', 'Costeira', '83708-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27228, 'Araucária', 'Pedro Biscaia', 'Tindiquera', '83708-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27229, 'Ponta Grossa', 'Pedro Blageski', 'Estrela', '84050-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27230, 'Curitiba', 'Pedro Bocchino', 'Cajuru', '82950-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27231, 'Curitiba', 'Pedro Bonat', 'Novo Mundo', '81110-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27232, 'Londrina', 'Pedro Boratin', 'Eucaliptos', '86031-560', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27233, 'Francisco Beltrão', 'Pedro Bordun', 'Antônio de Paiva Cantelmo', '85603-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27234, 'Foz do Iguaçu', 'Pedro Bortolini', 'Jardim Porto Belo', '85867-518', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27235, 'Pato Branco', 'Pedro Bortot', 'Bortot', '85504-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27236, 'Londrina', 'Pedro Botelho de Rezende', 'Jardim Burle Marx', '86047-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27237, 'Apucarana', 'Pedro Botelho Manhas', 'Loteamento Jardim Por do Sol', '86801-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27238, 'Apucarana', 'Pedro Boutros Hannoun Elias', 'Jardim Santos Dumont I', '86812-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27239, 'Ponta Grossa', 'Pedro Braune', 'Uvaranas', '84031-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27240, 'Curitiba', 'Pedro Braz', 'Uberaba', '81590-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27241, 'Curitiba', 'Pedro Breda', 'Santa Felicidade', '82015-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27242, 'Curitiba', 'Pedro Brudzinski', 'São Lourenço', '82210-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27243, 'Curitiba', 'Pedro Brunetti', 'Butiatuvinha', '82320-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27244, 'Curitiba', 'Pedro Brutkowski', 'Cidade Industrial', '81240-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27245, 'Araucária', 'Pedro Budziak', 'Costeira', '83709-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27246, 'Londrina', 'Pedro Bueno de Azevedo', 'Portal de Versalhes 3', '86055-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27247, 'Araucária', 'Pedro Burkowski', 'Costeira', '83709-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27248, 'Curitiba', 'Pedro Caetano M. Folador', 'Portão', '80330-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27249, 'Curitiba', 'Pedro Calisto', 'Umbará', '81930-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27251, 'Castro', 'Pedro Canova', 'Vila Frei Mathias', '84165-335', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27252, 'Londrina', 'Pedro Caraco', 'Vitória Régia', '86038-195', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27253, 'Campo Largo', 'Pedro Carlos Ansolim', 'Jardim Bela Vista', '83605-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27254, 'Cascavel', 'Pedro Carlos Neppel', 'Região do Lago 3', '85819-769', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27255, 'Foz do Iguaçu', 'Pedro Carneiro Pereira', 'Vila Borges', '85858-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27256, 'Londrina', 'Pedro Carrasco Alduan', 'Conjunto Parigot de Souza 3', '86081-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27257, 'Londrina', 'Pedro Casagrande', 'Assis', '86086-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27258, 'Curitiba', 'Pedro Cavichiolo', 'Campo de Santana', '81490-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27259, 'Curitiba', 'Pedro Charneski', 'São Braz', '82315-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27260, 'Araucária', 'Pedro Chempeck', 'Barigui', '83707-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27261, 'São José dos Pinhais', 'Pedro Chiuratto', 'Planta Quississana', '83085-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27262, 'Araucária', 'Pedro Cichon', 'Campina da Barra', '83709-848', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27263, 'Curitiba', 'Pedro Claudino da Rocha', 'Sítio Cercado', '81900-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27264, 'Curitiba', 'Pedro Collere', 'Vila Izabel', '80320-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27265, 'Laranjeiras do Sul', 'Pedro Conrado Sobrinho', 'Centro', '85301-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27266, 'Guarapuava', 'Pedro Conrado Sobrinho', 'Bonsucesso', '85035-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27267, 'São José dos Pinhais', 'Pedro Constantino da Rocha', 'Afonso Pena', '83045-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27268, 'São José dos Pinhais', 'Pedro Cordeiro da Cruz', 'Afonso Pena', '83065-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27269, 'Foz do Iguaçu', 'Pedro Corrêa', 'Jardim N Horizonte', '85855-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27270, 'Curitiba', 'Pedro Corrêa da Cruz', 'São Braz', '82310-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27271, 'Colombo', 'Pedro Costa', 'Jardim Solimões', '83402-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27272, 'Curitiba', 'Pedro Costa Cunha', 'Jardim Botânico', '80215-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27273, 'Londrina', 'Pedro Couto', 'Los Angeles', '86060-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27274, 'Curitiba', 'Pedro Cruzetta', 'Augusta', '81290-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27275, 'Colombo', 'Pedro Cubis', 'Jardim César Augusto', '83402-260', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27276, 'Campo Largo', 'Pedro Culpi Paulin', 'Jardim Rondinha', '83607-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27277, 'Londrina', 'Pedro Custódio Ferreira', 'Jardim Paris', '86082-079', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27278, 'Araucária', 'Pedro Czarneski', 'Vila Nova', '83703-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27279, 'Curitiba', 'Pedro da Silva', 'Boqueirão', '81770-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27280, 'Colombo', 'Pedro d''Agostin', 'Jardim Monza', '83406-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27281, 'Colombo', 'Pedro Dalazuana', 'Planta Santa Úrsula', '83405-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27282, 'Londrina', 'Pedro dal''Col', 'Jardim Higienópolis', '86015-107', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27283, 'Curitiba', 'Pedro Dalla Stella', 'Santa Felicidade', '82020-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27284, 'Toledo', 'Pedro dal''Pra', 'Vila Pioneiro', '85909-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27285, 'Cascavel', 'Pedro Dal''Pra', 'Maria Luiza', '85819-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27286, 'Curitiba', 'Pedro Dariva', 'Cidade Industrial', '81280-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27287, 'Araucária', 'Pedro de Alcântara Meira', 'Boqueirão', '83704-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27288, 'Curitiba', 'Pedro de Almeida', 'Atuba', '82840-410', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27289, 'Curitiba', 'Pedro de Araújo Franco', 'Jardim Botânico', '80215-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27290, 'Curitiba', 'Pedro de Campos Freire', 'Campo Comprido', '81220-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27291, 'Pato Branco', 'Pedro de Lima', 'Industrial', '85506-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27292, 'Araucária', 'Pedro de Souza Pinto', 'Tindiquera', '83708-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27293, 'Curitiba', 'Pedro de Toledo', 'Prado Velho', '80215-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27294, 'Curitiba', 'Pedro Deconto', 'Bigorrilho', '80710-180', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27295, 'Curitiba', 'Pedro Demeterco', 'Jardim das Américas', '81530-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27296, 'Pato Branco', 'Pedro Detoni', 'Industrial', '85504-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27297, 'Francisco Beltrão', 'Pedro Dezen', 'São Cristóvão', '85601-347', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27298, 'Colombo', 'Pedro do Rosário', 'Jardim Itália', '83410-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27299, 'Colombo', 'Pedro do Rosário', 'Vila Maria do Rosário', '83413-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27300, 'Castro', 'Pedro Dobis', 'Centro', '84165-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27301, 'Curitiba', 'Pedro Dorigo', 'Xaxim', '81810-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27302, 'Toledo', 'Pedro dos Santos Ramos', 'Jardim La Salle', '85903-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27303, 'Curitiba', 'Pedro Doska', 'Santa Cândida', '82620-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27304, 'Almirante Tamandaré', 'Pedro Drecher', 'Colônia Vila Prado', '83504-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27305, 'Curitiba', 'Pedro Driessen Filho', 'Cidade Industrial', '81450-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27306, 'Curitiba', 'Pedro Drulla', 'Jardim das Américas', '81540-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27307, 'Araucária', 'Pedro Druscz', 'Centro', '83702-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27308, 'Colombo', 'Pedro Dugonski', 'Jardim Viviane', '83407-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27309, 'Curitiba', 'Pedro Dzieryulski', 'Cajuru', '82900-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27310, 'Ponta Grossa', 'Pedro Elesbão Gonçalves', 'Uvaranas', '84025-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27311, 'Pinhais', 'Pedro Elias Graciano', 'Vila São Pedro', '83320-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27312, 'Curitiba', 'Pedro Eloy de Souza', 'Bairro Alto', '82820-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27313, 'São José dos Pinhais', 'Pedro Escolaro', 'Miringuava', '83090-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27314, 'Curitiba', 'Pedro Eugênio Bagatin', 'Barreirinha', '82560-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27315, 'Londrina', 'Pedro Fabre Francez', 'Residencial José B Almeida', '86041-825', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27316, 'Curitiba', 'Pedro Fabri', 'Cabral', '80035-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27317, 'Cambé', 'Pedro Fadel', 'Jardim Santo Antônio', '86182-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27318, 'Pinhais', 'Pedro Fanor', 'Jardim Pedro Demeterco', '83324-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27319, 'Londrina', 'Pedro Faria', 'Gleba Fazenda Palhano', '86055-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27320, 'Curitiba', 'Pedro Faucz', 'Santo Inácio', '82300-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27321, 'Cambé', 'Pedro Ferraciolli', 'Jardim Silvino', '86188-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27322, 'Curitiba', 'Pedro Ferrari', 'Butiatuvinha', '82400-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27323, 'Curitiba', 'Pedro Ferraz Rodrigues', 'Pilarzinho', '82100-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27324, 'Guarapuava', 'Pedro Ferreira da Silva', 'Vila Bela', '85025-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27325, 'Almirante Tamandaré', 'Pedro Ferreira de Freitas', 'Vila Pacheco', '83511-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27326, 'Araucária', 'Pedro Fila', 'Thomaz Coelho', '83707-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27327, 'Colombo', 'Pedro Fiorese', 'São João', '83415-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27328, 'Colombo', 'Pedro Fiorese', 'Fervida', '83415-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27329, 'Curitiba', 'Pedro Floriano Sobrinho', 'Fazendinha', '81330-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27330, 'Campo Mourão', 'Pedro Flórida Alcântara', 'Jardim Ione', '87303-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27331, 'São José dos Pinhais', 'Pedro Foggiatto', 'Aristocrata', '83030-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27332, 'Curitiba', 'Pedro Foltran', 'Bigorrilho', '80710-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27333, 'São José dos Pinhais', 'Pedro Franchetto', 'Miringuava', '83090-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27334, 'Cascavel', 'Pedro Francisco', 'Cascavel Velho', '85818-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27335, 'Ponta Grossa', 'Pedro Francisco Buss', 'Orfãs', '84015-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27336, 'Francisco Beltrão', 'Pedro Francisco Debacker', 'Padre Ulrico', '85604-458', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27337, 'Foz do Iguaçu', 'Pedro Francisco Keru', 'Conjunto Residencial Sol de Maio', '85862-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27338, 'Piraquara', 'Pedro Franco da Silva', 'Planta Granjas Eldorado', '83309-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27339, 'Curitiba', 'Pedro Frederico Voluz', 'Pinheirinho', '81870-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27340, 'Araucária', 'Pedro Furman', 'Chapada', '83706-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27341, 'Castro', 'Pedro Gaida Filho', 'Jardim Samambaia', '84182-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27342, 'Sarandi', 'Pedro Galindo Garcia', 'Jardim Primavera', '87111-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27343, 'São José dos Pinhais', 'Pedro Gapski Filho', 'Braga', '83020-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27344, 'Curitiba', 'Pedro Gasparello', 'Seminário', '80320-360', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27345, 'Araucária', 'Pedro Gawlak', 'Boqueirão', '83704-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27346, 'Campo Mourão', 'Pedro Gênero', 'Jardim Izabel', '87309-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27347, 'Piraquara', 'Pedro Goinski', 'Guarituba', '83311-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27348, 'Londrina', 'Pedro Gonçalves da Rosa', 'Jardim Europa', '86043-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27349, 'Colombo', 'Pedro Gonçalves de Lima', 'Jardim Aurora', '83411-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27350, 'Colombo', 'Pedro Gonshi', 'Jardim Santa Cândida', '83404-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27351, 'Colombo', 'Pedro Gorski', 'Vila Gorski', '83405-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27352, 'Cambé', 'Pedro Gudait', 'Jardim Santana', '86192-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27353, 'Campo Mourão', 'Pedro Guilherme Cavali', 'Jardim Santa Cruz', '87309-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27354, 'Cascavel', 'Pedro Gurgacz', 'Interlagos', '85814-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27355, 'Curitiba', 'Pedro Gurnacki', 'Cidade Industrial', '81280-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27356, 'Curitiba', 'Pedro Gusso', 'Cidade Industrial', '81315-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27357, 'Curitiba', 'Pedro Gusso', 'Novo Mundo', '81050-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27358, 'Curitiba', 'Pedro Gusso', 'Cidade Industrial', '81310-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27359, 'Curitiba', 'Pedro Haj Mussi', 'Seminário', '80740-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27360, 'São José dos Pinhais', 'Pedro Haluch', 'Centro', '83005-610', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27361, 'Curitiba', 'Pedro Hansaul', 'Portão', '81070-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27362, 'Curitiba', 'Pedro Horokoski', 'Campo Comprido', '81210-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27363, 'Campo Mourão', 'Pedro Hruschka', 'Jardim Santa Cruz', '87309-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27364, 'Curitiba', 'Pedro Huk', 'Uberaba', '81550-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27365, 'Apucarana', 'Pedro Idalgo Floro', 'Jardim Aeroporto', '86812-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27366, 'São José dos Pinhais', 'Pedro Iha', 'Campina', '83015-147', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27367, 'Toledo', 'Pedro Inácio Bracht', 'Jardim Parizzotto', '85914-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27368, 'Campo Mourão', 'Pedro Intronvini', 'Jardim Santa Cruz', '87309-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27369, 'Almirante Tamandaré', 'Pedro Irineu Gabardo', 'Planta Mosacal', '83513-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27370, 'Pato Branco', 'Pedro Ivo', 'Morro da Cruz', '85506-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27371, 'Cascavel', 'Pedro Ivo', 'Região do Lago', '85812-171', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27372, 'Cascavel', 'Pedro Ivo', 'Country', '85813-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27373, 'Cascavel', 'Pedro Ivo', 'Canadá', '85813-231', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27374, 'Cascavel', 'Pedro Ivo', 'Centro', '85812-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27375, 'Curitiba', 'Pedro Ivo', 'Centro', '80010-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27376, 'Guarapuava', 'Pedro Ivo de Campos', 'Morro Alto', '85067-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27377, 'Curitiba', 'Pedro Jacob Klock', 'Santa Cândida', '82720-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27378, 'Colombo', 'Pedro Jardeveski', 'Jardim Santa Fé', '83403-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27379, 'Araucária', 'Pedro Jess', 'Boqueirão', '83704-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27380, 'Foz do Iguaçu', 'Pedro João Medeiros', 'Jardim Florença', '85867-376', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27381, 'Almirante Tamandaré', 'Pedro Jorge Kotoviski', 'Jardim Formosa', '83511-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27382, 'Pato Branco', 'Pedro José da Silva', 'Pinheirinho', '85506-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27383, 'Araucária', 'Pedro José Saad', 'Tindiquera', '83708-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27384, 'Curitiba', 'Pedro Kachel', 'Santa Cândida', '82630-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27385, 'Castro', 'Pedro Kaled', 'Centro', '84165-540', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27386, 'Colombo', 'Pedro Kania', 'Jardim Osasco', '83403-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27387, 'São José dos Pinhais', 'Pedro Karwowski', 'Guatupê', '83060-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27388, 'Londrina', 'Pedro Khater', 'Avelino A Vieira', '86056-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27389, 'Pinhais', 'Pedro Klass', 'Vila Maria Antonieta', '83331-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27390, 'Curitiba', 'Pedro Klassa', 'Santo Inácio', '82010-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27391, 'Curitiba', 'Pedro Kogut', 'Cidade Industrial', '81230-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27392, 'Curitiba', 'Pedro Koloski', 'Umbará', '81930-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27393, 'Curitiba', 'Pedro Koschla', 'Campo Comprido', '81220-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27394, 'Curitiba', 'Pedro Krasinski', 'Capão Raso', '81110-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27395, 'Curitiba', 'Pedro Kulik', 'Santa Cândida', '82720-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27396, 'Curitiba', 'Pedro Lapola', 'Cidade Industrial', '81280-048', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27397, 'São José dos Pinhais', 'Pedro Laska', 'Planta Quississana', '83085-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27398, 'Curitiba', 'Pedro Lauffer', 'Campina do Siqueira', '80730-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27399, 'Araucária', 'Pedro Leal Sobrinho', 'Costeira', '83708-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27400, 'Maringá', 'Pedro Leite de Oliveira', 'Jardim Andrade', '87035-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27401, 'Curitiba', 'Pedro Leitoles', 'Santo Inácio', '82010-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27402, 'Foz do Iguaçu', 'Pedro Lenzi', 'Jardim São Rafael I', '85858-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27403, 'Ponta Grossa', 'Pedro Lessinski', 'Boa Vista', '84073-179', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27404, 'Curitiba', 'Pedro Lieneker', 'Cidade Industrial', '81460-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27405, 'São José dos Pinhais', 'Pedro Lino Ferreira da Cruz', 'Braga', '83020-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27406, 'Pato Branco', 'Pedro Lobo', 'Alvorada', '85508-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27407, 'Curitiba', 'Pedro Locatelli Júnior', 'Uberaba', '81570-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27408, 'Toledo', 'Pedro Lodi', 'Coopagro', '85903-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27409, 'Curitiba', 'Pedro Lopes', 'Pinheirinho', '81870-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27410, 'Pato Branco', 'Pedro Lora', 'Menino Deus', '85502-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27411, 'Curitiba', 'Pedro Lourenço Gebur', 'Campina do Siqueira', '80740-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27412, 'Cambé', 'Pedro Lovato', 'Jardim Santo Antônio', '86182-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27413, 'Londrina', 'Pedro Luiz', 'Jardim Tatiani', '86070-400', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27414, 'Ponta Grossa', 'Pedro Luiz Correia', 'Chapada', '84062-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27415, 'Ponta Grossa', 'Pedro Luiz Guzzo', 'Jardim Carvalho', '84016-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27416, 'Pato Branco', 'Pedro Luiz Tavares', 'Bela Vista', '85509-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27417, 'Araucária', 'Pedro Lukaski', 'Thomaz Coelho', '83707-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27418, 'Ponta Grossa', 'Pedro Machado', 'Colônia Dona Luiza', '84043-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27419, 'Curitiba', 'Pedro Magalhães de Oliveira', 'Pinheirinho', '81880-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27420, 'Campo Largo', 'Pedro Magatão', 'Loteamento Itaboa', '83605-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27421, 'Curitiba', 'Pedro Mainka', 'Bom Retiro', '80520-190', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27422, 'Curitiba', 'Pedro Manfredine', 'Abranches', '82220-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27423, 'Colombo', 'Pedro Manika', 'Jardim Eldorado', '83402-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27424, 'Foz do Iguaçu', 'Pedro Manoel Gonzales', 'Jardim Veraneio', '85855-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27425, 'Campo Largo', 'Pedro Marcon', 'Vila Ferrari', '83606-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27426, 'Almirante Tamandaré', 'Pedro Marcos Lustosa de Freitas', 'Vila Pacheco', '83511-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27427, 'Londrina', 'Pedro Marcos Prado', 'Lima Azevedo', '86060-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27428, 'Cascavel', 'Pedro Maria Neto', 'Santa Felicidade', '85803-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27429, 'Foz do Iguaçu', 'Pedro Marques', 'Vila Shalon', '85853-117', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27519, 'Londrina', 'Pedro Rozio Coelho', 'Colúmbia', '86057-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27430, 'Apucarana', 'Pedro Martinez Zurano', 'Núcleo Habitacional Djalma Mendes de Oliveira', '86806-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27431, 'Foz do Iguaçu', 'Pedro Martins', 'Vila São Sebastião', '85870-540', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27432, 'Londrina', 'Pedro Martins', 'Conjunto Habitacional Saltinho', '86042-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27433, 'São José dos Pinhais', 'Pedro Martins Follador', 'Três Marias', '83030-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27434, 'Ponta Grossa', 'Pedro Mascarenhas Ribas', 'Jardim Carvalho', '84015-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27435, 'Curitiba', 'Pedro Mazuroka', 'Sítio Cercado', '81900-785', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27436, 'São José dos Pinhais', 'Pedro Mendes', 'Guatupê', '83060-448', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27437, 'Apucarana', 'Pedro Menegazzo', 'Vila Nossa Senhora da Conceição', '86802-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27438, 'Ponta Grossa', 'Pedro Mezzomo', 'Boa Vista', '84071-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27439, 'Guarapuava', 'Pedro Michalovski', 'Bonsucesso', '85045-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27440, 'Almirante Tamandaré', 'Pedro Milek', 'Vila São Pedro', '83505-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27441, 'Piraquara', 'Pedro Minoli', 'Vila Mariana', '83311-196', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27442, 'Curitiba', 'Pedro Miquelissa', 'Xaxim', '81710-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27443, 'Paranavaí', 'Pedro Miranda', 'Jardim Ouro Branco', '87703-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27444, 'Paranavaí', 'Pedro Miranda', 'Jardim Ouro Branco', '87704-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27445, 'Cascavel', 'Pedro Miranda', 'Coqueiral', '85807-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27446, 'Apucarana', 'Pedro Montini', 'Jardim Kiri', '86802-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27447, 'Curitiba', 'Pedro Moreira Cardoso', 'Xaxim', '81720-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27448, 'Foz do Iguaçu', 'Pedro Morello', 'Loteamento Residencial Lagoa Vermelha', '85862-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27449, 'São José dos Pinhais', 'Pedro Moro', 'Braga', '83005-600', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27450, 'Curitiba', 'Pedro Moro Netto', 'Xaxim', '81810-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27451, 'São José dos Pinhais', 'Pedro Moro Redeschi', 'São Pedro', '83005-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27452, 'Curitiba', 'Pedro Mossoline Gasparin', 'Santa Felicidade', '82410-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27453, 'São José dos Pinhais', 'Pedro Munaretto', 'Bom Jesus', '83025-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27454, 'Curitiba', 'Pedro Muraro', 'São João', '82030-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27455, 'Curitiba', 'Pedro Nabosne', 'Alto Boqueirão', '81860-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27456, 'Toledo', 'Pedro Nardi', 'Residencial Santa Clara', '85907-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27457, 'Curitiba', 'Pedro Nazareno Gualdezi', 'Butiatuvinha', '82400-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27458, 'Curitiba', 'Pedro Nicco', 'Mossunguê', '81200-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27459, 'Colombo', 'Pedro Nodari', 'Jardim Santa Cândida', '83404-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27460, 'Curitiba', 'Pedro Nogarolli', 'Mercês', '80710-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27461, 'Curitiba', 'Pedro Nogas', 'Portão', '81010-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27462, 'Londrina', 'Pedro Nolasco da Silva', 'Jardim Tókio', '86063-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27463, 'Araucária', 'Pedro Nolasco Pizatto', 'Estação', '83705-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27464, 'Curitiba', 'Pedro Nolasko Pizzatto', 'Mercês', '80710-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27465, 'Umuarama', 'Pedro Osmir Pinha da Costa', 'Conjunto Residencial Guarani I', '87509-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27466, 'Colombo', 'Pedro Ossoski', 'Itajacuru', '83407-837', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27467, 'Curitiba', 'Pedro Pacheco', 'Uberaba', '81580-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27468, 'Apucarana', 'Pedro Paczko', 'Núcleo Bandeirantes', '86812-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27469, 'Araucária', 'Pedro Paluski', 'Fazenda Velha', '83703-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27470, 'Cambé', 'Pedro Pascueto', 'Jardim Vila Rica', '86192-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27471, 'Curitiba', 'Pedro Paulo Coraiola', 'Sítio Cercado', '81935-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27472, 'Curitiba', 'Pedro Paulo Emílio Zimer', 'Barreirinha', '82560-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27473, 'Apucarana', 'Pedro Paulo Fenato', 'Jardim Espanha', '86802-016', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27474, 'São José dos Pinhais', 'Pedro Paulo Gribogy', 'Costeira', '83015-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27475, 'Araucária', 'Pedro Paulo Pianowski', 'Costeira', '83708-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27476, 'Campo Mourão', 'Pedro Paulo Walker', 'Jardim Santa Cruz', '87309-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27477, 'Campo Mourão', 'Pedro Paulo Walker', 'Jardim Santa Cruz', '87309-696', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27478, 'Colombo', 'Pedro Pavin', 'Centro', '83414-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27479, 'Guarapuava', 'Pedro Pereira', 'Jardim das Américas', '85030-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27480, 'Almirante Tamandaré', 'Pedro Pereira de Oliveira', 'Jardim Campo Verde', '83502-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27481, 'São José dos Pinhais', 'Pedro Pereira Sobrinho', 'Cidade Jardim', '83035-240', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27482, 'Apucarana', 'Pedro Perosin', 'Jardim Santos Dumont III', '86812-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27483, 'Londrina', 'Pedro Piasentin', 'Jardim Perobal', '86043-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27484, 'Curitiba', 'Pedro Picussa', 'Umbará', '81930-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27485, 'Curitiba', 'Pedro Pilato', 'Umbará', '81930-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27486, 'Laranjeiras do Sul', 'Pedro Pinto de Oliveira', 'São Francisco', '85303-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27487, 'Curitiba', 'Pedro Piotto', 'Novo Mundo', '81050-618', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27488, 'São José dos Pinhais', 'Pedro Pires de Oliveira', 'Ouro Fino', '83015-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27489, 'Almirante Tamandaré', 'Pedro Polak', 'Jardim Paraíso', '83512-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27490, 'Curitiba', 'Pedro Polak', 'Abranches', '82220-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27491, 'Piraquara', 'Pedro Polati', 'Vila Marumbi', '83304-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27492, 'Curitiba', 'Pedro Polati', 'Fazendinha', '81330-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27493, 'Campo Mourão', 'Pedro Poletto', 'Jardim Maia', '87301-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27494, 'Colombo', 'Pedro Poli', 'Capivari', '83415-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27495, 'Londrina', 'Pedro Procópio de Oliveira', 'Jardim Barcelona', '86073-348', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27496, 'Curitiba', 'Pedro Prosdócimo', 'Tatuquara', '81470-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27497, 'Campo Mourão', 'Pedro Ptascak', 'Jardim Esperança', '87309-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27498, 'Curitiba', 'Pedro Racoski', 'Pilarzinho', '82110-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27499, 'Cascavel', 'Pedro Raimundo', 'Brasília', '85815-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27500, 'Pato Branco', 'Pedro Ramires de Mello', 'Centro', '85502-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27501, 'Pato Branco', 'Pedro Ramires de Mello', 'Centro', '85501-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27502, 'Curitiba', 'Pedro Ramos de Oliveira', 'Alto Boqueirão', '81750-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27503, 'Curitiba', 'Pedro Reva', 'Santa Felicidade', '82030-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27504, 'São José dos Pinhais', 'Pedro Ribaski', 'Ipê', '83055-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27505, 'Curitiba', 'Pedro Ribeiro dos Santos', 'Santa Felicidade', '82020-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27506, 'Apucarana', 'Pedro Ribeiro Valim', 'Jardim Eliane', '86809-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27507, 'Curitiba', 'Pedro Rigotto', 'Ahú', '80540-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27508, 'Curitiba', 'Pedro Rissetti', 'Guabirotuba', '81520-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27509, 'Curitiba', 'Pedro Rodrigues', 'São Miguel', '81450-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27510, 'Paranavaí', 'Pedro Rodrigues de Carvalho', 'Jardim Maringá', '87709-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27511, 'Curitiba', 'Pedro Rodrigues de Lima', 'Sítio Cercado', '81900-728', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27512, 'Colombo', 'Pedro Rodrigues dos Santos', 'Parque Residencial Santa Terezinha II', '83408-797', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27513, 'Curitiba', 'Pedro Rolim de Moura', 'Alto da Glória', '80030-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27514, 'Foz do Iguaçu', 'Pedro Rolon', 'Vila São Sebastião', '85870-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27515, 'Curitiba', 'Pedro Romano Durigan', 'Santa Felicidade', '82020-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27516, 'Curitiba', 'Pedro Romildo dall''Stella', 'Pilarzinho', '82115-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27517, 'Toledo', 'Pedro Rosa dos Santos', 'Centro', '85901-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27518, 'Toledo', 'Pedro Rosseto', 'Jardim Concórdia', '85906-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27520, 'Pato Branco', 'Pedro Rubilar de Andrade', 'Trevo Patinhos', '85503-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27521, 'Araucária', 'Pedro Rudi', 'Barigui', '83707-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27522, 'Maringá', 'Pedro Sanches', 'Zona 04', '87014-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27523, 'Curitiba', 'Pedro Saturnino', 'Uberaba', '81580-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27524, 'Campo Mourão', 'Pedro Schemberg', 'Centro', '87302-030', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27525, 'Laranjeiras do Sul', 'Pedro Schultz', 'Cristo Rei', '85304-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27526, 'São José dos Pinhais', 'Pedro Scripe', 'Miringuava', '83090-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27527, 'Curitiba', 'Pedro Sebastião Medeiros', 'Alto Boqueirão', '81770-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27528, 'Ponta Grossa', 'Pedro Secundino Pelissari', 'Uvaranas', '84030-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27529, 'Araucária', 'Pedro Senko', 'Boqueirão', '83704-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27530, 'Londrina', 'Pedro Severino', 'Aeroporto', '86039-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27531, 'Curitiba', 'Pedro Siemens', 'Xaxim', '81830-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27532, 'Francisco Beltrão', 'Pedro Silva', 'São Miguel', '85602-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27533, 'Guarapuava', 'Pedro Siqueira', 'Centro', '85010-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27534, 'Guarapuava', 'Pedro Siqueira', 'Santana', '85070-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27535, 'Curitiba', 'Pedro Siqueira Cortes', 'Abranches', '82220-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27536, 'Curitiba', 'Pedro Skora', 'Tingui', '82600-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27537, 'Campo Largo', 'Pedro Skrzipietz', 'Jardim Itaqui', '83604-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27538, 'Pato Branco', 'Pedro Soares', 'Vila Isabel', '85504-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27539, 'Curitiba', 'Pedro Sobiech', 'Campo Comprido', '81270-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27540, 'Colombo', 'Pedro Socher', 'Jardim Contorno', '83402-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27541, 'Campo Largo', 'Pedro Sovierzoski', 'Vila Operária', '83601-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27542, 'Curitiba', 'Pedro Spisla Filho', 'Santa Cândida', '82640-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27543, 'Campo Mourão', 'Pedro Staniszewski', 'Jardim Bandeirantes', '87308-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27544, 'Colombo', 'Pedro Staroi', 'Jardim Santa Fé', '83403-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27545, 'Curitiba', 'Pedro Stempin', 'Campo de Santana', '81490-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27546, 'Colombo', 'Pedro Strapasson', 'Vila Ana Maria', '83413-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27547, 'Campo Largo', 'Pedro Surek', 'Parque Bom Jesus', '83609-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27548, 'Curitiba', 'Pedro Susla', 'Taboão', '82130-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27549, 'Maringá', 'Pedro Taques', 'Zona 03', '87030-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27550, 'Maringá', 'Pedro Taques', 'Jardim Alvorada', '87033-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27551, 'Maringá', 'Pedro Taques', 'Jardim Alvorada', '87035-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27552, 'Curitiba', 'Pedro Tavares', 'Novo Mundo', '81050-620', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27553, 'Colombo', 'Pedro Taverna', 'Roseira', '83415-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27554, 'Almirante Tamandaré', 'Pedro Teixeira Alves', 'Planta Maria Clara', '83513-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27555, 'Guarapuava', 'Pedro Tereza Góes', 'Boqueirão', '85023-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27556, 'Castro', 'Pedro Thadeu I. Canha', 'Jardim Social Arapongas', '84174-275', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27557, 'São José dos Pinhais', 'Pedro Trevisan', 'Colônia Rio Grande', '83025-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27558, 'São José dos Pinhais', 'Pedro Valaski', 'Colônia Murici', '83085-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27559, 'Curitiba', 'Pedro Valentim dos Santos', 'Novo Mundo', '81020-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27560, 'Campo Largo', 'Pedro Vaz da Silva', 'Bom Jesus', '83601-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27561, 'Londrina', 'Pedro Vaz de Caminha', 'Aeroporto', '86039-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27562, 'Londrina', 'Pedro Vaz de Lima', 'Residencial Portal do Sol', '86082-785', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27563, 'Francisco Beltrão', 'Pedro Vedana', 'São Cristóvão', '85601-351', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27564, 'Londrina', 'Pedro Vendrami Filho', 'Residence Catuai Parque', '86047-606', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27565, 'Apucarana', 'Pedro Vicentini', 'Jardim Marissol', '86807-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27566, 'São José dos Pinhais', 'Pedro Vidolin', 'Cruzeiro', '83010-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27567, 'Pato Branco', 'Pedro Vieira', 'Trevo Patinhos', '85504-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27568, 'Curitiba', 'Pedro Vilmar Calizario da Silva', 'Atuba', '82860-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27569, 'Curitiba', 'Pedro Violani', 'Cajuru', '82940-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27570, 'Curitiba', 'Pedro Violani', 'Cajuru', '82930-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27571, 'Curitiba', 'Pedro Viriato de Souza', 'Vista Alegre', '80820-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27572, 'Cambé', 'Pedro Viriato Parigot de Souza', 'Chácara Manela', '86186-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27573, 'Guarapuava', 'Pedro Virtuoso', 'Boqueirão', '85020-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27574, 'Almirante Tamandaré', 'Pedro Vítor de Lima', 'Jardim Arco Íris', '83504-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27575, 'Francisco Beltrão', 'Pedro Volta', 'São Cristóvão', '85601-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27576, 'Guarapuava', 'Pedro Weber', 'Jardim das Américas', '85030-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27577, 'Foz do Iguaçu', 'Pedro Welter', 'Conjunto Residencial Sol de Maio', '85862-566', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27578, 'Curitiba', 'Pedro Wieler', 'Xaxim', '81830-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27579, 'Curitiba', 'Pedro Wobeto', 'Boqueirão', '81670-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27580, 'Apucarana', 'Pedro Xavier', 'Jardim Ponta Grossa', '86805-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27581, 'Araucária', 'Pedro Zageski', 'Estação', '83705-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27582, 'Curitiba', 'Pedro Zagonel', 'Novo Mundo', '81050-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27583, 'Pato Branco', 'Pedro Zancanaro', 'Bela Vista', '85509-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27584, 'Londrina', 'Pedro Zani', 'Jardim Imagawa', '86080-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27585, 'Colombo', 'Pedro Zanoni', 'Centro Industrial Mauá', '83413-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27586, 'Ponta Grossa', 'Pedro Zardo', 'Orfãs', '84010-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27587, 'Cascavel', 'Pedroso', 'Nova Cidade', '85803-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27588, 'Arapongas', 'Pega', 'Jardim Baroneza', '86706-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27589, 'Curitiba', 'Pelaguia Lipinski Mikos', 'Uberaba', '81590-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27590, 'Maringá', 'Pelicano', 'Parque Hortência', '87075-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27591, 'Ponta Grossa', 'Pelicano', 'Colônia Dona Luiza', '84046-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27592, 'Araucária', 'Pelicano', 'Capela Velha', '83706-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27593, 'Arapongas', 'Pelicano', 'Jardim Panorama', '86708-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27594, 'Foz do Iguaçu', 'Pelicanos', 'Portal da Foz', '85859-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27595, 'Cascavel', 'Pelicanos', 'Floresta', '85814-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27596, 'Umuarama', 'Pellegrino Mignoni', 'Conjunto Residencial Porto Belo', '87506-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27597, 'Francisco Beltrão', 'Pelotas', 'Pinheirinho', '85603-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27598, 'Cascavel', 'Pelotas', 'Canadá', '85813-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27599, 'Foz do Iguaçu', 'Penha', 'Vila Carima', '85855-688', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27600, 'Piraquara', 'Penha', 'Jardim Tropical', '83314-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27601, 'Londrina', 'Pensilvania', 'Kennedy', '86060-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27602, 'Francisco Beltrão', 'Pensilvânia', 'Antônio de Paiva Cantelmo', '85603-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27603, 'Telêmaco Borba', 'Pepita', 'Vila São Francisco de Assis', '84264-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27604, 'Maringá', 'Pequi', 'Jardim Tropical', '87080-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27605, 'Londrina', 'Pequim', 'Cláudia', '86050-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27606, 'Foz do Iguaçu', 'Pequira', 'Conjunto A', '85860-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27607, 'Foz do Iguaçu', 'Perci Ferreira', 'Jardim Residencial Atlanta', '85856-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27608, 'Curitiba', 'Percy Feliciano de Castilho', 'Bairro Alto', '82820-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27609, 'Paranavaí', 'Percy Guimarães Cleves', 'Jardim Ouro Branco', '87704-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27610, 'Paranavaí', 'Percy Guimarães Cleves', 'Jardim Ouro Branco', '87703-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27611, 'Campo Largo', 'Percy Luiz Wendler', 'Vila Bancária', '83601-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27613, 'Curitiba', 'Percy Withers', 'Água Verde', '80240-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27614, 'Francisco Beltrão', 'Perdigão', 'Pinheirinho', '85606-165', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27615, 'Foz do Iguaçu', 'Perdigão', 'Conjunto A', '85866-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27616, 'Arapongas', 'Perdigão', 'Conjunto Flamingos III', '86703-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27617, 'Foz do Iguaçu', 'Perdiz', 'Conjunto A', '85866-030', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27618, 'Maringá', 'Perdiz', 'Conjunto Residencial Ney Braga', '87083-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27619, 'Ponta Grossa', 'Perdiz', 'Colônia Dona Luiza', '84043-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27620, 'Araucária', 'Perdiz', 'Capela Velha', '83706-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27621, 'Londrina', 'Perdizes', 'Paraíso', '86078-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27622, 'Arapongas', 'Perdizes', 'Centro', '86701-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27623, 'Arapongas', 'Perdizes-do-mar', 'Jardim Aeroporto', '86702-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27624, 'Castro', 'Peregrino Ferrari Júnior', 'Centro', '84165-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27625, 'Cascavel', 'Pereira', 'Brasmadeira', '85814-126', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27626, 'Paranavaí', 'Pereira Passos', 'Jardim São Jorge', '87711-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27627, 'Ponta Grossa', 'Pereira Passos', 'Uvaranas', '84025-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27628, 'Curitiba', 'Pergentina Silva Soares', 'Jardim Botânico', '80210-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27629, 'Londrina', 'Peri', 'Barra Vento', '86026-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27630, 'Ponta Grossa', 'Peri', 'Uvaranas', '84033-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27631, 'Piraquara', 'Peri Jacob', 'Jardim Veneza', '83310-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27632, 'Ponta Grossa', 'Peri Pereira da Costa', 'Uvaranas', '84033-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27633, 'Foz do Iguaçu', 'Peri Siqueira Cercal', 'Loteamento Witt', '85862-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27634, 'Apucarana', 'Péricles', 'Vila Nova', '86812-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27635, 'Ponta Grossa', 'Péricles Guimarães Martins', 'Contorno', '84052-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27636, 'Foz do Iguaçu', 'Perimetral', 'Jardim Norma', '85869-625', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27637, 'Piraquara', 'Perimetral', 'Vila Militar I', '83303-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27638, 'Ponta Grossa', 'Perimetral', 'Colônia Dona Luiza', '84046-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27639, 'Guarapuava', 'Perimetral Norte', 'Morro Alto', '85067-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27640, 'Toledo', 'Perimetral Norte', 'Jardim Porto Alegre', '85906-290', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27641, 'Araucária', 'Periquito', 'Estação', '83705-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27642, 'Arapongas', 'Periquito', 'Vila Nova', '86707-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27643, 'Arapongas', 'Periquito-de-cabeça-preta', 'Jardim Aeroporto', '86702-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27644, 'Arapongas', 'Periquito-de-cabeça-preta', 'Gleba Arapongas', '86702-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27645, 'Arapongas', 'Periquito-estrela', 'Jardim Imperial', '86708-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27646, 'Arapongas', 'Periquito-pescoço-marron', 'Jardim São Rafael', '86703-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27647, 'Arapongas', 'Periquito-rei', 'Conjunto Centauro', '86709-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27648, 'Arapongas', 'Periquito-rico', 'Conjunto Novo Centauro', '86709-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27649, 'Londrina', 'Periquitos', 'Paraíso', '86078-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27650, 'Foz do Iguaçu', 'Periquitos', 'Portal da Foz', '85859-398', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27651, 'Ponta Grossa', 'Perita', 'Neves', '84021-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27652, 'Arapongas', 'Pernalta', 'Jardim Aeroporto', '86702-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27653, 'Foz do Iguaçu', 'Pernambuco', 'Vila Maracanã', '85852-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27654, 'Francisco Beltrão', 'Pernambuco', 'Centro', '85601-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27655, 'Londrina', 'Pernambuco', 'Centro', '86020-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27656, 'Guarapuava', 'Pernambuco', 'Vila Carli', '85045-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27657, 'Londrina', 'Pernambuco', 'Centro', '86020-121', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27658, 'Piraquara', 'Pernambuco', 'Jardim dos Estados 1', '83308-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27659, 'Piraquara', 'Pernambuco', 'Jardim dos Estados 2', '83308-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27660, 'Maringá', 'Pernambuco', 'Vila Emília', '87010-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27661, 'Ponta Grossa', 'Pernambuco', 'Olarias', '84035-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27662, 'Paranavaí', 'Pernambuco', 'Centro', '87705-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27663, 'Piraquara', 'Pernambuco', 'Jardim dos Estados 3', '83307-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27664, 'Paranavaí', 'Pernambuco', 'Centro', '87709-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27665, 'Paranavaí', 'Pernambuco', 'Centro', '87701-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27666, 'Paranaguá', 'Pernambuco', 'Vila do Povo', '83209-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27667, 'São José dos Pinhais', 'Pernambuco', 'Silveira da Motta', '83030-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27668, 'Umuarama', 'Pernambuco', 'Zona II', '87501-550', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27669, 'Telêmaco Borba', 'Pernambuco', 'Nossa Senhora de Fátima', '84264-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27670, 'Cascavel', 'Pernambuco', 'Centro', '85810-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27671, 'Colombo', 'Pernambuco', 'Vila Guaraci', '83404-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27672, 'Cascavel', 'Pernambuco', 'Centro', '85810-021', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27673, 'Campo Largo', 'Pernambuco', 'Vila Itaqui', '83604-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27674, 'Almirante Tamandaré', 'Pernambuco', 'Vila Dolores', '83514-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27675, 'Cascavel', 'Pernambuco', 'Coqueiral', '85807-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27676, 'Apucarana', 'Pernambuco', 'Jardim Apucarana', '86804-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27677, 'Araucária', 'Pernambuco', 'Iguaçu', '83701-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27678, 'Curitiba', 'Pernambuco', 'Guaíra', '80630-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27679, 'Londrina', 'Pero Fernandes Sardinha', 'Sabará I', '86066-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27680, 'Telêmaco Borba', 'Pero Lobo', 'Núcleo Bandeirantes', '84269-240', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27681, 'Foz do Iguaçu', 'Pero Vaz de Caminha', 'Parque Ouro Verde', '85855-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27682, 'Curitiba', 'Pero Vaz de Caminha', 'Tatuquara', '81470-096', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27683, 'Cascavel', 'Pero Vaz de Caminha', 'Pioneiros Catarinenses', '85805-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27684, 'Foz do Iguaçu', 'Peroba', 'Jardim Colônia', '85855-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27685, 'Ponta Grossa', 'Peroba', 'Uvaranas', '84033-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27686, 'Piraquara', 'Peroba', 'Vila Santa Maria', '83306-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27687, 'Maringá', 'Peroba', 'Jardim Pinheiros III', '87043-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27688, 'Telêmaco Borba', 'Peroba', 'Área 01', '84268-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27689, 'Apucarana', 'Peroba', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27690, 'Araucária', 'Peroba', 'Estação', '83705-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27691, 'Cascavel', 'Peroba', 'Recanto Tropical', '85807-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27692, 'Londrina', 'Perobal', 'Leonor', '86071-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27693, 'Umuarama', 'Perobal', 'Zona I', '87501-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27694, 'Campo Mourão', 'Perobal', 'Jardim Santa Nilce I', '87308-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27695, 'Maringá', 'Peroibe', 'Parque das Grevíleas', '87025-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27696, 'Foz do Iguaçu', 'Pérola', 'Parque Ouro Verde', '85854-410', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27697, 'Umuarama', 'Pérola', 'Conjunto Residencial Ouro Branco', '87508-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27698, 'Telêmaco Borba', 'Pérola', 'Área 10', '84266-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27699, 'Cascavel', 'Pérola', 'Esmeralda', '85806-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27700, 'Apucarana', 'Pérola', 'Vila Agari', '86808-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27701, 'Cambé', 'Pérola', 'Conjunto Habitacional Cristal', '86182-708', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27702, 'Curitiba', 'Pérola', 'Xaxim', '81710-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27703, 'São José dos Pinhais', 'Pérola do Oeste', 'São Cristóvão', '83040-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27704, 'Curitiba', 'Pérola do Oeste', 'Sítio Cercado', '81925-417', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27705, 'Telêmaco Borba', 'Pérola Negra', 'Vila Gomes', '84272-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27706, 'Foz do Iguaçu', 'Perpétuo Garcia', 'Parque Presidente II', '85863-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27707, 'Guarapuava', 'Pérsia', 'São Cristóvão', '85063-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27708, 'Francisco Beltrão', 'Peru', 'Luther King', '85605-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27709, 'Londrina', 'Peru', 'Jardim Indianápolis', '86010-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27710, 'Guarapuava', 'Peru', 'Morro Alto', '85063-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27711, 'Maringá', 'Peru', 'Jardim Alvorada', '87033-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27712, 'Toledo', 'Peru', 'Jardim Canaã', '85914-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27713, 'Telêmaco Borba', 'Peru', 'Socomim', '84266-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27714, 'Telêmaco Borba', 'Peru', 'Macopa', '84263-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27715, 'Colombo', 'Peru', 'Jardim Rio Verde', '83405-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27716, 'Araucária', 'Peru', 'Capela Velha', '83706-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27717, 'Apucarana', 'Peru', 'Jardim Diamantina', '86804-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27718, 'Cascavel', 'Peru', 'Pacaembu', '85816-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27719, 'Curitiba', 'Peru', 'Bacacheri', '82510-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27720, 'Arapongas', 'Peruinho-do-campo', 'Vila Paulo', '86705-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27721, 'Curitiba', 'Pery Sotto Maior Bittencourt', 'Atuba', '82630-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27722, 'Ponta Grossa', 'Pescador Martin', 'Colônia Dona Luiza', '84046-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27723, 'Londrina', 'Pescador Pedro', 'Conjunto Semiramis Barros Braga', '86088-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27724, 'Telêmaco Borba', 'Pêssego', 'Fazenda Limeira', '84270-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27725, 'Londrina', 'Pessegueiro', 'Leonor', '86071-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27726, 'Cascavel', 'Pessegueiro', 'Brasmadeira', '85814-138', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27727, 'Araucária', 'Pessegueiros', 'Estação', '83705-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27728, 'Piraquara', 'Peter Heirichs', 'Planta Parque das Andorinhas', '83311-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27729, 'Curitiba', 'Petit Carneiro', 'Água Verde', '80240-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27730, 'Guarapuava', 'Petrarca', 'Jardim das Américas', '85030-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27731, 'Arapongas', 'Petrel', 'Vila São José', '86706-189', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27732, 'Apucarana', 'Petróleo', 'Parque Industrial Zona Norte', '86806-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27733, 'São José dos Pinhais', 'Petronela Sokolowski', 'Ipê', '83055-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27734, 'Londrina', 'Petronilha Ribeiro Manzutti', 'Aquilles Sthengel', '86086-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27735, 'Francisco Beltrão', 'Petrônio Morais', 'Miniguaçu', '85605-200', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27736, 'Londrina', 'Petrônio Portella', 'Sebastião de Melo César', '86084-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27737, 'Francisco Beltrão', 'Petrópolis', 'Pinheirinho', '85603-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27738, 'Maringá', 'Petrópolis', 'Vila Morangueira', '87040-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27739, 'Piraquara', 'Petrópolis', 'Jardim Tropical', '83314-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27740, 'Sarandi', 'Petrópolis', 'Jardim Dom Bosco', '87111-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27741, 'Campo Largo', 'Petrópolis', 'Jardim Rivabem', '83605-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27742, 'Foz do Iguaçu', 'Petruca', 'Profilurb I', '85855-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27743, 'Londrina', 'Petruska Milianskaite Ruiz', 'Conjunto Residencial Itamaraty', '86076-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27744, 'Maringá', 'Petúnia', 'Jardim Industrial', '87065-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27745, 'Ponta Grossa', 'Petúnia', 'Contorno', '84060-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27746, 'Telêmaco Borba', 'Petúnia', 'Jardim Alegre', '84268-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27747, 'Piraquara', 'Philadelphia', 'Planta Campo Largo', '83310-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27748, 'Ponta Grossa', 'Philipp Jorge', 'Contorno', '84052-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27749, 'Arapongas', 'Pianau', 'Vila São José', '86706-187', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27750, 'Curitiba', 'Pianista Luís Thomaszeck', 'Vista Alegre', '80820-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27751, 'Foz do Iguaçu', 'Piapara', 'Conjunto A', '85860-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27752, 'Maringá', 'Piapara', 'Jardim Itaipu', '87065-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27753, 'Londrina', 'Piauí', 'Centro', '86010-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27754, 'Foz do Iguaçu', 'Piauí', 'Conjunto A', '85860-010', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27755, 'Guarapuava', 'Piauí', 'Vila Carli', '85045-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27756, 'Foz do Iguaçu', 'Piauí', 'Loteameto Jardim Colombelli', '85862-468', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27757, 'Londrina', 'Piauí', 'Centro', '86020-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27758, 'Francisco Beltrão', 'Piauí', 'Nossa Senhora Aparecida', '85601-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27759, 'Pato Branco', 'Piauí', 'Bortot', '85504-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27760, 'Paranaguá', 'Piauí', 'Vila do Povo', '83209-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27761, 'Piraquara', 'Piauí', 'Jardim dos Estados 1', '83308-340', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27762, 'Piraquara', 'Piauí', 'Jardim dos Estados 2', '83308-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27763, 'Ponta Grossa', 'Piauí', 'Olarias', '84035-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27764, 'Paranavaí', 'Piauí', 'Centro', '87702-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27765, 'Maringá', 'Piauí', 'Jardim Alvorada', '87033-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27766, 'Telêmaco Borba', 'Piauí', 'Vila Ozorio', '84268-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27767, 'São José dos Pinhais', 'Piauí', 'Boneca do Iguaçu', '83040-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27768, 'Umuarama', 'Piauí', 'Zona II', '87501-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27769, 'Campo Largo', 'Piauí', 'Jardim Boa Vista', '83609-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27770, 'Campo Largo', 'Piauí', 'Vila Itaqui', '83604-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27771, 'Almirante Tamandaré', 'Piauí', 'Vila Dolores', '83514-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27772, 'Colombo', 'Piauí', 'Jardim Curitiba', '83406-650', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27773, 'Araucária', 'Piauí', 'Iguaçu', '83701-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27774, 'Curitiba', 'Piauí', 'Guaíra', '80630-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27775, 'Curitiba', 'Piauí', 'Parolin', '80220-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27776, 'Foz do Iguaçu', 'Piava', 'Profilurb I', '85855-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27777, 'Curitiba', 'Piazza San Marco', 'Santa Felicidade', '82320-620', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27778, 'Arapongas', 'Picanço', 'Vila São José', '86706-188', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27779, 'Francisco Beltrão', 'Pica-pau', 'Padre Ulrico', '85604-459', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27780, 'Londrina', 'Pica-pau', 'Jacomo Violin', '86088-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27781, 'Foz do Iguaçu', 'Pica-pau', 'Portal da Foz', '85859-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27782, 'Campo Mourão', 'Pica-pau', 'Conjunto Habitacional Milton Luiz Pereira', '87306-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27783, 'Arapongas', 'Pica-pau', 'Centro', '86701-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27784, 'Araucária', 'Pica-pau', 'Estação', '83705-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27785, 'Apucarana', 'Pica-pau', 'Recanto das Araras', '86812-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27786, 'Arapongas', 'Pica-pau-chorão', 'Conjunto Novo Centauro', '86709-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27787, 'Arapongas', 'Pica-pau-do-campo', 'Jardim São Bento', '86706-737', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27788, 'Arapongas', 'Pica-pau-dourado', 'Parque Industrial', '86706-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27789, 'Arapongas', 'Pica-pau-loiro', 'Conjunto Águias', '86704-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27790, 'Arapongas', 'Pica-pau-real', 'Conjunto Padre Bernardo Merckel', '86706-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27791, 'Arapongas', 'Pica-pau-velho', 'Vila Industrial', '86706-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27792, 'Arapongas', 'Pica-pauzinho-dourado', 'Casa Família Arapongas IV', '86709-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27793, 'Arapongas', 'Pica-pauzinho-machado', 'Jardim Monte Carlo', '86704-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27794, 'Cascavel', 'Pico da Neblina', 'Periolo', '85817-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27795, 'Cascavel', 'Pico do Paraná', 'Periolo', '85817-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27796, 'Francisco Beltrão', 'Picolotto', 'Nossa Senhora Aparecida', '85601-790', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27797, 'Telêmaco Borba', 'Picuá', 'Vila São Francisco de Assis', '84264-640', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27798, 'Foz do Iguaçu', 'Picui', 'Conjunto A', '85866-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27799, 'Maringá', 'Pien', 'Parque das Laranjeiras', '87083-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27800, 'Pinhais', 'Pien', 'Jardim Dona Joaquina I', '83325-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27801, 'Curitiba', 'Pierina Bertuzzi Borin', 'Umbará', '81930-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27802, 'Maringá', 'Pierina Carniel Mazzer', 'Parque Industrial', '87065-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27803, 'Ponta Grossa', 'Pierre Fanchard', 'Contorno', '84062-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27804, 'Colombo', 'Pietro Canestraro Filho', 'Jardim Paraná', '83412-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27805, 'Londrina', 'Pietro Sborgi', 'Roseira', '86041-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27806, 'Foz do Iguaçu', 'Pilar', 'Jardim das Palmeiras', '85869-748', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27807, 'Almirante Tamandaré', 'Pilarzinho', 'Jardim Iracema', '83508-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27808, 'Curitiba', 'Piloto José', 'Pinheirinho', '81870-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27809, 'Ponta Grossa', 'Pimenteira', 'Uvaranas', '84033-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27810, 'Toledo', 'Pindotipora', 'Sachini', '85903-729', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27811, 'Pinhais', 'Pineville', 'Loteamento Pineville', '83325-585', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27812, 'Londrina', 'Pingo D''Agua', 'Ideal', '86030-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27813, 'Paranaguá', 'Pingos de Ouro', 'Conjunto Nilson Neves', '83215-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27814, 'Maringá', 'Pinguim', 'Distrito Industrial', '87065-700', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27815, 'Londrina', 'Pingüim', 'Indústrias Leves', '86030-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27816, 'Maringá', 'Pingüim', 'Parque Industrial Mário Bulhões', '87065-675', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27817, 'Umuarama', 'Pingüim', 'Zona VI', '87503-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27818, 'Araucária', 'Pingüim', 'Capela Velha', '83706-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27819, 'Paranaguá', 'Pinha', 'Vila São Vicente', '83209-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27820, 'Curitiba', 'Pinha', 'Uberaba', '81560-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27821, 'Foz do Iguaçu', 'Pinhais', 'Jardim Belvedere I', '85867-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27822, 'Telêmaco Borba', 'Pinhal Bonito', 'Área 02', '84267-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27823, 'Ponta Grossa', 'Pinhalão', 'Nova Rússia', '84053-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27824, 'Curitiba', 'Pinhalão', 'Sítio Cercado', '81925-416', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27825, 'Foz do Iguaçu', 'Pinhão', 'Loteamento Witt', '85862-518', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27826, 'Guarapuava', 'Pinhão', 'Conradinho', '85035-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27827, 'Laranjeiras do Sul', 'Pinhão', 'Água Verde', '85302-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27828, 'Piraquara', 'Pinheirinho', 'Planta Araçatuba', '83301-427', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27829, 'Curitiba', 'Pinheirinho', 'Capão Raso', '81130-380', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27830, 'Foz do Iguaçu', 'Pinheiro', 'Jardim Tropical', '85855-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27831, 'Londrina', 'Pinheiro', 'Leonor', '86071-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27832, 'Ponta Grossa', 'Pinheiro', 'Uvaranas', '84033-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27833, 'Curitiba', 'Pinheiro', 'Rebouças', '80230-160', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27834, 'Ponta Grossa', 'Pinheiro Chagas', 'Uvaranas', '84025-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27835, 'Curitiba', 'Pinheiro Guimarães', 'Portão', '80330-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27836, 'Curitiba', 'Pinheiro Lima', 'Centro', '80020-340', 'Galeria', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27837, 'Pato Branco', 'Pinheiro Machado', 'Centro', '85505-060', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27838, 'Toledo', 'Pinheiro Machado', 'Vila Industrial', '85904-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27839, 'Toledo', 'Pinheiro Machado', 'Vila Industrial', '85905-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27840, 'Cascavel', 'Pinheiro Machado', 'Claudete', '85811-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27841, 'Curitiba', 'Pinheiro Machado', 'Fazendinha', '81330-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27842, 'Telêmaco Borba', 'Pinheiro Seco', 'Área 02', '84267-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27843, 'Umuarama', 'Pinheiros', 'Jardim Paraíso', '87505-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27844, 'Almirante Tamandaré', 'Pinheiros', 'Jardim Silvana', '83512-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27845, 'Campo Mourão', 'Pinheiros', 'Conjunto Habitacional Montes Claros', '87310-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27846, 'Cambé', 'Pinheiros', 'Jardim Morumbi', '86191-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27847, 'Apucarana', 'Pinho Araucária', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27848, 'Arapongas', 'Pintadinho', 'Casa da Família', '86706-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27849, 'Arapongas', 'Pintadinho', 'Conjunto Ulisses Guimarães', '86706-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27850, 'Foz do Iguaçu', 'Pintado', 'Conjunto A', '85860-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27851, 'Ponta Grossa', 'Pintado', 'Cará-cará', '84043-727', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27852, 'Francisco Beltrão', 'Pintagol', 'Padre Ulrico', '85604-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27853, 'Londrina', 'Pintagol', 'Jacomo Violin', '86088-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27854, 'Maringá', 'Pintagol', 'Parque Hortência', '87075-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27855, 'Arapongas', 'Pintagol', 'Jardim Primavera', '86702-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27856, 'Cambé', 'Pintagol', 'Conjunto Habitacional Waldomiro M Gomes', '86182-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27857, 'Londrina', 'Pintarroxo', 'Jacomo Violin', '86088-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27858, 'Maringá', 'Pintarroxo', 'Parque Hortência', '87075-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27859, 'Arapongas', 'Pintarroxo', 'Vila Cascata', '86701-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27860, 'Londrina', 'Pintassilgo', 'Milton Gavetti', '86078-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27861, 'Francisco Beltrão', 'Pintassilgo', 'Padre Eurico', '85604-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27862, 'Foz do Iguaçu', 'Pintassilgo', 'Portal da Foz', '85859-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27863, 'Ponta Grossa', 'Pintassilgo', 'Chapada', '84064-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27864, 'Ponta Grossa', 'Pintassilgo', 'Colônia Dona Luiza', '84043-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27865, 'Maringá', 'Pintassilgo', 'Conjunto Residencial Ney Braga', '87083-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27866, 'Araucária', 'Pintassilgo', 'Capela Velha', '83706-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27867, 'Colombo', 'Pintassilgo', 'Jardim Ana Rosa II', '83401-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27868, 'Apucarana', 'Pintassilgo', 'Núcleo Habitacional Michel Soni', '86813-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27869, 'Cascavel', 'Pintassilgo', 'Floresta', '85814-770', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27870, 'Campo Mourão', 'Pintassilgo', 'Conjunto Habitacional Milton Luiz Pereira', '87306-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27871, 'Arapongas', 'Pintassilgo', 'Centro', '86701-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27872, 'Campo Largo', 'Pintassilgo', 'Vila Dona Fina', '83609-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27873, 'Toledo', 'Pinto Bandeira', 'Parque Residencial Pancera', '85902-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27874, 'Ponta Grossa', 'Pinus', 'Contorno', '84061-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27875, 'Telêmaco Borba', 'Pinus', 'Área 01', '84268-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27876, 'Piraquara', 'Pinus Silvestre', 'Chácara Águas Claras', '83308-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27877, 'Araucária', 'Pinus-eliotti', 'Estação', '83705-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27878, 'Colombo', 'Pio Bonato', 'Centro', '83414-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27879, 'Colombo', 'Pio Cavassin', 'Centro', '83414-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27880, 'Guarapuava', 'Pio VI', 'Morro Alto', '85065-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27881, 'Toledo', 'Pio X', 'Jardim Santa Maria', '85903-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27882, 'Apucarana', 'Pio X', 'Jardim Paulista', '86808-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27883, 'Foz do Iguaçu', 'Pio XII', 'Jardim Guaíra', '85855-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27884, 'Londrina', 'Pio XII', 'Centro', '86020-381', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27885, 'Londrina', 'Pio XII', 'Centro', '86020-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27886, 'Maringá', 'Pio XII', 'Zona 05', '87015-325', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27887, 'Paranavaí', 'Pio XII', 'Jardim São Jorge', '87710-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27888, 'Pato Branco', 'Pio XII', 'Centro', '85501-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27889, 'Piraquara', 'Pio XII', 'Vila Juliana', '83306-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27890, 'Cascavel', 'Pio XII', 'Cancelli', '85811-310', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27891, 'Cambé', 'Pio XII', 'Vila Atalaia', '86181-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27892, 'Cascavel', 'Pio XII', 'Vila Tolentino', '85802-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27893, 'Cascavel', 'Pio XII', 'Cancelli', '85811-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27894, 'Apucarana', 'Pio XII', 'Barra Funda', '86800-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27895, 'Cascavel', 'Pio XII', 'Centro', '85801-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27896, 'Cascavel', 'Pio XII', 'Centro', '85810-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27897, 'Arapongas', 'Pio XII', 'Centro', '86701-760', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27898, 'Curitiba', 'Pio XII', 'São Lourenço', '82200-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27899, 'Maringá', 'Pioneira Alcedina Francisca Daut', 'Conjunto Habitacional Itatiaia', '87045-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27900, 'Maringá', 'Pioneira Amália Carzoni Baltazar', 'Jardim Rebouças', '87083-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27901, 'Maringá', 'Pioneira Amélia Vieira da Silva César', 'Conjunto Habitacional Lea Leal', '87040-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27902, 'Maringá', 'Pioneira Ana Cordeiro Dias', 'Parque Residencial Cidade Nova', '87023-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27903, 'Maringá', 'Pioneira Ana Pastori Buzzo', 'Conjunto Habitacional João de Barro Thaís', '87075-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27904, 'Maringá', 'Pioneira Bruna Borim Marim', 'Parque Tarumã', '87053-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27905, 'Maringá', 'Pioneira Dejanira Marques da Silva', 'Parque Residencial Quebec', '87023-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27906, 'Maringá', 'Pioneira Dulcelina Rosa', 'Jardim Continental', '87070-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27907, 'Maringá', 'Pioneira Duzolina Pulzatto', 'Parque Residencial Quebec', '87023-707', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27908, 'Maringá', 'Pioneira Edinalva Alves Meira', 'Parque das Grevíleas', '87025-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27909, 'Maringá', 'Pioneira Elvira Lavorenti Perego', 'Parque Avenida', '87025-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27910, 'Maringá', 'Pioneira Elvira Pereira de Quadros', 'Parque Residencial Aeroporto (3ª Parte)', '87055-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27911, 'Maringá', 'Pioneira Erenita Ribeiro', 'Distrito Industrial 2', '87065-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27912, 'Maringá', 'Pioneira Filomena Caminato Men', 'Conjunto Habitacional Hermann Moraes Barros', '87023-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27913, 'Maringá', 'Pioneira Fiorentina Pietrobon Rui', 'Zona 20', '87060-336', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27914, 'Maringá', 'Pioneira Fumio Tanoue', 'Parque Tarumã', '87053-597', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27915, 'Maringá', 'Pioneira Genoveva Giunta', 'Parque Tarumã', '87053-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27916, 'Maringá', 'Pioneira Glacy de Andrade Figueira Walsh', 'Jardim Alvorada', '87035-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27917, 'Maringá', 'Pioneira Guilhermina Mazolini', 'Jardim Piata', '87043-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27918, 'Maringá', 'Pioneira Helena Felipe Abrão', 'Parque Hortência', '87075-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27919, 'Maringá', 'Pioneira Heronita Vieira Barbosa', 'Parque Residencial Quebec', '87023-494', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27920, 'Maringá', 'Pioneira Hinna Gravena Fernandes', 'Jardim Rebouças', '87083-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27921, 'Maringá', 'Pioneira Hulda Hummig Campos', 'Vila Santo Antônio', '87030-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27922, 'Maringá', 'Pioneira Izabel Pecz Belai', 'Distrito Industrial 2', '87065-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27923, 'Maringá', 'Pioneira Jacinta Moreira Gavioli', 'Jardim São Silvestre', '87055-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27924, 'Maringá', 'Pioneira Laura Sordi Leonardo', 'Jardim Itaipu', '87065-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27925, 'Maringá', 'Pioneira Luiza Tramontine Gravena', 'Jardim Santa Alice', '87040-558', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27926, 'Maringá', 'Pioneira Maria Batista de Souza Neves', 'Conjunto Habitacional Sol Nascente', '87055-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27927, 'Maringá', 'Pioneira Maria Bordgnon Pietrobon', 'Conjunto Habitacional Sanenge III', '87055-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27928, 'Maringá', 'Pioneira Maria Caron Rigolin', 'Parque Residencial Quebec', '87023-438', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27929, 'Maringá', 'Pioneira Maria Cavalcante Ruy', 'Jardim Nilza', '87065-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27930, 'Maringá', 'Pioneira Maria Colaço', 'Parque Tarumã', '87053-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27931, 'Maringá', 'Pioneira Maria Deusanira Borges da Silva', 'Jardim São Silvestre', '87055-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27932, 'Maringá', 'Pioneira Maria Fernandes Álvares', 'Parque Residencial Aeroporto', '87055-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27933, 'Maringá', 'Pioneira Maria Glezzi', 'Parque Tarumã', '87053-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27934, 'Sarandi', 'Pioneira Maria Leibantti Brogio', 'Jardim Monterey', '87112-315', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27935, 'Maringá', 'Pioneira Maria Lopes', 'Parque Residencial Aeroporto', '87055-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27936, 'Maringá', 'Pioneira Maria Magdalena de Jesus Vieira', 'Jardim Ouro Cola', '87070-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27937, 'Maringá', 'Pioneira Maria Otávia do Nascimento', 'Conjunto Habitacional Requião', '87047-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27938, 'Maringá', 'Pioneira Nair dos Santos Tavares', 'Zona 05', '87060-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27939, 'Maringá', 'Pioneira Norvina Maria Gonçalves', 'Jardim Copacabana', '87023-326', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27940, 'Maringá', 'Pioneira Olívia Julião Dias', 'Conjunto Habitacional Hermann Moraes Barros', '87023-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27941, 'Maringá', 'Pioneira Ondina Becker Vargas', 'Conjunto Habitacional Requião', '87047-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27942, 'Maringá', 'Pioneira Palmyra Tel', 'Jardim Verônica', '87060-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27943, 'Maringá', 'Pioneira Regina Marson Badan', 'Jardim Iguaçu', '87060-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27944, 'Maringá', 'Pioneira Regina Nicolina Celestino', 'Conjunto João de Barro Cidade Canção', '87053-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27945, 'Maringá', 'Pioneira Sofia Ratcov Parandiuc', 'Parque Lagoa Dourada', '87053-257', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27946, 'Maringá', 'Pioneira Zita Capaldi Thomazini', 'Conjunto João de Barro Porto Seguro II', '87055-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27947, 'Maringá', 'Pioneiro Abílio Gaspar', 'Parque Avenida', '87025-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27948, 'Maringá', 'Pioneiro Adelino Rigolin', 'Copacabana Residencial', '87023-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27949, 'Maringá', 'Pioneiro Ademar Natali', 'Parque Avenida', '87025-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27950, 'Maringá', 'Pioneiro Affonso Rosa Lobato', 'Copacabana Residencial', '87023-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27951, 'Maringá', 'Pioneiro Agenor Camargo', 'Copacabana Residencial', '87023-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27952, 'Maringá', 'Pioneiro Agostin Gomes', 'Parque Residencial Quebec', '87023-488', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27953, 'Maringá', 'Pioneiro Alberto Biazon', 'Vila Marumby', '87005-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27954, 'Pato Branco', 'Pioneiro Alberto Braun', 'Morro da Cruz', '85505-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27955, 'Maringá', 'Pioneiro Alcides Bernardes', 'Conjunto Residencial Planville', '87080-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27956, 'Maringá', 'Pioneiro Alcides de Araújo Vargas', 'Vila Esperança', '87020-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27957, 'Maringá', 'Pioneiro Aldo Lippi', 'Conjunto Habitacional João de Barro Thaís', '87075-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27958, 'Maringá', 'Pioneiro Aldo Montovonelli', 'Parque Tarumã', '87053-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27959, 'Maringá', 'Pioneiro Alexandre Men', 'Parque Residencial Cidade Nova', '87023-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27960, 'Maringá', 'Pioneiro Alfeu Maiochi', 'Conjunto Habitacional Sanenge III', '87055-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27961, 'Maringá', 'Pioneiro Alfredo José da Costa', 'Jardim Alvorada', '87035-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27962, 'Paranavaí', 'Pioneiro Alfredo Simonete', 'Jardim Canadá', '87708-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27963, 'Maringá', 'Pioneiro Alfredo Soares de Freitas', 'Jardim Continental', '87070-556', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27964, 'Maringá', 'Pioneiro Alfredo Tranjan', 'Jardim Liberdade', '87047-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27965, 'Maringá', 'Pioneiro Alfredo Vieira', 'Distrito Industrial 2', '87065-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27966, 'Maringá', 'Pioneiro Alício Arantes Campolina', 'Jardim Real', '87083-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27967, 'Maringá', 'Pioneiro Alício Arantes Campolina', 'Vila Esperança', '87020-750', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27968, 'Maringá', 'Pioneiro Alziro Pozzi', 'Jardim São Silvestre', '87055-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27969, 'Maringá', 'Pioneiro André Contessoto', 'Ebenezer', '87035-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27970, 'Maringá', 'Pioneiro Ângelo Bertoni', 'Jardim Higienópolis', '87060-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27971, 'Maringá', 'Pioneiro Ângelo Perin', 'Jardim Paraíso', '87053-017', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27972, 'Maringá', 'Pioneiro Antônio Alves Teixeira', 'Jardim Itaipu', '87065-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27973, 'Maringá', 'Pioneiro Antônio Barbosa do Amaral', 'Parque Residencial Quebec', '87023-486', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27974, 'Maringá', 'Pioneiro Antônio Batista', 'Conjunto João de Barro Porto Seguro II', '87055-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27975, 'Maringá', 'Pioneiro Antônio Carnelossi', 'Parque Hortência', '87075-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27976, 'Maringá', 'Pioneiro Antônio Fernandes da Costa', 'Zona 20', '87060-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27977, 'Maringá', 'Pioneiro Antônio Fernandes Maciel', 'Jardim Paraíso', '87053-018', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27978, 'Maringá', 'Pioneiro Antônio Francisco Branco', 'Vila Santa Izabel', '87080-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27979, 'Maringá', 'Pioneiro Antônio Franco de Morais', 'Jardim Brasil', '87083-415', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27980, 'Maringá', 'Pioneiro Antônio Fritzen', 'Jardim Bertioga', '87055-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27981, 'Maringá', 'Pioneiro Antônio Laurentino Tavares', 'Jardim América', '87045-700', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27982, 'Paranavaí', 'Pioneiro Antônio P. Campos', 'Parque Morumbi', '87703-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27983, 'Maringá', 'Pioneiro Antônio Paulo da Silva', 'Jardim Ipanema', '87053-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27984, 'Maringá', 'Pioneiro Antônio Pietrobom', 'Parque Avenida', '87025-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27985, 'Maringá', 'Pioneiro Antônio Planas', 'Parque Avenida', '87025-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27986, 'Maringá', 'Pioneiro Antônio Primo Milani', 'Parque Hortência', '87075-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27987, 'Maringá', 'Pioneiro Antônio Ruiz Saldanha', 'Jardim Itaipu', '87065-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27988, 'Maringá', 'Pioneiro Antônio Tait', 'Jardim São Silvestre', '87055-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27989, 'Maringá', 'Pioneiro Anúibal Borin', 'Jardim Paris', '87083-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27990, 'Maringá', 'Pioneiro Aparecido Guerra', 'Jardim Itaipu', '87065-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27991, 'Maringá', 'Pioneiro Aquino Cantagalli', 'Jardim São Domingos', '87070-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27992, 'Maringá', 'Pioneiro Arlindo Bonifácio Leite', 'Conjunto Habitacional Sol Nascente', '87055-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27993, 'Maringá', 'Pioneiro Arthur Henschel', 'Jardim São Silvestre', '87055-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27994, 'Maringá', 'Pioneiro Arthur Montagnoli', 'Parque Tarumã', '87053-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27995, 'Maringá', 'Pioneiro Arziro Moreschi', 'Conjunto Habitacional Requião', '87047-408', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27996, 'Maringá', 'Pioneiro Augostine Mizzavilla', 'Vila Esperança', '87020-490', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27997, 'Maringá', 'Pioneiro Basílio José da Silva', 'Copacabana Residencial', '87023-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27998, 'Maringá', 'Pioneiro Basílio Moreschi', 'Parque das Laranjeiras', '87083-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (27999, 'Maringá', 'Pioneiro Belizário José Francisco', 'Jardim Itaipu', '87065-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28000, 'Maringá', 'Pioneiro Benedito Alves de Góes', 'Jardim Liberdade', '87047-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28001, 'Maringá', 'Pioneiro Benedito Bueno', 'Ebenezer', '87035-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28002, 'Maringá', 'Pioneiro Benedito Carvalho', 'Conjunto Habitacional Sol Nascente', '87055-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28003, 'Maringá', 'Pioneiro Benedito José Jorge', 'Parque Residencial Anchieta', '87005-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28004, 'Maringá', 'Pioneiro Benedito Justino', 'Jardim Paraíso', '87053-086', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28005, 'Maringá', 'Pioneiro Benjamin Fernandes Dias', 'Jardim Iguaçu', '87060-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28006, 'Maringá', 'Pioneiro Bento de Freitas da Silva', 'Parque Residencial Tuiuti', '87047-390', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28007, 'Maringá', 'Pioneiro Bernardo Duqueses', 'Conjunto Habitacional Requião', '87047-499', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28008, 'Maringá', 'Pioneiro Boanerges Oliveira Fernandes', 'Jardim Botânico', '87060-537', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28009, 'Maringá', 'Pioneiro Braz José Jorge', 'Parque Hortência', '87075-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28010, 'Maringá', 'Pioneiro Bruno Alfredo Zanotto', 'Parque Residencial Quebec', '87023-435', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28011, 'Maringá', 'Pioneiro Bruno Bluthgen', 'Ebenezer', '87035-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28012, 'Maringá', 'Pioneiro Caetano Penatti', 'Parque das Grevíleas', '87025-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28013, 'Maringá', 'Pioneiro Caetano Vicentini', 'Zona 42', '87065-148', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28014, 'Maringá', 'Pioneiro Camillo Bulla', 'Conjunto Residencial Parigot de Souza', '87045-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28015, 'Maringá', 'Pioneiro Cândido Soares de Moura', 'Conjunto Habitacional Itatiaia', '87045-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28016, 'Maringá', 'Pioneiro Carlos Assalin', 'Jardim Guararapes', '87045-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28017, 'Maringá', 'Pioneiro Carlos Bulla', 'Jardim Paraíso', '87053-009', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28018, 'Maringá', 'Pioneiro Carlos Burian', 'Distrito Industrial 2', '87065-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28019, 'Maringá', 'Pioneiro Carlos de Almeida', 'Jardim Ouro Cola', '87070-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28020, 'Maringá', 'Pioneiro Carlos Luiz Hubel', 'Vila Esperança', '87020-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28021, 'Maringá', 'Pioneiro Carlos Poppi', 'Jardim Liberdade', '87047-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28022, 'Maringá', 'Pioneiro Carlos Scandinari', 'Jardim Ouro Cola', '87070-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28023, 'Maringá', 'Pioneiro Celeste Fadel', 'Jardim São Silvestre', '87055-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28024, 'Paranavaí', 'Pioneiro Celso Luiz Pereira', 'Parque Morumbi', '87703-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28025, 'Maringá', 'Pioneiro Cezare Mochi', 'Jardim Paraíso', '87053-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28026, 'Maringá', 'Pioneiro Cosme Gonçalves de Meireles', 'Parque Avenida', '87025-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28027, 'Maringá', 'Pioneiro Demétrio Kutchenko', 'Jardim Paraíso', '87053-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28028, 'Maringá', 'Pioneiro Diogo Martins Esteves', 'Jardim Iguaçu', '87060-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28029, 'Maringá', 'Pioneiro Dionísio Volpi Frediani', 'Jardim Novo Oásis', '87043-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28030, 'Maringá', 'Pioneiro Dirceu Palma', 'Parque Industrial Bandeirantes', '87070-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28031, 'Maringá', 'Pioneiro Domingos Danhoni', 'Jardim São Silvestre', '87055-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28032, 'Maringá', 'Pioneiro Domingos Marcote', 'Vila Esperança', '87020-670', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28033, 'Maringá', 'Pioneiro Domingos Miranda da Silva', 'Vila Esperança', '87020-630', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28034, 'Maringá', 'Pioneiro Domingos Salgueiro', 'Jardim Guaporé', '87060-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28035, 'Maringá', 'Pioneiro Durval Vieira Dantas', 'Jardim Paraíso', '87053-087', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28036, 'Paranavaí', 'Pioneiro Edvir Ferreira de Araújo', 'Jardim Maravilha', '87703-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28037, 'Maringá', 'Pioneiro Elias Martins', 'Conjunto Habitacional Sol Nascente', '87055-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28038, 'Maringá', 'Pioneiro Elson Ramos', 'Jardim Dourados', '87040-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28039, 'Maringá', 'Pioneiro Emílio Carlos Cristiano', 'Conjunto João de Barro Itaparica', '87043-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28040, 'Maringá', 'Pioneiro Emílio Helibrand', 'Conjunto Habitacional João de Barro Thaís', '87075-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28041, 'Maringá', 'Pioneiro Emílio Lucas', 'Jardim Santa Alice', '87040-559', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28042, 'Maringá', 'Pioneiro Emílio Oscar Froeming', 'Parque Residencial Quebec', '87023-705', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28043, 'Maringá', 'Pioneiro Ercílio Silva', 'Conjunto Habitacional Requião', '87047-498', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28044, 'Maringá', 'Pioneiro Etori Colli', 'Vila Santa Izabel', '87080-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28045, 'Maringá', 'Pioneiro Euclides Cordeiro da Silva', 'Conjunto Habitacional Requião', '87047-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28046, 'Maringá', 'Pioneiro Euclides Gavioli', 'Jardim São Silvestre', '87055-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28047, 'Paranavaí', 'Pioneiro Felicío Jorge', 'Jardim Santa Cecília', '87702-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28048, 'Maringá', 'Pioneiro Fiori Progiante', 'Zona 03', '87050-225', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28049, 'Maringá', 'Pioneiro Francisco Bim Sobrinho', 'Zona 47', '87065-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28050, 'Maringá', 'Pioneiro Francisco Castoldo', 'Jardim Ouro Cola', '87070-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28051, 'Maringá', 'Pioneiro Francisco Dalquana', 'Jardim América', '87045-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28052, 'Paranavaí', 'Pioneiro Francisco Ruiz Vitoriano', 'Jardim Ouro Branco', '87704-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28053, 'Maringá', 'Pioneiro Frrancisco Alves Toledo', 'Parque Residencial Patrícia', '87040-466', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28054, 'Maringá', 'Pioneiro Gabriel Forcelli', 'Jardim Internorte', '87045-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28055, 'Maringá', 'Pioneiro Gabriel José dos Santos', 'Conjunto João de Barro Cidade Canção', '87053-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28056, 'Maringá', 'Pioneiro Galileu Rigolin', 'Jardim Alvorada', '87035-100', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28057, 'Maringá', 'Pioneiro Gelindo Pelegrinello', 'Conjunto Habitacional Sol Nascente', '87055-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28058, 'Maringá', 'Pioneiro Geraldo Ferreira Coelho', 'Jardim Paraíso', '87053-026', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28059, 'Maringá', 'Pioneiro Geraldo José Jorge', 'Parque Hortência', '87075-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28060, 'Maringá', 'Pioneiro Geraldo Menegheti', 'Parque Tarumã', '87053-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28061, 'Maringá', 'Pioneiro Geraldo Meneguetti', 'Jardim Itapuã', '87010-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28062, 'Maringá', 'Pioneiro Geraldo Pinheiro da Fonseca', 'Jardim Botânico', '87060-536', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28063, 'Maringá', 'Pioneiro Geraldo Portela', 'Conjunto Habitacional Requião', '87047-429', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28064, 'Maringá', 'Pioneiro Geraldo Tono', 'Jardim Ouro Cola', '87070-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28065, 'Maringá', 'Pioneiro Germano Lazaretti', 'Jardim Copacabana', '87023-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28066, 'Maringá', 'Pioneiro Giusepe Portolese', 'Distrito Industrial 2', '87065-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28067, 'Maringá', 'Pioneiro Gregório Moreira', 'Jardim Piata', '87043-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28068, 'Maringá', 'Pioneiro Guarino Augusto Basseto', 'Loteamento Batel', '87043-427', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28069, 'Maringá', 'Pioneiro Guarino Augusto Basseto', 'Conjunto Residencial Rodolpho Bernardi', '87035-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28070, 'Maringá', 'Pioneiro Gumercindo Correia de Aguiar', 'Jardim Leblon', '87053-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28071, 'Maringá', 'Pioneiro Hélcio Siolari', 'Distrito Industrial 2', '87065-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28072, 'Maringá', 'Pioneiro Henrique Alves de Souza', 'Parque Residencial Aeroporto', '87055-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28073, 'Maringá', 'Pioneiro Henrique Garcia Espinosa', 'Jardim Ipanema', '87053-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28074, 'Maringá', 'Pioneiro Herculano Ferreira', 'Conjunto Habitacional Sanenge III', '87055-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28075, 'Maringá', 'Pioneiro Hermínio Zenaro Manin', 'Parque das Grevíleas', '87025-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28076, 'Maringá', 'Pioneiro Hettore Giacopini', 'Parque Lagoa Dourada', '87053-258', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28077, 'Maringá', 'Pioneiro Humberto Parolin', 'Conjunto Habitacional Lea Leal', '87040-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28078, 'Maringá', 'Pioneiro Ignacio Gomes', 'Jardim Monte Carlo', '87080-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28079, 'Maringá', 'Pioneiro Ignis Reggiani Durant', 'Conjunto Habitacional Requião', '87047-486', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28080, 'Maringá', 'Pioneiro Irineu Murazi', 'Zona 01', '87013-065', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28081, 'Maringá', 'Pioneiro Isaac José de Faria', 'Vila Morangueira', '87040-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28082, 'Maringá', 'Pioneiro Ismael Miles', 'Conjunto Habitacional Céu Azul', '87055-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28083, 'Maringá', 'Pioneiro Isoldino Dias Costa', 'Vila Esperança', '87020-510', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28084, 'Maringá', 'Pioneiro Jacinto Ferreira Branco', 'Zona 07', '87080-110', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28085, 'Maringá', 'Pioneiro Jacob Unt', 'Copacabana Residencial', '87023-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28086, 'Maringá', 'Pioneiro Jacy Gama', 'Jardim Brasil', '87083-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28087, 'Maringá', 'Pioneiro Jerônimo Ribeiro', 'Parque Industrial Mário Bulhões', '87065-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28088, 'Maringá', 'Pioneiro João Benedito da Silva', 'Jardim Universo', '87060-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28089, 'Maringá', 'Pioneiro João Custódio Pereira', 'Parque Tarumã', '87053-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28090, 'Maringá', 'Pioneiro João Faustino dos Santos', 'Jardim Ipanema', '87053-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28091, 'Maringá', 'Pioneiro João José Bortolatto', 'Parque Tarumã', '87053-649', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28092, 'Maringá', 'Pioneiro João José Queiroz', 'Jardim Ipanema', '87053-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28093, 'Paranavaí', 'Pioneiro João Komochena', 'Jardim Progresso', '87701-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28094, 'Maringá', 'Pioneiro João Matheus', 'Jardim Itaipu', '87065-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28095, 'Maringá', 'Pioneiro João Moreno', 'Conjunto João de Barro Porto Seguro II', '87055-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28096, 'Maringá', 'Pioneiro João Nunes', 'Jardim Paulista', '87047-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28097, 'Maringá', 'Pioneiro João Pedro de Lima', 'Conjunto Habitacional Sol Nascente', '87055-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28098, 'Maringá', 'Pioneiro João Pereira', 'Parque Industrial Bandeirantes', '87070-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28099, 'Maringá', 'Pioneiro João Pereira', 'Parque das Laranjeiras', '87083-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28100, 'Maringá', 'Pioneiro João Pereira', 'Jardim Tropical', '87080-685', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28101, 'Maringá', 'Pioneiro João Perin', 'Parque Tarumã', '87053-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28102, 'Maringá', 'Pioneiro João Pinheiro Dantas', 'Jardim Itaipu', '87065-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28103, 'Maringá', 'Pioneiro Joao Rufato', 'Parque Industrial 200', '87035-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28104, 'Maringá', 'Pioneiro João Zavatini', 'Copacabana Residencial', '87023-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28105, 'Maringá', 'Pioneiro Joaquim Domingos de Souza', 'Vila Esperança', '87020-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28106, 'Maringá', 'Pioneiro Joaquim dos Santos', 'Jardim Novo Oásis', '87043-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28107, 'Maringá', 'Pioneiro Joaquim Pedro de Oliveira', 'Conjunto Habitacional Requião', '87047-476', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28108, 'Maringá', 'Pioneiro Joaquim Pereira Rosa', 'Jardim São Silvestre', '87055-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28109, 'Maringá', 'Pioneiro Jorge Uliana', 'Parque das Laranjeiras', '87083-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28110, 'Maringá', 'Pioneiro José Alves Filho', 'Jardim Pinheiros II', '87043-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28111, 'Maringá', 'Pioneiro José Américo', 'Conjunto Habitacional Requião', '87047-496', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28112, 'Maringá', 'Pioneiro José Antônio da Silva', 'Conjunto Habitacional Itatiaia', '87045-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28113, 'Maringá', 'Pioneiro José Antônio Pires', 'Jardim Itaipu', '87065-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28114, 'Maringá', 'Pioneiro José Arduim', 'Parque das Laranjeiras', '87083-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28115, 'Maringá', 'Pioneiro José Augusto Gaspar', 'Parque Palmeiras', '87023-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28116, 'Maringá', 'Pioneiro José Augusto Ramos', 'Conjunto Habitacional João de Barro Thaís', '87075-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28117, 'Maringá', 'Pioneiro José Balan', 'Parque Residencial Aeroporto', '87055-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28118, 'Paranavaí', 'Pioneiro José Basílio de Oliveira', 'Jardim São Luiz', '87702-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28119, 'Maringá', 'Pioneiro José Capel Cortez', 'Jardim Paraíso', '87053-008', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28120, 'Pato Branco', 'Pioneiro José Catusso', 'Morro da Cruz', '85506-556', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28121, 'Maringá', 'Pioneiro José Coelho', 'Copacabana Residencial', '87023-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28122, 'Maringá', 'Pioneiro José de Paula', 'Jardim Novo Alvorada', '87035-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28123, 'Maringá', 'Pioneiro José Demori', 'Jardim Iguaçu', '87060-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28124, 'Maringá', 'Pioneiro José Dena', 'Copacabana Residencial', '87023-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28125, 'Maringá', 'Pioneiro José dos Santos', 'Jardim Itaipu', '87065-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28126, 'Maringá', 'Pioneiro José Faian', 'Conjunto Habitacional Sol Nascente', '87055-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28127, 'Maringá', 'Pioneiro José Favotto', 'Parque Tarumã', '87053-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28128, 'Maringá', 'Pioneiro José Fernandes', 'Conjunto João de Barro I', '87053-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28129, 'Maringá', 'Pioneiro José Fernandes Ribas', 'Jardim Alvorada', '87035-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28130, 'Maringá', 'Pioneiro José Francisco', 'Conjunto João de Barro Porto Seguro II', '87055-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28131, 'Maringá', 'Pioneiro José Fritzem', 'Jardim Bertioga', '87055-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28132, 'Maringá', 'Pioneiro José Gonçalves de Oliveira', 'Jardim Alvorada', '87035-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28133, 'Maringá', 'Pioneiro José Ignacio da Silva', 'Zona 06', '87015-545', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28134, 'Maringá', 'Pioneiro José Inocêncio Netto', 'Parque Residencial Anchieta', '87005-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28135, 'Maringá', 'Pioneiro José Jacinto Maia', 'Copacabana Residencial', '87023-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28136, 'Maringá', 'Pioneiro José Leite', 'Jardim Tabaete', '87005-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28137, 'Maringá', 'Pioneiro José Leopoldo Soares', 'Parque Residencial Eldorado', '87025-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28138, 'Maringá', 'Pioneiro José Lopes de Covos', 'Conjunto Habitacional João de Barro Thaís', '87075-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28139, 'Maringá', 'Pioneiro José Lourenço dos Santos', 'Parque da Gávea', '87053-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28140, 'Paranavaí', 'Pioneiro José Nascimento Giraide', 'Parque Morumbi', '87703-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28141, 'Maringá', 'Pioneiro José Onofrio Rezende', 'Conjunto Habitacional Lea Leal', '87040-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28142, 'Maringá', 'Pioneiro José Pedro Grandi', 'Parque das Grevíleas', '87025-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28143, 'Maringá', 'Pioneiro José Peralta Pardial', 'Parque Residencial Aeroporto (3ª Parte)', '87055-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28144, 'Maringá', 'Pioneiro José Pinto Portela', 'Parque Tarumã', '87053-599', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28145, 'Maringá', 'Pioneiro José Poppi', 'Parque Residencial Eldorado', '87025-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28146, 'Maringá', 'Pioneiro José Raimundo de Oliveira', 'Jardim São Silvestre', '87055-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28147, 'Sarandi', 'Pioneiro José Reggiano', 'Parque Alvamar', '87113-325', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28148, 'Maringá', 'Pioneiro José Romano', 'Jardim Ivemar', '87065-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28149, 'Maringá', 'Pioneiro José Silva Pedra', 'Jardim Itaipu', '87065-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28150, 'Maringá', 'Pioneiro José Tel', 'Jardim Guaporé', '87060-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28151, 'Maringá', 'Pioneiro José Tozzo', 'Copacabana Residencial', '87023-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28152, 'Maringá', 'Pioneiro José Vicente da Silva', 'Jardim Universo', '87060-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28153, 'Maringá', 'Pioneiro Juan Saldanha Garcia', 'Jardim Dourados', '87040-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28154, 'Maringá', 'Pioneiro Julian Martinez Alvarez', 'Jardim América', '87045-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28155, 'Maringá', 'Pioneiro Júlio de Oliveira Paiva', 'Conjunto Residencial Cidade Alta', '87053-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28156, 'Maringá', 'Pioneiro Júlio Poletto', 'Conjunto Habitacional Hermann Moraes Barros', '87023-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28157, 'Maringá', 'Pioneiro Júlio Ribeiro Vilella', 'Conjunto Residencial Parigot de Souza', '87045-680', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28158, 'Maringá', 'Pioneiro Kumaichi Sakamoto', 'Parque das Grevíleas', '87025-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28159, 'Maringá', 'Pioneiro Lademiro Kolicheski', 'Conjunto Residencial Cidade Alta', '87053-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28160, 'Maringá', 'Pioneiro Laudelino Tavares', 'Conjunto Habitacional Requião', '87047-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28161, 'Maringá', 'Pioneiro Lázaro Claro da Silva', 'Jardim Higienópolis', '87060-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28162, 'Maringá', 'Pioneiro Lino Gravena', 'Jardim Santa Alice', '87040-557', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28163, 'Maringá', 'Pioneiro Liziaro Bogo', 'Jardim Dourados', '87040-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28164, 'Maringá', 'Pioneiro Lourenço Favoreto', 'Parque das Grevíleas', '87025-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28165, 'Maringá', 'Pioneiro Lúcio Ferreira Dias', 'Copacabana Residencial', '87023-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28166, 'Maringá', 'Pioneiro Luiz Alfredo', 'Parque Residencial Quebec', '87023-493', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28167, 'Maringá', 'Pioneiro Luiz Minuceli', 'Conjunto Habitacional João de Barro Thaís', '87075-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28168, 'Maringá', 'Pioneiro Luiz Oberleitner', 'Conjunto Habitacional Requião', '87047-520', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28169, 'Maringá', 'Pioneiro Manoel Alves Carneiro', 'Jardim Itaipu', '87065-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28170, 'Maringá', 'Pioneiro Manoel Domingos Prina', 'Conjunto Residencial Cidade Alta', '87053-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28171, 'Maringá', 'Pioneiro Manoel dos Santos Ferreira', 'Conjunto Habitacional Hermann Moraes Barros', '87023-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28172, 'Maringá', 'Pioneiro Manoel Negrete Garcia', 'Gleba Patrimônio Maringá', '87070-558', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28173, 'Maringá', 'Pioneiro Manoel Tenório Souto', 'Jardim Itaipu', '87065-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28174, 'Maringá', 'Pioneiro Manoel Vitorino Silva', 'Conjunto Habitacional Sol Nascente', '87055-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28175, 'Maringá', 'Pioneiro Marcelino Leonardo', 'Jardim Monte Carlo', '87080-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28176, 'Maringá', 'Pioneiro Marcos Takashi Kawamoto', 'Cidade Jardim', '87020-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28177, 'Maringá', 'Pioneiro Mariano Palácio', 'Conjunto João de Barro Porto Seguro II', '87055-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28178, 'Maringá', 'Pioneiro Mário Buralli', 'Parque Lagoa Dourada', '87053-268', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28179, 'Maringá', 'Pioneiro Mário Lopes', 'Parque Residencial Aeroporto', '87055-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28180, 'Maringá', 'Pioneiro Mário Marangoni', 'Conjunto Residencial Ângelo Planas', '87060-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28181, 'Maringá', 'Pioneiro Mário Pagani', 'Conjunto Habitacional Sol Nascente', '87055-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28182, 'Maringá', 'Pioneiro Mário Pedreti Tilio', 'Parque Avenida', '87025-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28183, 'Maringá', 'Pioneiro Martinho Jorge Delmonico', 'Vila Esperança', '87020-650', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28184, 'Maringá', 'Pioneiro Matheus Castilho Martos', 'Jardim Liberdade', '87047-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28185, 'Maringá', 'Pioneiro Maurício Mariani', 'Jardim Itaipu', '87065-510', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28186, 'Maringá', 'Pioneiro Miguel Jordão Martines', 'Parque Industrial Mário Bulhões', '87065-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28187, 'Paranavaí', 'Pioneiro Moisés Lopes Ribeiro', 'Jardim Campo Belo', '87711-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28188, 'Maringá', 'Pioneiro Motokishi Sonoda', 'Jardim Novo Horizonte', '87010-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28189, 'Maringá', 'Pioneiro Múcio Rodrigues', 'Jardim Brasil', '87083-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28190, 'Maringá', 'Pioneiro Natale de Carle', 'Jardim São Domingos', '87070-805', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28191, 'Maringá', 'Pioneiro Natale Durante', 'Conjunto Habitacional Requião', '87047-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28192, 'Maringá', 'Pioneiro Nereu Mazzer', 'Parque das Grevíleas', '87025-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28193, 'Maringá', 'Pioneiro Noriyaso Ishikawa', 'Jardim Iguaçu', '87060-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28194, 'Telêmaco Borba', 'Pioneiro Norte', 'Vila Arcina', '84268-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28195, 'Maringá', 'Pioneiro Olímpio Forcelli', 'Jardim Internorte', '87045-690', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28196, 'Maringá', 'Pioneiro Olindo Alcini', 'Parque Hortência', '87075-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28197, 'Maringá', 'Pioneiro Orlando Betazzi', 'Jardim São Silvestre', '87055-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28198, 'Maringá', 'Pioneiro Orlando Carnelos', 'Jardim Itaipu', '87065-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28199, 'Maringá', 'Pioneiro Orlando Martins dos Santos', 'Jardim Paraíso', '87053-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28200, 'Maringá', 'Pioneiro Oscar Antunes', 'Vila Esperança', '87020-570', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28201, 'Maringá', 'Pioneiro Oscar Gravena', 'Parque Palmeiras', '87023-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28202, 'Paranavaí', 'Pioneiro Osvaldo Rasmussen', 'Parque Morumbi', '87703-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28203, 'Maringá', 'Pioneiro Oswaldo Ticianel', 'Parque Avenida', '87025-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28204, 'Maringá', 'Pioneiro Otaviano Selicani', 'Parque Residencial Aeroporto (3ª Parte)', '87055-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28205, 'Maringá', 'Pioneiro Otávio Lopes da Silva', 'Conjunto João de Barro Porto Seguro II', '87055-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28206, 'Maringá', 'Pioneiro Paschoal Locatelli', 'Conjunto Residencial Cidade Alta', '87053-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28207, 'Maringá', 'Pioneiro Paschoal Lorenceti', 'Parque Industrial', '87065-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28208, 'Maringá', 'Pioneiro Paschoal Pilli', 'Distrito Industrial 2', '87065-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28209, 'Maringá', 'Pioneiro Pedro Francoso', 'Parque Residencial Quebec', '87023-487', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28210, 'Maringá', 'Pioneiro Pedro Gabriel dos Santos', 'Conjunto Habitacional Hermann Moraes Barros', '87023-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28211, 'Maringá', 'Pioneiro Pedro Galbiatti', 'Conjunto Habitacional Requião', '87047-447', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28212, 'Maringá', 'Pioneiro Pedro Garcia', 'Jardim Rebouças', '87083-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28213, 'Maringá', 'Pioneiro Pedro Pupulim', 'Jardim Universo', '87060-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28214, 'Maringá', 'Pioneiro Pedro Valias de Rezende', 'Vila Santa Izabel', '87080-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28215, 'Maringá', 'Pioneiro Porphirio de Moraes', 'Conjunto Residencial Rodolpho Bernardi', '87035-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28216, 'Maringá', 'Pioneiro Rafael Fenato', 'Parque Residencial Cidade Nova', '87023-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28217, 'Maringá', 'Pioneiro Raul Ambrósio Valente', 'Jardim América', '87045-440', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28218, 'Maringá', 'Pioneiro Ricardo Banci', 'Jardim Paraíso', '87053-006', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28219, 'Maringá', 'Pioneiro Rinzo Guinoza', 'Jardim Dourados', '87040-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28220, 'Maringá', 'Pioneiro Roberto Mariani', 'Jardim São Silvestre', '87055-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28221, 'Maringá', 'Pioneiro Romano Pulzatto', 'Parque Residencial Quebec', '87023-706', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28222, 'Maringá', 'Pioneiro Romeu Pardini', 'Zona 28', '87053-289', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28223, 'Maringá', 'Pioneiro Rosa Montagner Baldo', 'Conjunto João de Barro Porto Seguro II', '87055-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28224, 'Maringá', 'Pioneiro Salvador Gualda Lopes', 'Jardim Industrial', '87065-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28225, 'Maringá', 'Pioneiro Salvador Thomazini', 'Parque Tarumã', '87053-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28226, 'Maringá', 'Pioneiro Santo Dela Valentina', 'Jardim Itaipu', '87065-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28227, 'Maringá', 'Pioneiro Santo Galante', 'Conjunto Residencial Cidade Alta', '87053-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28228, 'Paranavaí', 'Pioneiro Sebastião Alves da Silva', 'Jardim São Jorge', '87711-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28229, 'Maringá', 'Pioneiro Sebastião Alves Ramos', 'Jardim Paraíso', '87053-007', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28230, 'Maringá', 'Pioneiro Shigueo Arai', 'Conjunto João de Barro I', '87053-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28231, 'Maringá', 'Pioneiro Simão Romero', 'Vila Esperança', '87020-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28232, 'Maringá', 'Pioneiro Stephano Bianchini', 'Jardim Liberdade', '87047-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28233, 'Maringá', 'Pioneiro Targino Pereira da Silva', 'Jardim Porto Seguro', '87055-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28234, 'Maringá', 'Pioneiro Teodoro Negri', 'Conjunto Habitacional João de Barro Thaís', '87075-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28235, 'Paranavaí', 'Pioneiro Tonhão', 'Jardim Satélite', '87711-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28236, 'Maringá', 'Pioneiro Tranquillo Borghi', 'Copacabana Residencial', '87023-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28237, 'Maringá', 'Pioneiro Valdo Pessuto', 'Conjunto Habitacional Requião', '87047-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28238, 'Maringá', 'Pioneiro Valentim Zanin', 'Conjunto Habitacional Sol Nascente', '87055-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28239, 'Maringá', 'Pioneiro Victorio Gabriel', 'Jardim Santa Alice', '87040-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28240, 'Maringá', 'Pioneiro Victório Marcon', 'Distrito Industrial 2', '87065-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28241, 'Maringá', 'Pioneiro Virgílio Acelino Cardoso', 'Vila Santa Izabel', '87080-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28242, 'Maringá', 'Pioneiro Vitório Barison', 'Jardim São Jorge', '87080-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28243, 'Maringá', 'Pioneiro Waldemar Antônio Soares', 'Parque Residencial Quebec', '87023-436', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28244, 'Maringá', 'Pioneiro Waldemar Gomes da Cunha', 'Jardim San Remo', '87060-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28245, 'Maringá', 'Pioneiro Waldemar Lingiardi', 'Jardim Cerro Azul', '87010-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28246, 'Maringá', 'Pioneiro Waldemar Pulzatto', 'Jardim Brasil', '87083-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28247, 'Maringá', 'Pioneiro Waldomiro Beloti', 'Jardim Itaipu', '87065-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28248, 'Maringá', 'Pioneiro Waldomiro Borghi', 'Parque Tarumã', '87053-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28249, 'Maringá', 'Pioneiro Yoshito Ueda', 'Conjunto Residencial Cidade Alta', '87053-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28250, 'Francisco Beltrão', 'Pioneiros', 'Padre Eurico', '85604-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28251, 'Cascavel', 'Pioneiros', 'Parque Verde', '85807-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28252, 'Sarandi', 'Pionner', 'Jardim Universal', '87114-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28253, 'Campo Largo', 'Piotto', 'Loteamento Ouro Verde I', '83606-510', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28254, 'Londrina', 'Piquia', 'Santa Rita 1', '86071-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28255, 'Londrina', 'Piquiri', 'Jardim Ideal', '86025-345', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28256, 'Londrina', 'Piquiri', 'Vila Balarotti', '86025-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28257, 'Francisco Beltrão', 'Piquiri', 'São Miguel', '85602-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28258, 'Foz do Iguaçu', 'Piquiri', 'Conjunto Libra', '85857-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28259, 'Pato Branco', 'Piquiri', 'Pinheirinho', '85506-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28260, 'Sarandi', 'Piquiri', 'Jardim Primavera', '87111-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28261, 'Araucária', 'Piquiri', 'Iguaçu', '83701-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28262, 'Cascavel', 'Piquiri', 'São Cristóvão', '85813-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28263, 'Cascavel', 'Piquiri', 'Brasmadeira', '85814-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28264, 'Cascavel', 'Piquiri', 'Centro', '85812-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28265, 'Curitiba', 'Piquiri', 'Rebouças', '80230-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28266, 'Campo Mourão', 'Piquirivaí', 'Jardim Lar Paraná', '87305-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28267, 'Foz do Iguaçu', 'Pira', 'Conjunto A', '85860-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28268, 'Maringá', 'Piracanjuvas', 'Jardim Itaipu', '87065-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28269, 'Londrina', 'Piracema', 'San Fernando', '86040-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28270, 'Foz do Iguaçu', 'Piracicaba', 'Jardim Lancaster I', '85869-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28271, 'Guarapuava', 'Piracicaba', 'Santana', '85070-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28272, 'Francisco Beltrão', 'Piracicaba', 'Pinheirinho', '85603-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28273, 'Londrina', 'Piracicaba', 'San Remo', '86062-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28274, 'Cambé', 'Piracicaba', 'Jardim São Paulo', '86191-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28275, 'Apucarana', 'Pirahi', 'Vila Brasil', '86800-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28276, 'Foz do Iguaçu', 'Piraí', 'Conjunto Libra', '85857-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28277, 'Ponta Grossa', 'Pirai do Sul', 'Nova Rússia', '84053-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28278, 'São José dos Pinhais', 'Piraí do Sul', 'Afonso Pena', '83045-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28279, 'Telêmaco Borba', 'Piraí do Sul', 'Área 02', '84267-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28280, 'Colombo', 'Piraí do Sul', 'Vila São José', '83410-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28281, 'Curitiba', 'Piraí do Sul', 'Cidade Industrial', '81290-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28282, 'Foz do Iguaçu', 'Piraíba', 'Conjunto A', '85860-030', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28283, 'Foz do Iguaçu', 'Pirapara', 'Profilurb I', '85855-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28284, 'Foz do Iguaçu', 'Pirapitinga', 'Profilurb II', '85855-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28285, 'Pinhais', 'Pirapitinga', 'Loteamento Alphaville Graciosa', '83327-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28287, 'Foz do Iguaçu', 'Pirapó', 'Vila Carima', '85855-687', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28288, 'Maringá', 'Pirapó', 'Vila Esperança', '87020-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28289, 'Umuarama', 'Pirapó', 'Zona IV', '87504-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28290, 'Umuarama', 'Pirapó', 'Zona I-A', '87502-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28291, 'Araucária', 'Pirapó', 'Campina da Barra', '83709-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28292, 'Apucarana', 'Pirapó', 'Barra Funda', '86800-500', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28293, 'Paranaguá', 'Pirapora', 'Santos Dumont', '83209-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28294, 'Guarapuava', 'Piraquara', 'Boqueirão', '85022-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28295, 'Foz do Iguaçu', 'Piraquara', 'Jardim Belvedere I', '85867-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28296, 'Piraquara', 'Piraquara', 'Chácara Águas Claras', '83308-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28297, 'Pato Branco', 'Piraquara', 'Menino Deus', '85502-125', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28298, 'Ponta Grossa', 'Piraquara', 'Oficinas', '84036-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28299, 'Piraquara', 'Piraquara', 'Planta York', '83307-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28300, 'Almirante Tamandaré', 'Piraquara', 'Jardim Roma', '83504-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28301, 'Colombo', 'Piraquara', 'Jardim La Paloma', '83412-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28302, 'Curitiba', 'Piraquara', 'Sítio Cercado', '81910-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28303, 'Foz do Iguaçu', 'Pirarucu', 'Profilurb I', '85855-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28304, 'Francisco Beltrão', 'Pirassununga', 'Pinheirinho', '85603-520', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28305, 'Cambé', 'Piratinga', 'Jardim São Paulo', '86191-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28306, 'Foz do Iguaçu', 'Piratini', 'Jardim Itamaraty', '85863-410', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28307, 'Toledo', 'Piratini', 'Vila Brasil', '85909-629', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28308, 'Toledo', 'Piratini', 'Centro', '85901-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28309, 'Toledo', 'Piratini', 'Centro', '85901-280', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28310, 'Maringá', 'Piratininga', 'Zona 01', '87013-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28311, 'Apucarana', 'Piratininga', 'Jardim Alvorada', '86805-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28312, 'Apucarana', 'Piratininga', 'Jardim Ponta Grossa', '86804-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28313, 'Francisco Beltrão', 'Piratuba', 'Pinheirinho', '85603-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28314, 'Maringá', 'Pires Pardinho', 'Zona 05', '87015-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28315, 'Francisco Beltrão', 'Piriquito', 'Padre Ulrico', '85604-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28316, 'Campo Mourão', 'Piriquito', 'Conjunto Habitacional Milton Luiz Pereira', '87306-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28317, 'Apucarana', 'Piriquito', 'Recanto das Araras', '86812-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28318, 'Laranjeiras do Sul', 'Piriquitos', 'Vila Industrial', '85303-597', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28319, 'Londrina', 'Pisa', 'Parque Residencial João Piza', '86041-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28320, 'Cambé', 'Pisa', 'Jardim Montecatini', '86186-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28321, 'Curitiba', 'Pisa', 'Santa Felicidade', '82020-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28322, 'Londrina', 'Pistóia', 'Canadá', '86020-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28323, 'Londrina', 'Pitágoras', 'Califórnia', '86040-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28324, 'São José dos Pinhais', 'Pitágoras', 'Aristocrata', '83030-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28325, 'Cascavel', 'Pitágoras', 'Interlagos', '85814-385', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28326, 'Colombo', 'Pitágoras', 'Jardim Campo Alto', '83408-130', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28327, 'Curitiba', 'Pitágoras', 'Santa Cândida', '82630-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28328, 'Laranjeiras do Sul', 'Pitanga', 'Água Verde', '85302-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28329, 'Francisco Beltrão', 'Pitanga', 'Marrecas', '85601-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28330, 'Laranjeiras do Sul', 'Pitanga', 'São Francisco', '85303-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28331, 'Guarapuava', 'Pitanga', 'Bonsucesso', '85045-795', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28332, 'Ponta Grossa', 'Pitanga', 'Chapada', '84062-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28333, 'Maringá', 'Pitanga', 'Jardim Tropical', '87080-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28334, 'Pinhais', 'Pitanga', 'Vila Emiliano Perneta', '83324-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28335, 'Telêmaco Borba', 'Pitanga', 'Jardim Bonavila', '84264-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28336, 'Toledo', 'Pitanga', 'Jardim Paulista', '85909-086', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28337, 'São José dos Pinhais', 'Pitanga', 'Ouro Fino', '83015-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28338, 'Apucarana', 'Pitanga', 'Vila Flamboyant', '86804-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28339, 'Campo Mourão', 'Pitanga', 'Centro', '87301-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28340, 'Campo Mourão', 'Pitanga', 'Centro', '87302-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28341, 'Curitiba', 'Pitangas', 'Uberaba', '81560-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28342, 'Curitiba', 'Pitangua', 'São Braz', '82015-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28343, 'Francisco Beltrão', 'Pitangueira', 'São Cristóvão', '85601-358', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28344, 'Ponta Grossa', 'Pitangueira', 'Contorno', '84061-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28345, 'Cascavel', 'Pitangueira', 'Recanto Tropical', '85807-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28346, 'Londrina', 'Pitangueiras', 'Panorama', '86035-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28347, 'Apucarana', 'Pitangueiras', 'Jardim Guarujá', '86807-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28348, 'Londrina', 'Pitangui', 'Jardim Shinzato', '86027-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28349, 'Curitiba', 'Pitomba', 'Uberaba', '81540-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28350, 'Arapongas', 'Piuí-de-topete', 'Jardim São Bento', '86706-738', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28351, 'Umuarama', 'Piúna', 'Zona I', '87501-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28352, 'Arapongas', 'Piu-piu', 'Jardim Santo Antônio', '86705-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28353, 'Foz do Iguaçu', 'Pixinguinha', 'Conjunto Habitacional Plazza', '85862-226', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28354, 'Londrina', 'Pixinguinha', 'Meton', '86035-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28355, 'Pinhais', 'Pixinguinha', 'Vila Maria Antonieta', '83331-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28356, 'Maringá', 'Pixinguinha', 'Conjunto Residencial Cidade Alta', '87053-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28357, 'Cascavel', 'Pixinguinha', 'Brasília', '85815-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28358, 'Apucarana', 'Pixinguinha', 'Núcleo Habitacional Castelo Branco', '86812-336', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28359, 'Arapongas', 'Pixoxó', 'Jardim Aeroporto', '86702-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28360, 'Londrina', 'Placedino de Castro', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28361, 'Curitiba', 'Plácida Thomazi Zanoto', 'Prado Velho', '80215-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28362, 'Londrina', 'Plácido Carmagnani', 'San Izidro', '86040-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28363, 'Curitiba', 'Plácido de Castro', 'Guabirotuba', '81510-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28364, 'Almirante Tamandaré', 'Plácido Gomes', 'Planta Vila Rica', '83507-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28365, 'Curitiba', 'Plácido Gonçalves', 'Boqueirão', '81670-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28366, 'Cascavel', 'Plácido Mascarello', 'Santa Cruz', '85806-747', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28367, 'Curitiba', 'Plácido Prevedello', 'Ahú', '82200-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28368, 'Arapongas', 'Planadeira', 'Parque Veneza', '86701-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28369, 'Ponta Grossa', 'Planador', 'Cará-cará', '84043-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28370, 'Guarapuava', 'Planaltina', 'Boqueirão', '85022-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28371, 'Francisco Beltrão', 'Planalto', 'Marrecas', '85601-178', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28372, 'Foz do Iguaçu', 'Planalto', 'Jardim das Palmeiras', '85869-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28373, 'Foz do Iguaçu', 'Planalto', 'Jardim Itaipu', '85867-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28374, 'Maringá', 'Planalto', 'Residencial Ibirapuera', '87045-728', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28375, 'Telêmaco Borba', 'Planalto', 'Vila São José', '84263-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28376, 'São José dos Pinhais', 'Planalto', 'Ouro Fino', '83015-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28377, 'Cambé', 'Planalto', 'Parque Residencial Cambé', '86191-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28378, 'Cascavel', 'Planalto', 'Presidente', '85818-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28379, 'Curitiba', 'Planalto', 'Sítio Cercado', '81910-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28380, 'Cambé', 'Planalto Verde', 'Jardim Planalto Verde', '86192-380', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28382, 'São José dos Pinhais', 'Platão', 'Aristocrata', '83030-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28383, 'Cascavel', 'Platão', 'Interlagos', '85814-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28384, 'Colombo', 'Platão', 'Jardim Campo Alto', '83408-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28385, 'Curitiba', 'Platão', 'Barreirinha', '82700-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28386, 'Foz do Iguaçu', 'Platina', 'Parque Ouro Verde', '85854-040', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28387, 'Apucarana', 'Platina', 'Vila Agari', '86808-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28388, 'Curitiba', 'Plínio Algacyr Montanari', 'Uberaba', '81560-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28389, 'Curitiba', 'Plínio Barroso de Castro', 'Jardim Botânico', '80215-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28390, 'Ponta Grossa', 'Plínio Cezarotti', 'Uvaranas', '84031-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28391, 'Cambé', 'Plínio Corrêa de Araújo', 'Jardim Riviera', '86187-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28392, 'Almirante Tamandaré', 'Plínio Francisco Donel', 'Planta São João', '83514-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28393, 'Londrina', 'Plínio Maranho', 'Conjunto Professora Hilda Mandarino', '86080-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28394, 'Curitiba', 'Plínio Marinoni', 'Boqueirão', '81730-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28395, 'Ponta Grossa', 'Plínio Marques', 'Neves', '84020-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28396, 'Guarapuava', 'Plínio Salgado', 'Vila Bela', '85027-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28397, 'Cascavel', 'Plínio Salgado', 'Vila Tolentino', '85802-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28398, 'Curitiba', 'Plínio Tourinho', 'Jardim Botânico', '80215-120', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28399, 'Foz do Iguaçu', 'Plutão', 'Parque Residencial Três Fronteiras', '85859-677', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28400, 'Maringá', 'Plutão', 'Jardim Imperial II', '87023-006', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28401, 'Londrina', 'Plutão', 'Sol', '86070-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28402, 'Sarandi', 'Plutão', 'Jardim Universal', '87114-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28403, 'Cambé', 'Plutão', 'Parque Maracanã', '86185-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28404, 'Curitiba', 'Plutão', 'Sítio Cercado', '81910-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28405, 'Apucarana', 'Plutônio', 'Parque Industrial Zona Norte', '86806-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28406, 'Londrina', 'Poços de Caldas', 'Amaro', '86062-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28407, 'Foz do Iguaçu', 'Poços de Caldas', 'Jardim Lancaster I', '85869-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28408, 'Maringá', 'Poços de Caldas', 'Jardim Alvorada', '87033-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28409, 'Umuarama', 'Poços de Caldas', 'Parque Tarumã', '87508-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28410, 'Campo Largo', 'Poços de Caldas', 'Jardim Rivabem', '83605-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28411, 'Almirante Tamandaré', 'Poços de Caldas', 'Jardim Itamarati', '83505-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28412, 'Arapongas', 'Podargo', 'Vila Bernardes', '86705-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28413, 'Cascavel', 'Poente do Sol', 'Brasmadeira', '85814-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28414, 'Maringá', 'Poeta Ávares de Azevedo', 'Parque Avenida', '87025-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28415, 'Curitiba', 'Poeta Bernardo Guimarães', 'Tatuquara', '81470-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28416, 'Maringá', 'Poeta Carlos Drumond de Andrade', 'Parque Avenida', '87025-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28417, 'Maringá', 'Poeta Cruz e Souza', 'Parque Avenida', '87025-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28418, 'Curitiba', 'Poeta Francisco Ferreira Leite', 'Cristo Rei', '80050-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28419, 'Maringá', 'Poeta Gonçalves Dias', 'Conjunto Habitacional Itatiaia', '87045-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28420, 'Curitiba', 'Poeta Ildefonso Correia de Serro Azul', 'Cristo Rei', '80050-670', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28421, 'Curitiba', 'Poeta Leonardo Henke', 'Hugo Lange', '80040-400', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28422, 'Maringá', 'Poeta Mário de Andrade', 'Conjunto Habitacional Itatiaia', '87045-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28423, 'Maringá', 'Poeta Olavo Bilac', 'Jardim Liberdade', '87047-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28424, 'Ponta Grossa', 'Poeta Paulo Leminski', 'Contorno', '84061-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28425, 'Maringá', 'Poeta Paulo Leminski Filho', 'Jardim Itaipu', '87065-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28426, 'Curitiba', 'Poeta Sidônio Muralha', 'São Braz', '82015-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28427, 'Maringá', 'Poetisa Cora Coralina', 'Parque Avenida', '87025-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28428, 'Foz do Iguaçu', 'Pojuca', 'Loteamento Witt', '85862-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28429, 'Guarapuava', 'Polan Dunin', 'Industrial', '85045-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28430, 'Arapongas', 'Poleiro-triste', 'Conjunto Novo Centauro', '86709-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28431, 'Toledo', 'Polenice Genari', 'Centro', '85901-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28432, 'Maringá', 'Políbio Fagundes Neves', 'Jardim Alvorada', '87035-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28433, 'Maringá', 'Policial Dulci Juvêncio', 'Conjunto Habitacional Requião', '87047-466', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28434, 'Pinhais', 'Pólo Sul', 'Vila Irene Margarida', '83323-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28435, 'Foz do Iguaçu', 'Polônia', 'Jardim Europa', '85859-327', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28436, 'Guarapuava', 'Polônia', 'Industrial', '85053-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28437, 'Londrina', 'Polônia', 'Jardim Adriana II', '86046-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28438, 'Ponta Grossa', 'Polônia', 'Oficinas', '84036-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28439, 'Almirante Tamandaré', 'Polônia', 'Jardim Natal', '83505-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28440, 'Cambé', 'Polônia', 'Jardim Morada do Sol', '86181-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28441, 'Curitiba', 'Polysu', 'Juvevê', '80530-330', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28442, 'Araucária', 'Pomba', 'Capela Velha', '83706-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28443, 'Arapongas', 'Pomba-asa-branca', 'Conjunto Novo Centauro', '86709-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28444, 'Arapongas', 'Pomba-branca', 'Jardim Petrópolis', '86709-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28445, 'Arapongas', 'Pomba-do-cabo', 'Jardim Aeroporto', '86702-226', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28446, 'Arapongas', 'Pomba-do-mar', 'Jardim Petrópolis', '86709-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28447, 'Maringá', 'Pombal', 'Zona 03', '87050-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28448, 'Foz do Iguaçu', 'Pombas', 'Portal da Foz', '85859-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28449, 'Arapongas', 'Pomba-troncal', 'Centro', '86705-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28450, 'Arapongas', 'Pombo-correio', 'Jardim Bandeirantes', '86703-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28451, 'Cascavel', 'Pombo-correio', 'Floresta', '85814-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28452, 'Colombo', 'Pompeia', 'Centro Industrial Mauá', '83413-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28453, 'Cambé', 'Pompéia', 'Jardim São Paulo', '86191-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28454, 'Foz do Iguaçu', 'Pompeu de Toledo', 'Jardim São Miguel', '85858-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28455, 'Londrina', 'Pompeu Soares Cardoso', 'Jardim das Palmeiras', '86083-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28456, 'Umuarama', 'Pompílio Paulino de Lira', 'Parque Industrial I', '87507-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28457, 'Cambé', 'Poncã', 'Planta São Francisco', '86182-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28458, 'Guarapuava', 'Ponciano Honorato de Araújo', 'São Cristóvão', '85063-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28459, 'Londrina', 'Ponta Grossa', 'Dom Bosco', '86060-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28460, 'Francisco Beltrão', 'Ponta Grossa', 'Presidente Kennedy', '85605-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28461, 'Guarapuava', 'Ponta Grossa', 'Bonsucesso', '85045-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28462, 'Francisco Beltrão', 'Ponta Grossa', 'Centro', '85601-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28463, 'Laranjeiras do Sul', 'Ponta Grossa', 'São Francisco', '85303-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28464, 'Piraquara', 'Ponta Grossa', 'Planta Araçatuba', '83301-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28465, 'Maringá', 'Ponta Grossa', 'Zona 08', '87050-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28466, 'Telêmaco Borba', 'Ponta Grossa', 'Nossa Senhora do Perpétuo Socorro', '84265-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28467, 'Toledo', 'Ponta Grossa', 'Jardim Carelli', '85906-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28468, 'São José dos Pinhais', 'Ponta Grossa', 'Cruzeiro', '83010-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28469, 'Cambé', 'Ponta Grossa', 'Jardim Ana Eliza', '86187-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28471, 'Colombo', 'Ponta Grossa', 'Jardim Cristina', '83410-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28472, 'Araucária', 'Ponta Grossa', 'Iguaçu', '83701-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28473, 'Campo Mourão', 'Ponta Grossa', 'Jardim Tropical II', '87310-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28474, 'Almirante Tamandaré', 'Ponta Grossa', 'Jardim Taíza', '83505-136', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28475, 'Apucarana', 'Ponta Grossa', 'Centro', '86800-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28476, 'Curitiba', 'Ponta Grossa', 'Portão', '80610-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28477, 'Foz do Iguaçu', 'Ponta Porã', 'Jardim Duarte', '85861-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28478, 'Sarandi', 'Ponta Porã', 'Jardim Itamaraty', '87112-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28479, 'Foz do Iguaçu', 'Pontal', 'Loteamento Campos do Iguaçu', '85857-370', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28480, 'Toledo', 'Pontal', 'Boa Esperança', '85909-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28481, 'Umuarama', 'Pontal do Sul', 'Jardim Ipanema', '87508-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28482, 'Almirante Tamandaré', 'Pontal do Sul', 'Jardim Tamboara', '83505-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28483, 'Cascavel', 'Pontal do Sul', 'Periolo', '85817-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28484, 'Almirante Tamandaré', 'Ponte Nova', 'Jardim Itamarati', '83505-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28485, 'Curitiba', 'Ponte Serrada', 'São Braz', '82015-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28486, 'Colombo', 'Pontes de Miranda', 'Centro', '83414-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28487, 'Cascavel', 'Pontes de Miranda', 'São Cristóvão', '85816-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28488, 'Ponta Grossa', 'Pontes Lemes', 'Uvaranas', '84030-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28489, 'Foz do Iguaçu', 'Pôr do Sol', 'Jardim São Paulo II', '85856-430', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28490, 'Foz do Iguaçu', 'Pôr do Sol', 'Conjunto Libra', '85857-620', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28491, 'Foz do Iguaçu', 'Pôr do Sol', 'Jardim Alice I', '85858-255', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28492, 'Foz do Iguaçu', 'Pôr do Sol', 'Conjunto B', '85867-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28493, 'Campo Largo', 'Porcelana', 'Vila Itaqui', '83604-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28494, 'Guarapuava', 'Porecatu', 'Boqueirão', '85022-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28495, 'Foz do Iguaçu', 'Porecatu', 'Vila Carima', '85855-686', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28496, 'Ponta Grossa', 'Porecatu', 'Nova Rússia', '84053-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28497, 'Pinhais', 'Porecatu', 'Jardim Dona Joaquina I', '83325-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28498, 'Colombo', 'Porecatu', 'Jardim das Oliveiras', '83407-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28499, 'Cambé', 'Porecatu', 'Jardim Ana Eliza', '86187-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28500, 'Curitiba', 'Porecatu', 'Sítio Cercado', '81900-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28501, 'Arapongas', 'Porfírio', 'Vila Industrial', '86706-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28502, 'Campo Mourão', 'Porfírio Querino Pereira', 'Jardim Modelo', '87309-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28503, 'Pato Branco', 'Poriquis', 'Pinheirinho', '85506-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28504, 'Telêmaco Borba', 'Pororoca', 'Jardim Adriane', '84272-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28505, 'Curitiba', 'Portão', 'Portão', '80610-340', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28506, 'Telêmaco Borba', 'Porteira Grande', 'Área 02', '84267-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28507, 'Telêmaco Borba', 'Portela', 'Vila Cristina', '84272-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28508, 'Londrina', 'Porto', 'Parque Residencial João Piza', '86041-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28509, 'Londrina', 'Porto Alegre', 'Jardim Agari', '86020-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28510, 'Laranjeiras do Sul', 'Porto Alegre', 'Água Verde', '85302-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28511, 'Guarapuava', 'Porto Alegre', 'Jardim das Américas', '85030-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28512, 'Francisco Beltrão', 'Porto Alegre', 'Marrecas', '85601-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28513, 'Foz do Iguaçu', 'Porto Alegre', 'Jardim das Laranjeiras', '85868-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28514, 'Foz do Iguaçu', 'Porto Alegre', 'Conjunto C', '85870-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28515, 'Pinhais', 'Porto Alegre', 'Conjunto Residencial Renato Bonilauri', '83325-470', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28516, 'Piraquara', 'Porto Alegre', 'Vila Vicente Macedo', '83303-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28517, 'Maringá', 'Porto Alegre', 'Vila Morangueira', '87040-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28518, 'Toledo', 'Porto Alegre', 'Jardim Porto Alegre', '85906-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28519, 'Sarandi', 'Porto Alegre', 'Jardim Escala', '87114-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28520, 'São José dos Pinhais', 'Porto Alegre', 'Ouro Fino', '83015-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28521, 'Telêmaco Borba', 'Porto Alegre', 'Macopa', '84263-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28522, 'Umuarama', 'Porto Alegre', 'Zona V', '87504-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28523, 'Almirante Tamandaré', 'Porto Alegre', 'Jardim Gramados', '83504-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28524, 'Cascavel', 'Porto Alegre', 'Pioneiros Catarinenses', '85805-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28525, 'Cambé', 'Porto Alegre', 'Vila Mesquita', '86182-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28526, 'Campo Mourão', 'Porto Alegre', 'Vila Rio Grande', '87302-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28527, 'Colombo', 'Porto Alegre do Norte', 'Jardim Curitiba', '83406-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28528, 'Colombo', 'Porto Alegre do Sul', 'Jardim Curitiba', '83406-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28529, 'Guarapuava', 'Porto Amazonas', 'Boqueirão', '85022-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28530, 'Paranaguá', 'Porto Amazonas', 'Vila Paranaguá', '83221-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28531, 'Ponta Grossa', 'Porto Amazonas', 'Oficinas', '84036-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28532, 'Colombo', 'Porto Amazonas', 'Jardim Cristina III', '83410-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28533, 'Curitiba', 'Porto Amazonas', 'Cidade Industrial', '81240-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28534, 'Maringá', 'Porto Primavera', 'Parque das Grevíleas', '87025-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28535, 'Guarapuava', 'Porto Rico', 'Dos Estados', '85035-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28536, 'Pinhais', 'Porto Rico', 'Jardim Atuba I', '83326-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28537, 'São José dos Pinhais', 'Porto Rico', 'Boneca do Iguaçu', '83040-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28538, 'Apucarana', 'Porto Rico', 'Núcleo Habitacional Vale Verde', '86805-249', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28539, 'Colombo', 'Porto Rico', 'Vila Marcelina', '83404-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28540, 'Curitiba', 'Porto Rico', 'Sítio Cercado', '81925-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28541, 'Laranjeiras do Sul', 'Porto Santana', 'São Francisco', '85303-346', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28542, 'Maringá', 'Porto Seguro', 'Conjunto João de Barro Itaparica', '87043-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28543, 'Umuarama', 'Porto Seguro', 'Jardim San Rafael', '87508-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28544, 'Telêmaco Borba', 'Porto Seguro', 'Centro', '84261-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28545, 'Almirante Tamandaré', 'Porto Seguro', 'Jardim Miragem', '83505-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28546, 'Guarapuava', 'Porto União', 'Jardim das Américas', '85030-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28547, 'Francisco Beltrão', 'Porto União', 'Miniguaçu', '85605-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28548, 'Laranjeiras do Sul', 'Porto União', 'Água Verde', '85302-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28549, 'Toledo', 'Porto União', 'Jardim Porto Alegre', '85906-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28550, 'São José dos Pinhais', 'Porto União', 'São Sebastião', '83075-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28551, 'Campo Mourão', 'Porto União', 'Jardim Santa Nilce II', '87308-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28552, 'Almirante Tamandaré', 'Porto União', 'Jardim Apucarana', '83505-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28553, 'Cascavel', 'Porto União', 'Universitário', '85819-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28554, 'Curitiba', 'Porto União', 'Cidade Industrial', '81240-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28555, 'Guarapuava', 'Porto Velho', 'Conradinho', '85055-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28556, 'Maringá', 'Porto Velho', 'Jardim Social', '87010-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28557, 'Pinhais', 'Porto Velho', 'Conjunto Residencial Renato Bonilauri', '83325-460', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28558, 'Telêmaco Borba', 'Porto Velho', 'Vila Esperança', '84272-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28559, 'São José dos Pinhais', 'Porto Velho', 'Costeira', '83015-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28560, 'Cascavel', 'Porto Velho', 'São Cristóvão', '85816-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28561, 'Campo Mourão', 'Porto Velho', 'Jardim Santa Nilce II', '87308-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28562, 'Guarapuava', 'Porto Vitória', 'Jardim das Américas', '85031-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28563, 'Paranaguá', 'Portuária', 'Dom Pedro II', '83221-570', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28564, 'Guarapuava', 'Portugal', 'Industrial', '85053-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28565, 'Londrina', 'Portugal', 'Igapó', '86046-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28566, 'Ponta Grossa', 'Portugal', 'Oficinas', '84036-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28567, 'Sarandi', 'Portugal', 'Jardim Europa', '87111-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28568, 'Toledo', 'Portugal', 'Jardim Bandeirantes', '85906-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28569, 'Umuarama', 'Portugal', 'Zona I-A', '87504-530', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28570, 'Cascavel', 'Portugal', 'Cascavel Velho', '85818-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28571, 'Almirante Tamandaré', 'Portugal', 'Vila Emerentina', '83505-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28572, 'Colombo', 'Portugal', 'Parque Monte Castelo', '83409-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28573, 'Cambé', 'Portugal', 'Centro', '86181-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28574, 'Curitiba', 'Portugal', 'São Francisco', '80510-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28575, 'Curitiba', 'Portugal', 'Alto da Glória', '80030-170', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28576, 'Pato Branco', 'Possidio Salomoni', 'Cristo Rei', '85506-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28577, 'Ponta Grossa', 'Possidônio da Cunha Santos', 'Uvaranas', '84031-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28578, 'Londrina', 'Possidônio da Silva', 'Parigot de Souza 2', '86082-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28579, 'Londrina', 'Poti', 'Amália', '86027-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28580, 'Cascavel', 'Poti', 'Periolo', '85817-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28581, 'Colombo', 'Poti', 'Jardim Curitiba', '83406-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28582, 'Paranaguá', 'Potiguara', 'Vila Guarani', '83221-486', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28583, 'Cascavel', 'Potiguara', 'Santo Onofre', '85806-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28584, 'Foz do Iguaçu', 'Potiguaras', 'Jardim Tarobá', '85856-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28585, 'Londrina', 'Potiguares', 'Vila Paglia', '86026-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28586, 'Araucária', 'Potinga', 'Iguaçu', '83701-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28587, 'Almirante Tamandaré', 'Potira Rosina Saldanha Machado', 'Jardim Novo Horizonte da Cachoeira', '83502-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28588, 'Almirante Tamandaré', 'Pouso Alegre', 'Vila Feliz', '83505-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28589, 'Ponta Grossa', 'PR-11', 'Palmeirinha', '84072-010', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28590, 'Ponta Grossa', 'PR-11', 'Colônia Dona Luiza', '84043-440', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28591, 'Ponta Grossa', 'PR-151', 'Colônia Dona Luiza', '84043-460', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28592, 'Ponta Grossa', 'PR-151', 'Boa Vista', '84072-190', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28593, 'Castro', 'PR-151', 'Bom Sucesso', '84165-700', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28594, 'Telêmaco Borba', 'PR-160', 'Área 01', '84267-450', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28595, 'Telêmaco Borba', 'PR-160', 'Área 01', '84268-310', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28596, 'Telêmaco Borba', 'PR-160', 'Área 02', '84269-090', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28597, 'Telêmaco Borba', 'PR-160', 'Jardim Bom Jesus', '84262-430', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28598, 'Guarapuava', 'PR-170', 'Boqueirão', '85023-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28599, 'Guarapuava', 'PR-170', 'Alto Cascavel', '85031-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28600, 'Guarapuava', 'PR-170', 'Vila Bela', '85027-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28601, 'Francisco Beltrão', 'PR-180', 'Pinheirinho', '85606-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28602, 'Toledo', 'PR-182', 'Jardim Porto Alegre', '85906-300', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28603, 'Cascavel', 'PR-182', 'Canadá', '85813-460', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28604, 'Arapongas', 'PR-218 Saída Pará Astorga', 'Jardim Universitário', '86702-670', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28605, 'São José dos Pinhais', 'PR-25', 'Miringuava', '83090-480', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28606, 'Pato Branco', 'PR-280', 'São Cristóvão', '85508-280', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28607, 'Maringá', 'PR-317', 'Parque Industrial 200', '87035-510', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28608, 'Maringá', 'PR-317', 'Jardim Alvorada', '87035-065', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28609, 'Campo Mourão', 'PR-317', 'Jardim Esperança', '87309-670', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28775, 'Cascavel', 'Presidente Bernardes', 'Centro', '85801-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28610, 'Maringá', 'PR-317 Saída para Campo Mourão', 'Parque Industrial', '87065-005', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28611, 'Umuarama', 'PR-323', 'Parque Industrial', '87507-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28612, 'Maringá', 'PR-323 Saída Pará Paissandu', 'Parque Industrial', '87065-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28613, 'Castro', 'PR-340 Saída Pará Castrolanda', 'Jardim Social Arapongas', '84174-150', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28614, 'Castro', 'PR-340 Saída Pará Tibagi', 'Bom Sucesso', '84165-720', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28615, 'Araucária', 'PR-421', 'Barigui', '83707-700', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28616, 'Araucária', 'PR-423', 'Costeira', '83708-710', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28617, 'Araucária', 'PR-423', 'Estação', '83705-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28618, 'Campo Largo', 'PR-423', 'Jardim Itaqui', '83604-160', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28619, 'Campo Largo', 'PR-423', 'Jardim Três Rios', '83603-000', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28620, 'Campo Largo', 'PR-423', 'Jardim Bela Vista', '83605-430', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28621, 'Arapongas', 'PR-444', 'Jardim Petrópolis', '86702-625', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28622, 'Cambé', 'PR-445', 'Jardim União', '86185-770', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28623, 'Cambé', 'PR-445', 'Parque Residencial Ana Rosa', '86183-600', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28624, 'Guarapuava', 'PR-466', 'Primavera', '85050-290', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28625, 'Pato Branco', 'PR-469', 'Fraron', '85503-390', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28626, 'Francisco Beltrão', 'PR-482', 'São Cristóvão', '85606-380', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28627, 'Francisco Beltrão', 'PR-483', 'Marrecas', '85601-195', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28628, 'Umuarama', 'PR-489', 'Jardim Universitário', '87508-210', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28629, 'Campo Mourão', 'PR-558 Saída para Araruna', 'Jardim P Campo', '87302-215', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28630, 'Toledo', 'PR-585', 'Jardim Recanto', '85915-090', 'Rodovia', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28631, 'Foz do Iguaçu', 'Praga', 'Jardim Alice', '85858-190', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28632, 'Ponta Grossa', 'Praia Barra Sul', 'Contorno', '84060-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28633, 'Ponta Grossa', 'Praia Barra Velha', 'Contorno', '84060-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28634, 'Ponta Grossa', 'Praia Boa Viagem', 'Contorno', '84060-658', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28635, 'Ponta Grossa', 'Praia da Areia Branca', 'Contorno', '84060-629', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28636, 'Ponta Grossa', 'Praia da Armação', 'Contorno', '84060-639', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28637, 'Londrina', 'Praia da Baleia', 'Parque Residencial Porto Serguro II', '86083-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28638, 'Ponta Grossa', 'Praia da Bandeira', 'Contorno', '84060-649', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28639, 'Londrina', 'Praia da Barra', 'Parque Residencial Porto Serguro II', '86083-506', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28640, 'Ponta Grossa', 'Praia da Gávea', 'Contorno', '84060-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28641, 'Ponta Grossa', 'Praia da Penha', 'Contorno', '84060-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28642, 'Ponta Grossa', 'Praia da Urca', 'Contorno', '84060-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28643, 'Ponta Grossa', 'Praia das Águas Claras', 'Contorno', '84060-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28644, 'Ponta Grossa', 'Praia das Neves', 'Contorno', '84060-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28645, 'Ponta Grossa', 'Praia de Belmonte', 'Contorno', '84060-667', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28646, 'Ponta Grossa', 'Praia de Bom Jesus', 'Contorno', '84060-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28647, 'Ponta Grossa', 'Praia de Copacabana', 'Contorno', '84060-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28648, 'Ponta Grossa', 'Praia de Coroa', 'Contorno', '84060-666', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28649, 'Ponta Grossa', 'Praia de Enseada', 'Contorno', '84060-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28650, 'Ponta Grossa', 'Praia de Guarujá', 'Contorno', '84060-669', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28651, 'Londrina', 'Praia de Ilhéus', 'Parque Residencial Porto Serguro II', '86083-509', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28652, 'Ponta Grossa', 'Praia de Ipanema', 'Contorno', '84060-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28653, 'Ponta Grossa', 'Praia de Itapoa', 'Contorno', '84060-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28654, 'Londrina', 'Praia de Itapuã', 'Parque Residencial Porto Serguro II', '86083-508', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28656, 'Cambé', 'Praia de Leste', 'Chácara Santa Maria', '86189-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28657, 'Almirante Tamandaré', 'Praia de Leste', 'Jardim Tamboara', '83505-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28658, 'Ponta Grossa', 'Praia de Santa Clara', 'Contorno', '84060-668', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28659, 'Ponta Grossa', 'Praia de Ubatuba', 'Contorno', '84060-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28660, 'Ponta Grossa', 'Praia dos Bandeirantes', 'Contorno', '84060-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28661, 'Ponta Grossa', 'Praia Lua Nova', 'Contorno', '84060-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28662, 'Ponta Grossa', 'Praia Mansa', 'Contorno', '84060-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28663, 'Ponta Grossa', 'Praia Porto Belo', 'Contorno', '84060-638', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28664, 'Ponta Grossa', 'Praia Porto de Pedras', 'Contorno', '84060-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28665, 'Ponta Grossa', 'Praia Riacho Doce', 'Contorno', '84060-659', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28666, 'Ponta Grossa', 'Praia Tropical', 'Contorno', '84060-648', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28667, 'Cascavel', 'Prainha', 'Cataratas', '85818-746', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28668, 'Francisco Beltrão', 'Pranchita', 'Marrecas', '85601-177', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28669, 'Londrina', 'Prata', 'Jardim São Francisco de Assis', '86067-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28670, 'Foz do Iguaçu', 'Prata', 'Parque Ouro Verde', '85854-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28671, 'Toledo', 'Prata', 'Vila Becker', '85902-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28672, 'Telêmaco Borba', 'Prata', 'Área 02', '84267-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28673, 'Umuarama', 'Prata', 'Conjunto Residencial Ouro Branco', '87508-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28674, 'Apucarana', 'Prata', 'Parque Industrial Zona Norte', '86806-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28675, 'Cascavel', 'Prates', 'Universitário', '85819-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28676, 'Curitiba', 'Praxedes Silva Avelleda', 'Santa Felicidade', '82410-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28677, 'Londrina', 'Precidônio de Oliveira', 'Jatobá', '86043-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28678, 'Curitiba', 'Precila Fronza', 'Pilarzinho', '82115-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28679, 'São José dos Pinhais', 'Preciliano Fernandes', 'Planta Quississana', '83085-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28680, 'Ponta Grossa', 'Prefeito Albary Guimarães', 'Contorno', '84060-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28681, 'Araucária', 'Prefeito Aleixo Grebos', 'Boqueirão', '83704-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28682, 'Laranjeiras do Sul', 'Prefeito Amantino Stephanes', 'Centro', '85301-317', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28683, 'Curitiba', 'Prefeito Ambrósio Bini', 'Capão Raso', '81020-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28684, 'Curitiba', 'Prefeito Ângelo Lopes', 'Alto da Rua XV', '80040-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28685, 'Curitiba', 'Prefeito Ângelo Lopes', 'Cristo Rei', '80050-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28686, 'Londrina', 'Prefeito Antônio Fernandes Sobrinho', 'Centro', '86010-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28687, 'Londrina', 'Prefeito Antônio Fernandes Sobrinho', 'Centro', '86010-440', 'Bosque', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28688, 'Guarapuava', 'Prefeito Antônio Lustosa de Oliveira', 'Morro Alto', '85065-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28689, 'Campo Mourão', 'Prefeito Antônio Teodoro de Oliveira', 'Jardim Santa Cruz', '87309-620', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28690, 'Ponta Grossa', 'Prefeito Brasílio Ribas', 'Orfãs', '84010-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28691, 'Ponta Grossa', 'Prefeito Brasílio Ribas', 'Orfãs', '84015-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28692, 'Telêmaco Borba', 'Prefeito Cacildo Batista de Arpelau', 'Centro', '84261-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28693, 'Ponta Grossa', 'Prefeito Campos Mello', 'Boa Vista', '84070-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28694, 'Ponta Grossa', 'Prefeito Coronel Victor Antônio Batista', 'Neves', '84020-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28695, 'Ponta Grossa', 'Prefeito Cyro Martins', 'Cará-cará', '84033-290', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28696, 'Campo Mourão', 'Prefeito Daniel Portela', 'Jardim Izabel', '87309-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28697, 'Campo Mourão', 'Prefeito Devete de Paula Xavier', 'Jardim Capricórnio', '87301-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28698, 'Campo Mourão', 'Prefeito Devete de Paula Xavier', 'Centro', '87302-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28699, 'Campo Mourão', 'Prefeito Doutor Horácio Amaral', 'Jardim Santa Cruz', '87309-630', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28700, 'Umuarama', 'Prefeito Durval Seifert', 'Parque San Caetano', '87506-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28701, 'São José dos Pinhais', 'Prefeito Elpídio Monteiro Espíndola', 'Bom Jesus', '83025-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28702, 'Curitiba', 'Prefeito Erasto Gaertner', 'Bacacheri', '82510-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28703, 'Curitiba', 'Prefeito Erasto Gaertner', 'Bacacheri', '82515-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28704, 'Londrina', 'Prefeito Faria Lima', 'Maringá', '86061-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28705, 'São José dos Pinhais', 'Prefeito Francisco Quirino dos Santos', 'Afonso Pena', '83045-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28706, 'Ponta Grossa', 'Prefeito Fulton Vitel Borges de Macedo', 'Neves', '84020-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28707, 'Londrina', 'Prefeito Goichi', 'Lima Azevedo', '86060-085', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28708, 'Pato Branco', 'Prefeito Graeff', 'Morro da Cruz', '85505-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28709, 'Londrina', 'Prefeito Hugo Cabral', 'Centro', '86020-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28710, 'Londrina', 'Prefeito Hugo Cabral', 'Centro', '86020-111', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28711, 'Campo Largo', 'Prefeito Ivai Martins', 'Bom Jesus', '83601-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28712, 'Colombo', 'Prefeito João Agripino Tosin', 'Centro', '83414-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28713, 'Colombo', 'Prefeito João Batista Stoco', 'Planta Bom Jesus', '83407-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28714, 'Curitiba', 'Prefeito João Moreira Garcez', 'Centro', '80020-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28715, 'São José dos Pinhais', 'Prefeito João Nester', 'Cidade Jardim', '83035-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28716, 'Campo Mourão', 'Prefeito José Antônio dos Santos', 'Jardim Cidade Nova', '87308-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28717, 'Ponta Grossa', 'Prefeito José Hoffmann', 'Boa Vista', '84071-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28718, 'Campo Largo', 'Prefeito José Salles Pinto', 'Jardim São Vicente', '83602-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28719, 'Curitiba', 'Prefeito Lothario Meissner', 'Jardim Botânico', '80210-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28720, 'Curitiba', 'Prefeito Maurício Fruet', 'Cajuru', '82900-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28721, 'Curitiba', 'Prefeito Maurício Fruet', 'Jardim Botânico', '80210-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28722, 'Curitiba', 'Prefeito Maurício Fruet', 'Cajuru', '82920-330', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28723, 'Londrina', 'Prefeito Milton Ribeiro Menezes', 'Conjunto Habitacional Doutor Farid Libos', '86087-620', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28724, 'Guarapuava', 'Prefeito Moacir Júlio Silvestre', 'Cascavel', '85025-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28725, 'Guarapuava', 'Prefeito Moacir Júlio Silvestre', 'Centro', '85010-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28726, 'Guarapuava', 'Prefeito Moacir Júlio Silvestre', 'Batel', '85015-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28727, 'Guarapuava', 'Prefeito Moacir Júlio Silvestri', 'Jardim das Américas', '85030-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28728, 'Araucária', 'Prefeito Odorico Franco Ferreira', 'Centro', '83702-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28729, 'Curitiba', 'Prefeito Omar Sabbag', 'Jardim Botânico', '80210-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28730, 'Campo Mourão', 'Prefeito Pedro Viriato de Souza Filho', 'Jardim Tropical I', '87310-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28731, 'Colombo', 'Prefeito Pio Alberti', 'Jardim Guanabara', '83403-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28732, 'Pato Branco', 'Prefeito Plácido Machado', 'Morro da Cruz', '85505-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28733, 'Campo Mourão', 'Prefeito Roberto Brzezinski', 'Jardim Maia', '87301-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28734, 'Campo Mourão', 'Prefeito Roberto Brzezinski', 'Centro', '87302-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28735, 'Castro', 'Prefeito Ronie Cardoso', 'Jardim das Araucárias', '84174-105', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28736, 'Castro', 'Prefeito Ronie Cardoso', 'Jardim Colonial', '84178-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28737, 'Paranaguá', 'Prefeito Roque Vernalha', 'Vila Paranaguá', '83221-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28738, 'Paranaguá', 'Prefeito Roque Vernalha', 'Itiberê', '83206-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28739, 'Curitiba', 'Prefeito Rosalvo Gomes Mello Leitão', 'Centro Cívico', '80530-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28740, 'Curitiba', 'Prefeito Samuel Mileo', 'Sítio Cercado', '81920-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28741, 'Laranjeiras do Sul', 'Prefeito Silvério Araújo', 'São Francisco', '85303-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28742, 'Curitiba', 'Prefeito Sílvio Barros', 'Pilarzinho', '80520-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28743, 'Maringá', 'Prefeito Sincler Sambatti', 'Jardim Itaipu', '87065-580', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28744, 'Maringá', 'Prefeito Sincler Sambatti', 'Jardim Universo', '87060-460', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28745, 'Maringá', 'Prefeito Sincler Sambatti', 'Jardim Ipanema', '87053-105', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28746, 'Maringá', 'Prefeito Sincler Sambatti', 'Jardim Bertioga', '87055-405', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28747, 'Pato Branco', 'Prefeito Tomazzoni', 'Morro da Cruz', '85505-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28748, 'Apucarana', 'Presbítero Benoni Rodrigues Moreira', 'Jardim Paraíso', '86812-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28749, 'Paranaguá', 'Presbítero da Lauro Fonseca', 'Conjunto Residencial Prefeito Cominese', '83215-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28750, 'Curitiba', 'Presbítero Deusdete dos Santos', 'Cachoeira', '82710-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28751, 'Campo Mourão', 'Presbítero José Domingos S. Filho', 'Jardim Country Club', '87300-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28752, 'Curitiba', 'Presbítero Waldemiro Miguel Cidral', 'Sítio Cercado', '81935-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28753, 'Paranaguá', 'Presciliano Corrêa', 'Centro Histórico', '83203-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28754, 'Ponta Grossa', 'Presciliano Negrão', 'Chapada', '84062-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28755, 'Londrina', 'Prescilina de Souza Santana', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28756, 'Londrina', 'Presidente Abraham Lincoln', 'Jardim dos Alpes III', '86049-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28757, 'Curitiba', 'Presidente Affonso Camargo', 'Jardim Botânico', '80060-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28758, 'Curitiba', 'Presidente Affonso Camargo', 'Capão da Imbuia', '82810-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28759, 'Curitiba', 'Presidente Affonso Camargo', 'Cristo Rei', '80050-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28760, 'Curitiba', 'Presidente Affonso Camargo', 'Capão da Imbuia', '82800-240', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28761, 'Cambé', 'Presidente Affonso Pena', 'Jardim Riviera', '86187-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28762, 'Colombo', 'Presidente Arthur Bernardes', 'Jardim Santa Mônica', '83412-600', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28763, 'Curitiba', 'Presidente Arthur da Silva Bernardes', 'Portão', '80320-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28764, 'Ponta Grossa', 'Presidente Artur Bernardes', 'Neves', '84020-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28765, 'Cambé', 'Presidente Artur Bernardes', 'Novo Bandeirantes', '86188-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28766, 'Guarapuava', 'Presidente Artur da Costa e Silva', 'Alto da XV', '85065-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28767, 'Maringá', 'Presidente Artur da Costa e Silva', 'Conjunto Residencial Itamaraty', '87015-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28768, 'Curitiba', 'Presidente Beaurepaire Rohan', 'Cristo Rei', '80050-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28769, 'Londrina', 'Presidente Bernardes', 'Andrade', '86061-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28770, 'Umuarama', 'Presidente Bernardes', 'Zona VI', '87503-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28771, 'Cascavel', 'Presidente Bernardes', 'Canadá', '85813-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28772, 'Cascavel', 'Presidente Bernardes', 'Centro', '85810-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28773, 'Cascavel', 'Presidente Bernardes', 'Vila Tolentino', '85802-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28774, 'Cascavel', 'Presidente Bernardes', 'Cancelli', '85811-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28776, 'Toledo', 'Presidente Café Filho', 'Jardim Filadélpia', '85902-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28777, 'Colombo', 'Presidente Café Filho', 'Jardim Santa Mônica', '83412-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28778, 'Londrina', 'Presidente Campos Salles', 'Paulista', '86025-225', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28779, 'Araucária', 'Presidente Carlos Cavalcanti', 'Centro', '83702-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28780, 'Curitiba', 'Presidente Carlos Cavalcanti', 'São Francisco', '80510-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28781, 'Curitiba', 'Presidente Carlos Cavalcanti', 'Centro', '80020-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28782, 'Toledo', 'Presidente Carlos Luz', 'Jardim Filadélpia', '85902-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28783, 'Guarapuava', 'Presidente Castelo Branco', 'Morro Alto', '85065-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28784, 'Londrina', 'Presidente Castelo Branco', 'Jardim Bandeirantes', '86061-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28785, 'Ponta Grossa', 'Presidente Castelo Branco', 'Uvaranas', '84030-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28786, 'Pato Branco', 'Presidente Castelo Branco', 'La Salle', '85505-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28787, 'Umuarama', 'Presidente Castelo Branco', 'Zona VI', '87503-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28788, 'Umuarama', 'Presidente Castelo Branco', 'Zona I', '87501-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28789, 'Cascavel', 'Presidente Castelo Branco', 'Parque São Paulo', '85803-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28790, 'Araucária', 'Presidente Castelo Branco', 'Thomaz Coelho', '83707-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28791, 'Colombo', 'Presidente Castelo Branco', 'Jardim Santa Mônica', '83412-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28792, 'Londrina', 'Presidente Costa e Silva', 'Caiçaras', '86015-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28793, 'Guarapuava', 'Presidente Costa e Silva', 'Morro Alto', '85065-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28794, 'Pato Branco', 'Presidente Costa e Silva', 'La Salle', '85505-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28795, 'Araucária', 'Presidente Costa e Silva', 'Campina da Barra', '83709-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28796, 'Cascavel', 'Presidente Costa e Silva', 'Coqueiral', '85807-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28797, 'Cascavel', 'Presidente Costa e Silva', 'Alto Alegre', '85805-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28798, 'Foz do Iguaçu', 'Presidente Creveland', 'Centro', '85851-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28799, 'Cambé', 'Presidente Delfim Moreira', 'Novo Bandeirantes', '86188-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28800, 'Toledo', 'Presidente Deodoro da Fonseca', 'Jardim Filadélpia', '85902-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28801, 'Curitiba', 'Presidente Eisenhower', 'Jardim Social', '82520-090', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28802, 'Cascavel', 'Presidente Emílio Garrastazu Médici', 'Presidente', '85818-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28803, 'Toledo', 'Presidente Emílio Médici', 'Jardim Maria do Carmo', '85906-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28804, 'Cambé', 'Presidente Epitácio Pessoa', 'Novo Bandeirantes', '86188-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28805, 'Curitiba', 'Presidente Epitácio Pessoa', 'Tarumã', '82530-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28806, 'Londrina', 'Presidente Eurico Gaspar Dutra', 'Cafezal 1', '86049-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28807, 'Araucária', 'Presidente Eurico Gaspar Dutra', 'Boqueirão', '83704-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28808, 'Colombo', 'Presidente Eurico Gaspar Dutra', 'Jardim Palmares', '83412-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28809, 'Colombo', 'Presidente Faria', 'Vila Rosemari Galvão', '83411-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28810, 'Curitiba', 'Presidente Faria', 'Centro', '80020-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28811, 'Guarapuava', 'Presidente Getúlio Vargas', 'Trianon', '85012-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28812, 'Francisco Beltrão', 'Presidente Getúlio Vargas', 'São Miguel', '85602-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28813, 'Guarapuava', 'Presidente Getúlio Vargas', 'Centro', '85010-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28814, 'Paranaguá', 'Presidente Getúlio Vargas', 'Estradinha', '83206-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28815, 'Paranaguá', 'Presidente Getúlio Vargas', 'Serraria do Rocha', '83221-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28816, 'Ponta Grossa', 'Presidente Getúlio Vargas', 'Nova Rússia', '84070-550', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28817, 'Toledo', 'Presidente Getúlio Vargas', 'Boa Esperança', '85909-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28818, 'Cambé', 'Presidente Getúlio Vargas', 'Jardim Silvino', '86188-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28819, 'Apucarana', 'Presidente Getúlio Vargas', 'Jardim Ponta Grossa', '86805-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28820, 'Campo Mourão', 'Presidente Getúlio Vargas', 'Jardim Corinthias', '87309-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28821, 'Curitiba', 'Presidente Getúlio Vargas', 'Água Verde', '80240-041', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28822, 'Curitiba', 'Presidente Getúlio Vargas', 'Rebouças', '80250-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28823, 'Curitiba', 'Presidente Getúlio Vargas', 'Água Verde', '80240-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28824, 'Curitiba', 'Presidente Getúlio Vargas', 'Rebouças', '80230-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28825, 'Apucarana', 'Presidente Hoover', 'Vila Santa Helena', '86810-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28826, 'Campo Mourão', 'Presidente Humberto de Alencar C. Branco', 'Jardim Nossa Senhora Aparecida', '87309-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28827, 'Maringá', 'Presidente Humberto de Alencar Castelo Branco', 'Zona 05', '87015-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28828, 'Apucarana', 'Presidente Jackson', 'Vila Santa Helena', '86810-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28829, 'Toledo', 'Presidente Jânio Quadros', 'Jardim Maria do Carmo', '85906-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28830, 'Apucarana', 'Presidente Jefferson', 'Jardim Iguatemi', '86810-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28831, 'Francisco Beltrão', 'Presidente João Goulart', 'São Miguel', '85602-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28832, 'Toledo', 'Presidente João Goulart', 'Jardim Filadélpia', '85902-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28833, 'Cascavel', 'Presidente João Goulart', 'Presidente', '85818-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28834, 'Curitiba', 'Presidente João Goulart', 'Tatuquara', '81470-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28835, 'Laranjeiras do Sul', 'Presidente John F. Kennedy', 'Centro', '85301-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28836, 'Laranjeiras do Sul', 'Presidente John F. Kennedy', 'Cristo Rei', '85304-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28837, 'Toledo', 'Presidente José Linhares', 'Jardim Filadélpia', '85902-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28838, 'Pato Branco', 'Presidente Juscelino', 'Santo Antônio', '85507-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28839, 'Laranjeiras do Sul', 'Presidente Juscelino Kubitschek', 'Centro', '85301-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28840, 'Cascavel', 'Presidente Juscelino Kubitschek', 'Coqueiral', '85807-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28841, 'Cascavel', 'Presidente Juscelino Kubitschek', 'Alto Alegre', '85805-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28842, 'Colombo', 'Presidente Juscelino Kubitschek', 'Jardim Santa Mônica', '83412-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28843, 'Paranavaí', 'Presidente Juscelino Kubitschek de Oliveira', 'Jardim Paulista', '87709-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28844, 'Maringá', 'Presidente Juscelino Kubitschek de Oliveira', 'Zona 02', '87010-440', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28845, 'Araucária', 'Presidente Juscelino Kubitschek de Oliveira', 'Boqueirão', '83704-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28846, 'Guarapuava', 'Presidente Kennedy', 'Santana', '85070-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28847, 'Maringá', 'Presidente Kennedy', 'Zona 01', '87013-240', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28848, 'Pato Branco', 'Presidente Kennedy', 'Bortot', '85504-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28849, 'Ponta Grossa', 'Presidente Kennedy', 'Contorno', '84062-016', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28850, 'Ponta Grossa', 'Presidente Kennedy', 'Contorno', '84061-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28851, 'Ponta Grossa', 'Presidente Kennedy', 'Contorno', '84060-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28852, 'Telêmaco Borba', 'Presidente Kennedy', 'Centro', '84261-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28853, 'Castro', 'Presidente Kennedy', 'Centro', '84165-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28854, 'Cascavel', 'Presidente Kennedy', 'Centro', '85810-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28855, 'Cascavel', 'Presidente Kennedy', 'Centro', '85810-041', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28856, 'Cascavel', 'Presidente Kennedy', 'Coqueiral', '85807-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28857, 'Cambé', 'Presidente Kennedy', 'Centro', '86181-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28858, 'Apucarana', 'Presidente Kennedy', 'Centro', '86800-235', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28859, 'Curitiba', 'Presidente Kennedy', 'Água Verde', '80610-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28860, 'Curitiba', 'Presidente Kennedy', 'Rebouças', '80220-201', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28861, 'Curitiba', 'Presidente Kennedy', 'Rebouças', '80220-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28862, 'Apucarana', 'Presidente Lincoln', 'Vila Santa Helena', '86810-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28863, 'Campo Largo', 'Presidente Lincoln', 'Vila Bancária', '83601-595', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28864, 'Curitiba', 'Presidente Marechal Dutra', 'Cidade Industrial', '81310-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28865, 'Pato Branco', 'Presidente Médici', 'La Salle', '85505-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28866, 'Cambé', 'Presidente Nilo Peçanha', 'Jardim Silvino', '86187-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28867, 'Curitiba', 'Presidente Pádua Fleury', 'Hauer', '81610-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28868, 'Curitiba', 'Presidente Pádua Fleury', 'Hauer', '81630-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28869, 'Pato Branco', 'Presidente Prudente', 'São Roque', '85507-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28870, 'Cambé', 'Presidente Prudente de Morais', 'Jardim Riviera', '86187-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28871, 'Toledo', 'Presidente Ranieri Mazzili', 'Jardim Filadélpia', '85902-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28872, 'Cambé', 'Presidente Ranieri Mazzili', 'Novo Bandeirantes', '86188-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28873, 'Curitiba', 'Presidente Rodrigo Otávio', 'Cristo Rei', '80050-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28874, 'Curitiba', 'Presidente Rodrigo Otávio', 'Alto da Rua XV', '80040-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28875, 'Cambé', 'Presidente Rodrigues Alves', 'Jardim Riviera', '86187-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28876, 'Apucarana', 'Presidente Roosevelt', 'Jardim Iguatemi', '86810-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28877, 'Almirante Tamandaré', 'Presidente Tancredo A. Neves', 'Jardim Anita Garibaldi', '83504-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28878, 'Ponta Grossa', 'Presidente Tancredo de Almeida Neves', 'Contorno', '84061-460', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28879, 'Almirante Tamandaré', 'Presidente Tancredo de Almeida Neves', 'Loteamento Chico Mendes', '83505-778', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28880, 'Francisco Beltrão', 'Presidente Tancredo Neves', 'Nossa Senhora Aparecida', '85601-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28881, 'Paranavaí', 'Presidente Tancredo Neves', 'Jardim Ouro Branco', '87704-270', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28882, 'Paranavaí', 'Presidente Tancredo Neves', 'Vila São Vicente', '87709-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28883, 'Paranavaí', 'Presidente Tancredo Neves', 'Jardim Asa Branca', '87703-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28884, 'Paranavaí', 'Presidente Tancredo Neves', 'Jardim Guanabara', '87706-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28885, 'Paranavaí', 'Presidente Tancredo Neves', 'Vila Yara', '87702-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28886, 'Almirante Tamandaré', 'Presidente Tancredo Neves', 'Planta Bela Vista', '83514-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28887, 'Curitiba', 'Presidente Taunay', 'Bigorrilho', '80430-000', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28888, 'Curitiba', 'Presidente Taunay', 'Batel', '80420-180', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28889, 'Londrina', 'Presidente Vargas', 'Centro', '86020-340', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28890, 'Pato Branco', 'Presidente Vargas', 'Santo Antônio', '85507-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28891, 'Toledo', 'Presidente Vargas', 'Boa Esperança', '85908-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28892, 'Apucarana', 'Presidente Washington', 'Vila Santa Helena', '86810-330', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28893, 'Londrina', 'Presidente Washington Luiz', 'Bancários', '86062-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28894, 'Paranaguá', 'Presidente Washington Luiz', 'Vila Paranaguá', '83221-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28895, 'Cambé', 'Presidente Washington Luiz', 'Jardim Silvino', '86188-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28896, 'Curitiba', 'Presidente Washington Luiz', 'Jardim Social', '82520-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28897, 'Cambé', 'Presidente Wenceslau Braz', 'Novo Bandeirantes', '86188-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28898, 'Curitiba', 'Presidente Wenceslau Braz', 'Guaíra', '81010-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28899, 'Curitiba', 'Presidente Wenceslau Braz', 'Parolin', '81030-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28900, 'Curitiba', 'Presidente Wenceslau Braz', 'Guaíra', '81010-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28901, 'Londrina', 'Presidente Wilson', 'Universitário', '86050-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28902, 'Apucarana', 'Presidente Wilson', 'Jardim Iguatemi', '86810-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28903, 'Curitiba', 'Presidente Wilson', 'Uberaba', '81570-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28904, 'Londrina', 'Presidente Xavier da Silva', 'Bom Retiro', '86025-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28905, 'Cascavel', 'Presidente Zacarias', 'Periolo', '85817-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28906, 'Guarapuava', 'Presidente Zacarias de Góes', 'Santa Cruz', '85015-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28907, 'Apucarana', 'Prestes Maia', 'Vila Formosa', '86802-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28908, 'Cascavel', 'Prestes Maia', 'São Cristóvão', '85816-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28909, 'Curitiba', 'Pretextato Taborda Júnior', 'Santa Quitéria', '80310-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28910, 'Curitiba', 'Pretextato Taborda Júnior', 'Portão', '80330-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28911, 'Piraquara', 'Preto-Velho', 'Jardim Veneza', '83310-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28912, 'Curitiba', 'Previsto Columbia', 'Guaíra', '80630-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28913, 'Francisco Beltrão', 'Primavera', 'Nossa Senhora Aparecida', '85601-818', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28914, 'Maringá', 'Primavera', 'Vila Esperança', '87020-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28915, 'Toledo', 'Primavera', 'Jardim La Salle', '85903-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28916, 'Sarandi', 'Primavera', 'Jardim Primaverão', '87111-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28917, 'São José dos Pinhais', 'Primavera', 'Guatupê', '83060-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28918, 'Araucária', 'Primavera', 'Campina da Barra', '83709-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28919, 'Cascavel', 'Primavera', 'Nova Cidade', '85803-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28920, 'Cambé', 'Primavera', 'Jardim Ana Eliza', '86188-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28921, 'Arapongas', 'Primavera', 'Conjunto Ulisses Guimarães', '86706-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28922, 'Campo Mourão', 'Primavera', 'Jardim Lar Paraná', '87305-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28923, 'Apucarana', 'Primavera', 'Vila Swain', '86800-455', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28924, 'Toledo', 'Primeiro de Janeiro', 'Jardim Paulista', '85909-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28925, 'Cambé', 'Primeiro de Janeiro', 'Jardim União', '86185-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28926, 'Colombo', 'Primeiro de Janeiro', 'Jardim Palmares', '83412-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28927, 'Toledo', 'Primeiro de Julho', 'Vila Industrial', '85904-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28928, 'Guarapuava', 'Primeiro de Maio', 'Morro Alto', '85065-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28929, 'Laranjeiras do Sul', 'Primeiro de Maio', 'Cristo Rei', '85304-230', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28930, 'Francisco Beltrão', 'Primeiro de Maio', 'Industrial', '85601-330', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28931, 'Ponta Grossa', 'Primeiro de Maio', 'Nova Rússia', '84070-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28932, 'Pinhais', 'Primeiro de Maio', 'Jardim Pinhais', '83323-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28933, 'Londrina', 'Primeiro de Maio', 'Centro', '86010-100', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28934, 'Telêmaco Borba', 'Primeiro de Maio', 'Centro', '84261-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28935, 'Toledo', 'Primeiro de Maio', 'Boa Esperança', '85909-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28936, 'Umuarama', 'Primeiro de Maio', 'Mutirão Jardim Alvorada', '87506-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28937, 'Toledo', 'Primeiro de Maio', 'Jardim Paulista', '85910-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28938, 'Sarandi', 'Primeiro de Maio', 'Parque Industrial II', '87111-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28939, 'São José dos Pinhais', 'Primeiro de Maio', 'Boneca do Iguaçu', '83040-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28940, 'Araucária', 'Primeiro de Maio', 'Estação', '83705-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28941, 'Cascavel', 'Primeiro de Maio', 'Vila Tolentino', '85802-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28942, 'Apucarana', 'Primeiro de Maio', 'Vila Operária 1', '86801-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28943, 'Cambé', 'Primeiro de Maio', 'Jardim União', '86185-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28944, 'Curitiba', 'Primeiro de Maio', 'Xaxim', '81820-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28945, 'Curitiba', 'Primeiro de Maio', 'Xaxim', '81810-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28946, 'Toledo', 'Primeiro de Outubro', 'Boa Esperança', '85909-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28947, 'Curitiba', 'Primeiro-Ministro Brochado da Rocha', 'Pilarzinho', '82120-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28948, 'Curitiba', 'Primeiro-Ministro Olof Palme', 'Sítio Cercado', '81925-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28949, 'Londrina', 'Primitivo Alpiste', 'Conjunto Habitacional Saltinho', '86042-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28950, 'Pinhais', 'Primo Antônio Mottin', 'Jardim Triângulo', '83331-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28951, 'Toledo', 'Primo Argenton', 'Jardim Parizzotto', '85914-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28952, 'Toledo', 'Primo Arroso', 'Residencial Santa Clara', '85903-709', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28953, 'Londrina', 'Primo Birelo', 'Avelino A Vieira', '86056-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28954, 'Londrina', 'Primo Campana', 'Jardim Rosicler', '86072-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28955, 'Toledo', 'Primo Fachini', 'Jardim Pasqualli', '85905-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28956, 'Curitiba', 'Primo Favretto', 'Capão Raso', '81020-690', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28957, 'Londrina', 'Primo José Artuzo', 'Nova Olinda', '86073-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28958, 'Curitiba', 'Primo Júlio Zanquettim', 'Santa Felicidade', '82015-036', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28959, 'Piraquara', 'Primo Lattes', 'Planta York', '83307-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28960, 'Curitiba', 'Primo Lourenço Tosin', 'Novo Mundo', '81050-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28961, 'Pato Branco', 'Primo Miotto', 'La Salle', '85505-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28962, 'Londrina', 'Primo Rossignolo', 'Conjunto Novo Amparo 2', '86056-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28963, 'São José dos Pinhais', 'Primo Simione', 'Afonso Pena', '83050-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28964, 'Pato Branco', 'Primo Zanotto', 'Bortot', '85501-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28965, 'Campo Mourão', 'Primula', 'Jardim Paulista', '87310-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28966, 'Araucária', 'Prímula', 'Campina da Barra', '83709-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28967, 'Apucarana', 'Princesa Dona Leopoldina', 'Jardim Independência', '86811-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28968, 'Telêmaco Borba', 'Princesa dos Campos', 'Vila Santa Rita', '84263-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28969, 'Campo Mourão', 'Princesa dos Campos', 'Jardim Tropical II', '87310-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28970, 'Guarapuava', 'Princesa Isabel', 'Vila Carli', '85040-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28971, 'Paranaguá', 'Princesa Isabel', 'Centro Histórico', '83203-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28972, 'Pato Branco', 'Princesa Isabel', 'Alvorada', '85508-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28973, 'Pato Branco', 'Princesa Isabel', 'Chaparral', '85507-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28974, 'Ponta Grossa', 'Princesa Isabel', 'Orfãs', '84015-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28975, 'Paranaguá', 'Princesa Isabel', 'Jardim Paranaguá', '83218-335', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28976, 'Paranavaí', 'Princesa Isabel', 'Vila Prudêncio', '87702-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28977, 'Maringá', 'Princesa Isabel', 'Zona 04', '87014-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28978, 'Piraquara', 'Princesa Isabel', 'Jardim Bela Vista', '83301-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28979, 'Toledo', 'Princesa Isabel', 'Parque Residencial Gisela', '85905-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28980, 'Sarandi', 'Princesa Isabel', 'Jardim Panorama', '87113-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28981, 'Umuarama', 'Princesa Isabel', 'Zona IV', '87504-006', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28982, 'Sarandi', 'Princesa Isabel', 'Jardim Independência I', '87114-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28983, 'Colombo', 'Princesa Isabel', 'Planta Santa Úrsula', '83405-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28984, 'Cascavel', 'Princesa Isabel', 'Alto Alegre', '85805-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28985, 'Apucarana', 'Princesa Isabel', 'Vila São Jorge', '86800-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28986, 'Campo Largo', 'Princesa Isabel', 'Loteamento Ouro Verde I', '83606-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28987, 'Cambé', 'Princesa Isabel', 'Parque Residencial Manela', '86185-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28988, 'Campo Mourão', 'Princesa Isabel', 'Jardim Lar Paraná', '87305-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28989, 'Castro', 'Princesa Isabel', 'Centro', '84165-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28990, 'Londrina', 'Princesa Izabel', 'Vila Galvão', '86026-120', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28991, 'Curitiba', 'Princesa Izabel', 'São Francisco', '80410-110', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28992, 'Curitiba', 'Princesa Izabel', 'Campina do Siqueira', '80740-120', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28993, 'Curitiba', 'Princesa Izabel', 'Bigorrilho', '80730-080', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28994, 'Curitiba', 'Princesa Izabel', 'Mercês', '80430-120', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28995, 'Guarapuava', 'Princesa Leopoldina', 'Morro Alto', '85067-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28996, 'Cambé', 'Princesa Leopoldina', 'Parque Residencial Manela', '86185-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28997, 'Foz do Iguaçu', 'Princeza Isabel', 'Loteamento Santos Guglielme', '85852-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28998, 'Arapongas', 'Príncipe', 'Jardim São Bento', '86706-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (28999, 'Apucarana', 'Príncipe Dom Miguel', 'Jardim Independência', '86811-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29000, 'Pato Branco', 'Procópio de Lima', 'Trevo da Guarany', '85501-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29001, 'Londrina', 'Procópio Ferreira', 'Colúmbia', '86057-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29002, 'Foz do Iguaçu', 'Procópio Ferreira', 'Jardim Comercial das Bandeiras', '85864-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29003, 'Maringá', 'Procópio Ferreira', 'Jardim América', '87045-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29004, 'Cascavel', 'Procópio Ferreira', 'Brasília', '85815-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29005, 'Curitiba', 'Procópio Ferreira Martins', 'Cajuru', '82900-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29006, 'Curitiba', 'Procópio Ferreira Martins', 'Cajuru', '82940-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29007, 'Curitiba', 'Prodócimo Lago', 'Taboão', '82130-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29008, 'Curitiba', 'Professor Agostinho Bernardo da Veiga', 'Sítio Cercado', '81900-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29009, 'Almirante Tamandaré', 'Professor Alberto Krause', 'Vila Tanguá', '83508-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29010, 'Almirante Tamandaré', 'Professor Alberto Piekas', 'Jardim Taíza', '83505-127', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29011, 'Almirante Tamandaré', 'Professor Alberto Piekas', 'Colônia Vila Prado', '83504-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29012, 'Paranaguá', 'Professor Alceu de Oliveira Toledo', 'João Gualberto', '83203-595', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29013, 'Apucarana', 'Professor Alceu Naumann', 'Jardim Eldorado', '86802-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29014, 'Londrina', 'Professor Alfonso Valeiros', 'Milton Gavetti', '86078-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29015, 'Araucária', 'Professor Alfredo Parodi', 'Centro', '83702-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29016, 'Almirante Tamandaré', 'Professor Alfredo Valente', 'Jardim Roma', '83504-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29017, 'Curitiba', 'Professor Algacyr Munhoz Mader', 'Cidade Industrial', '81310-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29018, 'Curitiba', 'Professor Algacyr Munhoz Mader', 'Cidade Industrial', '81350-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29019, 'Ponta Grossa', 'Professor Altair Oliveira Mongruel', 'Ronda', '84051-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29020, 'Curitiba', 'Professor Álvaro Jorge', 'Vila Izabel', '80320-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29021, 'Curitiba', 'Professor Álvaro Luiz Junqueira França', 'Sítio Cercado', '81920-015', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29022, 'Guarapuava', 'Professor Amálio Pinheiro', 'Santa Cruz', '85015-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29023, 'Curitiba', 'Professor Amantino de Mello Ribas', 'Portão', '80320-410', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29024, 'Curitiba', 'Professor Ângelo Antônio Dallegrave', 'Santo Inácio', '82300-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29025, 'Curitiba', 'Professor Aniz Domingos', 'Cidade Industrial', '81460-218', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29026, 'Curitiba', 'Professor Antônio Carlos Raimundo', 'São João', '82030-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29027, 'São José dos Pinhais', 'Professor Antônio Dantas', 'Afonso Pena', '83050-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29028, 'Maringá', 'Professor Antônio de Santa Rosa', 'Jardim Universitário', '87020-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29029, 'Paranaguá', 'Professor Antônio dos Santos Filho', 'Parque São João', '83212-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29030, 'Apucarana', 'Professor Antônio Franco F. da Costa', 'Residencial Jaboti', '86800-465', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29031, 'Curitiba', 'Professor Antônio Martins Franco', 'Novo Mundo', '81030-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29032, 'Almirante Tamandaré', 'Professor Antônio Rodrigues Dias', 'Planta Nossa Senhora de Lourdes', '83506-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29033, 'Curitiba', 'Professor Antônio Tupy Pinheiro', 'Boa Vista', '82650-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29034, 'Curitiba', 'Professor Arlindo Loyola de Camargo', 'Portão', '80320-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29035, 'Curitiba', 'Professor Arnaldo Alves de Araújo', 'Seminário', '80740-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29036, 'Curitiba', 'Professor Arthur Loyola', 'Cabral', '80035-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29037, 'Curitiba', 'Professor Arthur Virmond de Lacerda', 'São Miguel', '81450-766', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29038, 'Curitiba', 'Professor Artur Santos de Almeida', 'Guabirotuba', '81520-355', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29039, 'Maringá', 'Professor Ary de Lima', 'Jardim Alvorada', '87035-110', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29040, 'Curitiba', 'Professor Ary Nogueira dos Santos', 'Boqueirão', '81750-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29041, 'Curitiba', 'Professor Assis Gonçalves', 'Água Verde', '80620-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29042, 'Araucária', 'Professor Augusto Sebastião Querne', 'Iguaçu', '83701-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29043, 'Castro', 'Professor Basílio Chirum', 'Água Suja', '84165-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29044, 'Piraquara', 'Professor Basílio Fuck', 'Vila Fuck', '83305-265', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29045, 'Guarapuava', 'Professor Becker', 'Santa Cruz', '85015-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29046, 'Guarapuava', 'Professor Becker', 'Centro', '85010-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29047, 'Guarapuava', 'Professor Becker', 'Alto da XV', '85065-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29048, 'Curitiba', 'Professor Benedicto Nicolau dos Santos', 'Vista Alegre', '80810-315', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29049, 'Curitiba', 'Professor Benedito Conceição', 'Capão da Imbuia', '82810-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29050, 'Curitiba', 'Professor Benedito Nicolau dos Santos', 'Centro Cívico', '80530-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29051, 'Maringá', 'Professor Bento Fernandes Dias', 'Conjunto Habitacional Karina', '87047-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29052, 'Cambé', 'Professor Bento Mussurunga', 'Jardim Silvino', '86188-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29053, 'Curitiba', 'Professor Bernardo Litzinger', 'Sítio Cercado', '81900-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29054, 'Curitiba', 'Professor Brandão', 'Alto da Rua XV', '80040-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29055, 'Curitiba', 'Professor Brasílio Ovídio da Costa', 'Santa Quitéria', '80310-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29056, 'Curitiba', 'Professor Brasílio Ovídio da Costa', 'Portão', '80320-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29057, 'Ponta Grossa', 'Professor Bruning', 'Uvaranas', '84020-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29058, 'Curitiba', 'Professor Camillo Stellfeld', 'Jardim das Américas', '81520-170', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29059, 'Castro', 'Professor Canderoy Mainardes', 'Vila Rio Branco', '84172-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29060, 'Francisco Beltrão', 'Professor Canizio Hillebrand', 'Cristo Rei', '85602-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29061, 'Ponta Grossa', 'Professor Cardoso Fontes', 'Ronda', '84050-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29062, 'Londrina', 'Professor Carlos Coimbra', 'Barbeta', '86078-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29063, 'Curitiba', 'Professor Carlos O. Gambus', 'Santa Felicidade', '82410-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29064, 'Curitiba', 'Professor Carlos Stellfeld', 'Bacacheri', '82510-210', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29065, 'Maringá', 'Professor Carlos Weiss', 'Jardim Universitário', '87020-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29066, 'Ponta Grossa', 'Professor Carrel', 'Colônia Dona Luiza', '84045-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29067, 'Londrina', 'Professor Célio Alves da Silva', 'Jardim Morumbi', '86035-126', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29068, 'Paranaguá', 'Professor Cleto', 'Centro Histórico', '83203-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29069, 'Paranaguá', 'Professor Cleto', 'Industrial', '83221-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29070, 'Ponta Grossa', 'Professor Coelho e Souza', 'Contorno', '84061-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29071, 'Ponta Grossa', 'Professor Colares', 'Centro', '84010-520', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29072, 'Londrina', 'Professor Couto', 'Santiago', '86071-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29073, 'Cambé', 'Professor Couto da Costa', 'Vila Mesquita', '86182-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29074, 'Ponta Grossa', 'Professor Curie', 'Oficinas', '84036-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29075, 'Curitiba', 'Professor Czeslaw Marian Biezanko', 'Umbará', '81930-638', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29076, 'Campo Largo', 'Professor Damaso Padilha Ferreira', 'Loteamento São Gerônimo', '83606-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29077, 'Curitiba', 'Professor Dario Garcia', 'Vista Alegre', '80820-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29078, 'Curitiba', 'Professor Dario Velloso', 'Vila Izabel', '80320-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29079, 'Curitiba', 'Professor David Jorge Curi', 'Cajuru', '82920-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29080, 'Paranaguá', 'Professor Décio', 'Rocio', '83221-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29081, 'Ponta Grossa', 'Professor Dias de Carvalho', 'Contorno', '84062-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29082, 'Cascavel', 'Professor Domingos Carlos Gonçalves', 'Nova Cidade', '85803-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29083, 'Curitiba', 'Professor Domingos Lukaszewiczs', 'Fanny', '81030-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29084, 'Ponta Grossa', 'Professor Doutor Estevão Zeve Coimbra', 'Contorno', '84061-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29085, 'Curitiba', 'Professor Doutor Irineu Antunes', 'Novo Mundo', '81050-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29086, 'Curitiba', 'Professor Doutor Pedro Ribeiro Macedo da Costa', 'Vila Izabel', '80320-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29087, 'Curitiba', 'Professor Doutor Sandoval Ribeiro Ribas', 'Cidade Industrial', '81270-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29088, 'Curitiba', 'Professor Duílio A. Calderari', 'Hugo Lange', '80040-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29089, 'Curitiba', 'Professor Edgard Octávio Fernandes', 'Sítio Cercado', '81910-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29090, 'Curitiba', 'Professor Edmundo José Binder', 'Cajuru', '82920-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29091, 'Curitiba', 'Professor Eduardo Correia Lima', 'Capão da Imbuia', '82810-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29092, 'Apucarana', 'Professor Edwaldo Canezin Tosch', 'Vila Feliz', '86808-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29093, 'Curitiba', 'Professor Elevir Dionysio', 'Portão', '81320-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29094, 'Curitiba', 'Professor Elysio Viana', 'Tarumã', '82530-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29095, 'Curitiba', 'Professor Emílio José A. Ubá', 'Cachoeira', '82710-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29096, 'Curitiba', 'Professor Emílio Schutz', 'Cajuru', '82950-440', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29097, 'Londrina', 'Professor Ênio Romagnolli', 'Portal de Versalhes 3', '86055-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29098, 'Apucarana', 'Professor Erasto Gaertner', 'Centro', '86800-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29099, 'Curitiba', 'Professor Erbo Stenzel', 'Sítio Cercado', '81900-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29100, 'Campo Mourão', 'Professor Ethanil Bento de Assis', 'Jardim Ana Eliza', '87303-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29101, 'Curitiba', 'Professor Eugênio Gudin', 'Tatuquara', '81480-229', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29102, 'Ponta Grossa', 'Professor Eugênio Malanski', 'Nova Rússia', '84053-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29103, 'Piraquara', 'Professor Evaristo Carlini', 'Jardim Santa Helena', '83308-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29104, 'Curitiba', 'Professor Ewaldo Schiebler', 'Jardim Social', '82530-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29105, 'Curitiba', 'Professor Fábio de Souza', 'Santa Quitéria', '80310-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29106, 'Curitiba', 'Professor Fábio de Souza', 'Portão', '80330-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29107, 'Ponta Grossa', 'Professor Fábio Fanucchi', 'Boa Vista', '84071-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29108, 'Ponta Grossa', 'Professor Faria Michaele', 'Centro', '84010-015', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29109, 'Apucarana', 'Professor Faustino Vieira', 'Loteamento Residencial Cazarin', '86802-426', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29110, 'Curitiba', 'Professor Fernando Carneiro', 'Cidade Industrial', '81460-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29111, 'Curitiba', 'Professor Fernando Moreira', 'Mercês', '80430-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29112, 'Curitiba', 'Professor Fernando Moreira', 'Centro', '80410-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29113, 'Cambé', 'Professor Floriano Bento Viana', 'Novo Bandeirantes', '86188-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29114, 'Curitiba', 'Professor Francisco Basseti Júnior', 'Cascatinha', '82010-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29115, 'Curitiba', 'Professor Francisco Dranka', 'Orleans', '81200-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29116, 'Curitiba', 'Professor Francisco Mendes', 'Uberaba', '81580-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29117, 'Araucária', 'Professor Francisco Ribeiro', 'Barigui', '83707-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29118, 'Almirante Tamandaré', 'Professor Francisco Tiago da Costa', 'Jardim Paris', '83508-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29119, 'Curitiba', 'Professor Francisco Zardo', 'Santa Felicidade', '82320-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29120, 'Curitiba', 'Professor Gabriel Nery Ballin', 'Pilarzinho', '80520-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29121, 'Curitiba', 'Professor Gaspar Luiz de Lacerda Pinto', 'Tatuquara', '81480-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29122, 'Maringá', 'Professor Giampero Monacci', 'Jardim Novo Horizonte', '87010-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29123, 'Maringá', 'Professor Guido Inácio Bersch', 'Jardim Universitário', '87020-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29124, 'Curitiba', 'Professor Guido Straube', 'Vila Izabel', '80320-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29125, 'Curitiba', 'Professor Guido Viaro', 'Prado Velho', '80215-180', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29126, 'Curitiba', 'Professor Guilherme Butler', 'Barreirinha', '82700-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29127, 'Ponta Grossa', 'Professor Hamilton Pereira Vaz', 'Boa Vista', '84072-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29128, 'Curitiba', 'Professor Haroldo Trevisani Beltrão', 'Água Verde', '80240-200', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29129, 'Ponta Grossa', 'Professor Heitor Ditzel', 'Estrela', '84050-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29130, 'Curitiba', 'Professor Henrique Berg', 'Cidade Industrial', '81290-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29131, 'Curitiba', 'Professor Hermann Mathias Gorgen', 'Boqueirão', '81750-245', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29132, 'Curitiba', 'Professor Homero Batista de Barros', 'Pinheirinho', '81870-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29133, 'Curitiba', 'Professor Hostílio Araújo', 'Pilarzinho', '82110-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29134, 'Curitiba', 'Professor Hugo Hohmann', 'Campo Comprido', '81200-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29135, 'Curitiba', 'Professor Hyperides Zanello', 'Bigorrilho', '80730-130', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29136, 'Guarapuava', 'Professor Iank', 'Dos Estados', '85035-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29137, 'Curitiba', 'Professor Ignacio Alves de Souza Filho', 'Pilarzinho', '82110-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29138, 'Piraquara', 'Professor Índio Corrêa', 'Planta Vila Iraí', '83302-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29139, 'Curitiba', 'Professor Irland Godoy', 'Pilarzinho', '82100-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29140, 'Maringá', 'Professor Itamar Orlando Soares', 'Jardim Universitário', '87020-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29141, 'Ponta Grossa', 'Professor Ivon Zardo', 'Estrela', '84050-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29142, 'Apucarana', 'Professor Izidoro Luiz Ceravolo', 'Vila Marigilda', '86800-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29143, 'Maringá', 'Professor Jailton Saraiva', 'Jardim América', '87045-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29144, 'Curitiba', 'Professor João Argemiro Loyola', 'Seminário', '80240-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29145, 'Curitiba', 'Professor João Atila Rocha', 'Abranches', '82130-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29146, 'Londrina', 'Professor João Cândido', 'Centro', '86010-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29147, 'Londrina', 'Professor João Cândido', 'Centro', '86010-001', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29148, 'Telêmaco Borba', 'Professor João Cândido', 'Vila Monte Belo', '84262-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29149, 'Apucarana', 'Professor João Cândido Ferreira', 'Centro', '86800-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29150, 'Apucarana', 'Professor João Cândido Ferreira', 'Centro', '86809-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29151, 'Araucária', 'Professor João Chorosnicki', 'Vila Nova', '83703-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29152, 'Araucária', 'Professor João Chorosnicki', 'Boqueirão', '83704-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29153, 'São José dos Pinhais', 'Professor João Clímaco de Carvalho', 'São Pedro', '83020-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29154, 'São José dos Pinhais', 'Professor João da Costa Viana', 'Cidade Jardim', '83035-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29155, 'Curitiba', 'Professor João de Freitas', 'Boqueirão', '81670-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29156, 'Curitiba', 'Professor João Doetzer', 'Jardim das Américas', '81540-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29158, 'Curitiba', 'Professor João Gilberto Martins', 'Ganchinho', '81935-376', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29159, 'Maringá', 'Professor João José Leandro', 'Parque Lagoa Dourada', '87053-259', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29160, 'Curitiba', 'Professor João Kochaki', 'Jardim das Américas', '81520-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29161, 'Curitiba', 'Professor João Manoel Mondrone', 'Vista Alegre', '80820-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29162, 'Curitiba', 'Professor João Mazzarotto', 'Capão Raso', '81110-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29163, 'Curitiba', 'Professor João Poeck', 'Sítio Cercado', '81925-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29164, 'Curitiba', 'Professor João Soares Barcelos', 'Hauer', '81630-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29165, 'Curitiba', 'Professor João Soares Barcelos', 'Boqueirão', '81670-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29166, 'Londrina', 'Professor Joaquim de Matos Barreto', 'Lima Azevedo', '86060-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29167, 'Londrina', 'Professor Joaquim de Matos Barreto', 'Maringá', '86015-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29168, 'Curitiba', 'Professor Joaquim de Mattos Barreto', 'São Lourenço', '82200-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29169, 'Curitiba', 'Professor Jorge Leitner', 'Bacacheri', '82520-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29170, 'Ponta Grossa', 'Professor José Antônio Daros', 'Contorno', '84052-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29171, 'Telêmaco Borba', 'Professor José de Anchieta', 'Vila Monte Belo', '84262-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29172, 'Curitiba', 'Professor José Farâni Mansur Guérios', 'Parolin', '80220-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29173, 'Telêmaco Borba', 'Professor José Loureiro Fernandes', 'Jardim São Silvestre', '84270-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29174, 'Curitiba', 'Professor José Maurício Higgins', 'Boqueirão', '81650-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29175, 'Curitiba', 'Professor José Maurício Higgins', 'Boqueirão', '81670-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29176, 'Curitiba', 'Professor José Moscalewski', 'Pilarzinho', '82100-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29177, 'Curitiba', 'Professor José Nogueira dos Santos', 'Boqueirão', '81670-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29178, 'Curitiba', 'Professor José Nogueira dos Santos', 'Hauer', '81630-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29179, 'Maringá', 'Professor José Pereira Diniz', 'Jardim Internorte', '87045-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29180, 'Ponta Grossa', 'Professor José Pessolano Brandes', 'Boa Vista', '84071-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29181, 'Sarandi', 'Professor José Rezende', 'Jardim Tropical', '87113-817', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29182, 'Curitiba', 'Professor José Rodrigues Vieira', 'Cidade Industrial', '81450-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29183, 'Londrina', 'Professor Juliano Stinghen', 'Barbeta', '86078-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29184, 'Guarapuava', 'Professor Júlio Lourenço da Rosa', 'Morro Alto', '85065-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29185, 'Curitiba', 'Professor Júlio Theodorico Guimarães', 'Pinheirinho', '81825-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29186, 'Ponta Grossa', 'Professor Kamal Tebcherani', 'Oficinas', '84036-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29187, 'Araucária', 'Professor Kazimiera Szymanski', 'Porto das Laranjeiras', '83703-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29188, 'Curitiba', 'Professor Kydd James Galliano', 'Cascatinha', '82020-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29189, 'Curitiba', 'Professor Laertes Munhoz', 'Seminário', '80310-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29190, 'Maringá', 'Professor Lauro Eduardo Werneck', 'Zona 07', '87020-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29191, 'Curitiba', 'Professor Lauro Zak', 'Xaxim', '81810-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29192, 'Curitiba', 'Professor Leo Kessler', 'Jardim das Américas', '81520-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29193, 'Castro', 'Professor Leo Zappe', 'Núcleo Habitacional Padre Piva', '84178-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29194, 'Curitiba', 'Professor Leonardo Cobbe', 'Barreirinha', '82220-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29195, 'Curitiba', 'Professor Leonel Moro', 'Xaxim', '81710-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29196, 'Curitiba', 'Professor Leônidas Ferreira da Costa', 'Parolin', '80220-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29197, 'Curitiba', 'Professor Lício de Lima', 'Novo Mundo', '81030-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29198, 'Curitiba', 'Professor Lindolfo da Rocha Pombo', 'Bacacheri', '82520-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29199, 'Curitiba', 'Professor Loureiro Fernandes', 'Santa Cândida', '82640-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29200, 'Curitiba', 'Professor Lucir Gallieri', 'São Braz', '82315-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29201, 'Curitiba', 'Professor Ludovico Weber', 'Santa Cândida', '82720-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29202, 'Curitiba', 'Professor Luiz Aníbal Calderari', 'Capão Raso', '81110-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29203, 'Curitiba', 'Professor Luiz Benício da Silva Bastos', 'São João', '82030-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29204, 'Curitiba', 'Professor Luiz Carlos Pereira da Silva', 'Jardim Botânico', '80215-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29205, 'Curitiba', 'Professor Luiz César', 'Água Verde', '80620-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29206, 'Curitiba', 'Professor Lycio Grein de Castro Vellozo', 'Mercês', '80710-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29207, 'Curitiba', 'Professor Macedo Filho', 'Bom Retiro', '80520-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29208, 'Curitiba', 'Professor Manoel de Abreu', 'Portão', '81070-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29209, 'Curitiba', 'Professor Manoel de Oliveira Franco', 'Cajuru', '82970-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29210, 'Curitiba', 'Professor Manoel Vieira de Alencar', 'Jardim Social', '82520-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29211, 'São José dos Pinhais', 'Professor Mário Cantalicio Flores', 'Afonso Pena', '83050-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29212, 'Telêmaco Borba', 'Professor Martins Franco', 'Jardim Alegre', '84268-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29213, 'Curitiba', 'Professor Masaharu Taniguchi', 'Bairro Alto', '82840-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29214, 'Curitiba', 'Professor Miguel Wouk', 'Tarumã', '82530-250', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29215, 'Curitiba', 'Professor Milton Carneiro', 'Pilarzinho', '80520-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29216, 'Curitiba', 'Professor Milton de Macedo Munhoz', 'Campina do Siqueira', '80740-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29217, 'Curitiba', 'Professor Milton Miró Vernalha', 'Cidade Industrial', '81460-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29218, 'Curitiba', 'Professor Milton Vianna', 'Sítio Cercado', '81920-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29219, 'Curitiba', 'Professor Narciso Mendes', 'Xaxim', '81810-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29220, 'Curitiba', 'Professor Newton Stadler de Souza', 'Tatuquara', '81480-306', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29221, 'Telêmaco Borba', 'Professor Ney de Oliveira Pimenta', 'Centro', '84261-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29222, 'Maringá', 'Professor Ney Marques', 'Jardim Universitário', '87020-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29223, 'Curitiba', 'Professor Nilo Brandão', 'São Lourenço', '82210-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29224, 'Londrina', 'Professor Nilton Camargo da Silva', 'Portal de Versalhes 3', '86055-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29225, 'Curitiba', 'Professor Nivaldo Braga', 'Cajuru', '82900-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29226, 'Curitiba', 'Professor Nivaldo Braga', 'Capão da Imbuia', '82810-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29227, 'Curitiba', 'Professor Nivaldo Maranhão Faria', 'Bairro Alto', '82840-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29228, 'Curitiba', 'Professor Nuno de Souza e Silva', 'Santo Inácio', '82010-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29229, 'Maringá', 'Professor Oberon Floriano Dittert', 'Jardim Universitário', '87020-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29230, 'Curitiba', 'Professor Octávio da Silveira', 'Água Verde', '80240-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29231, 'Curitiba', 'Professor Oge de Araújo', 'São Braz', '82300-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29232, 'Curitiba', 'Professor Olavo Del Claro', 'São Braz', '82315-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29233, 'Curitiba', 'Professor Olímpio de Almeida', 'Bacacheri', '82515-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29234, 'Curitiba', 'Professor Oliveiros Vilaça', 'Cidade Industrial', '81290-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29235, 'Curitiba', 'Professor Omar Gonçalves da Motta', 'Boa Vista', '82650-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29236, 'Curitiba', 'Professor Orlando Alves Chaves', 'Portão', '81320-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29237, 'Curitiba', 'Professor Orlando Sprenger Lobo', 'Tingui', '82620-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29238, 'Cascavel', 'Professor Orozendo Cordeiro de Jesus', '14 de Novembro', '85804-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29239, 'Curitiba', 'Professor Oscar Kolbe', 'Lindóia', '81010-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29240, 'Curitiba', 'Professor Oscar Martins Gomes', 'Xaxim', '81830-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29241, 'Curitiba', 'Professor Oscar Osvaldo Jasper', 'Uberaba', '81570-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29242, 'Curitiba', 'Professor Oscar Sanches Monteiro', 'Cidade Industrial', '81350-606', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29243, 'Curitiba', 'Professor Osvaldo Kohatsu', 'Vista Alegre', '82100-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29244, 'Curitiba', 'Professor Osvaldo Lopes', 'São Lourenço', '82200-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29245, 'Curitiba', 'Professor Osvaldo Ormiamin', 'Cidade Industrial', '81250-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29246, 'Curitiba', 'Professor Oswaldo Dória', 'Hugo Lange', '80040-440', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29247, 'Londrina', 'Professor Parigot de Souza', 'Centro', '86010-500', 'Viaduto', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29248, 'Ponta Grossa', 'Professor Paschoal Salles Rosa', 'Cará-cará', '84032-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29249, 'Curitiba', 'Professor Paulo d''Assumpção', 'Jardim das Américas', '81540-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29250, 'Guarapuava', 'Professor Pedro Carli', 'Vila Carli', '85040-005', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29251, 'Paranavaí', 'Professor Pedro Real', 'Jardim Paulista', '87709-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29252, 'Curitiba', 'Professor Pedro Viriato P. Souza', 'Campina do Siqueira', '80740-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29253, 'Curitiba', 'Professor Pedro Viriato P. Souza', 'Mossunguê', '81200-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29254, 'Curitiba', 'Professor Pedro Viriato P. Souza', 'Cidade Industrial', '81280-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29255, 'Ponta Grossa', 'Professor Plácido Cardon', 'Contorno', '84060-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29256, 'Curitiba', 'Professor Plácido e Silva', 'Parolin', '80220-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29257, 'Curitiba', 'Professor Porthos Velozo', 'Parolin', '80220-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29258, 'Toledo', 'Professor Queirolo', 'Jardim Recanto', '85902-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29259, 'Paranaguá', 'Professor Randolfo Arzua', 'Serraria do Rocha', '83221-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29260, 'Paranaguá', 'Professor Randolfo Arzua', 'Palmital', '83206-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29261, 'Curitiba', 'Professor Raul Pinheiro Machado', 'Bacacheri', '82520-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29262, 'Curitiba', 'Professor Raul Rodrigues Gomes', 'Alto Boqueirão', '81770-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29263, 'Ponta Grossa', 'Professor Robert Karel Bowles', 'Chapada', '84063-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29264, 'Cambé', 'Professor Rocha Pombo', 'Jardim Silvino', '86188-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29265, 'Curitiba', 'Professor Rodolfo Belz', 'Santa Cândida', '82640-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29266, 'Curitiba', 'Professor Rodolfo Wolf', 'Cascatinha', '82020-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29267, 'Curitiba', 'Professor Romão Wachowicz', 'Cidade Industrial', '81350-607', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29268, 'Londrina', 'Professor Romário Martins', 'Ouro Branco', '86042-185', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29269, 'Curitiba', 'Professor Rosário Farâni Mansur Guérios', 'Capão da Imbuia', '82810-625', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29270, 'Curitiba', 'Professor Rúbens Elke Braga', 'Parolin', '80220-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29271, 'Curitiba', 'Professor Rúbens Gomes de Souza', 'Tarumã', '82800-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29272, 'Curitiba', 'Professor Rúbens Oscar Guelli', 'Sítio Cercado', '81925-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29273, 'Londrina', 'Professor Samuel Moura', 'Judith', '86061-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29274, 'Curitiba', 'Professor Sebastião Paraná', 'Vila Izabel', '80320-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29275, 'São José dos Pinhais', 'Professor Serino Pedroso de Morais', 'Afonso Pena', '83065-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29276, 'Ponta Grossa', 'Professor Sezinio Malherbi', 'Chapada', '84062-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29277, 'Londrina', 'Professor Sinésio Medeiros', 'Barbeta', '86078-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29278, 'Curitiba', 'Professor Teobaldo Leonardo Kletemberg', 'Cidade Industrial', '81250-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29279, 'São José dos Pinhais', 'Professor Teodoro Winhler', 'Cidade Jardim', '83035-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29280, 'São José dos Pinhais', 'Professor Thales de Souza e Silva', 'Afonso Pena', '83050-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29281, 'Curitiba', 'Professor Thomaz Wartelsteiner', 'Portão', '80330-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29282, 'Curitiba', 'Professor Toshiaki Saito', 'Uberaba', '81550-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29283, 'Curitiba', 'Professor Ulisses Vieira', 'Vila Izabel', '80320-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29284, 'Curitiba', 'Professor Ulisses Vieira', 'Santa Quitéria', '80310-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29285, 'Curitiba', 'Professor Veríssimo Antônio de Souza', 'Portão', '80320-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29286, 'Curitiba', 'Professor Waldir de Jesus', 'Capão Raso', '81130-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29287, 'Paranaguá', 'Professor Waldomiro Ferreira de Freitas', 'Vila dos Comerciários', '83215-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29288, 'Curitiba', 'Professor Wenceslau Muniz', 'Cidade Industrial', '81310-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29289, 'Curitiba', 'Professor Werner Adolf Reichen Filho', 'São João', '82030-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29290, 'Londrina', 'Professor Wilton Coutinho', 'Santiago', '86071-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29291, 'Maringá', 'Professor Yukio Saito', 'Chácaras Morangueira', '87040-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29292, 'Curitiba', 'Professor Zacarias Liteka', 'Sítio Cercado', '81910-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29293, 'Almirante Tamandaré', 'Professor Zelete Custódio Vicente', 'Jardim Josiane', '83504-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29294, 'Curitiba', 'Professor Zildo Manoel da Cruz', 'Portão', '80320-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29295, 'Curitiba', 'Professor Zimmermann', 'Pinheirinho', '81870-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29296, 'Curitiba', 'Professora Aida de Alvarenga Bonatto', 'Tatuquara', '81880-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29297, 'Telêmaco Borba', 'Professora Alice Mercês Bittencourt', 'Área 02', '84267-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29298, 'Ponta Grossa', 'Professora Alzira Braga Ribas', 'Olarias', '84026-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29299, 'Ponta Grossa', 'Professora Alzira Braga Ribas', 'Neves', '84020-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29300, 'Curitiba', 'Professora Amália Gasparotto Dona', 'Sítio Cercado', '81900-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29301, 'Curitiba', 'Professora Ana de Oliveira Viana', 'Fanny', '81030-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29302, 'Guarapuava', 'Professora Ana Vanda Bassara', 'Boqueirão', '85020-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29303, 'Guarapuava', 'Professora Anna Joaquina da Purificaçao Lacerda', 'Santa Cruz', '85015-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29304, 'Sarandi', 'Professora Anna Saddi Barros da Cunha', 'Parque Alvamar', '87113-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29305, 'Curitiba', 'Professora Annette Macedo', 'Jardim Botânico', '80210-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29306, 'Curitiba', 'Professora Antônia Reginato Vianna', 'Capão da Imbuia', '82810-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29307, 'Curitiba', 'Professora Augusta Ribas', 'Pinheirinho', '81880-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29308, 'Ponta Grossa', 'Professora Balbina Branco', 'Neves', '84020-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29309, 'Londrina', 'Professora Behair Edna Mendonça', 'Colúmbia', '86057-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29310, 'Ponta Grossa', 'Professora Braulina Carneiro dos Santos', 'Uvaranas', '84030-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29311, 'Guarapuava', 'Professora Carlita Guimarães Pupo', 'Bonsucesso', '85035-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29312, 'Curitiba', 'Professora Carmem Lima de Almeida', 'Bacacheri', '82600-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29313, 'Londrina', 'Professora Célia Gonçalves Dias', 'Milton Gavetti', '86078-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29314, 'Curitiba', 'Professora Clara Kaehler', 'Tatuquara', '81470-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29315, 'Curitiba', 'Professora Delminda Santos Fernandes', 'Sítio Cercado', '81910-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29316, 'Londrina', 'Professora Delvina Borges', 'Universitário', '86050-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29317, 'Araucária', 'Professora Djanira Ribas de Albuquerque', 'Boqueirão', '83704-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29318, 'São José dos Pinhais', 'Professora Dolores Taborda Ribas', 'Rio Pequeno', '83065-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29320, 'Curitiba', 'Professora Doracy Cesarino', 'Portão', '80320-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29321, 'Curitiba', 'Professora Dorotea Spak Choma', 'Tarumã', '82530-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29322, 'Telêmaco Borba', 'Professora Edith Gordan', 'Centro', '84261-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29323, 'Curitiba', 'Professora Edmée Neal Algouver', 'Alto Boqueirão', '81770-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29324, 'Paranaguá', 'Professora Eleosina Plaisant', 'Bockmann', '83206-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29325, 'Curitiba', 'Professora Emma Carvalho dos Santos', 'Xaxim', '81830-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29326, 'Paranavaí', 'Professora Enira Braga de Moraes', 'Jardim Nakamura', '87701-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29327, 'Curitiba', 'Professora Ephigênia do Rego Barros', 'Mercês', '80730-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29328, 'Curitiba', 'Professora Ernestina Alves de Almeida', 'Boqueirão', '81670-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29329, 'São José dos Pinhais', 'Professora Ernestina de Macedo Souza', 'Afonso Pena', '83050-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29330, 'Campo Largo', 'Professora Escolástica', 'Itaqui', '83604-490', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29331, 'Curitiba', 'Professora Estella Mariano Lacombe', 'Abranches', '82130-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29332, 'Maringá', 'Professora Ester Gonçalves Josepetti', 'Jardim Alvorada', '87035-120', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29333, 'Londrina', 'Professora Evelina S. Grandis', 'Conjunto Professora Hilda Mandarino', '86080-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29334, 'Curitiba', 'Professora Gelvira Correia Pacheco', 'Bacacheri', '82520-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29335, 'Curitiba', 'Professora Georgina Mongruel', 'Santa Cândida', '82640-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29336, 'Francisco Beltrão', 'Professora Guislene Rehbein Pedron', 'Nova Petrópolis', '85601-146', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29337, 'Ponta Grossa', 'Professora Haidée de Oliveira Madureira', 'Boa Vista', '84073-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29338, 'Curitiba', 'Professora Helena Dionyzio', 'Capão Raso', '81110-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29339, 'Curitiba', 'Professora Hilda Hanke Gonçalves', 'Cidade Industrial', '81240-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29340, 'Curitiba', 'Professora Hilda Hanke Gonçalves', 'Cidade Industrial', '81250-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29341, 'Curitiba', 'Professora Hildgard Schmah', 'Portão', '81070-425', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29342, 'Curitiba', 'Professora Ieza Almeida Bronholo', 'Novo Mundo', '81050-540', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29343, 'São José dos Pinhais', 'Professora Ilza de Souza Santos', 'Afonso Pena', '83050-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29344, 'Curitiba', 'Professora Ivette Fonseca de Siqueira', 'Batel', '80420-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29345, 'Curitiba', 'Professora Ivette Rocha Krüger', 'Cidade Industrial', '81460-358', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29346, 'Ponta Grossa', 'Professora Izaura Torres Cruz', 'Jardim Carvalho', '84015-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29347, 'Curitiba', 'Professora Joanita Bernett Passos', 'Boqueirão', '81730-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29348, 'Ponta Grossa', 'Professora Judith Macedo Silveira', 'Olarias', '84035-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29349, 'Ponta Grossa', 'Professora Jugurta Gonçalves de Oliveira', 'Contorno', '84052-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29350, 'Curitiba', 'Professora Júlia A. Di Lenna', 'Santa Cândida', '82640-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29351, 'Ponta Grossa', 'Professora Júlia Carneiro Rosas', 'Uvaranas', '84020-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29352, 'Ponta Grossa', 'Professora Júlia Carneiro Rosas', 'Uvaranas', '84021-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29353, 'Curitiba', 'Professora Júlia Valery Legat Neal', 'Xaxim', '81810-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29354, 'Apucarana', 'Professora Karel Kober', 'Vila Feliz', '86808-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29355, 'Londrina', 'Professora Kazuco Ohara', 'Colúmbia', '86057-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29356, 'Curitiba', 'Professora Kloldi Jane Assis', 'Sítio Cercado', '81925-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29357, 'Curitiba', 'Professora Laís de Lima Conter Parfieniuk', 'Santa Cândida', '82650-475', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29358, 'Guarapuava', 'Professora Leni M. Jacob', 'Boqueirão', '85020-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29359, 'Guarapuava', 'Professora Leonidia', 'Bonsucesso', '85035-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29360, 'Guarapuava', 'Professora Leonidia', 'Centro', '85010-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29361, 'Araucária', 'Professora Leonor Machado Busse', 'Thomaz Coelho', '83707-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29362, 'Maringá', 'Professora Letícia de Paula Molinari', 'Copacabana Residencial', '87023-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29363, 'São José dos Pinhais', 'Professora Lourdes Grutter Bonin', 'Afonso Pena', '83050-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29364, 'Almirante Tamandaré', 'Professora Mafalda', 'Planta São Venâncio', '83504-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29365, 'Curitiba', 'Professora Maria Balbina Costa Dias', 'Barreirinha', '82560-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29366, 'Curitiba', 'Professora Maria Brígida N. dos Santos', 'Cascatinha', '82020-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29367, 'Londrina', 'Professora Maria Cintra de Alcântara', 'Milton Gavetti', '86078-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29368, 'São José dos Pinhais', 'Professora Maria Clarice Polak Suckenski', 'Rio Pequeno', '83065-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29369, 'Maringá', 'Professora Maria Cleusa Milléo Romano', 'Jardim Santa Rosa', '87060-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29370, 'Curitiba', 'Professora Maria da Glória Saldanha Loyola', 'Uberaba', '81540-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29371, 'Curitiba', 'Professora Maria de Assumpção', 'Hauer', '81630-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29372, 'Curitiba', 'Professora Maria de Assumpção', 'Boqueirão', '81670-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29373, 'Curitiba', 'Professora Maria do Carmo de Figueiredo Silva', 'Alto Boqueirão', '81770-779', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29374, 'Curitiba', 'Professora Maria do Carmo Martins', 'São Braz', '82300-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29375, 'Londrina', 'Professora Maria do Rosário Castaldi', 'Conjunto Café', '86038-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29376, 'Curitiba', 'Professora Maria Esther Carvalho de Barros', 'Capão da Imbuia', '82810-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29377, 'Curitiba', 'Professora Maria Genebra', 'São Braz', '82300-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29378, 'Curitiba', 'Professora Maria Helena Kruzielski Bredow', 'São Braz', '82300-440', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29379, 'Castro', 'Professora Maria Helvina C. de Mello', 'Invernada do Matadouro', '84174-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29380, 'Castro', 'Professora Maria Helvina C. de Mello', 'Vila Rio Branco', '84172-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29381, 'Curitiba', 'Professora Maria José Godoy', 'Bom Retiro', '80520-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29382, 'São José dos Pinhais', 'Professora Maria Lenita Duma', 'Guatupê', '83060-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29383, 'Araucária', 'Professora Maria Nassar Schaustek', 'Campina da Barra', '83709-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29384, 'Curitiba', 'Professora Maria Salles Godoy', 'Guabirotuba', '81510-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29385, 'Ponta Grossa', 'Professora Maria Sezinia Ferreira Amora', 'Oficinas', '84045-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29386, 'São José dos Pinhais', 'Professora Maria Vidal Novaes', 'Ipê', '83055-518', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29387, 'Cambé', 'Professora Mariana S. Muniz', 'Planta São Francisco', '86182-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29388, 'São José dos Pinhais', 'Professora Marieta de Souza e Silva', 'Afonso Pena', '83050-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29389, 'Curitiba', 'Professora Marina Pinto', 'Mercês', '80710-255', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29390, 'Maringá', 'Professora Nadir Apparecida Cancian', 'Zona 07', '87030-085', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29391, 'Ponta Grossa', 'Professora Neusa Warneck Ribas', 'Oficinas', '84035-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29392, 'Paranavaí', 'Professora Neuza Cascão Borba', 'Jardim Aeroporto', '87705-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29393, 'Apucarana', 'Professora Nilza Carolina Pedersoli Bertasso', 'Jardim Trabalhista', '86807-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29394, 'Curitiba', 'Professora Noemi dos Santos', 'Bacacheri', '82600-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29395, 'Maringá', 'Professora Odete Ribaroli G. de Castro', 'Jardim Liberdade', '87047-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29396, 'Curitiba', 'Professora Olga Balster', 'Cajuru', '82900-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29397, 'Curitiba', 'Professora Olga Balster', 'Capão da Imbuia', '82810-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29398, 'São José dos Pinhais', 'Professora Olívia de Moraes Senko', 'Águas Belas', '83010-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29399, 'São José dos Pinhais', 'Professora Olívia Nogueira', 'São Pedro', '83020-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29400, 'Colombo', 'Professora Otília de Souza Ferrarini', 'Jardim dos Eucaliptos', '83408-547', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29401, 'Telêmaco Borba', 'Professora Otília Macedo Sikorski', 'Centro', '84261-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29402, 'Curitiba', 'Professora Pompília L. dos Santos', 'Cidade Industrial', '81450-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29403, 'Maringá', 'Professora Rachel Dora Paraná Pintinha', 'Jardim Alvorada', '87033-440', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29404, 'Curitiba', 'Professora Regina Ambrósio Pimentel', 'Santa Felicidade', '82020-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29405, 'Curitiba', 'Professora Regina Célia Marinoni', 'Prado Velho', '80215-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29406, 'Apucarana', 'Professora Risoleta Pádua Rodrigues', 'Jardim Aeroporto', '86812-507', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29407, 'Campo Mourão', 'Professora Rosa', 'Jardim Tropical II', '87310-086', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29408, 'Almirante Tamandaré', 'Professora Rosa Frederica Johnson', 'Jardim Monte Santo', '83501-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29409, 'Curitiba', 'Professora Rosa Kolody', 'Água Verde', '80620-500', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29410, 'Curitiba', 'Professora Rosa Saporski', 'Mercês', '80810-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29411, 'Curitiba', 'Professora Sandália Manzon', 'Santa Cândida', '82640-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29412, 'Curitiba', 'Professora Sílvia Gonçalves Cordeiro Ribas', 'Santa Felicidade', '82410-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29413, 'Curitiba', 'Professora Sônia Maria Coimbra Kenski', 'Cajuru', '82980-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29414, 'Apucarana', 'Professora Talita Bresolin', 'Jardim São Pedro', '86802-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29415, 'Almirante Tamandaré', 'Professora Terezinha Camargo', 'Planta São Venâncio', '83504-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29416, 'Curitiba', 'Professora Terezita Faria dos Santos Lima', 'Pilarzinho', '82110-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29417, 'Curitiba', 'Professora Valdomira Zortéa', 'Umbará', '81930-606', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29418, 'Curitiba', 'Professora Victória Grassi Mattei', 'São Lourenço', '82200-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29419, 'Curitiba', 'Professora Woyslava Trzeciak Ângelotti', 'Sítio Cercado', '81920-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29420, 'Curitiba', 'Professora Yeda de Souza de Castro', 'Jardim das Américas', '81530-330', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29421, 'Cambé', 'Professora Zelda C. Cursi Mastriani', 'Planta São Francisco', '86182-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29422, 'Curitiba', 'Profeta Amos', 'Umbará', '81930-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29423, 'Umuarama', 'Profeta Daniel', 'Parque Dom Pedro II', '87508-066', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29424, 'Curitiba', 'Profeta Daniel', 'Umbará', '81930-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29425, 'Foz do Iguaçu', 'Profeta Elias', 'Jardim Evangélico', '85870-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29426, 'Umuarama', 'Profeta Elias', 'Parque Dom Pedro II', '87508-047', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29427, 'Curitiba', 'Profeta Elias', 'Umbará', '81930-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29428, 'Umuarama', 'Profeta Elizeu', 'Parque Dom Pedro II', '87508-048', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29429, 'Curitiba', 'Profeta Elizeu', 'Umbará', '81930-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29430, 'Umuarama', 'Profeta Ezequiel', 'Parque Dom Pedro II', '87508-077', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29431, 'Curitiba', 'Profeta Ezequiel', 'Umbará', '81930-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29432, 'Umuarama', 'Profeta Isaías', 'Parque Dom Pedro II', '87508-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29433, 'Curitiba', 'Profeta Isaías', 'Umbará', '81930-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29434, 'Umuarama', 'Profeta Jeremias', 'Parque Dom Pedro II', '87508-076', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29435, 'Umuarama', 'Profeta Joel', 'Parque Dom Pedro II', '87508-046', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29436, 'Curitiba', 'Profeta Joel', 'Umbará', '81930-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29437, 'Umuarama', 'Profeta Jonas', 'Parque Dom Pedro II', '87508-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29438, 'Curitiba', 'Profeta Moisés', 'Santa Cândida', '82640-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29439, 'Umuarama', 'Profeta Oséias', 'Parque Dom Pedro II', '87508-049', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29440, 'Umuarama', 'Profeta Samuel', 'Parque Dom Pedro II', '87508-067', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29441, 'Umuarama', 'Profeta Zacarias', 'Parque Dom Pedro II', '87508-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29442, 'Curitiba', 'Progênito Machuca', 'Cajuru', '82940-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29443, 'Francisco Beltrão', 'Progresso', 'São Miguel', '85602-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29444, 'Londrina', 'Progresso', 'Jardim Londrilar', '86010-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29445, 'Paranavaí', 'Projetada', 'Jardim São Jorge', '87711-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29446, 'Paranavaí', 'Projetada', 'Vila Alta', '87708-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29447, 'Maringá', 'Projetada', 'Parque Industrial Bandeirantes', '87070-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29448, 'Sarandi', 'Projetada', 'Parque Industrial II', '87111-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29449, 'Sarandi', 'Projetada 1', 'Jardim Triângulo', '87112-785', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29450, 'Ponta Grossa', 'Projetada 10', 'Uvaranas', '84020-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29451, 'Sarandi', 'Projetada 6', 'Jardim Triângulo', '87112-835', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29452, 'Paranavaí', 'Projetada A', 'Vila Operária', '87708-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29453, 'Sarandi', 'Projetada A', 'Jardim Nova Independência I', '87114-815', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29454, 'Sarandi', 'Projetada A', 'Jardim Monterey', '87112-795', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29455, 'Umuarama', 'Projetada A', 'Parque das Jaboticabeiras', '87509-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29456, 'Arapongas', 'Projetada A', 'Parque Industrial V', '86702-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29457, 'Paranavaí', 'Projetada B', 'Vila Operária', '87708-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29458, 'Sarandi', 'Projetada B', 'Conjunto Casa da Família', '87114-835', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29459, 'Sarandi', 'Projetada B', 'Jardim Nova Independência I', '87114-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29460, 'Paranavaí', 'Projetada C', 'Vila Operária', '87708-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29461, 'Sarandi', 'Projetada C', 'Jardim Nova Independência I', '87114-825', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29462, 'Sarandi', 'Projetada Cinco', 'Jardim Triângulo', '87112-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29463, 'Paranavaí', 'Projetada D', 'Vila Operária', '87708-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29464, 'Arapongas', 'Projetada D', 'Parque Industrial V', '86702-266', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29465, 'Sarandi', 'Projetada Dois', 'Jardim Triângulo', '87112-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29466, 'Paranavaí', 'Projetada e', 'Vila Operária', '87708-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29467, 'Umuarama', 'Projetada E', 'Parque 1º de Maio', '87509-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29468, 'Paranavaí', 'Projetada F', 'Vila Operária', '87708-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29469, 'Paranavaí', 'Projetada G', 'Vila Operária', '87708-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29470, 'Paranavaí', 'Projetada H', 'Vila Operária', '87708-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29471, 'Umuarama', 'Projetada J C', 'Parque das Jaboticabeiras', '87509-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29472, 'Umuarama', 'Projetada K C', 'Parque das Jaboticabeiras', '87509-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29473, 'Umuarama', 'Projetada L C', 'Parque das Jaboticabeiras', '87509-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29474, 'Sarandi', 'Projetada Quatro', 'Jardim Triângulo', '87112-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29475, 'Sarandi', 'Projetada Três', 'Jardim Triângulo', '87112-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29476, 'Sarandi', 'Projetada Um', 'Jardim Triângulo', '87112-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29477, 'Maringá', 'Promissão', 'Parque das Grevíleas', '87025-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29478, 'Cascavel', 'Promotor Cezar Salgado', 'Parque São Paulo', '85803-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29479, 'Curitiba', 'Prosdócimo Guerra', 'Juvevê', '80530-310', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29480, 'Toledo', 'Protásio Alves', 'Jardim Parigot', '85904-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29481, 'Toledo', 'Protásio Alves', 'Nilton A de Castro Arruda', '85903-698', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29482, 'Toledo', 'Protásio Alves', 'Vila Industrial', '85905-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29483, 'Cambé', 'Provérbios', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29484, 'Castro', 'Prudência Celeste da Fonseca Novaes', 'Jardim dos Bancários', '84172-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29485, 'Pato Branco', 'Prudêncio Alves de Oliveira', 'Bancários', '85504-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29486, 'Foz do Iguaçu', 'Prudêncio Sotelo', 'Jardim Porto Belo', '85867-516', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29487, 'Francisco Beltrão', 'Prudente Albuquerque', 'Jardim Santa Fé', '85602-509', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29488, 'Curitiba', 'Prudente de Moraes', 'Centro', '80430-220', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29489, 'Londrina', 'Prudente de Morais', 'Champagnat', '86062-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29490, 'Laranjeiras do Sul', 'Prudente de Morais', 'Getúlio Vargas', '85304-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29491, 'Guarapuava', 'Prudente de Morais', 'Morro Alto', '85065-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29492, 'Foz do Iguaçu', 'Prudente de Morais', 'Parque Presidente', '85863-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29493, 'Pinhais', 'Prudente de Morais', 'Vila Amélia', '83330-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29494, 'Maringá', 'Prudente de Morais', 'Zona 07', '87020-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29495, 'Ponta Grossa', 'Prudente de Morais', 'Estrela', '84040-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29496, 'Toledo', 'Prudente de Morais', 'Jardim Europa', '85908-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29497, 'Telêmaco Borba', 'Prudente de Morais', 'Alto das Oliveiras', '84265-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29498, 'Cascavel', 'Prudente de Morais', 'Parque São Paulo', '85803-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29499, 'Colombo', 'Prudente de Morais', 'Jardim das Perdizes', '83409-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29500, 'Apucarana', 'Prudente de Morais', 'Jardim Trabalhista', '86807-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29501, 'Guarapuava', 'Prudentópolis', 'Morro Alto', '85067-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29502, 'Ponta Grossa', 'Prudentópolis', 'Chapada', '84062-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29503, 'Paranavaí', 'Prudentópolis', 'Jardim Ouro Branco', '87704-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29504, 'Telêmaco Borba', 'Prudentópolis', 'Centro', '84261-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29505, 'São José dos Pinhais', 'Prudentópolis', 'Afonso Pena', '83045-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29506, 'Curitiba', 'Prudentópolis', 'Pinheirinho', '81880-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29507, 'Curitiba', 'Público', 'Centro', '80020-330', 'Passeio', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29508, 'Cascavel', 'Públio Pimentel', 'Alto Alegre', '85805-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29509, 'Cascavel', 'Públio Pimentel', 'Santa Cruz', '85806-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29510, 'Curitiba', 'Puccini', 'São Braz', '82300-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29511, 'Foz do Iguaçu', 'Puma', 'Conjunto A', '85860-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29512, 'Campo Mourão', 'Puma', 'Centro', '87302-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29513, 'Foz do Iguaçu', 'Purus', 'Loteamento Campos do Iguaçu', '85857-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29514, 'Londrina', 'Purus', 'Pietraroia', '86025-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29515, 'Araucária', 'Purús', 'Iguaçu', '83701-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29516, 'Curitiba', 'Purús', 'Bacacheri', '82520-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29517, 'Foz do Iguaçu', 'Q', 'Conjunto C', '85870-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29518, 'Umuarama', 'Q', 'Parque Bonfim', '87507-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29519, 'Campo Largo', 'Q', 'Vila Torres II', '83609-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29520, 'Arapongas', 'Q', 'Jardim Caravelle', '86702-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29521, 'Paranavaí', 'Quadra A', 'Vila Operária', '87708-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29522, 'Paranavaí', 'Quadra B', 'Vila Operária', '87708-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29523, 'Paranavaí', 'Quadra C', 'Vila Operária', '87708-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29524, 'Paranavaí', 'Quadra D', 'Vila Operária', '87708-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29525, 'Paranavaí', 'Quadra E', 'Vila Operária', '87708-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29526, 'Paranavaí', 'Quadra F', 'Vila Operária', '87708-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29527, 'Paranavaí', 'Quadra G', 'Vila Operária', '87708-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29528, 'Paranavaí', 'Quadra H', 'Vila Operária', '87708-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29529, 'Paranavaí', 'Quadra I', 'Vila Operária', '87708-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29530, 'Paranavaí', 'Quadra J', 'Vila Operária', '87708-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29531, 'Cambé', 'Quarenta e Três', 'Parque Residencial Ana Rosa', '86183-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29532, 'Ponta Grossa', 'Quaresmeira', 'Contorno', '84061-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29533, 'Cascavel', 'Quaresmeira', 'Recanto Tropical', '85807-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29534, 'Curitiba', 'Quari', 'São Francisco', '80510-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29535, 'Curitiba', 'Quarto Centenário da Cidade do Rio de Janeiro', 'Tatuquara', '81880-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29536, 'Foz do Iguaçu', 'Quartzo', 'Parque Ouro Verde', '85854-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29537, 'Londrina', 'Quartzo', 'Waldemar Hauer', '86030-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29538, 'Maringá', 'Quartzo', 'Jardim Real', '87083-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29539, 'Ponta Grossa', 'Quartzo', 'Neves', '84021-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29540, 'Cambé', 'Quartzo', 'Conjunto Habitacional Cristal', '86182-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29541, 'Cascavel', 'Quartzo', 'Esmeralda', '85806-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29542, 'Londrina', 'Quata', 'Jardim Alvorada', '86062-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29543, 'Francisco Beltrão', 'Quatigua', 'São Miguel', '85602-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29544, 'Pinhais', 'Quatigua', 'Jardim Pedro Demeterco', '83324-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29545, 'Telêmaco Borba', 'Quatigua', 'Centro', '84261-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29546, 'Curitiba', 'Quatigua', 'São Braz', '82315-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29547, 'Ponta Grossa', 'Quatorze', 'Chapada', '84062-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29548, 'Paranaguá', 'Quatorze', 'Vila Garcia', '83218-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29549, 'Ponta Grossa', 'Quatorze', 'Jardim Carvalho', '84016-528', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29550, 'Ponta Grossa', 'Quatorze', 'Chapada', '84064-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29551, 'Ponta Grossa', 'Quatorze', 'Contorno', '84060-606', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29552, 'Ponta Grossa', 'Quatorze', 'Uvaranas', '84022-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29553, 'Ponta Grossa', 'Quatorze', 'Uvaranas', '84030-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29554, 'Campo Largo', 'Quatorze', 'Jardim Lorenzete', '83603-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29555, 'Almirante Tamandaré', 'Quatorze', 'Loteamento Marinoni', '83508-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29556, 'Almirante Tamandaré', 'Quatorze', 'Jardim Silvana', '83512-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29557, 'Almirante Tamandaré', 'Quatorze', 'Jardim Tatiana', '83513-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29558, 'Campo Largo', 'Quatorze', 'Jardim Guarany I', '83608-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29559, 'Londrina', 'Quatorze Bis', 'Aeroporto', '86039-215', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29560, 'Ponta Grossa', 'Quatorze Bis', 'Cará-cará', '84043-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29561, 'Cascavel', 'Quatorze Bis', 'Santos Dumont', '85804-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29562, 'Curitiba', 'Quatorze Bis', 'Pinheirinho', '81820-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29563, 'Paranavaí', 'Quatorze de Dezembro', 'Jardim André Luiz', '87708-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29564, 'Laranjeiras do Sul', 'Quatorze de Julho', 'Centro', '85301-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29565, 'Ponta Grossa', 'Quatorze de Julho', 'Centro', '84010-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29566, 'Toledo', 'Quatorze de Julho', 'Jardim La Salle', '85902-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29567, 'Castro', 'Quatorze de Julho', 'Vila Rio Branco', '84172-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29568, 'Curitiba', 'Quatorze de Julho', 'Alto Boqueirão', '81830-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29569, 'Foz do Iguaçu', 'Quatorze de Maio', 'Vila Paraguaia', '85864-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29570, 'Foz do Iguaçu', 'Quatorze de Março', 'Centro', '85851-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29571, 'Cascavel', 'Quatorze de Novembro', 'Vila Tolentino', '85802-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29572, 'Sarandi', 'Quatorze de Outubro', 'Parque Industrial II', '87111-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29573, 'Sarandi', 'Quatorze de Outubro', 'Jardim Ipanema', '87112-335', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29574, 'Foz do Iguaçu', 'Quatro', 'Portal da Foz', '85859-536', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29575, 'Foz do Iguaçu', 'Quatro', 'Conjunto Residencial Yang Ming', '85854-297', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29576, 'Ponta Grossa', 'Quatro', 'Contorno', '84060-567', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29577, 'Ponta Grossa', 'Quatro', 'Cará-cará', '84032-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29578, 'Paranaguá', 'Quatro', 'Rocio', '83221-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29579, 'Paranaguá', 'Quatro', 'Jardim Paraná', '83215-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29580, 'Paranaguá', 'Quatro', 'Vila Garcia', '83218-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29581, 'Ponta Grossa', 'Quatro', 'Uvaranas', '84026-588', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29582, 'Ponta Grossa', 'Quatro', 'Jardim Carvalho', '84016-508', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29583, 'Ponta Grossa', 'Quatro', 'Contorno', '84060-588', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29584, 'Ponta Grossa', 'Quatro', 'Chapada', '84064-567', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29585, 'Ponta Grossa', 'Quatro', 'Chapada', '84063-417', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29586, 'Paranavaí', 'Quatro', 'Conjunto Dona Josefa', '87708-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29587, 'Ponta Grossa', 'Quatro', 'Uvaranas', '84032-458', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29588, 'Ponta Grossa', 'Quatro', 'Uvaranas', '84022-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29589, 'Maringá', 'Quatro', 'Parque Industrial', '87065-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29590, 'Ponta Grossa', 'Quatro', 'Uvaranas', '84030-479', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29591, 'Paranavaí', 'Quatro', 'Jardim Maringá', '87709-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29592, 'Piraquara', 'Quatro', 'Chácara Águas Claras', '83309-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29593, 'Piraquara', 'Quatro', 'Chácara Águas Claras', '83309-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29594, 'Piraquara', 'Quatro', 'Chácara Águas Claras', '83309-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29595, 'Telêmaco Borba', 'Quatro', 'Vila Santa Rita', '84263-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29596, 'Umuarama', 'Quatro', 'Jardim Maria Lúcia', '87501-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29597, 'Sarandi', 'Quatro', 'Jardim Nova Independência I', '87114-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29598, 'Umuarama', 'Quatro', 'Jardim Monte Carlo', '87506-540', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29599, 'Umuarama', 'Quatro', 'Jardim Beira Rio', '87507-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29600, 'Umuarama', 'Quatro', 'Jardim São Cristóvão', '87507-358', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29601, 'Toledo', 'Quatro', 'Parque Residencial Gisela', '85905-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29602, 'Almirante Tamandaré', 'Quatro', 'Jardim Arco Íris', '83504-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29603, 'Almirante Tamandaré', 'Quatro', 'Planta Bela Vista', '83514-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29604, 'Campo Largo', 'Quatro', 'Vila Conceição', '83608-297', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29605, 'Campo Largo', 'Quatro', 'Vila Pompéia', '83608-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29606, 'Almirante Tamandaré', 'Quatro', 'Jardim Maria Luiza', '83514-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29607, 'Almirante Tamandaré', 'Quatro', 'Jardim Santa Rita de Cássia', '83506-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29608, 'Almirante Tamandaré', 'Quatro', 'Jardim Areias', '83514-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29609, 'Almirante Tamandaré', 'Quatro', 'Jardim Valença', '83512-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29610, 'Campo Largo', 'Quatro', 'Moradias Bom Jesus', '83602-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29611, 'Almirante Tamandaré', 'Quatro', 'Jardim Tatiana', '83513-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29612, 'Campo Largo', 'Quatro', 'Jardim das Palmas', '83602-047', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29613, 'Almirante Tamandaré', 'Quatro', 'Jardim Cíntia Mara', '83513-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29614, 'Almirante Tamandaré', 'Quatro', 'Jardim Alvorada', '83505-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29615, 'Almirante Tamandaré', 'Quatro', 'Jardim Bela Vista', '83513-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29616, 'Almirante Tamandaré', 'Quatro', 'São Miguel', '83511-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29617, 'Almirante Tamandaré', 'Quatro', 'Jardim das Oliveiras', '83502-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29618, 'Almirante Tamandaré', 'Quatro', 'Vila Santa Edwiges', '83504-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29619, 'Campo Largo', 'Quatro', 'Jardim das Palmeiras', '83602-037', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29620, 'Campo Largo', 'Quatro', 'Vila Gilcy', '83609-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29621, 'Campo Largo', 'Quatro', 'Jardim Clímax', '83608-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29622, 'Campo Largo', 'Quatro', 'Jardim Paraíso Mineral', '83606-117', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29623, 'Campo Largo', 'Quatro', 'Núcleo Habitacional Mathias Batista', '83604-157', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29624, 'Campo Largo', 'Quatro', 'Jardim Lorenzete', '83603-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29625, 'Campo Largo', 'Quatro', 'Loteamento Helvidia', '83605-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29626, 'Campo Largo', 'Quatro', 'Jardim Santa Luzia', '83606-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29627, 'Campo Largo', 'Quatro', 'Vila São Luiz', '83608-237', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29628, 'Castro', 'Quatro', 'Morada do Sol', '84172-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29629, 'Almirante Tamandaré', 'Quatro', 'Loteamento Marinoni', '83508-557', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29630, 'Campo Largo', 'Quatro', 'Jardim Keli Cristina', '83609-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29631, 'Campo Largo', 'Quatro', 'Jardim Guarany I', '83608-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29632, 'Campo Largo', 'Quatro', 'Vila Torres I', '83609-550', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29633, 'Campo Largo', 'Quatro', 'Vila Mariano Torres', '83608-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29634, 'Campo Largo', 'Quatro', 'Loteamento São Gerônimo', '83606-178', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29635, 'Campo Largo', 'Quatro', 'Jardim das Acácias', '83603-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29636, 'Campo Largo', 'Quatro', 'Jardim Florestal', '83602-026', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29637, 'Foz do Iguaçu', 'Quatro Barras', 'Jardim Residencial São Roque', '85853-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29638, 'Almirante Tamandaré', 'Quatro Barras', 'Loteamento Chico Mendes', '83505-757', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29639, 'Almirante Tamandaré', 'Quatro Barras', 'Jardim Roma', '83504-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29640, 'Curitiba', 'Quatro Barras', 'Sítio Cercado', '81900-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29641, 'Almirante Tamandaré', 'Quatro de Abril', 'Loteamento Nova Morada', '83504-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29642, 'Guarapuava', 'Quatro de Julho', 'Alto Cascavel', '85031-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29643, 'Telêmaco Borba', 'Quatro de Maio', 'Fazenda Limeira', '84267-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29644, 'Umuarama', 'Quatro de Outubro', 'Conjunto Residencial Vinte e Oito de Outubro', '87509-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29645, 'Foz do Iguaçu', 'Quatro Pontes', 'Jardim Cedro', '85862-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29646, 'Maringá', 'Quebec', 'Jardim Canadá', '87080-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29647, 'Sarandi', 'Quebec', 'Jardim Califórnia', '87112-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29648, 'Foz do Iguaçu', 'Quedas do Iguaçu', 'Jardim Duarte', '85861-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29649, 'Guarapuava', 'Quedas do Iguaçu', 'Alto Cascavel', '85031-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29650, 'Laranjeiras do Sul', 'Quedas do Iguaçu', 'Água Verde', '85302-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29651, 'Colombo', 'Quedas do Iguaçu', 'Jardim Guaraituba', '83410-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29652, 'Foz do Iguaçu', 'Queixada', 'Conjunto A', '85861-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29653, 'Arapongas', 'Quem-Quem', 'Vila Evereste', '86705-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29654, 'Londrina', 'Quênia', 'Ouro Verde', '86080-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29655, 'Pinhais', 'Quênia', 'Vila Varginha', '83320-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29656, 'Ponta Grossa', 'Querência do Norte', 'Olarias', '84026-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29657, 'Francisco Beltrão', 'Quero-quero', 'Padre Eurico', '85604-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29658, 'Foz do Iguaçu', 'Quero-quero', 'Parque Morumbi II', '85859-655', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29659, 'Londrina', 'Quero-quero', 'Jacomo Violin', '86088-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29660, 'Maringá', 'Quero-quero', 'Jardim Olímpico', '87070-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29661, 'Ponta Grossa', 'Quero-quero', 'Chapada', '84064-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29662, 'Arapongas', 'Quero-quero', 'Jardim Bandeirantes', '86703-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29663, 'Arapongas', 'Quete', 'Casa Família Arapongas II', '86706-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29664, 'Arapongas', 'Quetzal', 'Vila Araponguinha', '86705-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29665, 'Foz do Iguaçu', 'Quilombo', 'Jardim Vitória', '85853-667', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29666, 'São José dos Pinhais', 'Quinta', 'Ipê', '83055-380', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29667, 'Foz do Iguaçu', 'Quinta do Sol', 'Jardim Alvorada', '85859-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29668, 'São José dos Pinhais', 'Quinta do Sol', 'Bom Jesus', '83025-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29669, 'Colombo', 'Quinta do Sol', 'Jardim Guaraituba', '83410-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29670, 'Curitiba', 'Quinta do Sol', 'São Braz', '82315-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29671, 'Londrina', 'Quintino Bocaiúva', 'Centro', '86020-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29672, 'Foz do Iguaçu', 'Quintino Bocaiúva', 'Centro', '85851-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29673, 'Guarapuava', 'Quintino Bocaiúva', 'Trianon', '85012-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29674, 'Guarapuava', 'Quintino Bocaiúva', 'Centro', '85010-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29675, 'Ponta Grossa', 'Quintino Bocaiúva', 'Orfãs', '84015-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29676, 'Maringá', 'Quintino Bocaiúva', 'Zona 07', '87020-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29677, 'Toledo', 'Quintino Bocaiúva', 'Jardim Europa', '85908-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29678, 'Campo Largo', 'Quintino Bocaiúva', 'Centro', '83601-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29679, 'Cascavel', 'Quintino Bocaiúva', 'Parque São Paulo', '85803-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29680, 'Apucarana', 'Quintino Bocaiúva', 'Vila Santa Rosa', '86811-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29681, 'Colombo', 'Quintino Bocaiúva', 'Planta Vila Nova', '83404-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29682, 'Curitiba', 'Quintino Bocaiúva', 'Cabral', '80035-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29683, 'Curitiba', 'Quinto Regimento de Aviação', 'Bacacheri', '82515-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29684, 'Campo Mourão', 'Quinto Salvadori', 'Jardim Cidade Nova', '87308-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29685, 'Campo Mourão', 'Quinto Slomp', 'Jardim Copacabana', '87302-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29686, 'Ponta Grossa', 'Quinze', 'Uvaranas', '84030-757', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29687, 'Ponta Grossa', 'Quinze', 'Contorno', '84060-607', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29688, 'Ponta Grossa', 'Quinze', 'Uvaranas', '84022-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29689, 'Ponta Grossa', 'Quinze', 'Chapada', '84064-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29690, 'Ponta Grossa', 'Quinze', 'Jardim Carvalho', '84016-529', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29691, 'Campo Largo', 'Quinze', 'Jardim Guarany I', '83608-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29692, 'Almirante Tamandaré', 'Quinze', 'Loteamento Marinoni', '83508-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29693, 'Maringá', 'Quinze de Agosto', 'Jardim Alamar', '87014-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29694, 'Laranjeiras do Sul', 'Quinze de Novembro', 'Centro', '85301-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29695, 'Laranjeiras do Sul', 'Quinze de Novembro', 'São Francisco', '85303-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29696, 'Guarapuava', 'Quinze de Novembro', 'Centro', '85010-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29697, 'Foz do Iguaçu', 'Quinze de Novembro', 'Jardim Santa Rita', '85862-307', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29698, 'Guarapuava', 'Quinze de Novembro', 'Morro Alto', '85065-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29699, 'Guarapuava', 'Quinze de Novembro', 'Boqueirão', '85020-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29700, 'Londrina', 'Quinze de Novembro', 'Centro', '86020-100', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29701, 'Paranaguá', 'Quinze de Novembro', 'Centro Histórico', '83203-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29702, 'Pinhais', 'Quinze de Novembro', 'Jardim Pinhais', '83323-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29703, 'Paranavaí', 'Quinze de Novembro', 'Jardim Iguaçu', '87705-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29704, 'Maringá', 'Quinze de Novembro', 'Zona 01', '87013-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29705, 'Ponta Grossa', 'Quinze de Novembro', 'Centro', '84010-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29706, 'Telêmaco Borba', 'Quinze de Novembro', 'Centro', '84265-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29707, 'Toledo', 'Quinze de Novembro', 'Centro', '85902-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29708, 'Telêmaco Borba', 'Quinze de Novembro', 'Nossa Senhora do Perpétuo Socorro', '84265-530', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29709, 'Toledo', 'Quinze de Novembro', 'Centro', '85900-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29710, 'Sarandi', 'Quinze de Novembro', 'Parque Industrial IV', '87111-707', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29711, 'Umuarama', 'Quinze de Novembro', 'Jardim Alvorada', '87506-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29712, 'São José dos Pinhais', 'Quinze de Novembro', 'Centro', '83005-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29713, 'Campo Largo', 'Quinze de Novembro', 'Centro', '83601-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29714, 'Apucarana', 'Quinze de Novembro', 'Vila Regina', '86801-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29715, 'Apucarana', 'Quinze de Novembro', 'Vila Feliz', '86808-140', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29716, 'Almirante Tamandaré', 'Quinze de Novembro', 'Jardim Formosa', '83511-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29717, 'Castro', 'Quinze de Novembro', 'Centro', '84165-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29718, 'Colombo', 'Quinze de Novembro', 'Centro', '83414-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29719, 'Cambé', 'Quinze de Novembro', 'Jardim União', '86185-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29720, 'Curitiba', 'Quinze de Novembro', 'Centro', '80020-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29721, 'Curitiba', 'Quinze de Novembro', 'Centro', '80060-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29722, 'Curitiba', 'Quinze de Novembro', 'Alto da Rua XV', '80050-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29723, 'Pinhais', 'Quinze de Outubro', 'Jardim Pinhais', '83323-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29724, 'Umuarama', 'Quinze de Outubro', 'Mutirão Jardim Alvorada', '87506-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29725, 'Curitiba', 'Quinze de Outubro', 'Cajuru', '82970-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29726, 'Ponta Grossa', 'Quinze de Setembro', 'Uvaranas', '84020-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29727, 'Londrina', 'Quiri', 'Santa Rita 1', '86071-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29728, 'Cascavel', 'Quiri', 'Periolo', '85817-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29729, 'São José dos Pinhais', 'Quirino Zagonel', 'Braga', '83020-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29730, 'Arapongas', 'Quiri-quiri', 'Jardim Coroados', '86707-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29731, 'Ponta Grossa', 'Quiruá', 'Colônia Dona Luiza', '84046-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29732, 'Arapongas', 'Quiruá', 'Jardim Coroados', '86707-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29733, 'Arapongas', 'Quiscalo', 'Centro', '86701-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29734, 'Foz do Iguaçu', 'Quitandinha', 'Jardim das Palmeiras II', '85869-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29735, 'Colombo', 'Quitandinha', 'Jardim Guaraituba', '83410-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29736, 'Curitiba', 'Quitandinha', 'Sítio Cercado', '81900-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29737, 'Foz do Iguaçu', 'Quito', 'Beverly Falls Park', '85858-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29738, 'Maringá', 'Quito', 'Vila Morangueira', '87040-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29739, 'Telêmaco Borba', 'Quito', 'Nossa Senhora de Fátima', '84264-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29740, 'Colombo', 'Quivi', 'Planta Santa Tereza', '83401-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29741, 'Foz do Iguaçu', 'Quixadá', 'Parque Residencial Três Fronteiras', '85855-608', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29742, 'Foz do Iguaçu', 'R', 'Conjunto C', '85870-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29743, 'Umuarama', 'R', 'Parque Bonfim', '87507-466', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29744, 'Campo Largo', 'R', 'Vila Torres II', '83609-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29745, 'Arapongas', 'Rabiforcado', 'Vila Paulo', '86705-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29746, 'Arapongas', 'Rabilonga', 'Vila Cascata', '86701-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29747, 'Umuarama', 'Rachel de Queirós', 'Jardim Vitória', '87509-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29748, 'Curitiba', 'Rachid Pacifico Fatuch', 'Santa Felicidade', '82015-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29749, 'Londrina', 'Rachid Scaff', 'Ernani de Moura Lima', '86037-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29750, 'Ponta Grossa', 'Radialista Nelson Anunziato', 'Boa Vista', '84073-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29751, 'Maringá', 'Radialista Osvaldo Santos', 'Conjunto Residencial Ney Braga', '87083-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29752, 'Curitiba', 'Radialista Rúbens Chagas', 'Cidade Industrial', '81350-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29753, 'Guarapuava', 'Rafael Alves Marcondes', 'Vila Carli', '85040-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29754, 'Curitiba', 'Rafael Amatuzzi Samways', 'Orleans', '81200-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29755, 'Curitiba', 'Rafael Arcanjo Machado', 'Uberaba', '81570-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29756, 'Paranavaí', 'Rafael Bruno', 'Centro', '87701-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29757, 'Apucarana', 'Rafael Chombo', 'Núcleo Habitacional Mathias Hoffman', '86805-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29758, 'Colombo', 'Rafael de Queiroz', 'Jardim Planalto', '83409-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29759, 'Colombo', 'Rafael Ferreira de Lima', 'Jardim dos Eucaliptos', '83408-518', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29760, 'Curitiba', 'Rafael Francisco Greca', 'Água Verde', '80620-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29761, 'Curitiba', 'Rafael Klier de Assumpção', 'Santa Cândida', '82640-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29762, 'Londrina', 'Rafael Martinez Lopes', 'Jardim Vale Verde', '86040-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29763, 'Curitiba', 'Rafael Mischiatti', 'Uberaba', '81590-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29764, 'Pinhais', 'Rafael Percicotti', 'Jardim Triângulo', '83331-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29765, 'Cascavel', 'Rafael Picoli', 'Centro', '85813-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29766, 'Cascavel', 'Rafael Picoli', 'Canadá', '85813-221', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29767, 'Cascavel', 'Rafael Picoli', 'Centro', '85812-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29768, 'Cascavel', 'Rafael Picoli', 'Região do Lago 1', '85812-181', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29769, 'Londrina', 'Rafael Plaza', 'São Lourenço', '86043-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29770, 'São José dos Pinhais', 'Rafael Puchetti', 'Braga', '83020-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29771, 'Curitiba', 'Rafael Rodrigo Zanella', 'Santa Felicidade', '82020-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29772, 'Paranaguá', 'Rafael Silva', 'Serraria do Rocha', '83221-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29773, 'Apucarana', 'Rafael Sorpile', 'Núcleo Habitacional Heitor S Pinheiro', '86805-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29774, 'Curitiba', 'Rafael Vechione', 'Vista Alegre', '80820-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29775, 'Almirante Tamandaré', 'Rafaela', 'Jardim Rafaela', '83512-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29776, 'Curitiba', 'Rafaella Vidal Chagas', 'Sítio Cercado', '81920-730', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29777, 'São José dos Pinhais', 'Rafka Fayad', 'Guatupê', '83060-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29778, 'Curitiba', 'Raggi Izar', 'Boqueirão', '81670-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29779, 'Curitiba', 'Raggi Izar', 'Hauer', '81630-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29780, 'Curitiba', 'Rai Fischer', 'Cidade Industrial', '81310-445', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29781, 'Londrina', 'Raimunda Monteiro Garcia', 'Jardim Santa Fé', '86035-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29782, 'Laranjeiras do Sul', 'Raimundo Ayres de Araújo', 'Getúlio Vargas', '85304-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29783, 'Apucarana', 'Raimundo Batista', 'Núcleo Habitacional da Fraternidade', '86801-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29784, 'Curitiba', 'Raimundo Becker', 'Pilarzinho', '82120-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29785, 'Pinhais', 'Raimundo Belão', 'Jardim Triângulo', '83331-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29786, 'Pato Branco', 'Raimundo Cadorin', 'Santa Terezinha', '85506-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29787, 'Londrina', 'Raimundo Correia', 'Jardim Tatiani', '86070-470', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29788, 'Foz do Iguaçu', 'Raimundo Correia', 'Jardim Jupira', '85865-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29789, 'Guarapuava', 'Raimundo Correia', 'Santana', '85070-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29790, 'Ponta Grossa', 'Raimundo Correia', 'Oficinas', '84036-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29791, 'Maringá', 'Raimundo Correia', 'Zona 06', '87015-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29792, 'Colombo', 'Raimundo Correia', 'Vila Petrópolis', '83409-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29793, 'Curitiba', 'Raimundo da Motta Azevedo Correia', 'Ahú', '82200-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29794, 'Castro', 'Raimundo F. Gaião', 'Vila Rio Branco', '84172-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29795, 'Cascavel', 'Raimundo Ferreira Lima', 'Interlagos', '85814-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29796, 'Campo Largo', 'Raimundo Ferreira Portela', 'Vila Itaqui', '83604-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29797, 'Londrina', 'Raimundo Hilário Pinho', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29798, 'Toledo', 'Raimundo Leonardi', 'Jardim La Salle', '85903-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29799, 'Toledo', 'Raimundo Leonardi', 'Centro', '85900-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29800, 'Londrina', 'Raimundo Navarro Cortez', 'Portal de Versalhes 3', '86055-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29801, 'Londrina', 'Raimundo Nonato de Andrade', 'Conjunto Parigot de Souza 3', '86081-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29802, 'Curitiba', 'Raimundo Pereira do Amaral', 'Cidade Industrial', '81230-417', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29803, 'Araucária', 'Raimundo Suckow', 'Iguaçu', '83701-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29804, 'Curitiba', 'Raimundo Teobaldo Costa', 'Fazendinha', '81330-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29805, 'Londrina', 'Rainha-de-sabá', 'Nossa Senhora de Lourdes', '86039-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29806, 'Londrina', 'Rainha-do-lar', 'Newton Guimarães', '86082-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29807, 'Londrina', 'Raja Gabaglia', 'Quebec', '86060-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29808, 'Curitiba', 'Ralf Alberto Larsen', 'Alto Boqueirão', '81770-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29809, 'Ponta Grossa', 'Ramalho Ortigão', 'Colônia Dona Luiza', '84045-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29810, 'Colombo', 'Ramão da Silva', 'Centro Industrial Mauá', '83413-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29811, 'Foz do Iguaçu', 'Ramão Nascimento', 'Jardim Porto Belo', '85867-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29812, 'Curitiba', 'Ramília Gonçalves', 'Portão', '80320-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29813, 'Guarapuava', 'Ramiro Barcelos', 'Vila Carli', '85040-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29814, 'Londrina', 'Ramiro Borges Santana', 'Parque Residencial Campos Elísios', '86044-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29815, 'Curitiba', 'Ramiro Trevisan', 'Centro', '80430-225', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29816, 'Toledo', 'Ramiro Zibetti', 'Jardim Porto Alegre', '85906-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29817, 'Ponta Grossa', 'Ramiz Galvão', 'Oficinas', '84040-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29818, 'Sarandi', 'Ramom Carrasco', 'Parque Alvamar', '87113-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29819, 'Foz do Iguaçu', 'Ramon Santa Cruz Aguadyo', 'Vila Paraguaia', '85864-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29820, 'Campo Mourão', 'Ramos de Lima', 'Jardim Fernando', '87305-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29821, 'Londrina', 'Rancharia', 'Champagnat', '86062-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29822, 'Foz do Iguaçu', 'Rancharia', 'Jardim Vitória', '85853-666', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29823, 'Cambé', 'Rancharia', 'Jardim São Paulo', '86191-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29824, 'Curitiba', 'Rancho Alegre', 'Sítio Cercado', '81910-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29825, 'Curitiba', 'Randolfo Serzedelo', 'Fanny', '81030-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29826, 'Almirante Tamandaré', 'Randolfo Siqueira', 'Jardim Marize', '83507-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29827, 'Londrina', 'Rangel Pestana', 'Campo Belo', '86062-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29828, 'Foz do Iguaçu', 'Ranieri Mazzili', 'Parque Presidente', '85863-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29829, 'Curitiba', 'Raphael Costa Blanco', 'Ganchinho', '81935-377', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29830, 'Londrina', 'Raphael Ferraro', 'Novo Antares', '86036-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29831, 'Curitiba', 'Raphael Fiandanese Filho', 'Santo Inácio', '82010-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29832, 'Colombo', 'Raphael Francisco Greca', 'Itajacuru', '83407-836', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29833, 'São José dos Pinhais', 'Raphael Nester', 'Rio Pequeno', '83065-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29834, 'Foz do Iguaçu', 'Raphael Rouver', 'Jardim São Paulo I', '85856-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29835, 'Curitiba', 'Raphaela de Oliveira Gabilan', 'Barreirinha', '82560-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29836, 'Maringá', 'Raphaella Name Lucchesi', 'Jardim Olímpico', '87070-480', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29837, 'Londrina', 'Raposo Tavares', 'Larsen', '86010-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29838, 'Guarapuava', 'Raposo Tavares', 'Alto Cascavel', '85031-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29839, 'Maringá', 'Raposo Tavares', 'Zona 01', '87013-140', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29840, 'Ponta Grossa', 'Raposo Tavares', 'Uvaranas', '84030-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29841, 'Almirante Tamandaré', 'Raposo Tavares', 'Monte Mart', '83508-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29842, 'Cascavel', 'Raposo Tavares', 'São Cristóvão', '85816-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29843, 'Curitiba', 'Raposo Tavares', 'Pilarzinho', '82100-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29844, 'Londrina', 'Raquel', 'Nossa Senhora de Lourdes', '86039-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29845, 'Almirante Tamandaré', 'Raquel Cândido de Siqueira', 'Jardim São José', '83501-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29846, 'Curitiba', 'Raquel Carneiro do Amaral e Silva', 'Jardim das Américas', '81540-225', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29847, 'Campo Largo', 'Raquel de Queirós', 'São Marcos', '83602-686', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29848, 'Guarapuava', 'Raquel de Queiroz', 'Santana', '85070-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29849, 'Pinhais', 'Raquel de Queiroz', 'Núcleo Colonial de Pinhais', '83321-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29850, 'Curitiba', 'Raquel Prado', 'Mercês', '80520-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29851, 'Curitiba', 'Raquel Prado', 'Mercês', '80510-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29852, 'São José dos Pinhais', 'Raul Bassso Stangue', 'Afonso Pena', '83040-455', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29853, 'Ponta Grossa', 'Raul Bopp', 'Cará-cará', '84043-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29854, 'Campo Largo', 'Raul Bueno da Rocha', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-778', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29855, 'Curitiba', 'Raul Caron', 'Capão da Imbuia', '82810-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29856, 'Londrina', 'Raul Coradi', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29857, 'Londrina', 'Raul Costa Júnior', 'Estados', '86083-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29858, 'Londrina', 'Raul Coutinho', 'Conjunto Semiramis Barros Braga', '86088-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29859, 'Paranaguá', 'Raul Cruz', 'Vila do Caic', '83215-688', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29860, 'Paranavaí', 'Raul da Silveira Torres', 'Jardim Ipê', '87706-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29861, 'Curitiba', 'Raul de Azevedo Macedo', 'Xaxim', '81830-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29862, 'Ponta Grossa', 'Raul de Mesquita', 'Neves', '84020-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29863, 'Curitiba', 'Raul de Oliveira', 'Cajuru', '82950-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29864, 'São José dos Pinhais', 'Raul de Oliveira Machado', 'Zaniolo', '83025-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29865, 'Araucária', 'Raul Domingues Siqueira', 'Cachoeira', '83701-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29866, 'Ponta Grossa', 'Raul Faria', 'Ronda', '84050-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29867, 'Londrina', 'Raul Faria Carneiro', 'Santiago', '86071-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29868, 'Curitiba', 'Raul Félix', 'Portão', '81070-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29869, 'Curitiba', 'Raul Ferreira Leite', 'Guabirotuba', '81520-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29870, 'Piraquara', 'Raul Gomes', 'Vila Izabel', '83305-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29871, 'Castro', 'Raul Inocente dos Santos', 'Vila Farias', '84178-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29872, 'Curitiba', 'Raul Joaquim Quadros Gomes', 'Tarumã', '82530-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29873, 'Londrina', 'Raul Juliatto', 'Parque Residencial Granville', '86047-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29874, 'Ponta Grossa', 'Raul Kiel Cordeiro', 'Oficinas', '84035-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29875, 'Curitiba', 'Raul Kuhn', 'Cachoeira', '82710-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29876, 'Curitiba', 'Raul Leite', 'Bairro Alto', '82820-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29877, 'Curitiba', 'Raul Leopoldo Zimmer', 'Santo Inácio', '82010-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29878, 'Curitiba', 'Raul Machado Berges', 'Cidade Industrial', '81170-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29879, 'Curitiba', 'Raul Menssig', 'Uberaba', '81580-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29880, 'Londrina', 'Raul Mignoni', 'Roseira', '86041-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29881, 'Apucarana', 'Raul Milano', 'Núcleo Habitacional Mathias Hoffman', '86805-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29882, 'Londrina', 'Raul Mouro', 'Parque Residencial Professora Marieta', '86082-767', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29883, 'Curitiba', 'Raul Munhoz', 'São Francisco', '80510-260', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29884, 'Londrina', 'Raul Noronha da Silva', 'Conjunto Café', '86038-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29885, 'São José dos Pinhais', 'Raul Obladen', 'Braga', '83020-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29886, 'Francisco Beltrão', 'Raul Pila', 'Presidente Kennedy', '85605-120', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29887, 'Curitiba', 'Raul Poiteven', 'Alto Boqueirão', '81770-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29888, 'Guarapuava', 'Raul Pompéia', 'Bonsucesso', '85060-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29889, 'Foz do Iguaçu', 'Raul Pompéia', 'Jardim Jupira', '85865-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29890, 'Francisco Beltrão', 'Raul Pompéia', 'São Miguel', '85602-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29891, 'Pinhais', 'Raul Pompéia', 'Planta Núcleo Colonial de Pinhais', '83321-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29892, 'Ponta Grossa', 'Raul Pompéia', 'Jardim Carvalho', '84016-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29893, 'Colombo', 'Raul Pompéia', 'Jardim Quitandinha', '83409-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29894, 'Curitiba', 'Raul Pompéia', 'Cidade Industrial', '81250-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29895, 'Curitiba', 'Raul Pompéia', 'Cidade Industrial', '81260-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29896, 'Curitiba', 'Raul Pompéia', 'Cidade Industrial', '81240-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29897, 'Londrina', 'Raul Seixas', 'Conjunto Vivi Xavier', '86082-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29898, 'Curitiba', 'Raul Seixas', 'Tatuquara', '81470-115', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29899, 'Paranaguá', 'Raul Silva', 'Porto dos Padres', '83221-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29900, 'Curitiba', 'Raul Suplicy de Lacerda', 'Alto Boqueirão', '81860-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29901, 'Curitiba', 'Raul Vaz', 'Cajuru', '82980-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29902, 'Curitiba', 'Raul Zanon', 'Cidade Industrial', '81240-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29903, 'Curitiba', 'Raulino Cercal', 'Alto Boqueirão', '81850-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29904, 'Guarapuava', 'Raulino G. de Córdova', 'Morro Alto', '85067-430', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29905, 'Guarapuava', 'Raulino G. de Córdova', 'Boqueirão', '85020-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29906, 'Foz do Iguaçu', 'Raulino Gabriel', 'Jardim Porto Belo', '85867-519', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29907, 'Londrina', 'Raymunda Madalena Reeberg', 'Jardim Santa Fé', '86035-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29908, 'Curitiba', 'Raymundo Bon', 'Boa Vista', '82650-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29909, 'Curitiba', 'Raymundo Camargo Munhoz', 'Umbará', '81930-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29910, 'Curitiba', 'Raymundo Kulik', 'Santa Cândida', '82720-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29911, 'Curitiba', 'Raymundo Nina Rodrigues', 'Cajuru', '82950-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29912, 'Curitiba', 'Raymundo Nina Rodrigues', 'Cajuru', '82920-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29913, 'Londrina', 'Raymundo Ramos da Costa Almeida', 'Jardim Maria Celina', '86081-565', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29914, 'Curitiba', 'Raymundo Ramos Ferreira', 'Cidade Industrial', '81350-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29915, 'Curitiba', 'Raynoldo Morbis', 'Cajuru', '82980-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29916, 'Piraquara', 'Real', 'Jardim Santa Mônica', '83302-050', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29917, 'Londrina', 'Realejo', 'Conjunto Habitacional Violim', '86084-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29918, 'Arapongas', 'Realejo', 'Conjunto Centauro', '86709-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29919, 'Guarapuava', 'Realeza', 'Jardim das Américas', '85030-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29920, 'Foz do Iguaçu', 'Realeza', 'Jardim Cedro', '85862-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29921, 'Curitiba', 'Realeza', 'Sítio Cercado', '81900-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29922, 'Francisco Beltrão', 'Realeza', 'Marrecas', '85601-479', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29923, 'Pinhais', 'Realeza', 'Jardim Pedro Demeterco', '83324-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29924, 'Cascavel', 'Realeza', 'Pacaembu', '85816-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29925, 'Londrina', 'Rebeca', 'Nossa Senhora de Lourdes', '86039-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29926, 'Ponta Grossa', 'Rebita', 'Contorno', '84052-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29927, 'Londrina', 'Rebouças', 'Vitória', '86060-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29928, 'Guarapuava', 'Rebouças', 'Boqueirão', '85020-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29929, 'Piraquara', 'Rebouças', 'Planta Araçatuba', '83301-670', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29930, 'Maringá', 'Rebouças', 'Zona 10', '87030-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29931, 'Ponta Grossa', 'Rebouças', 'Uvaranas', '84030-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29932, 'Telêmaco Borba', 'Rebouças', 'Macopa', '84263-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29933, 'São José dos Pinhais', 'Rebouças', 'Cidade Jardim', '83035-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29934, 'Colombo', 'Rebouças', 'Jardim Cristina', '83410-560', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29935, 'Ponta Grossa', 'Recalque', 'Uvaranas', '84025-006', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29936, 'Curitiba', 'Recanto Di Itália', 'Santa Felicidade', '82015-035', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29937, 'Curitiba', 'Recanto dos Eucaliptos', 'Alto Boqueirão', '81770-265', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29938, 'Campo Mourão', 'Recelene C. Teixeira', 'Jardim Corinthias', '87309-067', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29939, 'Londrina', 'Reciclagem', 'Cilo 3', '86073-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29940, 'Foz do Iguaçu', 'Recife', 'Jardim Alvorada', '85859-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29941, 'Guarapuava', 'Recife', 'São Cristóvão', '85060-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29942, 'Foz do Iguaçu', 'Recife', 'Conjunto C', '85870-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29943, 'Londrina', 'Recife', 'Jardim Agari', '86020-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29944, 'Maringá', 'Recife', 'Parque Residencial Cidade Nova', '87023-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29945, 'Pinhais', 'Recife', 'Conjunto Residencial Renato Bonilauri', '83325-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29946, 'Piraquara', 'Recife', 'Vila Vicente Macedo', '83303-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29947, 'Telêmaco Borba', 'Recife', 'Macopa', '84263-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29948, 'São José dos Pinhais', 'Recife', 'Costeira', '83015-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29949, 'Sarandi', 'Recife', 'Jardim Escala', '87114-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29950, 'Cascavel', 'Recife', 'Coqueiral', '85807-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29951, 'Cambé', 'Recife', 'Vila Salomé', '86192-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29952, 'Cascavel', 'Recife', 'Centro', '85810-031', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29953, 'Cascavel', 'Recife', 'Centro', '85810-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29954, 'Curitiba', 'Recife', 'Cabral', '80035-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29955, 'Foz do Iguaçu', 'Redenção', 'Jardim Nacional', '85862-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29956, 'Toledo', 'Redentor', 'Vila Becker', '85902-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29957, 'Londrina', 'Reducinio Valim Martins', 'Jardim Neman Sahyun', '86041-288', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29958, 'Ponta Grossa', 'Refidim', 'Jardim Carvalho', '84016-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29959, 'Cambé', 'Regência', 'Jardim Vila Rica', '86192-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29960, 'Guarapuava', 'Regente Feijó', 'Vila Carli', '85040-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29961, 'Foz do Iguaçu', 'Regente Feijó', 'Jardim Vasco da Gama', '85862-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29962, 'Laranjeiras do Sul', 'Regente Feijó', 'Getúlio Vargas', '85304-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29963, 'Maringá', 'Regente Feijó', 'Zona 03', '87050-230', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29964, 'Cascavel', 'Regente Feijó', 'Parque São Paulo', '85803-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29965, 'Cambé', 'Regente Feijó', 'Parque Residencial Manela', '86185-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29966, 'Apucarana', 'Regina Alves Pereira', 'Vila Regina', '86801-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29967, 'São José dos Pinhais', 'Regina Berton Moletta', 'Cruzeiro', '83010-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29968, 'Londrina', 'Regina Bidoia', 'Residencial Abussafe', '86037-786', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29969, 'Apucarana', 'Regina Bovolin Macedo', 'Recanto Bom Retiro', '86803-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29970, 'Paranaguá', 'Regina de Félix Lima', 'Divinéia', '83212-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29971, 'Curitiba', 'Regina de Jesus Siqueira', 'Ganchinho', '81935-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29972, 'Londrina', 'Regina Fabrini Scotton', 'Jardim Burle Marx', '86047-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29973, 'Campo Mourão', 'Regina Fabris Trivelatto', 'Jardim Paulista', '87310-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29974, 'Londrina', 'Regina Longhi Pirola', 'Residencial Vila Romana', '86031-818', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29975, 'Londrina', 'Regina Marques Felício', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29976, 'Cambé', 'Regina P. Raminelli', 'Jardim José Favaro', '86183-797', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29977, 'Curitiba', 'Regina Schulman', 'Boqueirão', '81750-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29978, 'Curitiba', 'Regina Tisser Stier', 'Cidade Industrial', '81260-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29979, 'Curitiba', 'Reginaldo Antônio Zem', 'Pilarzinho', '82100-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29980, 'Curitiba', 'Reginato Quartarolli', 'Alto Boqueirão', '81860-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29981, 'Foz do Iguaçu', 'Registro', 'Jardim Vitória', '85853-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29982, 'Ponta Grossa', 'Regnun Dei', 'Estrela', '84050-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29983, 'Guarapuava', 'Rei Cristo', 'Industrial', '85045-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29984, 'Toledo', 'Rei Cristo', 'Vila Becker', '85902-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29985, 'Umuarama', 'Rei Davi', 'Parque Dom Pedro II', '87508-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29986, 'Curitiba', 'Rei David', 'Santa Cândida', '82640-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29987, 'Foz do Iguaçu', 'Rei Pelé', 'Parque Morumbi II', '85859-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29988, 'Umuarama', 'Rei Salomão', 'Parque Dom Pedro II', '87508-057', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29989, 'Curitiba', 'Rei Salomão', 'Santa Cândida', '82640-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29990, 'Umuarama', 'Rei Saul', 'Parque Dom Pedro II', '87508-056', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29991, 'Sarandi', 'Rei Zumbi dos Palmares', 'Jardim Nova Independência', '87114-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29992, 'Arapongas', 'Rei-do-bosque', 'Conjunto Novo Centauro', '86709-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29993, 'Curitiba', 'Reinaldino Schaffemberg de Quadros', 'Alto da Rua XV', '80050-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29994, 'Curitiba', 'Reinaldo Athaide Santos', 'Barreirinha', '82220-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29995, 'Curitiba', 'Reinaldo Baldan', 'Pinheirinho', '81880-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29996, 'Toledo', 'Reinaldo Barilli', 'Conjunto Habitacional São Francisco', '85915-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29997, 'Curitiba', 'Reinaldo Casagrande', 'Santo Inácio', '82010-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29998, 'Colombo', 'Reinaldo Ceccon', 'Santa Gema', '83407-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (29999, 'Curitiba', 'Reinaldo de Carvalho', 'Ganchinho', '81935-326', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30000, 'Curitiba', 'Reinaldo Egon Heidinger', 'Cabral', '80035-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30001, 'Paranaguá', 'Reinaldo Elias', 'Vila Guadalupe', '83221-370', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30002, 'Maringá', 'Reinaldo G. Bittencourt Filho', 'Parque das Laranjeiras', '87083-175', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30003, 'Londrina', 'Reinaldo Grotti', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30004, 'Curitiba', 'Reinaldo Gusso', 'Capão Raso', '81110-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30005, 'Curitiba', 'Reinaldo Hecke', 'Abranches', '82210-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30006, 'Curitiba', 'Reinaldo Issberner', 'Cajuru', '82900-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30007, 'Curitiba', 'Reinaldo Jacob Von Muhlen', 'Santa Cândida', '82640-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30008, 'Londrina', 'Reinaldo José da Silva', 'Maria Lúcia', '86072-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30009, 'Pinhais', 'Reinaldo José Miranda', 'Moradias Santa Clara', '83325-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30010, 'Curitiba', 'Reinaldo Koop', 'Boqueirão', '81750-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30011, 'Pato Branco', 'Reinaldo Luiz Agustini', 'Aeroporto', '85503-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30012, 'Curitiba', 'Reinaldo M. Von der Osten', 'Pilarzinho', '82110-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30013, 'Piraquara', 'Reinaldo Machado', 'Jardim Veneza', '83310-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30014, 'Telêmaco Borba', 'Reinaldo Martins de Oliveira', 'Centro', '84261-710', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30015, 'Piraquara', 'Reinaldo Meira', 'Vila São Cristóvão', '83305-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30016, 'Piraquara', 'Reinaldo Michel', 'Planta Meireles', '83304-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30017, 'São José dos Pinhais', 'Reinaldo Miguel Valenga', 'Costeira', '83015-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30018, 'Curitiba', 'Reinaldo Pazello', 'Santa Quitéria', '80310-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30019, 'São José dos Pinhais', 'Reinaldo Puchetti', 'Ipê', '83055-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30020, 'Cambé', 'Reinaldo Resquetti', 'Jardim Boa Vista', '86191-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30021, 'Pinhais', 'Reinaldo Ribas', 'Conjunto Residencial Áquila', '83326-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30022, 'Ponta Grossa', 'Reinaldo Ribas Silveira', 'Ronda', '84051-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30023, 'Curitiba', 'Reinaldo Richter', 'Campo Comprido', '81220-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30024, 'Curitiba', 'Reinaldo Rodrigues Lima', 'Cajuru', '82960-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30025, 'Londrina', 'Reinaldo Sanches Mussi', 'Jacutinga', '86087-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30026, 'Curitiba', 'Reinaldo São Braz Fabrim', 'Cajuru', '82950-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30027, 'Francisco Beltrão', 'Reinaldo Sass', 'Miniguaçu', '85605-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30028, 'Curitiba', 'Reinaldo Stocco', 'Pinheirinho', '81820-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30029, 'Curitiba', 'Reinaldo Strobel', 'Cidade Industrial', '81260-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30030, 'Curitiba', 'Reinaldo Tha', 'Cajuru', '82900-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30031, 'Campo Mourão', 'Reineiro Bernardes', 'Jardim Ione', '87303-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30032, 'Curitiba', 'Reinhard Maack', 'Santa Cândida', '82640-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30033, 'Curitiba', 'Reinhold Jabin', 'Tatuquara', '81480-267', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30034, 'Piraquara', 'Reinhold Müller', 'Vila Mariana', '83311-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30035, 'Curitiba', 'Reinoldes Stepurski', 'Campo Comprido', '81220-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30036, 'Curitiba', 'Reinoldo Ihlenfeldt', 'Santa Cândida', '82640-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30037, 'Curitiba', 'Reinoldo Scherner', 'Uberaba', '81570-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30038, 'Foz do Iguaçu', 'Rejane Marisa Dalbo', 'Jardim Polo Centro', '85863-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30039, 'Colombo', 'Remaldo Dambyski', 'Centro Industrial Mauá', '83413-678', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30040, 'Londrina', 'Remo Ferrarese', 'Jardim Santa Cruz', '86084-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30041, 'Foz do Iguaçu', 'Renascença', 'Jardim Paraná', '85867-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30042, 'Francisco Beltrão', 'Renascença', 'Marrecas', '85601-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30043, 'Guarapuava', 'Renascença', 'Jardim das Américas', '85030-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30044, 'Pinhais', 'Renascença', 'Jardim Pedro Demeterco', '83324-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30045, 'São José dos Pinhais', 'Renascença', 'Cidade Jardim', '83035-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30046, 'Colombo', 'Renascença', 'Jardim Anai', '83410-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30047, 'Curitiba', 'Renascença', 'Santa Felicidade', '82410-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30048, 'Curitiba', 'Renato Baroni', 'Guabirotuba', '81510-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30049, 'Londrina', 'Renato Carneiro Lobo', 'Sabará III', '86066-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30050, 'Araucária', 'Renato Côco Denis', 'Campina da Barra', '83709-849', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30051, 'Londrina', 'Renato Fabretti', 'Colinas', '86056-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30052, 'Cascavel', 'Renato Festugato', 'Presidente', '85818-118', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30053, 'Guarapuava', 'Renato Guimarães Pupo', 'Boqueirão', '85022-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30054, 'Paranaguá', 'Renato Leone', 'Parque São João', '83212-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30055, 'Pinhais', 'Renato Luiz Lopes', 'Chácara Esperança', '83328-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30056, 'Castro', 'Renato Menarin', 'Invernada do Matadouro', '84174-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30057, 'Castro', 'Renato Menarin', 'Jardim dos Bancários', '84172-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30058, 'Londrina', 'Renato Mussi', 'Giovani Lunardelli', '86037-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30059, 'Pinhais', 'Renato Nunes Ribas', 'Planta Portland', '83323-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30060, 'Curitiba', 'Renato Polatti', 'Campo Comprido', '81230-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30061, 'Curitiba', 'Renato Russo', 'Uberaba', '81560-645', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30062, 'Colombo', 'Renato Soares de Almeida', 'Santa Rita', '83412-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30063, 'Curitiba', 'Renato Thadeo', 'Bacacheri', '82520-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30064, 'Curitiba', 'Renato Wilczak', 'Sítio Cercado', '81900-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30065, 'Curitiba', 'Renato Xavier da Silva', 'Santo Inácio', '82010-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30066, 'Curitiba', 'Renato Ziliotto', 'Campina do Siqueira', '80740-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30067, 'Curitiba', 'Renato Zorze', 'Uberaba', '81530-610', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30068, 'São José dos Pinhais', 'Renault', 'Roseira', '83070-255', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30069, 'Arapongas', 'Rendeira', 'Jardim Aeroporto', '86702-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30070, 'Curitiba', 'René Alberto Emílio Conter', 'Cidade Industrial', '81460-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30071, 'Curitiba', 'René Borba Carneiro', 'Cidade Industrial', '81315-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30072, 'Apucarana', 'René Camargo de Azambuja', 'Jardim São Pedro', '86809-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30073, 'Apucarana', 'René Camargo de Azambuja', 'Centro', '86800-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30074, 'Londrina', 'René Descartes', 'Maringá', '86060-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30075, 'Curitiba', 'René Descartes', 'Barreirinha', '82220-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30076, 'São José dos Pinhais', 'Renê Descartes', 'Aristocrata', '83030-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30077, 'Ponta Grossa', 'Renê Gomes Napoli', 'Boa Vista', '84073-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30078, 'Curitiba', 'Renê Raul Wengenroth Silva', 'Cidade Industrial', '81350-597', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30079, 'Paranaguá', 'Renê Santos', 'Parque São João', '83212-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30080, 'Curitiba', 'Renée Devrainne Frank', 'Jardim das Américas', '81530-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30081, 'Laranjeiras do Sul', 'República', 'Centro', '85301-225', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30082, 'Foz do Iguaçu', 'República Argentina', 'Centro', '85851-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30083, 'Foz do Iguaçu', 'República Argentina', 'Jardim Esmeralda', '85856-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30084, 'Laranjeiras do Sul', 'República Argentina', 'Cristo Rei', '85304-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30085, 'Foz do Iguaçu', 'República Argentina', 'Centro', '85852-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30086, 'Ponta Grossa', 'República Argentina', 'Orfãs', '84015-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30087, 'Cascavel', 'República Argentina', 'Pacaembu', '85816-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30088, 'Campo Largo', 'República Argentina', 'Bom Jesus', '83604-366', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30089, 'Curitiba', 'República Argentina', 'Água Verde', '80240-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30090, 'Curitiba', 'República Argentina', 'Água Verde', '80620-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30091, 'Curitiba', 'República Argentina', 'Portão', '80610-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30092, 'Curitiba', 'República Argentina', 'Novo Mundo', '81050-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30093, 'Curitiba', 'República Argentina', 'Novo Mundo', '81050-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30094, 'Ponta Grossa', 'República da Colômbia', 'Ronda', '84051-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30095, 'Curitiba', 'República da Islândia', 'Boa Vista', '82560-245', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30096, 'Curitiba', 'República da Síria', 'Jardim Social', '82520-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30097, 'Ponta Grossa', 'República de São Salvador', 'Boa Vista', '84070-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30098, 'Foz do Iguaçu', 'República do Líbano', 'Jardim Jupira', '85865-380', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30099, 'Ponta Grossa', 'República do Líbano', 'Centro', '84010-055', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30100, 'Ponta Grossa', 'República do Líbano', 'Jardim Carvalho', '84015-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30101, 'Paranaguá', 'República do Líbano', 'Alvorada', '83206-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30102, 'Curitiba', 'República do Líbano', 'Jardim Social', '82520-500', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30103, 'Ponta Grossa', 'República do Panamá', 'Ronda', '84051-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30104, 'Foz do Iguaçu', 'República do Paraguai', 'Jardim Jupira', '85865-240', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30105, 'Paranaguá', 'República do Paraguai', 'Palmital', '83206-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30106, 'Ponta Grossa', 'República do Peru', 'Ronda', '84051-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30107, 'Ponta Grossa', 'República Dominicana', 'Uvaranas', '84026-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30108, 'Pinhais', 'República Dominicana', 'Vila Varginha', '83320-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30109, 'Apucarana', 'República Dominicana', 'Jardim Diamantina', '86804-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30110, 'Curitiba', 'República Dominicana', 'Guaíra', '81010-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30111, 'Curitiba', 'República Francesa', 'Jardim Social', '82520-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30112, 'Curitiba', 'República Guarani', 'Atuba', '82860-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30113, 'Curitiba', 'República Islâmica do Irã', 'Jardim das Américas', '81540-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30114, 'Curitiba', 'República Oriental do Uruguay', 'Bigorrilho', '80710-235', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30116, 'Curitiba', 'Reselene de Souza', 'Cidade Industrial', '81305-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30117, 'Francisco Beltrão', 'Resende', 'Pinheirinho', '85603-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30118, 'Guarapuava', 'Resende', 'Batel', '85015-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30119, 'Foz do Iguaçu', 'Resende', 'Novo Mundo', '85862-396', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30120, 'Guarapuava', 'Reserva', 'Primavera', '85050-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30121, 'Ponta Grossa', 'Reserva', 'Chapada', '84062-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30122, 'Telêmaco Borba', 'Reserva', 'Área 02', '84267-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30123, 'Curitiba', 'Reserva', 'Boqueirão', '81750-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30124, 'Londrina', 'Reserva Ecológica do Oiapoque', 'Vila A B Vicentini', '86077-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30125, 'Curitiba', 'Reskala Snege', 'Alto Boqueirão', '81850-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30126, 'Foz do Iguaçu', 'Resplendor', 'Jardim das Palmeiras II', '85869-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30127, 'Telêmaco Borba', 'Restingão', 'Área 02', '84267-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30128, 'Campo Largo', 'Retiro São José', 'Vila Bancária', '83601-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30129, 'Curitiba', 'Reverendo Augusto Paes de Ávila', 'Boqueirão', '81770-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30130, 'Curitiba', 'Reverendo Braz Hernandes', 'Barreirinha', '82560-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30131, 'Curitiba', 'Reverendo Elias Abrahão', 'Alto Boqueirão', '81830-465', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30132, 'Curitiba', 'Reverendo Jahyr Dittrich', 'Sítio Cercado', '81925-567', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30133, 'Londrina', 'Reverendo Jinius e Newman', 'Conjunto Café', '86038-065', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30134, 'Curitiba', 'Reverendo Joaquim dos Santos Oliveira', 'Atuba', '82860-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30135, 'Curitiba', 'Reverendo Lauro de Castro', 'Cajuru', '82970-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30136, 'Londrina', 'Reverendo Luiz Boaventura', 'Nova Londres', '86015-565', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30137, 'Curitiba', 'Reverendo Mariano Rodrigues de Castro', 'Cajuru', '82970-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30138, 'Curitiba', 'Reverendo Paulo Hecke', 'Ahú', '82200-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30139, 'Curitiba', 'Reverendo Raul Rodrigues de Castro', 'Cajuru', '82970-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30140, 'Curitiba', 'Reynaldo Bonat', 'Cidade Industrial', '81310-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30141, 'Colombo', 'Reynaldo Cavalli', 'Jardim Osasco', '83403-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30142, 'Curitiba', 'Reynaldo Contin', 'Umbará', '81930-557', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30143, 'Pinhais', 'Reynaldo Crozetta', 'Jardim Atuba I', '83326-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30144, 'Curitiba', 'Reynaldo Tortato', 'Campo de Santana', '81490-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30145, 'Curitiba', 'Rezala Simão', 'Santa Quitéria', '80330-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30146, 'Londrina', 'Rezek Andery', 'Jardim Piza', '86073-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30147, 'Londrina', 'Rhodes', 'Vila Rodrigues', '86010-830', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30148, 'Cambé', 'Riacho Fundo', 'Jardim Alvorada', '86191-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30149, 'Londrina', 'Riachuelo', 'Jardim Higienópolis', '86015-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30150, 'Foz do Iguaçu', 'Riachuelo', 'Jardim Itamaraty', '85863-745', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30151, 'Guarapuava', 'Riachuelo', 'Vila Carli', '85040-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30152, 'Maringá', 'Riachuelo', 'Zona 03', '87050-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30153, 'Ponta Grossa', 'Riachuelo', 'Centro', '84010-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30154, 'Paranavaí', 'Riachuelo', 'Jardim São Jorge', '87711-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30155, 'Paranavaí', 'Riachuelo', 'Jardim São Jorge', '87710-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30156, 'Toledo', 'Riachuelo', 'Boa Esperança', '85909-226', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30157, 'Sarandi', 'Riachuelo', 'Jardim Independência III', '87114-240', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30158, 'Cascavel', 'Riachuelo', 'Centro', '85812-111', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30159, 'Cascavel', 'Riachuelo', 'Centro', '85812-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30160, 'Cascavel', 'Riachuelo', 'Independência', '85813-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30161, 'Almirante Tamandaré', 'Riachuelo', 'Jardim Iracema', '83508-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30162, 'Cambé', 'Riachuelo', 'Jardim Alvorada', '86191-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30163, 'Campo Mourão', 'Riachuelo', 'Jardim Urupês', '87303-200', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30164, 'Curitiba', 'Riachuelo', 'Centro', '80020-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30165, 'Curitiba', 'Ribeiralta', 'Bacacheri', '82520-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30166, 'Telêmaco Borba', 'Ribeirão', 'Área 02', '84267-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30167, 'Guarapuava', 'Ribeirão Claro', 'Bonsucesso', '85055-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30168, 'Pinhais', 'Ribeirão Claro', 'Jardim Pedro Demeterco', '83324-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30169, 'Ponta Grossa', 'Ribeirão Claro', 'Olarias', '84026-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30170, 'Maringá', 'Ribeirão Claro', 'Vila Christino', '87050-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30171, 'São José dos Pinhais', 'Ribeirão Claro', 'Ouro Fino', '83015-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30172, 'Curitiba', 'Ribeirão Claro', 'Cidade Industrial', '81250-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30173, 'Foz do Iguaçu', 'Ribeirão de Iguape', 'Loteamento Campos do Iguaçu', '85857-430', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30174, 'Ponta Grossa', 'Ribeirão do Pinhal', 'Nova Rússia', '84053-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30175, 'Curitiba', 'Ribeirão do Pinhal', 'Xaxim', '81830-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30176, 'Foz do Iguaçu', 'Ribeirão Preto', 'Parque Residencial Três Fronteiras', '85855-606', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30177, 'Londrina', 'Ribeirão Preto', 'San Remo', '86062-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30178, 'Guarapuava', 'Ribeirão Preto', 'Boqueirão', '85022-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30179, 'Pato Branco', 'Ribeirão Preto', 'São Roque', '85507-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30180, 'Castro', 'Ribeirão Preto', 'Jardim Social Primavera', '84172-600', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30181, 'Toledo', 'Ribeirinho', 'Boa Esperança', '85909-197', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30182, 'Londrina', 'Ricardo Antônio Beltrame', 'Aquilles Sthengel', '86086-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30183, 'Londrina', 'Ricardo Antonio Ferro', 'Parque Residencial Michael Licha', '86078-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30184, 'Curitiba', 'Ricardo Barion', 'Cidade Industrial', '81450-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30185, 'Pato Branco', 'Ricardo Bôrtolo Tesser', 'Vila Esperança', '85503-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30186, 'Curitiba', 'Ricardo Brusamolim', 'Pilarzinho', '82120-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30187, 'Apucarana', 'Ricardo Candeo', 'Núcleo Habitacional das Indústrias', '86806-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30188, 'Colombo', 'Ricardo Canestraro', 'Jardim Panorama', '83412-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30189, 'Curitiba', 'Ricardo Carta', 'Seminário', '80310-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30190, 'Curitiba', 'Ricardo Emílio Michel', 'Cidade Industrial', '81250-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30191, 'Londrina', 'Ricardo Funaro', 'Santa Rita 1', '86072-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30192, 'Toledo', 'Ricardo Galante', 'Residencial Santa Clara', '85903-696', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30193, 'Curitiba', 'Ricardo Gasparian Machado', 'Pinheirinho', '81870-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30194, 'Curitiba', 'Ricardo Gonçalez Júnior', 'Atuba', '82860-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30195, 'Curitiba', 'Ricardo Guther', 'Guaíra', '80630-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30196, 'Curitiba', 'Ricardo Halick', 'Cachoeira', '82220-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30197, 'Curitiba', 'Ricardo Haun', 'Santo Inácio', '82300-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30198, 'Ponta Grossa', 'Ricardo Henneberg', 'Nova Rússia', '84053-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30199, 'Curitiba', 'Ricardo Hugo Iwersen', 'Uberaba', '81590-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30200, 'Curitiba', 'Ricardo Jorge Pereira', 'Santa Cândida', '82630-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30201, 'Ponta Grossa', 'Ricardo Kossatz', 'Uvaranas', '84031-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30202, 'Francisco Beltrão', 'Ricardo Kunz', 'Presidente Kennedy', '85605-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30203, 'Ponta Grossa', 'Ricardo Lemos', 'Oficinas', '84036-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30204, 'Curitiba', 'Ricardo Lemos', 'Ahú', '80540-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30205, 'Curitiba', 'Ricardo Lunardelli Netto', 'Santo Inácio', '82010-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30206, 'Ponta Grossa', 'Ricardo Lustosa Ribas', 'Estrela', '84040-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30207, 'Foz do Iguaçu', 'Ricardo M. Ramos', 'Loteamento Parque do Patriarco', '85854-516', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30208, 'Toledo', 'Ricardo Maccari', 'Residencial Santa Clara', '85908-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30209, 'Umuarama', 'Ricardo Márcio dos Santos', 'Jardim Cruzeiro', '87504-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30210, 'Londrina', 'Ricardo Monti', 'Jamile Dequech', '86048-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30211, 'Curitiba', 'Ricardo Negrão Filho', 'Portão', '81320-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30212, 'Foz do Iguaçu', 'Ricardo Novakowski', 'Jardim do Horto', '85854-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30213, 'Toledo', 'Ricardo Otto Schimidt', 'Conjunto Habitacional São Francisco', '85915-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30214, 'Toledo', 'Ricardo Refatti', 'Vila Pioneiro', '85909-746', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30215, 'Londrina', 'Ricardo Ruller', 'Portal de Versalhes 3', '86055-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30216, 'Curitiba', 'Ricardo Scremin', 'Centro Cívico', '80530-240', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30217, 'Curitiba', 'Ricardo Senegaglia', 'Campo Comprido', '81230-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30218, 'Curitiba', 'Ricardo Valt', 'Mossunguê', '81200-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30219, 'Londrina', 'Ricardo Vecchia', 'Jardim Vale Verde', '86040-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30220, 'Ponta Grossa', 'Ricardo Wagner', 'Olarias', '84035-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30221, 'Londrina', 'Richard Blumberg', 'Heimtal', '86084-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30222, 'Piraquara', 'Richard Lickfeld', 'Planta Tamoyo', '83312-096', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30223, 'Piraquara', 'Richard Nowel', 'Vila Rosa', '83304-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30224, 'Curitiba', 'Richard Strauss', 'Vista Alegre', '80820-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30225, 'Curitiba', 'Richard Wagner', 'Vista Alegre', '80820-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30226, 'Guarapuava', 'Riciere Portolan', 'Vila Jordão', '85015-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30227, 'São José dos Pinhais', 'Ricieri Alberti', 'Rio Pequeno', '83070-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30228, 'Laranjeiras do Sul', 'Ricieri Denez', 'São Francisco', '85303-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30229, 'Cascavel', 'Ricieri Perin', 'Pioneiros Catarinenses', '85805-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30230, 'Pato Branco', 'Ricieri Picoli', 'Bonatto', '85506-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30231, 'Londrina', 'Ricieri Ricardo Ticianelli', 'Áurea', '86038-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30232, 'Londrina', 'Ricieri Tassoni', 'Leste Oeste', '86037-806', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30233, 'Arapongas', 'Riconto', 'Vila São Lazaro', '86705-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30234, 'Curitiba', 'Ride Boza', 'Umbará', '81940-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30235, 'Ponta Grossa', 'Rimon Perez', 'Jardim Carvalho', '84016-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30236, 'Sarandi', 'Rio Alonso', 'Parque Alvamar II', '87113-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30237, 'Apucarana', 'Rio Alonzo', 'Núcleo Habitacional Papa João Paulo I', '86801-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30238, 'Maringá', 'Rio Amazonas', 'Conjunto Residencial Paulino Carlos Filho', '87043-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30239, 'Pinhais', 'Rio Amazonas', 'Planta Bairro Weissópolis', '83322-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30240, 'Ponta Grossa', 'Rio Amazonas', 'Chapada', '84064-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30241, 'Cambé', 'Rio Amazonas', 'Jardim Santo Amaro', '86185-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30242, 'Curitiba', 'Rio Amazonas', 'Bairro Alto', '82840-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30243, 'Maringá', 'Rio Andaraí', 'Jardim Oásis', '87043-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30244, 'Apucarana', 'Rio Andrada', 'Núcleo Habitacional Papa João Paulo I', '86801-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30245, 'Cascavel', 'Rio Anhangabaú', 'Brasmadeira', '85814-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30246, 'Apucarana', 'Rio Apucarana', 'Núcleo Habitacional Papa João Paulo I', '86801-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30247, 'Maringá', 'Rio Aquidauana', 'Conjunto Residencial Paulino Carlos Filho', '87043-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30248, 'Ponta Grossa', 'Rio Araguaia', 'Chapada', '84064-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30249, 'Telêmaco Borba', 'Rio Araguaia', 'Área 07', '84270-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30250, 'Cambé', 'Rio Araguaia', 'Jardim Santo Amaro', '86185-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30251, 'Cascavel', 'Rio Araguaia', 'Brasmadeira', '85814-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30252, 'Colombo', 'Rio Araguaia', 'Jardim Moinho Velho', '83403-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30253, 'Pinhais', 'Rio Araguari', 'Planta Weissopolis', '83322-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30254, 'Curitiba', 'Rio Araguari', 'Atuba', '82840-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30255, 'Curitiba', 'Rio Araguari', 'Bairro Alto', '82820-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30256, 'Maringá', 'Rio Arinos', 'Jardim Novo Oásis', '87043-597', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30257, 'São José dos Pinhais', 'Rio Atuba', 'Ipê', '83055-057', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30258, 'Guarapuava', 'Rio Azul', 'Dos Estados', '85035-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30259, 'Foz do Iguaçu', 'Rio Azul', 'Vila Carima', '85855-685', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30260, 'Ponta Grossa', 'Rio Azul', 'Oficinas', '84036-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30261, 'Maringá', 'Rio Azul', 'Jardim Oásis', '87043-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30262, 'Pinhais', 'Rio Azul', 'Jardim Dona Joaquina I', '83325-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30263, 'Pinhais', 'Rio Azul', 'Jardim Atuba I', '83326-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30264, 'Sarandi', 'Rio Azul', 'Parque Alvamar II', '87113-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30265, 'Cascavel', 'Rio Azul', 'Brasmadeira', '85814-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30266, 'Curitiba', 'Rio Azul', 'Fazendinha', '81320-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30267, 'Telêmaco Borba', 'Rio Bagagem', 'Área 08', '84270-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30268, 'Almirante Tamandaré', 'Rio Bambeca', 'Jardim Santa Maria', '83511-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30269, 'Maringá', 'Rio Barreiro', 'Parque Residencial Tuiuti', '87043-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30270, 'Telêmaco Borba', 'Rio Barreiro', 'Área 08', '84270-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30271, 'Maringá', 'Rio Belo', 'Jardim Novo Oásis', '87043-606', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30272, 'Maringá', 'Rio Beni', 'Jardim Novo Oásis', '87043-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30273, 'Sarandi', 'Rio Bom', 'Parque Alvamar II', '87113-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30274, 'Apucarana', 'Rio Bom', 'Núcleo Habitacional Papa João Paulo I', '86801-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30275, 'Curitiba', 'Rio Bom', 'São Braz', '82315-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30276, 'Laranjeiras do Sul', 'Rio Bonito', 'São Francisco', '85303-347', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30277, 'Ponta Grossa', 'Rio Bonito', 'Neves', '84020-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30278, 'Telêmaco Borba', 'Rio Bonito', 'Área 02', '84269-050', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30279, 'Sarandi', 'Rio Bonito', 'Parque Alvamar II', '87113-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30280, 'Cascavel', 'Rio Bonito', 'Brasmadeira', '85814-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30281, 'Cascavel', 'Rio Bora', 'Brasmadeira', '85814-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30282, 'Almirante Tamandaré', 'Rio Botiatuba Mirin', 'Jardim Santa Maria', '83511-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30283, 'Guarapuava', 'Rio Branco', 'Conradinho', '85055-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30284, 'Londrina', 'Rio Branco', 'Shangri-La', '86070-011', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30285, 'Londrina', 'Rio Branco', 'Jardim Tatiani', '86070-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30286, 'Foz do Iguaçu', 'Rio Branco', 'Conjunto C', '85870-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30287, 'Maringá', 'Rio Branco', 'Zona 04', '87014-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30288, 'Piraquara', 'Rio Branco', 'Jardim dos Estados 2', '83308-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30289, 'Maringá', 'Rio Branco', 'Zona 05', '87015-380', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30290, 'Pato Branco', 'Rio Branco', 'Pinheirinho', '85506-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30291, 'Telêmaco Borba', 'Rio Branco', 'Área 08', '84270-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30292, 'Sarandi', 'Rio Branco', 'Jardim Independência III', '87114-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30293, 'Umuarama', 'Rio Branco', 'Zona I', '87501-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30294, 'Sarandi', 'Rio Branco', 'Parque Alvamar II', '87113-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30295, 'Apucarana', 'Rio Branco', 'Centro', '86800-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30296, 'Almirante Tamandaré', 'Rio Branco', 'Jardim Valma', '83507-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30297, 'Almirante Tamandaré', 'Rio Branco', 'Jardim Amazonas', '83507-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30298, 'Cambé', 'Rio Branco', 'Vila Salomé', '86192-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30299, 'Ponta Grossa', 'Rio Branco do Sul', 'Oficinas', '84036-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30300, 'Almirante Tamandaré', 'Rio Branco do Sul', 'Jardim Roma', '83504-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30301, 'Maringá', 'Rio Brilhante', 'Jardim São Francisco', '87043-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30302, 'Sarandi', 'Rio Brilhante', 'Jardim Esplanada', '87112-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30303, 'Apucarana', 'Rio Bulha', 'Núcleo Habitacional Papa João Paulo I', '86801-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30304, 'Telêmaco Borba', 'Rio Caburaí', 'Vila Rosa', '84272-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30305, 'Pinhais', 'Rio Cachoeira', 'Planta Bairro Weissópolis', '83322-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30306, 'Almirante Tamandaré', 'Rio Cachoeirinha', 'Jardim Colonial', '83512-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30307, 'Maringá', 'Rio Camaçari', 'Conjunto João de Barro Itaparica', '87043-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30308, 'Telêmaco Borba', 'Rio Camaqua', 'Área 03', '84271-510', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30309, 'Pinhais', 'Rio Canguiri', 'Planta Weissopolis', '83322-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30310, 'Telêmaco Borba', 'Rio Canoas', 'Área 03', '84271-520', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30311, 'Sarandi', 'Rio Cantu', 'Parque Alvamar II', '87113-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30312, 'Apucarana', 'Rio Cantu', 'Núcleo Habitacional Papa João Paulo I', '86801-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30313, 'Maringá', 'Rio Capiberibe', 'Conjunto Residencial Branca Vieira', '87043-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30314, 'Almirante Tamandaré', 'Rio Capivarai', 'Jardim Colonial', '83501-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30315, 'Ponta Grossa', 'Rio Capivari', 'Neves', '84020-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30316, 'Apucarana', 'Rio Capivari', 'Núcleo Habitacional Papa João Paulo I', '86801-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30317, 'Colombo', 'Rio Capivari', 'Jardim Moinho Velho', '83403-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30318, 'Cascavel', 'Rio Capivari', 'Brasmadeira', '85814-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30319, 'Ponta Grossa', 'Rio Cará-cará', 'Cará-cará', '84033-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30320, 'Piraquara', 'Rio Carajá', 'Planta Belvedere', '83311-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30321, 'Cascavel', 'Rio Cascavel', 'Brasmadeira', '85814-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30322, 'Pinhais', 'Rio Catas Altas', 'Planta Weissopolis', '83322-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30323, 'Ponta Grossa', 'Rio Cavernoso', 'Neves', '84020-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30324, 'Sarandi', 'Rio Cavivari', 'Parque Alvamar II', '87113-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30325, 'Sarandi', 'Rio Chopim', 'Parque Alvamar II', '87113-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30326, 'Apucarana', 'Rio Chopin', 'Núcleo Habitacional Papa João Paulo I', '86801-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30327, 'Maringá', 'Rio Cinza', 'Jardim Novo Oásis', '87043-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30328, 'Cambé', 'Rio Cinza', 'Jardim Santo André', '86185-216', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30329, 'Foz do Iguaçu', 'Rio Claro', 'Jardim Lancaster', '85869-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30330, 'Guarapuava', 'Rio Claro', 'Boqueirão', '85022-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30331, 'Maringá', 'Rio Claro', 'Jardim Oásis', '87043-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30332, 'Paranavaí', 'Rio Claro', 'Jardim Vera Cruz', '87709-370', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30333, 'Sarandi', 'Rio Claro', 'Parque Alvamar II', '87113-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30334, 'Cascavel', 'Rio Claro', 'Periolo', '85817-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30335, 'Almirante Tamandaré', 'Rio Conceição', 'Jardim Rafaela', '83512-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30336, 'Maringá', 'Rio Congoinhas', 'Parque Residencial Tuiuti', '87043-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30337, 'Apucarana', 'Rio Congoinhas', 'Núcleo Habitacional Papa João Paulo I', '86801-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30338, 'Cambé', 'Rio Congonhas', 'Jardim Santo André', '86185-217', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30339, 'Sarandi', 'Rio Corumbataí', 'Parque Alvamar II', '87113-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30340, 'Apucarana', 'Rio Corumbataí', 'Núcleo Habitacional Papa João Paulo I', '86801-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30341, 'Ponta Grossa', 'Rio Coutinho', 'Neves', '84020-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30342, 'Cambé', 'Rio Coxim', 'Jardim Santo Amaro', '86185-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30343, 'Pinhais', 'Rio Cristal', 'Jardim Boa Vista', '83327-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30344, 'Pinhais', 'Rio Cubatão', 'Planta Bairro Weissópolis', '83322-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30345, 'Maringá', 'Rio Cuiabá', 'Jardim Oásis', '87043-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30346, 'Maringá', 'Rio Cunha', 'Jardim Novo Oásis', '87043-598', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30347, 'Almirante Tamandaré', 'Rio Curua', 'Jardim Amazonas', '83507-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30348, 'Almirante Tamandaré', 'Rio Custódio', 'Jardim Santa Maria', '83511-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30349, 'Ponta Grossa', 'Rio da Areia', 'Neves', '84020-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30350, 'Sarandi', 'Rio da Areia', 'Parque Alvamar II', '87113-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30351, 'Almirante Tamandaré', 'Rio da Barra', 'Jardim Rafaela', '83512-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30352, 'Cascavel', 'Rio da Paz', 'Nova Cidade', '85803-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30353, 'Laranjeiras do Sul', 'Rio da Prata', 'São Francisco', '85303-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30354, 'Londrina', 'Rio da Prata', 'Oguido', '86025-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30355, 'Maringá', 'Rio da Prata', 'Jardim Novo Oásis', '87043-599', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30356, 'Pinhais', 'Rio da Prata', 'Planta Bairro Weissópolis', '83322-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30357, 'Sarandi', 'Rio da Prata', 'Parque Alvamar II', '87113-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30358, 'Cascavel', 'Rio da Prata', 'Brasmadeira', '85814-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30359, 'Ponta Grossa', 'Rio Danúbio', 'Chapada', '84064-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30360, 'Maringá', 'Rio Danúbio', 'Jardim Oásis', '87043-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30361, 'Ponta Grossa', 'Rio das Almas', 'Cará-cará', '84033-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30362, 'Maringá', 'Rio das Antas', 'Jardim São Francisco', '87043-367', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30363, 'Apucarana', 'Rio das Antas', 'Núcleo Habitacional Papa João Paulo I', '86801-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30364, 'Cascavel', 'Rio das Antas', 'Brasmadeira', '85814-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30365, 'Sarandi', 'Rio das Cinzas', 'Parque Alvamar II', '87113-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30366, 'Telêmaco Borba', 'Rio das Cinzas', 'Área 08', '84270-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30367, 'Apucarana', 'Rio das Cinzas', 'Núcleo Habitacional Papa João Paulo I', '86801-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30368, 'Cascavel', 'Rio das Cinzas', 'Santa Cruz', '85806-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30369, 'Cascavel', 'Rio das Ondas', 'Brasmadeira', '85814-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30370, 'Pinhais', 'Rio das Pedras', 'Planta Bairro Weissópolis', '83322-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30371, 'Cascavel', 'Rio das Pedras', 'Brasmadeira', '85814-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30372, 'Maringá', 'Rio das Várzeas', 'Parque Residencial Tuiuti', '87043-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30373, 'Curitiba', 'Rio de Janeiro', 'Água Verde', '80610-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30374, 'Curitiba', 'Rio de Janeiro', 'Guaíra', '80630-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30375, 'Foz do Iguaçu', 'Rio de Janeiro', 'Conjunto C', '85870-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30376, 'Laranjeiras do Sul', 'Rio de Janeiro', 'Água Verde', '85302-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30377, 'Foz do Iguaçu', 'Rio de Janeiro', 'Vila Bom Jesus', '85852-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30378, 'Guarapuava', 'Rio de Janeiro', 'Dos Estados', '85035-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30379, 'Londrina', 'Rio de Janeiro', 'Centro', '86010-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30380, 'Piraquara', 'Rio de Janeiro', 'Jardim dos Estados 1', '83308-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30381, 'Maringá', 'Rio de Janeiro', 'Parque Residencial Cidade Nova', '87023-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30382, 'Pinhais', 'Rio de Janeiro', 'Planta Bairro Weissópolis', '83322-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30383, 'Paranaguá', 'Rio de Janeiro', 'Parque Agari', '83215-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30384, 'Piraquara', 'Rio de Janeiro', 'Jardim dos Estados 2', '83308-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30385, 'Paranaguá', 'Rio de Janeiro', 'Jardim Guaraituba', '83209-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30386, 'Ponta Grossa', 'Rio de Janeiro', 'Nova Rússia', '84070-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30387, 'Ponta Grossa', 'Rio de Janeiro', 'Centro', '84010-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30388, 'Umuarama', 'Rio de Janeiro', 'Zona II', '87501-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30389, 'Sarandi', 'Rio de Janeiro', 'Jardim Independência II', '87113-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30390, 'São José dos Pinhais', 'Rio de Janeiro', 'Águas Belas', '83010-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30391, 'Campo Largo', 'Rio de Janeiro', 'Jardim Esmeralda', '83604-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30392, 'Cascavel', 'Rio de Janeiro', 'Centro', '85801-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30393, 'Cascavel', 'Rio de Janeiro', 'Centro', '85801-031', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30394, 'Araucária', 'Rio de Janeiro', 'Iguaçu', '83701-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30395, 'Apucarana', 'Rio de Janeiro', 'Jardim Governador Lupion', '86808-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30396, 'Castro', 'Rio de Janeiro', 'Jardim das Araucárias', '84174-070', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30397, 'Almirante Tamandaré', 'Rio de Janeiro', 'Jardim Gramados', '83504-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30398, 'Colombo', 'Rio de Janeiro', 'Vila Guaraci', '83404-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30399, 'Pinhais', 'Rio do Cedro', 'Planta Bairro Weissópolis', '83322-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30400, 'Telêmaco Borba', 'Rio do Ouro', 'Área 02', '84267-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30401, 'Apucarana', 'Rio do Peixe', 'Núcleo Habitacional Papa João Paulo I', '86801-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30402, 'Foz do Iguaçu', 'Rio do Sul', 'Jardim Residencial São Roque', '85853-708', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30403, 'Piraquara', 'Rio do Sul', 'Planta São Tiago', '83306-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30404, 'São José dos Pinhais', 'Rio do Sul', 'São Sebastião', '83075-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30405, 'Curitiba', 'Rio do Sul', 'Campo Comprido', '81240-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30406, 'Curitiba', 'Rio do Sul', 'Campo Comprido', '81220-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30407, 'Foz do Iguaçu', 'Rio Doce', 'Loteamento Campos do Iguaçu', '85857-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30408, 'Telêmaco Borba', 'Rio Doce', 'Área 08', '84270-050', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30409, 'Colombo', 'Rio Doce', 'Jardim Colúmbia', '83403-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30410, 'Apucarana', 'Rio dos Índios', 'Núcleo Habitacional Papa João Paulo I', '86801-207', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30411, 'Sarandi', 'Rio dos Patos', 'Parque Alvamar II', '87113-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30412, 'Apucarana', 'Rio dos Patos', 'Núcleo Habitacional Papa João Paulo I', '86801-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30413, 'Maringá', 'Rio Encantado', 'Jardim Novo Oásis', '87043-608', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30414, 'Apucarana', 'Rio Floriano', 'Núcleo Habitacional Papa João Paulo I', '86801-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30415, 'Apucarana', 'Rio Formoso', 'Núcleo Habitacional Papa João Paulo I', '86801-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30416, 'Maringá', 'Rio Ganges', 'Jardim Novo Oásis', '87043-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30417, 'Sarandi', 'Rio Goioerê', 'Parque Alvamar II', '87113-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30418, 'Apucarana', 'Rio Goioerê', 'Núcleo Habitacional Papa João Paulo I', '86801-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30419, 'Cascavel', 'Rio Gonçalves Dias', 'Brasmadeira', '85814-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30420, 'Telêmaco Borba', 'Rio Grajaú', 'Área 08', '84270-010', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30421, 'Telêmaco Borba', 'Rio Grande', 'Área 08', '84270-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30422, 'Francisco Beltrão', 'Rio Grande do Norte', 'Nossa Senhora Aparecida', '85601-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30423, 'Guarapuava', 'Rio Grande do Norte', 'Dos Estados', '85035-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30424, 'Londrina', 'Rio Grande do Norte', 'Matos', '86026-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30425, 'Ponta Grossa', 'Rio Grande do Norte', 'Boa Vista', '84070-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30426, 'Paranavaí', 'Rio Grande do Norte', 'Centro', '87701-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30427, 'Paranavaí', 'Rio Grande do Norte', 'Centro', '87705-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30428, 'Maringá', 'Rio Grande do Norte', 'Jardim Alvorada', '87033-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30429, 'Umuarama', 'Rio Grande do Norte', 'Jardim Tropical', '87503-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30430, 'Umuarama', 'Rio Grande do Norte', 'Zona V', '87504-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30431, 'São José dos Pinhais', 'Rio Grande do Norte', 'Boneca do Iguaçu', '83040-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30432, 'Campo Largo', 'Rio Grande do Norte', 'Vila Itaqui', '83604-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30433, 'Almirante Tamandaré', 'Rio Grande do Norte', 'Vila Dolores', '83514-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30434, 'Colombo', 'Rio Grande do Norte', 'Vila Guaraci', '83404-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30435, 'Cascavel', 'Rio Grande do Norte', 'São Cristóvão', '85813-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30436, 'Araucária', 'Rio Grande do Norte', 'Iguaçu', '83701-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30437, 'Cambé', 'Rio Grande do Norte', 'Centro', '86181-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30438, 'Curitiba', 'Rio Grande do Norte', 'Guaíra', '80630-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30439, 'Francisco Beltrão', 'Rio Grande do Sul', 'Alvorada', '85601-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30440, 'Guarapuava', 'Rio Grande do Sul', 'Dos Estados', '85035-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30441, 'Foz do Iguaçu', 'Rio Grande do Sul', 'Vila Maracanã', '85852-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30442, 'Londrina', 'Rio Grande do Sul', 'Matarazzo', '86026-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30443, 'Laranjeiras do Sul', 'Rio Grande do Sul', 'Água Verde', '85302-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30444, 'Paranavaí', 'Rio Grande do Sul', 'Vila City', '87709-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30445, 'Paranavaí', 'Rio Grande do Sul', 'Centro', '87702-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30446, 'Paranavaí', 'Rio Grande do Sul', 'Centro', '87703-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30447, 'Piraquara', 'Rio Grande do Sul', 'Jardim dos Estados 1', '83308-430', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30448, 'Ponta Grossa', 'Rio Grande do Sul', 'Orfãs', '84015-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30449, 'Piraquara', 'Rio Grande do Sul', 'Jardim dos Estados 2', '83308-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30450, 'São José dos Pinhais', 'Rio Grande do Sul', 'São Domingos', '83030-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30451, 'Umuarama', 'Rio Grande do Sul', 'Jardim América', '87502-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30452, 'Toledo', 'Rio Grande do Sul', 'Jardim Porto Alegre', '85906-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30453, 'Umuarama', 'Rio Grande do Sul', 'Jardim Belvedere', '87505-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30454, 'Cascavel', 'Rio Grande do Sul', 'Centro', '85801-011', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30455, 'Apucarana', 'Rio Grande do Sul', 'Jardim Apucarana', '86804-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30456, 'Campo Largo', 'Rio Grande do Sul', 'Jardim Esmeralda', '83604-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30457, 'Colombo', 'Rio Grande do Sul', 'Vila Guaraci', '83404-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30458, 'Araucária', 'Rio Grande do Sul', 'Iguaçu', '83701-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30459, 'Cascavel', 'Rio Grande do Sul', 'Centro', '85801-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30460, 'Curitiba', 'Rio Grande do Sul', 'Água Verde', '80620-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30461, 'Curitiba', 'Rio Grande do Sul', 'Água Verde', '80610-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30462, 'Curitiba', 'Rio Grande do Sul', 'Guaíra', '80630-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30463, 'Maringá', 'Rio Guaíba', 'Jardim Oásis', '87043-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30464, 'Curitiba', 'Rio Guaíba', 'Bairro Alto', '82840-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30465, 'Pinhais', 'Rio Guanabara', 'Planta Bairro Weissópolis', '83322-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30466, 'Maringá', 'Rio Guandu', 'Conjunto Residencial Branca Vieira', '87043-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30467, 'Telêmaco Borba', 'Rio Guaporé', 'Área 07', '84270-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30468, 'Colombo', 'Rio Guaporé', 'Jardim Moinho Velho', '83403-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30469, 'Cascavel', 'Rio Guaporé', 'Santa Cruz', '85806-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30470, 'Curitiba', 'Rio Guaporé', 'Bairro Alto', '82840-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30471, 'Cascavel', 'Rio Guarani', 'Brasmadeira', '85814-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30472, 'Pinhais', 'Rio Guaratuba', 'Planta Bairro Weissópolis', '83322-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30473, 'Maringá', 'Rio Gurupi', 'Jardim Novo Oásis', '87043-587', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30474, 'Maringá', 'Rio Hudson', 'Conjunto João de Barro Champagnat', '87043-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30475, 'Ponta Grossa', 'Rio Iapó', 'Neves', '84020-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30476, 'Apucarana', 'Rio Iapó', 'Núcleo Habitacional Papa João Paulo I', '86801-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30477, 'Maringá', 'Rio Ica', 'Jardim Novo Oásis', '87043-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30478, 'Cambé', 'Rio Ica', 'Jardim Santo Amaro', '86185-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30479, 'Colombo', 'Rio Ica', 'Jardim Colúmbia', '83403-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30480, 'Maringá', 'Rio Iguaçu', 'Jardim Campos Elísios', '87043-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30481, 'Ponta Grossa', 'Rio Iguaçu', 'Cará-cará', '84033-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30482, 'Pinhais', 'Rio Iguaçu', 'Planta Bairro Weissópolis', '83322-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30483, 'São José dos Pinhais', 'Rio Iguaçu', 'Ipê', '83055-056', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30484, 'Sarandi', 'Rio Iguaçu', 'Parque Alvamar II', '87113-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30485, 'Telêmaco Borba', 'Rio Iguaçu', 'Área 06', '84271-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30486, 'Almirante Tamandaré', 'Rio Iguaçu', 'Jardim Cristiane', '83507-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30487, 'Apucarana', 'Rio Iguaçu', 'Núcleo Habitacional Papa João Paulo I', '86801-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30488, 'Cambé', 'Rio Iguaçu', 'Jardim Santo Amaro', '86185-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30489, 'Colombo', 'Rio Iguaçu', 'Jardim Esmeralda', '83403-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30490, 'Curitiba', 'Rio Iguaçu', 'Centro Cívico', '80530-400', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30491, 'Telêmaco Borba', 'Rio Iguapé', 'Área 03', '84271-530', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30492, 'Ponta Grossa', 'Rio Imbaú', 'Cará-cará', '84033-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30493, 'Telêmaco Borba', 'Rio Imbaú', 'Área 03', '84271-480', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30494, 'Pinhais', 'Rio Ipiranga', 'Planta Bairro Weissópolis', '83322-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30495, 'Cascavel', 'Rio Ipiranga', 'Brasmadeira', '85814-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30496, 'Curitiba', 'Rio Iriri', 'Bairro Alto', '82840-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30497, 'Telêmaco Borba', 'Rio Irirí', 'Área 03', '84271-540', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30498, 'Maringá', 'Rio Itajaí', 'Conjunto Residencial Branca Vieira', '87043-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30499, 'Telêmaco Borba', 'Rio Itanhém', 'Área 08', '84270-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30500, 'Maringá', 'Rio Itapemirim', 'Conjunto Residencial Branca Vieira', '87043-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30501, 'Maringá', 'Rio Itapoa', 'Conjunto João de Barro Itaparica', '87043-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30502, 'Pinhais', 'Rio Itaqui', 'Planta Bairro Weissópolis', '83322-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30503, 'São José dos Pinhais', 'Rio Itaqui', 'Guatupê', '83065-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30504, 'Ponta Grossa', 'Rio Itararé', 'Chapada', '84064-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30505, 'Sarandi', 'Rio Itararé', 'Parque Alvamar II', '87113-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30506, 'Cascavel', 'Rio Itararé', 'Santa Cruz', '85806-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30507, 'Pinhais', 'Rio Ivai', 'Planta Bairro Weissópolis', '83322-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30508, 'Telêmaco Borba', 'Rio Ivai', 'Área 08', '84270-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30509, 'Apucarana', 'Rio Ivai', 'Núcleo Habitacional Papa João Paulo I', '86801-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30510, 'Cascavel', 'Rio Ivai', 'Santa Cruz', '85806-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30511, 'Colombo', 'Rio Ivai', 'Jardim Moinho Velho', '83403-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30512, 'Cambé', 'Rio Ivai', 'Jardim Santo Amaro', '86185-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30513, 'Cambé', 'Rio Ivinhema', 'Jardim Santo Amaro', '86185-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30514, 'Apucarana', 'Rio Jacaré', 'Núcleo Habitacional Papa João Paulo I', '86801-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30515, 'Apucarana', 'Rio Jacucaca', 'Núcleo Habitacional Papa João Paulo I', '86801-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30516, 'Maringá', 'Rio Jacui', 'Conjunto Residencial Branca Vieira', '87043-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30517, 'Maringá', 'Rio Jacutinga', 'Jardim Oásis', '87043-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30518, 'Apucarana', 'Rio Jaguariaiva', 'Núcleo Habitacional Papa João Paulo I', '86801-205', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30519, 'Maringá', 'Rio Jaguaribe', 'Conjunto Residencial Branca Vieira', '87043-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30520, 'Maringá', 'Rio Jaguaribe', 'Conjunto Habitacional Lea Leal', '87040-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30521, 'Telêmaco Borba', 'Rio Jaguaribe', 'Área 08', '84270-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30522, 'Curitiba', 'Rio Jaguaribe', 'Bairro Alto', '82840-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30523, 'Cambé', 'Rio Jamunda', 'Jardim Santo Amaro', '86185-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30524, 'Pinhais', 'Rio Japurá', 'Planta Bairro Weissópolis', '83322-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30525, 'Telêmaco Borba', 'Rio Japurá', 'Área 07', '84270-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30526, 'Almirante Tamandaré', 'Rio Japurá', 'Jardim Amazonas', '83507-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30527, 'Cambé', 'Rio Japurá', 'Jardim Santo Amaro', '86185-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30528, 'Colombo', 'Rio Japurá', 'Jardim Esmeralda', '83403-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30529, 'Curitiba', 'Rio Japurã', 'Bairro Alto', '82820-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30530, 'Curitiba', 'Rio Japurã', 'Atuba', '82840-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30531, 'Maringá', 'Rio Japuratuba', 'Conjunto Residencial Branca Vieira', '87043-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30532, 'Maringá', 'Rio Jari', 'Jardim Novo Oásis', '87043-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30533, 'Pinhais', 'Rio Jari', 'Planta Weissopolis', '83322-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30534, 'Curitiba', 'Rio Jari', 'Atuba', '82840-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30535, 'Curitiba', 'Rio Jari', 'Bairro Alto', '82820-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30536, 'Maringá', 'Rio Jaú', 'Jardim Novo Oásis', '87043-588', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30537, 'Pinhais', 'Rio Javari', 'Planta Bairro Weissópolis', '83322-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30538, 'Colombo', 'Rio Javari', 'Jardim Ivanir', '83403-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30539, 'Cambé', 'Rio Javarí', 'Jardim Santo Amaro', '86185-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30540, 'Colombo', 'Rio Jequitinhonha', 'Jardim Moinho Velho', '83403-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30541, 'Cambé', 'Rio Jequitinhonha', 'Jardim Santo Amaro', '86185-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30542, 'Ponta Grossa', 'Rio Jordão', 'Neves', '84020-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30543, 'Maringá', 'Rio Jordão', 'Conjunto João de Barro Champagnat', '87043-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30544, 'Telêmaco Borba', 'Rio Jordão', 'Área 03', '84271-490', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30545, 'Apucarana', 'Rio Jordão', 'Núcleo Habitacional Papa João Paulo I', '86801-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30546, 'Maringá', 'Rio Jurema', 'Loteamento Batel', '87043-437', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30547, 'Maringá', 'Rio Juruá', 'Jardim Oásis', '87043-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30548, 'Telêmaco Borba', 'Rio Juruá', 'Área 07', '84270-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30549, 'Almirante Tamandaré', 'Rio Juruá', 'Jardim Amazonas', '83507-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30550, 'Cambé', 'Rio Juruá', 'Jardim Santo Amaro', '86185-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30551, 'Curitiba', 'Rio Juruá', 'Atuba', '82840-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30552, 'Curitiba', 'Rio Jutaí', 'Atuba', '82840-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30553, 'Maringá', 'Rio Ligeiro', 'Parque Residencial Tuiuti', '87043-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30554, 'Apucarana', 'Rio Ligeiro', 'Núcleo Habitacional Papa João Paulo I', '86801-206', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30555, 'Maringá', 'Rio Macaúbas', 'Conjunto João de Barro Itaparica', '87043-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30556, 'Foz do Iguaçu', 'Rio Madeira', 'Loteamento Campos do Iguaçu', '85857-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30557, 'Pinhais', 'Rio Madeira', 'Planta Bairro Weissópolis', '83322-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30558, 'Maringá', 'Rio Madeira', 'Conjunto Residencial Branca Vieira', '87043-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30559, 'Cascavel', 'Rio Madeira', 'Santa Cruz', '85806-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30560, 'Colombo', 'Rio Madeira', 'Jardim Esmeralda', '83403-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30561, 'Almirante Tamandaré', 'Rio Madeira', 'Jardim Amazonas', '83507-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30562, 'Cambé', 'Rio Madeira', 'Jardim Santo Amaro', '86185-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30563, 'Maringá', 'Rio Mamoré', 'Jardim Novo Oásis', '87043-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30564, 'Almirante Tamandaré', 'Rio Mamoré', 'Jardim Amazonas', '83507-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30565, 'Cascavel', 'Rio Mamoré', 'Brasmadeira', '85814-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30566, 'Maringá', 'Rio Manso', 'Jardim Novo Oásis', '87043-607', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30567, 'Telêmaco Borba', 'Rio Manso', 'Área 07', '84270-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30568, 'Almirante Tamandaré', 'Rio Marmeleiro', 'Jardim Rafaela', '83512-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30569, 'Telêmaco Borba', 'Rio Mármore', 'Área 07', '84270-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30570, 'Maringá', 'Rio Mearim', 'Conjunto Residencial Branca Vieira', '87043-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30571, 'Cascavel', 'Rio Melissa', 'Brasmadeira', '85814-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30572, 'Ponta Grossa', 'Rio Miranda', 'Cará-cará', '84033-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30573, 'Cambé', 'Rio Miranda', 'Jardim Santo Amaro', '86185-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30574, 'Telêmaco Borba', 'Rio Moa', 'Vila Rosa', '84272-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30575, 'Curitiba', 'Rio Mucuri', 'Bairro Alto', '82840-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30576, 'Sarandi', 'Rio Negrinho', 'Parque Alvamar II', '87113-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30577, 'Foz do Iguaçu', 'Rio Negro', 'Loteamento Campos do Iguaçu', '85857-550', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30578, 'Francisco Beltrão', 'Rio Negro', 'São Miguel', '85602-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30579, 'Guarapuava', 'Rio Negro', 'Boqueirão', '85020-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30580, 'Londrina', 'Rio Negro', 'Real', '86025-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30581, 'Ponta Grossa', 'Rio Negro', 'Uvaranas', '84025-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30582, 'Pinhais', 'Rio Negro', 'Planta Bairro Weissópolis', '83322-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30583, 'Paranavaí', 'Rio Negro', 'Jardim Ouro Branco', '87704-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30584, 'Maringá', 'Rio Negro', 'Conjunto Residencial Paulino Carlos Filho', '87043-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30585, 'Maringá', 'Rio Negro', 'Conjunto Habitacional Lea Leal', '87040-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30586, 'Sarandi', 'Rio Negro', 'Jardim Gralha Azul', '87112-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30587, 'Sarandi', 'Rio Negro', 'Parque Alvamar II', '87113-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30588, 'São José dos Pinhais', 'Rio Negro', 'Cruzeiro', '83010-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30589, 'Telêmaco Borba', 'Rio Negro', 'Área 07', '84270-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30590, 'Cascavel', 'Rio Negro', 'São Cristóvão', '85816-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30591, 'Cambé', 'Rio Negro', 'Jardim Santo Amaro', '86185-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30592, 'Almirante Tamandaré', 'Rio Negro', 'Jardim Amazonas', '83507-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30593, 'Apucarana', 'Rio Negro', 'Vila Regina', '86801-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30594, 'Colombo', 'Rio Negro', 'Jardim Anai', '83410-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30595, 'Curitiba', 'Rio Negro', 'Bairro Alto', '82820-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30596, 'Ponta Grossa', 'Rio Nilo', 'Chapada', '84064-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30597, 'Curitiba', 'Rio Norte Belém', 'São Lourenço', '82210-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30598, 'Curitiba', 'Rio Norte Belém', 'São Lourenço', '82200-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30599, 'Ponta Grossa', 'Rio Novo', 'Chapada', '84064-217', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30600, 'Sarandi', 'Rio Novo', 'Parque Alvamar II', '87113-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30601, 'Cascavel', 'Rio Oiapoque', 'Brasmadeira', '85814-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30602, 'Maringá', 'Rio Oipoque', 'Jardim Oásis', '87043-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30603, 'Almirante Tamandaré', 'Rio Ouro Fino', 'Jardim Colonial', '83512-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30604, 'Almirante Tamandaré', 'Rio Pacotuba', 'Jardim Santa Maria', '83511-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30605, 'Cascavel', 'Rio Pajeu', 'Brasmadeira', '85814-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30606, 'São José dos Pinhais', 'Rio Palmital', 'Ipê', '83055-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30607, 'Maringá', 'Rio Paraguaçu', 'Conjunto Residencial Branca Vieira', '87043-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30608, 'Telêmaco Borba', 'Rio Paraguaçu', 'Área 08', '84270-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30609, 'Ponta Grossa', 'Rio Paraguai', 'Chapada', '84064-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30610, 'Pinhais', 'Rio Paraná', 'Planta Bairro Weissópolis', '83322-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30611, 'Ponta Grossa', 'Rio Paraná', 'Chapada', '84064-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30612, 'Telêmaco Borba', 'Rio Paraná', 'Área 03', '84271-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30613, 'Sarandi', 'Rio Paraná', 'Parque Alvamar II', '87113-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30614, 'Almirante Tamandaré', 'Rio Paraná', 'Jardim Cristiane', '83507-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30615, 'Apucarana', 'Rio Paraná', 'Núcleo Habitacional Papa João Paulo I', '86801-090', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30616, 'Cambé', 'Rio Paraná', 'Jardim do Café', '86185-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30617, 'Colombo', 'Rio Paranaíba', 'Jardim Esmeralda', '83403-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30618, 'Pinhais', 'Rio Paranapanema', 'Planta Bairro Weissópolis', '83322-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30619, 'Maringá', 'Rio Paranapanema', 'Conjunto Residencial Branca Vieira', '87043-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30620, 'Ponta Grossa', 'Rio Paranapanema', 'Chapada', '84064-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30621, 'Telêmaco Borba', 'Rio Paranapanema', 'Área 08', '84270-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30622, 'Sarandi', 'Rio Paranapanema', 'Parque Alvamar II', '87113-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30623, 'Cambé', 'Rio Paranapanema', 'Jardim Santo Amaro', '86185-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30624, 'Apucarana', 'Rio Paranapanema', 'Núcleo Habitacional Papa João Paulo I', '86801-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30625, 'Colombo', 'Rio Paranapanema', 'Jardim Moinho Velho', '83403-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30626, 'Maringá', 'Rio Paranapanema II', 'Zona 37', '87043-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30627, 'Sarandi', 'Rio Pardinho', 'Parque Alvamar II', '87113-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30628, 'Londrina', 'Rio Pardo', 'Portuguesa', '86025-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30629, 'Ponta Grossa', 'Rio Pardo', 'Neves', '84020-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30630, 'Telêmaco Borba', 'Rio Pardo', 'Área 03', '84271-500', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30631, 'Maringá', 'Rio Parnaíba', 'Conjunto Residencial Branca Vieira', '87043-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30632, 'Pinhais', 'Rio Parnaíba', 'Planta Bairro Weissópolis', '83322-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30633, 'Telêmaco Borba', 'Rio Parnaíba', 'Área 08', '84270-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30634, 'Cambé', 'Rio Parnaíba', 'Jardim Santo Amaro', '86185-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30635, 'Telêmaco Borba', 'Rio Parú', 'Área 07', '84270-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30636, 'Almirante Tamandaré', 'Rio Passauna', 'Jardim Santa Maria', '83511-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30637, 'Pinhais', 'Rio Passaúna', 'Planta Bairro Weissópolis', '83322-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30638, 'Pinhais', 'Rio Pelotas', 'Planta Bairro Weissópolis', '83322-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30639, 'Curitiba', 'Rio Pelotas', 'Bairro Alto', '82840-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30640, 'Pinhais', 'Rio Pequeno', 'Planta Bairro Weissópolis', '83322-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30641, 'Maringá', 'Rio Pingüim', 'Jardim Oásis', '87043-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30642, 'Pinhais', 'Rio Pinhão', 'Planta Bairro Weissópolis', '83322-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30643, 'Maringá', 'Rio Piquiri', 'Conjunto Residencial Branca Vieira', '87043-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30644, 'Pinhais', 'Rio Piquiri', 'Planta Bairro Weissópolis', '83322-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30645, 'Ponta Grossa', 'Rio Piquiri', 'Cará-cará', '84033-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30646, 'Telêmaco Borba', 'Rio Piquiri', 'Área 08', '84270-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30647, 'Cambé', 'Rio Piquiri', 'Jardim Santo Amaro', '86185-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30648, 'Apucarana', 'Rio Piquiri', 'Núcleo Habitacional Papa João Paulo I', '86801-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30649, 'Colombo', 'Rio Piquiri', 'Jardim Esmeralda', '83403-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30650, 'Ponta Grossa', 'Rio Piracicaba', 'Chapada', '84064-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30651, 'Colombo', 'Rio Piracicaba', 'Jardim Moinho Velho', '83403-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30652, 'Ponta Grossa', 'Rio Pirapó', 'Cará-cará', '84033-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30653, 'Sarandi', 'Rio Pirapó', 'Parque Alvamar II', '87113-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30654, 'Apucarana', 'Rio Pirapó', 'Núcleo Habitacional Papa João Paulo I', '86801-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30655, 'Cambé', 'Rio Pirapó', 'Jardim Santo Amaro', '86185-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30656, 'Pinhais', 'Rio Piraquara', 'Planta Bairro Weissópolis', '83322-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30657, 'Telêmaco Borba', 'Rio Pitangui', 'Área 08', '84270-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30658, 'Maringá', 'Rio Poá', 'Jardim Dourados', '87040-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30659, 'Maringá', 'Rio Preto', 'Jardim São Francisco', '87043-366', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30660, 'Umuarama', 'Rio Preto', 'Jardim Belvedere', '87505-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30661, 'Almirante Tamandaré', 'Rio Purus', 'Jardim Amazonas', '83507-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30662, 'Maringá', 'Rio Purús', 'Loteamento Batel', '87043-436', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30663, 'Pinhais', 'Rio Purús', 'Planta Bairro Weissópolis', '83322-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30664, 'Cambé', 'Rio Purús', 'Jardim Santo Amaro', '86185-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30665, 'Ponta Grossa', 'Rio Ribeira', 'Neves', '84020-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30666, 'Sarandi', 'Rio Ribeira', 'Parque Alvamar II', '87113-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30667, 'Colombo', 'Rio Ribeira', 'Jardim Moinho Velho', '83403-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30668, 'Pinhais', 'Rio Sagrado', 'Planta Weissopolis', '83322-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30669, 'Maringá', 'Rio Samambaia', 'Jardim Campos Elísios', '87043-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30670, 'Maringá', 'Rio San Martin', 'Conjunto João de Barro Champagnat', '87043-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30671, 'Ponta Grossa', 'Rio Santa Rita', 'Chapada', '84064-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30672, 'Ponta Grossa', 'Rio São Francisco', 'Chapada', '84064-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30673, 'Pinhais', 'Rio São Francisco', 'Planta Bairro Weissópolis', '83322-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30674, 'Cambé', 'Rio São Francisco', 'Jardim Santo Amaro', '86185-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30675, 'Colombo', 'Rio São Francisco', 'Jardim Esmeralda', '83403-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30676, 'Cascavel', 'Rio São Francisco', 'Brasmadeira', '85814-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30677, 'Maringá', 'Rio São Francisco II', 'Zona 37', '87043-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30678, 'Pinhais', 'Rio São João', 'Planta Bairro Weissópolis', '83322-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30679, 'Pinhais', 'Rio São Luiz', 'Planta Bairro Weissópolis', '83322-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30680, 'Maringá', 'Rio Sena', 'Jardim Oásis', '87043-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30681, 'Ponta Grossa', 'Rio Sena', 'Chapada', '84064-216', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30682, 'Maringá', 'Rio Seridó', 'Conjunto Residencial Branca Vieira', '87043-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30683, 'Ponta Grossa', 'Rio Solimões', 'Chapada', '84064-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30684, 'Pinhais', 'Rio Solimões', 'Planta Bairro Weissópolis', '83322-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30685, 'Maringá', 'Rio Solimões', 'Jardim Campos Elísios', '87043-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30686, 'Telêmaco Borba', 'Rio Solimões', 'Área 08', '84270-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30687, 'Cascavel', 'Rio Solimões', 'Brasmadeira', '85814-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30688, 'Colombo', 'Rio Solimões', 'Jardim Colúmbia', '83403-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30689, 'Ponta Grossa', 'Rio Taiuva', 'Cará-cará', '84033-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30690, 'Almirante Tamandaré', 'Rio Tanguá', 'Jardim Rafaela', '83512-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30691, 'Pinhais', 'Rio Tapajós', 'Planta Bairro Weissópolis', '83322-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30692, 'Maringá', 'Rio Tapajós', 'Conjunto Residencial Branca Vieira', '87043-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30693, 'Telêmaco Borba', 'Rio Tapajós', 'Área 08', '84270-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30694, 'Almirante Tamandaré', 'Rio Tapajós', 'Jardim Napole', '83507-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30695, 'Maringá', 'Rio Taperoa', 'Conjunto Residencial Branca Vieira', '87043-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30696, 'Apucarana', 'Rio Taquara', 'Núcleo Habitacional Papa João Paulo I', '86801-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30697, 'Cambé', 'Rio Taquari', 'Jardim Santo Amaro', '86185-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30698, 'Cambé', 'Rio Tefé', 'Jardim Santo Amaro', '86185-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30699, 'Cascavel', 'Rio Tefé', 'Brasmadeira', '85814-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30700, 'Telêmaco Borba', 'Rio Teles', 'Área 03', '84271-550', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30701, 'Maringá', 'Rio Tibagi', 'Loteamento Batel', '87043-438', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30702, 'Pinhais', 'Rio Tibagi', 'Planta Bairro Weissópolis', '83322-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30703, 'Ponta Grossa', 'Rio Tibagi', 'Chapada', '84064-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30704, 'Sarandi', 'Rio Tibagi', 'Parque Alvamar II', '87113-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30705, 'Cascavel', 'Rio Tibagi', 'Brasmadeira', '85814-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30706, 'Cambé', 'Rio Tibagi', 'Jardim Santo Amaro', '86185-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30707, 'Colombo', 'Rio Tibagi', 'Jardim Esmeralda', '83403-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30708, 'Apucarana', 'Rio Tibagi', 'Núcleo Habitacional Papa João Paulo I', '86801-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30709, 'Maringá', 'Rio Tibiriçá', 'Jardim Novo Oásis', '87043-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30710, 'Ponta Grossa', 'Rio Tietê', 'Chapada', '84064-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30711, 'Pinhais', 'Rio Tietê', 'Planta Bairro Weissópolis', '83322-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30712, 'Cambé', 'Rio Tietê', 'Jardim Santo Amaro', '86185-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30713, 'Curitiba', 'Rio Tietê', 'Bairro Alto', '82840-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30714, 'Maringá', 'Rio Tigre', 'Jardim Oásis', '87043-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30715, 'Pinhais', 'Rio Tingui', 'Planta Bairro Weissópolis', '83322-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30716, 'Maringá', 'Rio Tocantins', 'Conjunto Residencial Paulino Carlos Filho', '87043-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30717, 'Pinhais', 'Rio Tocantins', 'Planta Bairro Weissópolis', '83322-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30718, 'Telêmaco Borba', 'Rio Tocantins', 'Área 08', '84270-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30719, 'Colombo', 'Rio Tocantins', 'Jardim Esmeralda', '83403-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30720, 'Almirante Tamandaré', 'Rio Tocantins', 'Jardim Amazonas', '83507-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30721, 'Cambé', 'Rio Tocantins', 'Jardim Santo Amaro', '86185-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30722, 'Maringá', 'Rio Trombetas', 'Loteamento Batel', '87043-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30723, 'Pinhais', 'Rio Trombetas', 'Planta Bairro Weissópolis', '83322-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30724, 'Telêmaco Borba', 'Rio Trombetas', 'Área 07', '84270-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30725, 'Colombo', 'Rio Trombetas', 'Jardim Ivanir', '83403-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30726, 'Londrina', 'Rio Turvo', 'Tietê', '86025-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30727, 'Ponta Grossa', 'Rio Uruguai', 'Chapada', '84064-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30728, 'Pinhais', 'Rio Uruguai', 'Planta Bairro Weissópolis', '83322-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30729, 'Foz do Iguaçu', 'Rio Verde', 'Loteamento Menger', '85862-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30730, 'Maringá', 'Rio Verde', 'Conjunto Habitacional Lea Leal', '87040-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30731, 'Ponta Grossa', 'Rio Verde', 'Cará-cará', '84033-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30732, 'Ponta Grossa', 'Rio Verde', 'Neves', '84020-550', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30733, 'Telêmaco Borba', 'Rio Verde', 'Área 03', '84271-570', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30734, 'Campo Largo', 'Rio Verde', 'Ferraria', '83608-650', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30735, 'Campo Largo', 'Rio Verde', 'Vila de Lurdes', '83601-560', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30736, 'Maringá', 'Rio Vermelho', 'Jardim Campos Elísios', '87043-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30737, 'Cambé', 'Rio Vermelho', 'Jardim Santo Amaro', '86185-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30738, 'Curitiba', 'Rio Vila Guaíra', 'Guaíra', '80220-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30739, 'Curitiba', 'Rio Vila Guaíra', 'Guaíra', '80630-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30740, 'Maringá', 'Rio Xingu', 'Conjunto Residencial Paulino Carlos Filho', '87043-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30741, 'Pinhais', 'Rio Xingu', 'Planta Weissopolis', '83322-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30742, 'Telêmaco Borba', 'Rio Xingu', 'Área 07', '84270-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30743, 'Almirante Tamandaré', 'Rio Xingu', 'Jardim Amazonas', '83507-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30744, 'Colombo', 'Rio Xingu', 'Jardim Esmeralda', '83403-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30745, 'Cambé', 'Rio Xingu', 'Jardim Santo Amaro', '86185-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30746, 'Colombo', 'Riosto Pavin', 'Centro', '83414-165', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30747, 'Arapongas', 'Ripidura', 'Vila Rugna', '86705-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30748, 'Arapongas', 'Ripina', 'Conjunto José Bretas Cupertino', '86702-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30749, 'Ponta Grossa', 'Rissa', 'Jardim Carvalho', '84016-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30750, 'Curitiba', 'Riszardo Edmundo Gluchowski', 'Cajuru', '82970-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30751, 'Curitiba', 'Rita Ana de Cássia', 'Uberaba', '81580-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30752, 'Foz do Iguaçu', 'Rita Angélica de Carvalho', 'Jardim N Horizonte', '85855-728', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30753, 'Londrina', 'Rita Cajola', 'Colinas', '86056-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30754, 'Londrina', 'Rita da Conceição Barbosa', 'Luiz de Sá', '86085-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30755, 'Almirante Tamandaré', 'Rita de Cássia Barbieri', 'Jardim Giannini', '83511-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30756, 'Londrina', 'Rita de Cássia Viviane de Andrade', 'Jardim Barcelona', '86073-357', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30757, 'Toledo', 'Rita Leduc Maschio', 'Jardim Maschio', '85909-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30758, 'Curitiba', 'Rita Margarida de Jesus', 'Cajuru', '82920-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30759, 'Londrina', 'Rita Pereira', 'Jardim São Jorge', '86082-828', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30760, 'Foz do Iguaçu', 'Rita Soares', 'Jardim Norma', '85869-618', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30761, 'Castro', 'Rivadávia de Gracia Lara', 'Jardim das Araucárias', '84174-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30762, 'Curitiba', 'Rivadávia Fonseca de Macedo', 'Cajuru', '82980-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30763, 'Guarapuava', 'Rivadávia Roseira Ribas', 'Bonsucesso', '85055-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30764, 'Curitiba', 'Rivaddavia de Macedo Júnior', 'Cidade Industrial', '81460-336', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30765, 'Curitiba', 'Rivair Galdino Rodeiro', 'Cidade Industrial', '81460-156', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30766, 'Colombo', 'Rivoli', 'Centro Industrial Mauá', '83413-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30767, 'Foz do Iguaçu', 'Robalo', 'Profilurb I', '85855-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30768, 'Londrina', 'Robert Boyle', 'Maringá', '86060-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30769, 'Ponta Grossa', 'Robert Frost', 'Cará-cará', '84043-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30770, 'Curitiba', 'Robert Kennedy', 'Tingui', '82600-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30771, 'Londrina', 'Robert Koch', 'Operária', '86038-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30772, 'Londrina', 'Robert Koch', 'Aragarça', '86037-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30773, 'Curitiba', 'Robert Redzimski', 'Cidade Industrial', '81270-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30774, 'Londrina', 'Robert Salum', 'Vila Ipiranga', '86010-030', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30775, 'Londrina', 'Roberto Alexandre', 'Estados', '86083-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30776, 'Apucarana', 'Roberto Alves Pereira', 'Loteamento Santa Maria', '86813-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30777, 'Foz do Iguaçu', 'Roberto Apoloni Neumann', 'Jardim Esmeralda', '85856-150', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30778, 'Curitiba', 'Roberto B. de Almeida', 'Alto Boqueirão', '81830-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30779, 'Paranaguá', 'Roberto Barroso', 'Alto São Sebastião', '83203-725', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30780, 'Foz do Iguaçu', 'Roberto Batata', 'Parque Morumbi III', '85859-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30781, 'Curitiba', 'Roberto Bernert', 'Cidade Industrial', '81280-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30782, 'Toledo', 'Roberto Berwanger', 'Residencial Santa Clara', '85914-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30783, 'Londrina', 'Roberto Beverglieri Filho', 'Jardim Olímpico', '86056-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30784, 'Sarandi', 'Roberto Cavalari Sobrinho', 'Jardim Nova Paulista', '87111-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30785, 'Curitiba', 'Roberto Christensen', 'Portão', '80330-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30786, 'Curitiba', 'Roberto Cichon', 'Cristo Rei', '80050-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30787, 'Curitiba', 'Roberto Cichon', 'Capão da Imbuia', '82800-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30788, 'Londrina', 'Roberto Conceição', 'São Lourenço', '86043-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30789, 'Cambé', 'Roberto Conceição', 'Jardim São José', '86192-550', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30790, 'Curitiba', 'Roberto de Oliveira', 'Tatuquara', '81470-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30791, 'Campo Largo', 'Roberto Dobrzanski', 'Loteamento São José', '83606-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30792, 'Umuarama', 'Roberto Domingos Martins', 'Jardim Cruzeiro', '87504-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30793, 'Almirante Tamandaré', 'Roberto Drecheler', 'Vila Tanguá', '83508-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30794, 'Toledo', 'Roberto Fachini', 'Sachini', '85903-728', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30795, 'Curitiba', 'Roberto Faria', 'Fanny', '81030-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30796, 'Curitiba', 'Roberto Flávio Taddei', 'Atuba', '82630-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30797, 'Curitiba', 'Roberto Fritsch', 'Sítio Cercado', '81925-269', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30798, 'Curitiba', 'Roberto Gava', 'Pilarzinho', '82120-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30799, 'Curitiba', 'Roberto Hauer', 'Hauer', '81610-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30800, 'Laranjeiras do Sul', 'Roberto Henk', 'Cristo Rei', '85304-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30801, 'Castro', 'Roberto Henrique', 'Jardim das Araucárias', '84174-605', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30802, 'Curitiba', 'Roberto José Breckenfeld', 'Pinheirinho', '81820-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30803, 'Londrina', 'Roberto Júlio Roehrig', 'Mediterrâneo', '86047-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30804, 'Curitiba', 'Roberto Koch', 'Lindóia', '81010-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30805, 'Curitiba', 'Roberto Kranz', 'Cidade Industrial', '81460-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30806, 'Curitiba', 'Roberto Lambach', 'Bacacheri', '82515-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30807, 'Colombo', 'Roberto Lambach Falavinha', 'Jardim Nossa Senhora de Fátima', '83405-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30808, 'Castro', 'Roberto Lesnau', 'Vila Santa Cruz', '84168-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30809, 'Curitiba', 'Roberto Lobo', 'Guabirotuba', '81510-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30810, 'Apucarana', 'Roberto Marchiori', 'Núcleo Habitacional João Goulart', '86807-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30811, 'Curitiba', 'Roberto Menghini', 'Cidade Industrial', '81170-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30812, 'São José dos Pinhais', 'Roberto Meres de Credo', 'Afonso Pena', '83065-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30813, 'Foz do Iguaçu', 'Roberto Olmedo', 'Loteamento Witt', '85862-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30814, 'Colombo', 'Roberto Opolis', 'Jardim Florença', '83414-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30815, 'Curitiba', 'Roberto Osório de Almeida', 'Cidade Industrial', '81460-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30816, 'Cascavel', 'Roberto Paiva', 'Esmeralda', '85806-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30817, 'Curitiba', 'Roberto Peixoto de Souza', 'Fazendinha', '81330-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30818, 'Curitiba', 'Roberto Ramon Orta Viacava', 'Sítio Cercado', '81900-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30819, 'Foz do Iguaçu', 'Roberto Rikle', 'Jardim São Paulo II', '85856-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30820, 'Ponta Grossa', 'Roberto Rizental', 'Centro', '84010-175', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30821, 'Ponta Grossa', 'Roberto Rizental', 'Boa Vista', '84073-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30822, 'Londrina', 'Roberto Romanelli', 'Jardim Paris', '86082-088', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30823, 'Curitiba', 'Roberto Senna', 'Novo Mundo', '81020-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30824, 'Colombo', 'Roberto Sgoda', 'Jardim Santa Fé', '83403-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30825, 'Umuarama', 'Roberto Silveira', 'Zona VI', '87503-110', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30826, 'Londrina', 'Roberto Simonsen', 'Itamarati', '86061-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30827, 'Maringá', 'Roberto Simonsen', 'Jardim Alvorada', '87035-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30828, 'Curitiba', 'Roberto Simonsen', 'Guabirotuba', '81510-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30829, 'Londrina', 'Roberto Siqueira de Toledo', 'Milton Gavetti', '86078-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30830, 'Curitiba', 'Roberto Taner', 'Pilarzinho', '82115-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30831, 'Castro', 'Roberto Tavares Abreu', 'Jardim das Araucárias', '84174-540', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30832, 'Guarapuava', 'Roberto Teixeira Marcondes', 'Cascavel', '85027-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30833, 'Curitiba', 'Roberto Vichinheski', 'Pilarzinho', '82120-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30834, 'Apucarana', 'Roberval Alves Barreto', 'Jardim Santos Dumont I', '86812-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30835, 'Laranjeiras do Sul', 'Robinson Fae', 'Centro', '85301-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30836, 'Sarandi', 'Robson Rufino Muniz', 'Parque Industrial IV', '87111-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30837, 'Ponta Grossa', 'Rocha Carvalhaes', 'Colônia Dona Luiza', '84045-570', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30838, 'Ponta Grossa', 'Rocha Carvalhães', 'Orfãs', '84015-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30839, 'Guarapuava', 'Rocha Loures', 'Bonsucesso', '85055-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30840, 'Ponta Grossa', 'Rocha Pita', 'Ronda', '84051-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30841, 'Guarapuava', 'Rocha Pombo', 'Cascavel', '85025-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30842, 'Londrina', 'Rocha Pombo', 'Centro', '86010-370', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30843, 'Maringá', 'Rocha Pombo', 'Zona 01', '87013-030', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30844, 'Paranavaí', 'Rocha Pombo', 'Jardim Santos Dumont', '87706-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30845, 'Paranaguá', 'Rocha Pombo', 'Cruzeiro', '83221-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30846, 'Ponta Grossa', 'Rocha Pombo', 'Jardim Carvalho', '84016-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30847, 'Toledo', 'Rocha Pombo', 'Jardim Paraná', '85904-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30848, 'São José dos Pinhais', 'Rocha Pombo', 'Águas Belas', '83010-620', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30849, 'São José dos Pinhais', 'Rocha Pombo', 'São Cristóvão', '83005-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30850, 'Campo Mourão', 'Rocha Pombo', 'Centro', '87300-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30851, 'Campo Mourão', 'Rocha Pombo', 'Centro', '87303-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30852, 'Campo Largo', 'Rocha Pombo', 'Centro', '83601-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30853, 'Colombo', 'Rocha Pombo', 'Jardim Central', '83409-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30854, 'Castro', 'Rocha Pombo', 'Centro', '84165-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30855, 'Cascavel', 'Rocha Pombo', 'São Cristóvão', '85816-540', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30856, 'Curitiba', 'Rocha Pombo', 'Juvevê', '80030-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30857, 'Curitiba', 'Rocha Pombo', 'Juvevê', '80530-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30858, 'Curitiba', 'Rockefeller', 'Rebouças', '80230-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30859, 'Colombo', 'Roddie Moraes', 'Jardim Ana Terra', '83406-166', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30860, 'Londrina', 'Rodésia', 'Ouro Verde', '86080-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30861, 'Colombo', 'Rodésia', 'Vila Alto da Cruz III', '83405-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30862, 'Foz do Iguaçu', 'Rodolfo Amoedo', 'Parque Residencial Três Bandeiras', '85862-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30863, 'Curitiba', 'Rodolfo Amoedo', 'Xaxim', '81810-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30864, 'Toledo', 'Rodolfo Becker', 'Residencial Santa Clara', '85907-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30865, 'Curitiba', 'Rodolfo Bernardelli', 'Uberaba', '81580-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30866, 'Laranjeiras do Sul', 'Rodolfo Bertuol', 'São Francisco', '85303-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30867, 'Colombo', 'Rodolfo Camargo', 'Roça Grande', '83401-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30868, 'Campo Largo', 'Rodolfo Castagnoli', 'Vila Operária', '83601-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30869, 'Maringá', 'Rodolfo Cremm', 'Jardim Andrade', '87035-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30870, 'Curitiba', 'Rodolfo de Mattia', 'Alto Boqueirão', '81850-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30871, 'Castro', 'Rodolfo de Meira', 'Jardim das Araucárias', '84172-565', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30872, 'São José dos Pinhais', 'Rodolfo Grutter Filho', 'Guatupê', '83065-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30873, 'Araucária', 'Rodolfo Hasselmann', 'Centro', '83702-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30874, 'Araucária', 'Rodolfo Hasselmann', 'Cachoeira', '83701-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30875, 'Londrina', 'Rodolfo Massaro', 'Conjunto Habitacional João Paz', '86087-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30876, 'Colombo', 'Rodolfo Mehl', 'Vila Yara', '83408-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30877, 'Ponta Grossa', 'Rodolfo Osternack', 'Uvaranas', '84031-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30878, 'Curitiba', 'Rodolfo Reksidler', 'São Lourenço', '82210-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30879, 'São José dos Pinhais', 'Rodolfo Scherner', 'Braga', '83020-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30880, 'Ponta Grossa', 'Rodolfo Serzedelo', 'Uvaranas', '84020-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30881, 'Foz do Iguaçu', 'Rodolfo Sther', 'Centro', '85852-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30882, 'Curitiba', 'Rodolfo Teixeira de Souza', 'Pinheirinho', '81820-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30883, 'Ponta Grossa', 'Rodolfo Wilson Taques', 'Boa Vista', '84072-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30884, 'Pinhais', 'Rodolfo Xavier', 'Vila Tarumã', '83323-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30885, 'Castro', 'Rodolfo Zappe', 'Jardim das Araucárias', '84172-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30886, 'Paranaguá', 'Rodolpho Affolter', 'Vila São Vicente', '83209-158', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30887, 'Curitiba', 'Rodolpho Augusto', 'Alto Boqueirão', '81770-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30888, 'Curitiba', 'Rodolpho Doubek', 'Cidade Industrial', '81170-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30889, 'Curitiba', 'Rodolpho Hatschbach', 'Cidade Industrial', '81460-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30890, 'Curitiba', 'Rodolpho Nunes Pereira', 'Abranches', '82220-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30891, 'Curitiba', 'Rodolpho Rosenau', 'Cabral', '82200-340', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30892, 'Paranaguá', 'Rodolpho Schwarzabach', 'Parque São João', '83212-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30893, 'Curitiba', 'Rodolpho Senff', 'Jardim das Américas', '81530-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30894, 'Curitiba', 'Rodolpho Senff Júnior', 'Capão Raso', '81110-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30895, 'Curitiba', 'Rodolpho Zaninelli', 'Mossunguê', '81210-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30896, 'Ponta Grossa', 'Rodonita', 'Neves', '84021-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30897, 'Umuarama', 'Rodoviária', 'Zona I', '87501-056', 'Estação', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30898, 'Foz do Iguaçu', 'Rodoviária Internacional', 'Jardim Polo Centro', '85863-460', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30899, 'Piraquara', 'Rodozindo Mazon', 'Vila São Cristóvão', '83305-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30900, 'Almirante Tamandaré', 'Rodrigo da Rosa dos Santos', 'Jardim Campo Verde', '83502-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30901, 'Curitiba', 'Rodrigo de Freitas', 'Bacacheri', '82515-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30902, 'Paranaguá', 'Rodrigo Gomes', 'Jardim Araçá', '83221-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30903, 'Curitiba', 'Rodrigo Guilherme Theobaldo Vita', 'Uberaba', '81590-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30904, 'Maringá', 'Rodrigo Jacques', 'Zona 37', '87043-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30905, 'Ponta Grossa', 'Rodrigo Octávio', 'Uvaranas', '84030-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30906, 'Ponta Grossa', 'Rodrigo Octávio', 'Uvaranas', '84025-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30907, 'Curitiba', 'Rodrigo Octávio de Langaard Menezes Filho', 'São Lourenço', '82200-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30908, 'Castro', 'Rodrigo Octávio Torres Pereira', 'Vila Rio Branco', '84172-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30909, 'Araucária', 'Rodrigo Pereira Gomes', 'Thomaz Coelho', '83707-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30910, 'Ponta Grossa', 'Rodrigo Silva', 'Uvaranas', '84030-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30911, 'Maringá', 'Rodrigo Silva', 'Zona 04', '87014-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30912, 'Pinhais', 'Rodrigo Silvério Ieger', 'Moradias Palmital', '83325-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30913, 'Londrina', 'Rodrigues Alves', 'Hedy', '86062-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30914, 'Guarapuava', 'Rodrigues Alves', 'Boqueirão', '85020-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30915, 'Ponta Grossa', 'Rodrigues Alves', 'Orfãs', '84015-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30916, 'Paranaguá', 'Rodrigues Alves', 'Centro Histórico', '83203-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30917, 'Pinhais', 'Rodrigues Alves', 'Vila Amélia', '83331-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30918, 'Toledo', 'Rodrigues Alves', 'Coopagro', '85903-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30919, 'Umuarama', 'Rodrigues Alves', 'Jardim Petrópolis', '87506-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30920, 'Telêmaco Borba', 'Rodrigues Alves', 'Alto das Oliveiras', '84266-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30921, 'Cascavel', 'Rodrigues Alves', 'Parque São Paulo', '85803-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30922, 'Apucarana', 'Rodrigues Alves', 'Vila Marigilda', '86800-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30923, 'Cascavel', 'Rodrigues Alves', 'Maria Luiza', '85819-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30924, 'Curitiba', 'Rodrigues Alves', 'Seminário', '80240-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30925, 'Guarapuava', 'Rodrigues Arzão', 'Primavera', '85050-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30926, 'Paranavaí', 'Rodrigues Ayres', 'Jardim Avaré', '87709-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30927, 'Foz do Iguaçu', 'Rodrigues de Freitas', 'Loteamento Menger', '85862-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30928, 'Paranaguá', 'Roge da Costa', 'Palmital', '83206-130', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30929, 'São José dos Pinhais', 'Roger Bacon', 'Aristocrata', '83030-045', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30930, 'Colombo', 'Roger Bacon', 'Jardim Campo Alto', '83408-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30931, 'Curitiba', 'Rogério Coelho', 'Pinheirinho', '81825-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30932, 'Curitiba', 'Rogério de Aguillar Minetto', 'Jardim das Américas', '81520-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30933, 'Castro', 'Rogério Galeto', 'Água Suja', '84165-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30934, 'Curitiba', 'Rogério Gimenez', 'Sítio Cercado', '81910-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30935, 'Pinhais', 'Rogério Gomes', 'Moradias Santa Clara', '83325-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30936, 'Curitiba', 'Rogério Gomes dos Santos', 'Xaxim', '81810-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30937, 'Almirante Tamandaré', 'Rogério Gulin', 'Vila Palmira', '83514-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30938, 'Londrina', 'Rogério Júnior Moreira', 'Jardim Pioneiros', '86036-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30940, 'Curitiba', 'Rogério Paulo Cruz', 'Cidade Industrial', '81305-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30941, 'Curitiba', 'Rogério Pereira de Camargo', 'Cidade Industrial', '81280-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30942, 'Laranjeiras do Sul', 'Rogério Stefanes Gaspar', 'Centro', '85301-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30943, 'Curitiba', 'Rogério Xavier Rocha Loures', 'Pinheirinho', '81870-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30944, 'Arapongas', 'Rola', 'Jardim Bandeirantes', '86703-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30945, 'Arapongas', 'Rola-azul', 'Conjunto Del Condor', '86703-326', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30946, 'Arapongas', 'Rola-espelho', 'Jardim Monte Carlo', '86704-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30947, 'Foz do Iguaçu', 'Rolândia', 'Jardim Paraná', '85867-170', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30948, 'Guarapuava', 'Rolândia', 'Jardim das Américas', '85030-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30949, 'Londrina', 'Rolândia', 'Aurora', '86060-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30950, 'Maringá', 'Rolândia', 'Zona 08', '87050-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30951, 'Ponta Grossa', 'Rolândia', 'Nova Rússia', '84053-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30952, 'Pinhais', 'Rolândia', 'Jardim Alto Tarumã', '83325-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30953, 'São José dos Pinhais', 'Rolândia', 'Cruzeiro', '83010-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30954, 'Umuarama', 'Rolândia', 'Zona II', '87502-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30955, 'Colombo', 'Rolândia', 'Jardim Cristina III', '83410-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30956, 'Cambé', 'Rolândia', 'Jardim Ana Eliza', '86188-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30957, 'Campo Mourão', 'Rolândia', 'Conjunto Habitacional Parigot de Souza', '87310-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30958, 'Apucarana', 'Rolândia', 'Vila Martins', '86800-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30959, 'Curitiba', 'Rolândia', 'Barreirinha', '82560-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30960, 'Umuarama', 'Rolando Mendes Junqueira', 'Jardim dos Príncipes', '87502-047', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30961, 'Curitiba', 'Rolando Salin Zappa Mansur', 'Cachoeira', '82220-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30962, 'Londrina', 'Roldão José Alves', 'Conjunto Novo Amparo 2', '86056-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30963, 'Curitiba', 'Roldão Rodrigues Queiroz', 'Boqueirão', '81650-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30964, 'Curitiba', 'Rolf Faria Gugisch', 'Pilarzinho', '82120-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30965, 'Curitiba', 'Rolfe Mertens', 'Pilarzinho', '80520-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30966, 'Cascavel', 'Rolim de Moura', 'São Cristóvão', '85816-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30967, 'Francisco Beltrão', 'Rolinha', 'Padre Ulrico', '85604-466', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30968, 'Arapongas', 'Rolinha-branca', 'Parque Veneza', '86701-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30969, 'Londrina', 'Rolinhas', 'Jacomo Violin', '86088-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30970, 'Arapongas', 'Rolinhas', 'Centro', '86701-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30971, 'Francisco Beltrão', 'Roma', 'Jardim Floresta', '85603-388', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30972, 'Foz do Iguaçu', 'Roma', 'Beverly Falls Park', '85858-265', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30973, 'Guarapuava', 'Roma', 'Santana', '85070-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30974, 'Londrina', 'Roma', 'Parque Residencial João Piza', '86041-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30975, 'Ponta Grossa', 'Roma', 'Jardim Carvalho', '84036-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30976, 'Paranaguá', 'Roma', 'Parque Agari', '83215-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30977, 'Ponta Grossa', 'Roma', 'Jardim Carvalho', '84016-658', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30978, 'Telêmaco Borba', 'Roma', 'Nossa Senhora do Perpétuo Socorro', '84265-050', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30979, 'Cambé', 'Roma', 'Residencial Monte Castelo', '86186-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30980, 'Colombo', 'Roma', 'Planta Boros', '83413-280', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30981, 'Cascavel', 'Roma', 'Cascavel Velho', '85818-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30982, 'Curitiba', 'Roma', 'Uberaba', '81560-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30983, 'Paranaguá', 'Romã', 'Vila São Vicente', '83209-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30984, 'Paranaguá', 'Romano Ancelmo Fontana', 'Parque São João', '83212-070', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30985, 'Curitiba', 'Romano Bertagnoli', 'Mercês', '80710-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30986, 'Curitiba', 'Romano Durigan', 'Cascatinha', '82020-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30987, 'Toledo', 'Romano Felkircher', 'Parque Residencial Pancera', '85914-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30988, 'Curitiba', 'Romano Fressato', 'Jardim das Américas', '81520-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30989, 'Colombo', 'Romano Mocelin', 'Jardim Arapongas', '83402-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30990, 'Curitiba', 'Romano Pizzato', 'Barreirinha', '82700-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30991, 'Pato Branco', 'Romano Radaelli', 'Cristo Rei', '85506-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30992, 'Ponta Grossa', 'Romanos', 'Chapada', '84062-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30993, 'Cambé', 'Romanos', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30994, 'Ponta Grossa', 'Romanzeira', 'Contorno', '84061-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30995, 'Londrina', 'Romão Antiveros', 'Conjunto Habitacional Bronzzetti', '86037-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30996, 'Cascavel', 'Romão Chrum', 'São Cristóvão', '85813-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30997, 'Londrina', 'Romão Garcia Ortiz', 'Jardim Piza', '86073-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30998, 'Curitiba', 'Romão Hofmeister', 'Pilarzinho', '82100-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (30999, 'Apucarana', 'Romão Kluthcowski', 'Vila Rural Nova Ukrania', '86810-470', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31000, 'Cascavel', 'Romário Correia de Oliveira', '14 de Novembro', '85804-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31001, 'Curitiba', 'Romário Gonçalves', 'Umbará', '81930-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31002, 'Foz do Iguaçu', 'Romário Martins', 'Jardim Veraneio', '85855-640', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31003, 'Ponta Grossa', 'Romário Martins', 'Neves', '84020-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31004, 'Maringá', 'Romário Martins', 'Vila Cleópatra', '87010-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31005, 'São José dos Pinhais', 'Romário Martins', 'Miringuava', '83090-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31006, 'Cascavel', 'Romário Martins', 'Pioneiros Catarinenses', '85805-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31007, 'Curitiba', 'Romário Martins', 'Jardim Social', '82520-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31008, 'Colombo', 'Romário Tanner', 'Parque Industrial Guaraituba', '83411-117', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31009, 'Foz do Iguaçu', 'Romário Vidal', 'Vila Yolanda', '85853-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31010, 'Curitiba', 'Romédio Dorigo', 'Água Verde', '80620-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31011, 'Guarapuava', 'Romênia', 'São Cristóvão', '85063-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31012, 'Londrina', 'Romênia', 'Igapó', '86046-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31013, 'Curitiba', 'Romeu Bach', 'Boqueirão', '81650-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31014, 'Ponta Grossa', 'Romeu Balster', 'Ronda', '84050-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31015, 'Curitiba', 'Romeu Branco Quadros', 'Guabirotuba', '81510-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31016, 'Cascavel', 'Romeu Caponi', 'Periolo', '85817-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31017, 'Maringá', 'Romeu d''Alencar Domenici', 'Parque Residencial Quebec', '87023-505', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31018, 'Curitiba', 'Romeu de Albuquerque Silva', 'Mossunguê', '81200-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31019, 'Londrina', 'Romeu Dematte', 'Lago Parque', '86015-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31020, 'Curitiba', 'Romeu Felipe Bacellar', 'Cidade Industrial', '81460-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31021, 'Guarapuava', 'Romeu Karpinski Rocha', 'Bonsucesso', '85035-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31022, 'Guarapuava', 'Romeu L. C. Bastos', 'Boqueirão', '85020-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31023, 'Curitiba', 'Romeu Pereira de Godoy', 'Umbará', '81930-627', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31024, 'Pinhais', 'Romeu Pires', 'Prive Bois de Boulogne', '83330-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31025, 'Curitiba', 'Romeu Quevedo da Costa Filho', 'Cidade Industrial', '81350-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31027, 'Campo Mourão', 'Romilda Bambini Piacentini', 'Jardim Bandeirantes', '87308-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31028, 'Londrina', 'Romilda Delboni Roveri', 'Portal Norte', '86079-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31029, 'Ponta Grossa', 'Romildo de Jesus Choqueta', 'Boa Vista', '84070-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31030, 'Guarapuava', 'Romualdo Baraúna', 'Alto Cascavel', '85031-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31031, 'Sarandi', 'Romualdo Eschholz', 'Parque Alvamar', '87113-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31032, 'Toledo', 'Romualdo Paiter', 'Jardim Europa', '85907-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31033, 'Campo Largo', 'Romualdo Portugal', 'Vila Operária', '83601-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31034, 'Curitiba', 'Rômulo Antônio Pellanda', 'Prado Velho', '80215-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31035, 'Curitiba', 'Rômulo César Alves', 'Santa Felicidade', '82410-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31036, 'Piraquara', 'Rômulo Polatti', 'Vila Rosa', '83304-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31037, 'Ponta Grossa', 'Ronald de Carvalho', 'Cará-cará', '84043-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31038, 'Paranavaí', 'Ronaldo D. da Silva Azeredo', 'Parque Morumbi', '87703-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31039, 'Curitiba', 'Ronaldo José Carboni', 'Capão da Imbuia', '82810-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31040, 'Ponta Grossa', 'Ronaldo Mayer', 'Boa Vista', '84072-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31041, 'Maringá', 'Ronaldo Petrucci', 'Vila Nevada', '87020-519', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31042, 'Ponta Grossa', 'Ronaldo Piekarski', 'Uvaranas', '84030-738', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31043, 'Londrina', 'Ronan Ferreira dos Reis', 'Parque Residencial Elizabeth', '86077-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31044, 'Guarapuava', 'Roncador', 'Boqueirão', '85023-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31045, 'Londrina', 'Roncador', 'Lindóia', '86031-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31046, 'Colombo', 'Roncador', 'Jardim Amazonas', '83410-840', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31047, 'Curitiba', 'Roncador', 'Cidade Industrial', '81250-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31048, 'Ponta Grossa', 'Ronda', 'Contorno', '84052-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31049, 'Pinhais', 'Rondon', 'Jardim Dona Joaquina I', '83325-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31050, 'Colombo', 'Rondon', 'Jardim Cristina III', '83410-526', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31051, 'Guarapuava', 'Rondônia', 'Boqueirão', '85022-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31052, 'Foz do Iguaçu', 'Rondônia', 'Centro', '85851-390', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31053, 'Francisco Beltrão', 'Rondônia', 'Nossa Senhora Aparecida', '85601-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31054, 'Maringá', 'Rondônia', 'Parque das Grevíleas', '87025-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31055, 'Piraquara', 'Rondônia', 'Jardim dos Estados 2', '83308-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31056, 'Paranaguá', 'Rondônia', 'Vila do Povo', '83209-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31057, 'São José dos Pinhais', 'Rondônia', 'Boneca do Iguaçu', '83040-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31058, 'Telêmaco Borba', 'Rondônia', 'Vila São Francisco de Assis', '84264-648', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31059, 'Umuarama', 'Rondônia', 'Zona VII', '87503-470', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31060, 'Campo Largo', 'Rondônia', 'Vila Itaqui', '83604-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31061, 'Araucária', 'Rondônia', 'Iguaçu', '83701-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31062, 'Colombo', 'Rondônia', 'Jardim Jalisco', '83404-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31063, 'Maringá', 'Rondonópolis', 'Vila Morangueira', '87040-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31064, 'Curitiba', 'Ronel Regnier Barrozo', 'Abranches', '82130-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31065, 'Curitiba', 'Roni Eldo de Albuquerque', 'Bairro Alto', '82820-340', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31066, 'Cascavel', 'Roni Sperotto', 'Alto Alegre', '85805-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31067, 'Foz do Iguaçu', 'Ronie Peterson', 'Vila Borges', '85858-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31068, 'Ponta Grossa', 'Roosevelt', 'Centro', '84010-690', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31069, 'Paranavaí', 'Roosevelt', 'Jardim São Jorge', '87710-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31070, 'Colombo', 'Roque Culik', 'Planta Bom Jesus', '83407-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31071, 'Curitiba', 'Roque de Oliveira Bueno', 'Cidade Industrial', '81460-337', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31072, 'Araucária', 'Roque Langer', 'Cachoeira', '83701-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31073, 'Curitiba', 'Roque Lazarotto', 'Boa Vista', '82560-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31074, 'Curitiba', 'Roque Moreira Consenza', 'Cajuru', '82920-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31075, 'Curitiba', 'Roque Navarrete Sanchez', 'Fazendinha', '81320-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31076, 'São José dos Pinhais', 'Roque Negoseke', 'Cruzeiro', '83010-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31077, 'Araucária', 'Roque Saad', 'Boqueirão', '83704-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31078, 'Londrina', 'Roque Sambatti', 'Portal de Versalhes 3', '86055-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31079, 'Colombo', 'Roque Scrok', 'Jardim Guarujá', '83407-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31080, 'Piraquara', 'Roque Vernalha', 'Centro', '83301-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31081, 'Francisco Beltrão', 'Roraima', 'Nossa Senhora Aparecida', '85601-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31082, 'Guarapuava', 'Roraima', 'Boqueirão', '85020-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31083, 'Paranaguá', 'Roraima', 'Vila do Povo', '83209-648', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31084, 'Telêmaco Borba', 'Roraima', 'Vila São Francisco de Assis', '84264-649', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31085, 'Araucária', 'Roraima', 'Iguaçu', '83701-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31086, 'Colombo', 'Roraima', 'Jardim Jalisco', '83404-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31087, 'Campo Largo', 'Roraima', 'Jardim Esmeralda', '83604-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31088, 'Curitiba', 'Roraima', 'Cajuru', '82940-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31089, 'Curitiba', 'Roraima', 'Cajuru', '82930-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31090, 'Ponta Grossa', 'Rosa', 'Contorno', '84060-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31091, 'Apucarana', 'Rosa', 'Jardim das Flores I', '86810-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31092, 'Piraquara', 'Rosa Alves Pereira', 'Vila Fuck', '83305-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31093, 'Maringá', 'Rosa Angeloni Zequim', 'Jardim Santa Rosa', '87060-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31094, 'Maringá', 'Rosa Antônia Rech Rubini', 'Conjunto Habitacional Requião', '87047-478', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31095, 'Londrina', 'Rosa Badin Vieira', 'Terras de Santana II', '86055-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31096, 'Piraquara', 'Rosa Baltassini Carradi', 'Planta Araçatuba', '83301-426', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31097, 'Londrina', 'Rosa Bergamin', 'Jardim Maria Celina', '86081-555', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31098, 'Londrina', 'Rosa Branca', 'Ricardo', '86035-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31099, 'Londrina', 'Rosa Capelari', 'Jardim Ouro Preto', '86035-187', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31100, 'Curitiba', 'Rosa Carvalho Chaves', 'Fanny', '81030-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31101, 'Curitiba', 'Rosa Cavichiolo Nichele', 'Umbará', '81930-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31102, 'Curitiba', 'Rosa Ceronato Durigan', 'Cascatinha', '82020-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31103, 'Araucária', 'Rosa Cichon', 'Tindiquera', '83708-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31104, 'Foz do Iguaçu', 'Rosa Cirilo de Castro', 'Jardim Polo Centro', '85863-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31105, 'Maringá', 'Rosa Cruz', 'Jardim Higienópolis', '87060-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31106, 'Cambé', 'Rosa Cursi Piffer', 'Conjunto Residencial Roberto Conceição', '86183-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31107, 'Curitiba', 'Rosa Dalarmi', 'Campo Comprido', '81270-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31108, 'Curitiba', 'Rosa de Barros', 'Campo Comprido', '81220-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31109, 'Curitiba', 'Rosa de Quadros', 'Cajuru', '82930-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31110, 'Ponta Grossa', 'Rosa Domingos Franco', 'Jardim Carvalho', '84016-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31111, 'Maringá', 'Rosa Donata Diniz', 'Jardim São Silvestre', '87055-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31112, 'Curitiba', 'Rosa Ferro Cumin', 'Santa Felicidade', '82320-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31113, 'Ponta Grossa', 'Rosa Furiatti', 'Colônia Dona Luiza', '84046-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31114, 'Curitiba', 'Rosa Hauer', 'Boqueirão', '81750-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31115, 'São José dos Pinhais', 'Rosa Húngaro Mariotto', 'Planta Quississana', '83085-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31116, 'Curitiba', 'Rosa Kaint Nadolny', 'Campo Comprido', '81200-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31117, 'Apucarana', 'Rosa Klayber Balthazar', 'Loteamento Residencial Parque da Raposa II', '86812-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31118, 'São José dos Pinhais', 'Rosa Lass Rattmann', 'Colônia Murici', '83085-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31119, 'Colombo', 'Rosa Lazarotto Strapasson', 'Jardim Santa Helena', '83407-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31120, 'Curitiba', 'Rosa Leite Anderle', 'Sítio Cercado', '81925-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31121, 'Curitiba', 'Rosa Leonardi', 'Campo Comprido', '81240-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31122, 'Almirante Tamandaré', 'Rosa Liski Bugalski', 'Jardim Ipanema', '83507-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31123, 'Londrina', 'Rosa Lombardi Ferraro', 'Jardim Nova Esperança', '86044-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31124, 'Guarapuava', 'Rosa Lustosa de Siqueira', 'Santana', '85070-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31125, 'Pinhais', 'Rosa Macarini', 'Jardim Pedro Demeterco', '83324-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31126, 'Curitiba', 'Rosa Machado', 'São Lourenço', '82210-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31127, 'Colombo', 'Rosa Machio Batistão', 'Jardim Bandeirantes', '83408-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31128, 'Curitiba', 'Rosa Marangoni Stocco', 'Cidade Industrial', '81450-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31129, 'São José dos Pinhais', 'Rosa Maranho Bobato', 'Planta Quississana', '83085-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31130, 'Paranavaí', 'Rosa Maria dos Santos', 'Parque Morumbi', '87703-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31131, 'Londrina', 'Rosa Maria S. Pereira', 'Conjunto Professora Hilda Mandarino', '86080-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31132, 'Curitiba', 'Rosa Mehl', 'Uberaba', '81560-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31133, 'Londrina', 'Rosa Moralles Rodrigues', 'Jardim Vale Verde', '86040-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31134, 'São José dos Pinhais', 'Rosa Moro Machado', 'Rio Pequeno', '83070-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31135, 'Curitiba', 'Rosa Neumann', 'Campina do Siqueira', '80740-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31136, 'Cascavel', 'Rosa Norma Vessaro', 'São Cristóvão', '85813-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31137, 'Curitiba', 'Rosa Oliva Cruzeta', 'São Braz', '82300-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31138, 'Colombo', 'Rosa Palace', 'Sapopema', '83407-086', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31139, 'São José dos Pinhais', 'Rosa Pereira da Cunha', 'Guatupê', '83060-047', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31140, 'Piraquara', 'Rosa Probst Brasil', 'Vila Susi', '83304-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31141, 'Apucarana', 'Rosa Ribeiro Zacarias', 'Jardim Catuaí', '86802-618', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31142, 'Curitiba', 'Rosa Rigoni Landal', 'Cidade Industrial', '81260-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31143, 'Curitiba', 'Rosa Sahagoff', 'Uberaba', '81580-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31144, 'Curitiba', 'Rosa Sanson da Silva', 'Barreirinha', '82540-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31145, 'Colombo', 'Rosa Schneider', 'Parque Residencial Santa Terezinha II', '83408-807', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31146, 'Curitiba', 'Rosa Simão', 'Cidade Industrial', '81315-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31147, 'Londrina', 'Rosa Siqueira', 'Jardim Alah I', '86039-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31148, 'Apucarana', 'Rosa Stabile', 'Vila Operária Stabile', '86811-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31149, 'Apucarana', 'Rosa Torres', 'Jardim Menegazzo', '86802-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31150, 'Curitiba', 'Rosa Tortato', 'Pinheirinho', '81870-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31151, 'Curitiba', 'Rosa Trevisan', 'Santa Felicidade', '82320-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31152, 'Curitiba', 'Rosa Wonze Gusso', 'Barreirinha', '82700-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31153, 'Foz do Iguaçu', 'Rosália Bertolini Welter', 'Loteamento Parque do Patriarco', '85854-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31154, 'Araucária', 'Rosália Kaminski', 'Porto das Laranjeiras', '83703-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31155, 'Colombo', 'Rosália Kubis Weigert', 'Jardim Contorno', '83402-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31156, 'São José dos Pinhais', 'Rosália Stanczyk', 'Afonso Pena', '83040-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31157, 'Curitiba', 'Rosália Uniga', 'Santa Cândida', '82650-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31158, 'Curitiba', 'Rosalina Calixto', 'Sítio Cercado', '81900-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31159, 'Curitiba', 'Rosalina Casari', 'Boqueirão', '81730-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31160, 'Guarapuava', 'Rosalina da Rocha', 'Bonsucesso', '85045-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31161, 'Piraquara', 'Rosalina de Oliveira Abreu', 'Guarituba', '83311-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31162, 'Toledo', 'Rosalino Barbieri', 'Residencial Santa Clara', '85903-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31163, 'Curitiba', 'Rosalino Mazziotti', 'Novo Mundo', '81020-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31164, 'Cambé', 'Rosalvo Alves Paciência', 'Jardim Tarobá', '86191-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31165, 'Piraquara', 'Rosalvo Silva', 'Jardim Alterosa', '83314-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31166, 'Curitiba', 'Rosamélia de Oliveira', 'Campo Comprido', '81230-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31167, 'Maringá', 'Rosana', 'Parque das Grevíleas', '87025-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31168, 'Guarapuava', 'Rosana Campos', 'Conradinho', '85055-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31169, 'Castro', 'Rosana Cardoso Amato', 'Jardim das Araucárias', '84174-629', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31170, 'Londrina', 'Rosane Wainberg', 'Jardim Nova Esperança', '86044-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31171, 'Londrina', 'Rosângela Cunha Redondo', 'Arthur Thomas', '86031-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31172, 'Foz do Iguaçu', 'Rosângela da Silva', 'Jardim Irmã', '85867-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31173, 'Londrina', 'Rosângela Ferreira da Silva', 'Parigot de Souza 2', '86082-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31174, 'Londrina', 'Rosanis Muniz Silva', 'Conjunto Residencial Vale do Arvoredo', '86047-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31175, 'Paranaguá', 'Rosário', 'Parque Agari', '83215-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31176, 'Foz do Iguaçu', 'Rosário da Silva', 'Jardim Alvorada', '85859-707', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31177, 'Apucarana', 'Rosário do Ivai', 'Núcleo Habitacional Nossa Senhora Aparecida', '86801-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31178, 'Telêmaco Borba', 'Rosas de Ouro', 'Vila Cristina', '84272-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31179, 'São José dos Pinhais', 'Rose Cléia Moreira Dombrowski', 'Ipê', '83055-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31180, 'Londrina', 'Roseiral', 'Ricardo', '86035-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31181, 'Colombo', 'Roseli Pansolin Alberti', 'Jardim Cristina II', '83410-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31182, 'Ponta Grossa', 'Roseli Souza Pinto', 'Olarias', '84026-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31183, 'Londrina', 'Rosemary Alves', 'Conjunto Residencial Marajoara', '86080-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31184, 'Curitiba', 'Rosiane Jacomel', 'Cidade Industrial', '81460-327', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31185, 'Paranavaí', 'Rosil Cangre', 'Jardim São Jorge', '87711-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31186, 'São José dos Pinhais', 'Rosildo Rocco', 'Planta Quississana', '83085-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31187, 'Curitiba', 'Rosina Sanson Pereira Pinto', 'Uberaba', '81580-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31188, 'Curitiba', 'Rosinei de Oliveira', 'Sítio Cercado', '81930-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31189, 'Foz do Iguaçu', 'Rosita Ortiz', 'Novo Mundo', '85862-428', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31190, 'Ponta Grossa', 'Rosmar Dinies Escobar', 'Contorno', '84060-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31191, 'Guarapuava', 'Rosmari Siqueira Camargo', 'São Cristóvão', '85063-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31192, 'Curitiba', 'Rossana Mansur de Macedo', 'Capão da Imbuia', '82810-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31193, 'Guarapuava', 'Rotary', 'Santana', '85070-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31194, 'Londrina', 'Rotary', 'Leonardo da Vinci', '86060-005', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31195, 'Paranaguá', 'Rotary', 'João Gualberto', '83203-570', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31196, 'Umuarama', 'Rotary', 'Jardim dos Príncipes', '87502-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31197, 'Sarandi', 'Rotary', 'Jardim Independência I', '87114-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31198, 'Umuarama', 'Rotary', 'Parque Presidente', '87505-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31199, 'Ponta Grossa', 'Rotary Club de Ponta Grossa', 'Chapada', '84062-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31200, 'Maringá', 'Rotary Internacional', 'Zona 05', '87015-300', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31201, 'Piraquara', 'Rotterdam', 'Holandez', '83312-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31202, 'Curitiba', 'Rotterdam', 'Fazendinha', '81330-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31203, 'Guarapuava', 'Rouxinol', 'Boqueirão', '85022-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31204, 'Maringá', 'Rouxinol', 'Conjunto Habitacional João de Barro Thaís', '87075-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31205, 'Pinhais', 'Rouxinol', 'Jardim Cláudia', '83326-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31206, 'Sarandi', 'Rouxinol', 'Conjunto Floresta', '87112-710', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31207, 'Umuarama', 'Rouxinol', 'Jardim Alphavile', '87504-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31208, 'Araucária', 'Rouxinol', 'Estação', '83705-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31209, 'Almirante Tamandaré', 'Rouxinol', 'Loteamento Montparnasse', '83508-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31210, 'Campo Mourão', 'Rouxinol', 'Jardim Tropical I', '87310-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31211, 'Arapongas', 'Rouxinol', 'Centro', '86701-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31212, 'Arapongas', 'Rouxinol', 'Vila Aparecida', '86706-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31213, 'Curitiba', 'Rovigo', 'Cascatinha', '82020-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31214, 'São José dos Pinhais', 'Roza Kieça Sokaski', 'Afonso Pena', '83045-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31215, 'Foz do Iguaçu', 'Rozalia Caballero', 'Vila São Sebastião', '85870-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31216, 'Curitiba', 'Rozalina Colodel Durigan', 'Santa Felicidade', '82030-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31217, 'Londrina', 'Rozalina Meneghetti Lerco', 'Loteamento Terra Bonita', '86047-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31218, 'Foz do Iguaçu', 'Rozario Lázaro', 'Jardim Florença', '85867-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31219, 'Castro', 'Rozendo Manoel Galetto', 'Jardim das Araucárias', '84174-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31220, 'Ponta Grossa', 'Rubelita', 'Neves', '84021-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31221, 'Maringá', 'Rubelita', 'Jardim Santa Helena', '87083-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31222, 'Toledo', 'Rubelite Salinas', 'Boa Esperança', '85909-198', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31223, 'Curitiba', 'Rubem Berta', 'Pinheirinho', '81150-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31224, 'Curitiba', 'Ruben Dario', 'Mossunguê', '81200-115', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31225, 'Curitiba', 'Rúbens Alceu Túlio', 'Boa Vista', '82540-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31226, 'Londrina', 'Rubens Ávila', 'Alto da Colina', '86055-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31227, 'Campo Largo', 'Rubens Braga', 'São Marcos', '83602-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31228, 'Curitiba', 'Rúbens Cardoso de Brito', 'Guabirotuba', '81510-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31229, 'Curitiba', 'Rúbens Carlos Assumpção', 'Jardim Social', '82530-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31230, 'Londrina', 'Rúbens Carlos de Jesus', 'Terra de Santana (I E II)', '86055-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31231, 'Francisco Beltrão', 'Rubens da Silva Martins', 'São Miguel', '85602-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31232, 'Paranaguá', 'Rúbens de Santana Tavares', 'Conjunto Residencial Prefeito Cominese', '83215-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31233, 'Curitiba', 'Rúbens Dória de Oliveira', 'Sítio Cercado', '81920-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31234, 'Curitiba', 'Rúbens Evangelista de Macedo', 'Bacacheri', '82520-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31235, 'Curitiba', 'Rúbens F. Kurowski', 'Barreirinha', '82710-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31236, 'Curitiba', 'Rubens Fabri', 'Cidade Industrial', '81460-346', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31237, 'Guarapuava', 'Rúbens Fleuri da Rocha', 'Bonsucesso', '85055-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31238, 'Francisco Beltrão', 'Rúbens Fonseca', 'São Miguel', '85602-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31239, 'Ponta Grossa', 'Rúbens Guilherme Quintopp', 'Boa Vista', '84072-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31240, 'São José dos Pinhais', 'Rúbens Huergo', 'Cruzeiro', '83010-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31241, 'Cascavel', 'Rúbens Lopes', 'Universitário', '85819-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31242, 'Curitiba', 'Rúbens Maister', 'Barreirinha', '82700-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31243, 'Curitiba', 'Rúbens Padilha Mendes', 'Cajuru', '82900-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31244, 'Londrina', 'Rúbens Pereira Lima', 'Conjunto Semiramis Barros Braga', '86088-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31245, 'Umuarama', 'Rubens Rodrigues Corrêa', 'Zona I-A', '87501-355', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31246, 'Curitiba', 'Rúbens Santos Costa', 'Cristo Rei', '80050-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31247, 'Maringá', 'Rubens Sebastião Marin', 'Parque Industrial', '87045-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31248, 'Campo Mourão', 'Rúbens Vaz', 'Jardim Fernando', '87305-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31249, 'Londrina', 'Rubi', 'Waldemar Hauer', '86030-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31250, 'Maringá', 'Rubi', 'Jardim Real', '87083-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31251, 'Ponta Grossa', 'Rubi', 'Neves', '84021-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31252, 'Telêmaco Borba', 'Rubi', 'Área 04', '84266-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31253, 'Umuarama', 'Rubi', 'Conjunto Residencial Ouro Branco', '87508-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31254, 'Cascavel', 'Rubi', 'Esmeralda', '85806-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31255, 'Cambé', 'Rubi', 'Conjunto Habitacional Cristal', '86182-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31256, 'Campo Mourão', 'Rubi', 'Jardim Tropical I', '87310-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31257, 'Apucarana', 'Rubi', 'Vila Agari', '86808-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31258, 'Curitiba', 'Rubyn Hein', 'Uberaba', '81560-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31259, 'Curitiba', 'Rudi Labsch', 'Cidade Industrial', '81350-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31260, 'Foz do Iguaçu', 'Rudi Lakus', 'Jardim Norma', '85869-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31261, 'Londrina', 'Rudolf Keilhold', 'Conjunto Semiramis Barros Braga', '86088-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31262, 'Toledo', 'Rudolf Russ', 'Residencial Santa Clara', '85903-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31263, 'Londrina', 'Rudolfo Guilherme Weber', 'Parque Residencial Elizabeth', '86077-355', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31264, 'Toledo', 'Rudolfo Thielke', 'Sachini', '85903-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31265, 'Londrina', 'Rudolph Diesel', 'Industrial', '86063-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31266, 'Curitiba', 'Rudyard Kipling', 'Xaxim', '81810-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31267, 'Maringá', 'Ruela 96/2', 'Parque Residencial Quebec', '87023-497', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31268, 'Maringá', 'Ruela 96/3', 'Parque Residencial Quebec', '87023-295', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31269, 'Maringá', 'Ruela 96/4', 'Parque Residencial Quebec', '87023-296', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31270, 'Maringá', 'Ruela 97/1', 'Parque Residencial Quebec', '87023-489', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31271, 'Maringá', 'Ruela 97/2', 'Parque Residencial Quebec', '87023-498', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31272, 'Maringá', 'Ruela 97/3', 'Parque Residencial Quebec', '87023-499', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31273, 'Curitiba', 'Rufino Gonçalves', 'Tatuquara', '81480-287', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31274, 'Guarapuava', 'Rufino Pacheco', 'Bonsucesso', '85055-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31275, 'Foz do Iguaçu', 'Rufino Vilhordo', 'Parque Presidente II', '85863-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31276, 'Curitiba', 'Rui Antônio Gabardo', 'Tatuquara', '81880-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31277, 'Guarapuava', 'Rui Barbosa', 'Boqueirão', '85020-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31278, 'Laranjeiras do Sul', 'Rui Barbosa', 'Getúlio Vargas', '85304-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31279, 'Laranjeiras do Sul', 'Rui Barbosa', 'Centro', '85301-420', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31280, 'Londrina', 'Rui Barbosa', 'Jardim Tatiani', '86070-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31281, 'Foz do Iguaçu', 'Rui Barbosa', 'Centro', '85851-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31282, 'Foz do Iguaçu', 'Rui Barbosa', 'Centro', '85852-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31283, 'Maringá', 'Rui Barbosa', 'Zona 06', '87080-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31284, 'Paranaguá', 'Rui Barbosa', 'Jardim Paranaguá', '83218-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31285, 'Pato Branco', 'Rui Barbosa', 'Bortot', '85504-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31286, 'Maringá', 'Rui Barbosa', 'Zona 06', '87020-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31287, 'Ponta Grossa', 'Rui Barbosa', 'Centro', '84010-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31288, 'Pinhais', 'Rui Barbosa', 'Núcleo Colonial de Pinhais', '83321-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31289, 'São José dos Pinhais', 'Rui Barbosa', 'Afonso Pena', '83065-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31290, 'Toledo', 'Rui Barbosa', 'Centro', '85901-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31291, 'São José dos Pinhais', 'Rui Barbosa', 'Aristocrata', '83025-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31292, 'São José dos Pinhais', 'Rui Barbosa', 'Centro', '83005-340', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31293, 'Toledo', 'Rui Barbosa', 'Centro', '85900-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31294, 'São José dos Pinhais', 'Rui Barbosa', 'Afonso Pena', '83045-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31295, 'São José dos Pinhais', 'Rui Barbosa', 'Ipê', '83055-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31296, 'Umuarama', 'Rui Barbosa', 'Zona VI', '87503-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31297, 'Toledo', 'Rui Barbosa', 'Centro', '85905-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31298, 'Telêmaco Borba', 'Rui Barbosa', 'Socomim', '84265-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31299, 'Sarandi', 'Rui Barbosa', 'Jardim Independência I', '87114-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31300, 'São José dos Pinhais', 'Rui Barbosa', 'Boneca do Iguaçu', '83040-550', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31301, 'Almirante Tamandaré', 'Rui Barbosa', 'Jardim Iracema', '83508-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31302, 'Cambé', 'Rui Barbosa', 'Centro', '86181-140', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31303, 'Cascavel', 'Rui Barbosa', 'Centro', '85810-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31304, 'Colombo', 'Rui Barbosa', 'Planta Teixeira de Lara', '83409-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31305, 'Castro', 'Rui Barbosa', 'Vila Rio Branco', '84172-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31306, 'Campo Largo', 'Rui Barbosa', 'Centro', '83601-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31307, 'Cascavel', 'Rui Barbosa', 'Claudete', '85811-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31308, 'Curitiba', 'Rui Barbosa', 'Centro', '80010-030', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31309, 'Curitiba', 'Rui Castro dos Santos', 'Juvevê', '80040-285', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31310, 'Curitiba', 'Rui Ferraz de Carvalho', 'Prado Velho', '80215-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31311, 'Foz do Iguaçu', 'Rui Ferreira', 'Centro', '85851-400', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31312, 'Foz do Iguaçu', 'Rui Jacob Guilich', 'Conjunto Residencial Apora', '85869-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31313, 'Curitiba', 'Rui Leão', 'Alto da Glória', '80030-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31314, 'Toledo', 'Rui Oliveira', 'Jardim Porto Alegre', '85906-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31315, 'Colombo', 'Rui Puppi', 'Sapopema', '83407-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31316, 'Francisco Beltrão', 'Rui Ramos', 'Luther King', '85605-160', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31317, 'Curitiba', 'Rui Riva de Almeida', 'Cidade Industrial', '81460-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31318, 'Londrina', 'Rui Roberto Soares', 'Avelino A Vieira', '86056-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31319, 'Londrina', 'Rússia', 'Igapó', '86046-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31320, 'Guarapuava', 'Rússia', 'São Cristóvão', '85063-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31321, 'Cambé', 'Rússia', 'Jardim Morada do Sol', '86181-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31322, 'Apucarana', 'Rússia', 'Vila Maria Eliza', '86808-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31323, 'Almirante Tamandaré', 'Rússia', 'Vila Graziela', '83505-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31324, 'Pinhais', 'Ruth Ferreira Amend', 'Planta Vila Bordignon', '83325-577', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31325, 'Londrina', 'Ruth Ferreira de Souza', 'Residencial Abussafe', '86037-746', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31326, 'Curitiba', 'Rutílio de Sá Ribas', 'Jardim Botânico', '80210-140', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31327, 'Guarapuava', 'Rutílio Loures Ribas', 'Primavera', '85050-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31328, 'Londrina', 'Rutilo', 'Waldemar Hauer', '86030-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31329, 'Ponta Grossa', 'Rutilo', 'Neves', '84021-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31330, 'Curitiba', 'Ruy Arzua Pereira', 'Abranches', '82130-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31331, 'Ponta Grossa', 'Ruy Bahls', 'Neves', '84020-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31332, 'Curitiba', 'Ruy de Santis', 'Santa Felicidade', '82020-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31333, 'Londrina', 'Ruy Ferraz de Carvalho', 'Terra de Santana (I E II)', '86055-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31334, 'Curitiba', 'Ruy Fonseca Itiberê da Cunha', 'Cidade Industrial', '81170-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31335, 'Curitiba', 'Ruy Holzmann', 'Santa Cândida', '82720-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31336, 'Londrina', 'Ruy Neves Ribas', 'Parque Residencial Alcântara', '86047-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31337, 'Curitiba', 'Ruy Neves Ribas', 'Bigorrilho', '80730-190', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31338, 'Curitiba', 'Ruy Renê Langer', 'Jardim Social', '82520-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31339, 'Ponta Grossa', 'Ruy Ribeiro Couto', 'Cará-cará', '84043-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31340, 'Londrina', 'Ruy Vianna', 'Jamile Dequech', '86048-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31341, 'Curitiba', 'Ruy Virmond Carnasciali', 'Seminário', '80310-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31342, 'Londrina', 'Ruy Virmond Carnascialli', 'Leonor', '86071-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31343, 'Curitiba', 'Ryu Mizuno', 'Jardim das Américas', '81530-630', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31344, 'Foz do Iguaçu', 'S', 'Conjunto C', '85870-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31345, 'Campo Largo', 'S', 'Vila Torres II', '83609-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31346, 'Curitiba', 'S148', 'Novo Mundo', '81020-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31347, 'Guarapuava', 'Sá de Miranda', 'Vila Bela', '85027-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31348, 'Pinhais', 'Saara', 'Vl Dona Guiomar', '83320-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31349, 'Colombo', 'Saara', 'Planta Santa Úrsula', '83405-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31350, 'Foz do Iguaçu', 'Sabará', 'Novo Mundo', '85862-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31351, 'Telêmaco Borba', 'Sabará', 'Núcleo Bandeirantes', '84269-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31352, 'Ponta Grossa', 'Sabáudia', 'Boa Vista', '84071-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31353, 'Maringá', 'Sabáudia', 'Zona 08', '87050-650', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31354, 'Apucarana', 'Sabáudia', 'Vila Martins', '86800-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31355, 'Curitiba', 'Sabáudia', 'Sítio Cercado', '81900-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31356, 'Foz do Iguaçu', 'Sabiá', 'Portal da Foz', '85859-540', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31357, 'Francisco Beltrão', 'Sabiá', 'Padre Eurico', '85604-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31358, 'Maringá', 'Sabiá', 'Jardim Olímpico', '87070-545', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31359, 'Maringá', 'Sabiá', 'Conjunto Residencial Ney Braga', '87075-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31360, 'Ponta Grossa', 'Sabiá', 'Chapada', '84064-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31361, 'Sarandi', 'Sabiá', 'Conjunto Floresta', '87112-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31362, 'Umuarama', 'Sabiá', 'Jardim Alphavile', '87504-658', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31363, 'Telêmaco Borba', 'Sabiá', 'Jardim São Silvestre', '84270-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31364, 'Cascavel', 'Sabiá', 'Floresta', '85814-730', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31365, 'Cambé', 'Sabiá', 'Conjunto Habitacional Waldomiro M Gomes', '86182-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31366, 'Arapongas', 'Sabiá', 'Centro', '86701-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31367, 'Araucária', 'Sabiá', 'Estação', '83705-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31368, 'Apucarana', 'Sabiá', 'Recanto das Araras', '86812-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31369, 'Campo Mourão', 'Sabiá', 'Jardim Tropical I', '87310-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31370, 'Arapongas', 'Sabiá-branco', 'Jardim Petrópolis', '86709-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31371, 'Arapongas', 'Sabiá-castanho', 'Conjunto Padre Bernardo Merckel', '86706-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31372, 'Arapongas', 'Sabiacica', 'Jardim Monte Carlo', '86704-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31373, 'Arapongas', 'Sabiá-coleira', 'Conjunto Centauro', '86709-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31374, 'Arapongas', 'Sabiá-de-praia', 'Parque Veneza', '86701-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31375, 'Arapongas', 'Sabiá-do-banhado', 'Conjunto Del Condor', '86703-336', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31376, 'Arapongas', 'Sabiá-do-brejo', 'Conjunto Padre Chico', '86707-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31377, 'Arapongas', 'Sabiá-laranjeira', 'Jardim Petrópolis', '86709-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31378, 'Foz do Iguaçu', 'Sabiapoca', 'Conjunto A', '85866-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31379, 'Arapongas', 'Sabiapoca', 'Jardim Caravelle', '86702-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31380, 'Arapongas', 'Sabiatinga', 'Conjunto Flamingos', '86703-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31381, 'Arapongas', 'Sabiaúna', 'Vila Industrial', '86706-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31382, 'Arapongas', 'Sabiá-vermelho', 'Jardim São Bento', '86706-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31383, 'Curitiba', 'Sabina Lupinski', 'Boa Vista', '82650-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31384, 'Curitiba', 'Sabino da Costa Cristo', 'Alto Boqueirão', '81830-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31385, 'Apucarana', 'Saburo Ito', 'Vila Operária 1', '86801-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31386, 'Londrina', 'Saburo Nakatsukasa', 'Alto da Boa Vista', '86083-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31387, 'Curitiba', 'Saburo Okubo', 'Pilarzinho', '82120-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31388, 'Londrina', 'Sacadura Cabral', 'Parque Industrial José Belinati', '86039-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31389, 'Arapongas', 'Saci', 'Jardim Aeroporto', '86702-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31390, 'Foz do Iguaçu', 'Sacramento', 'Jardim Nacional', '85862-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31391, 'Curitiba', 'Sadala Aziz Domingos', 'Cidade Industrial', '81170-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31392, 'Apucarana', 'Sadamoto Kurahashi', 'Loteamento Santa Cândida', '86802-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31393, 'Cambé', 'Sadamu Anami', 'Novo Bandeirantes', '86188-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31394, 'Londrina', 'Sadamu Tomiyama', 'Tomy', '86036-210', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31395, 'Londrina', 'Sadão Koga', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31396, 'Londrina', 'Sadão Nozaki', 'Tucano', '86047-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31397, 'Cascavel', 'Sadi Antônio Zortéa', 'Coqueiral', '85807-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31398, 'Foz do Iguaçu', 'Sadi Vidal', 'Vila São Sebastião', '85870-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31399, 'Paranaguá', 'Sady Freceiro Miranda', 'Vila Paranaguá', '83221-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31400, 'Umuarama', 'Sady Gomes dos Santos', 'Jardim Petrópolis', '87506-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31401, 'Londrina', 'Safira', 'Waldemar Hauer', '86030-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31402, 'Foz do Iguaçu', 'Safira', 'Parque Ouro Verde', '85854-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31403, 'Ponta Grossa', 'Safira', 'Neves', '84021-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31404, 'Maringá', 'Safira', 'Jardim Real', '87083-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31405, 'Telêmaco Borba', 'Safira', 'Núcleo Bandeirantes', '84269-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31406, 'Cascavel', 'Safira', 'Esmeralda', '85806-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31407, 'Londrina', 'Sagitário', 'Sol', '86070-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31408, 'Curitiba', 'Sagitário', 'Sítio Cercado', '81910-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31409, 'Toledo', 'Sagrada Família', 'Boa Esperança', '85909-227', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31410, 'Umuarama', 'Sagrada Família', 'Parque Dom Pedro II', '87508-058', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31411, 'Londrina', 'Sagrado Coração', 'Monções', '86015-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31412, 'Maringá', 'Sagrado Coração de Jesus', 'Vila Morangueira', '87040-110', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31413, 'Campo Largo', 'Sagrado Coração de Jesus', 'Centro', '83601-325', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31414, 'Curitiba', 'Sagrado Coração de Jesus', 'Água Verde', '80620-405', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31415, 'Foz do Iguaçu', 'Sagüi', 'Conjunto A', '85861-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31416, 'Arapongas', 'Saí', 'Parque Veneza', '86701-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31417, 'Arapongas', 'Saí-azul', 'Conjunto Palmares', '86706-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31418, 'Ponta Grossa', 'Said Ajuz', 'Estrela', '84050-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31419, 'Curitiba', 'Said Fatuch', 'Jardim Botânico', '80210-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31420, 'Maringá', 'Said Jacob', 'Conjunto Habitacional Requião', '87047-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31421, 'Curitiba', 'Said João Sallum', 'Bairro Alto', '82820-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31422, 'Curitiba', 'Said Mohamad El-Khatib', 'Cidade Industrial', '81170-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31423, 'Curitiba', 'Sain''Hilaire', 'Água Verde', '80240-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31424, 'Ponta Grossa', 'SaintHilaire', 'Oficinas', '84035-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31425, 'Maringá', 'Saint''Hilaire', 'Zona 05', '87015-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31426, 'Maringá', 'Saint''Hilaire', 'Zona 05', '87015-161', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31427, 'Arapongas', 'Saí-púrpura', 'Jardim dos Pássaros', '86702-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31428, 'Foz do Iguaçu', 'Saíra', 'Parque Morumbi II', '85859-656', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31429, 'Foz do Iguaçu', 'Saíra', 'Conjunto A', '85866-050', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31430, 'Ponta Grossa', 'Saíra', 'Colônia Dona Luiza', '84043-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31431, 'Araucária', 'Saíra', 'Capela Velha', '83706-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31432, 'Arapongas', 'Saíra', 'Jardim Aeroporto', '86702-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31433, 'Arapongas', 'Saíra-da-serra', 'Conjunto Novo Centauro', '86709-536', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31434, 'Arapongas', 'Saíra-diamante', 'Casa Família Arapongas IV', '86709-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31435, 'Arapongas', 'Saira-do-paraíso', 'Jardim dos Pássaros', '86702-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31436, 'Arapongas', 'Saíra-militar', 'Jardim Aeroporto', '86702-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31437, 'Arapongas', 'Saira-turqueza', 'Vila Domingos', '86705-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31438, 'Ponta Grossa', 'Saí-tema', 'Colônia Dona Luiza', '84046-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31439, 'Arapongas', 'Saí-verde', 'Conjunto Del Condor', '86703-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31440, 'Apucarana', 'Sakiche Kanno', 'Jardim Portal do Lago', '86802-068', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31441, 'Guarapuava', 'Salamandra', 'Vila Bela', '85025-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31442, 'Ponta Grossa', 'Salatiel de Paula', 'Chapada', '84062-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31443, 'Campo Largo', 'Salatiel Gasparino Ferreira', 'Jardim Bela Vista', '83605-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31444, 'Ponta Grossa', 'Saldanha da Gama', 'Orfãs', '84015-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31445, 'Curitiba', 'Saldanha da Gama', 'Centro', '80060-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31446, 'Guarapuava', 'Saldanha Marinho', 'Centro', '85010-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31447, 'Guarapuava', 'Saldanha Marinho', 'Dos Estados', '85035-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31448, 'Guarapuava', 'Saldanha Marinho', 'Trianon', '85012-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31449, 'Ponta Grossa', 'Saldanha Marinho', 'Centro', '84010-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31450, 'Maringá', 'Saldanha Marinho', 'Zona 09', '87030-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31451, 'Cascavel', 'Saldanha Marinho', 'Presidente', '85818-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31452, 'Curitiba', 'Saldanha Marinho', 'Centro', '80410-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31453, 'Curitiba', 'Saldanha Marinho', 'Bigorrilho', '80730-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31454, 'Curitiba', 'Saldanha Marinho', 'Centro', '80410-151', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31455, 'Curitiba', 'Saldanha Marinho', 'Centro', '80430-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31456, 'Guarapuava', 'Saldanha Nassar', 'Santana', '85070-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31457, 'Foz do Iguaçu', 'Sales', 'Jardim Lancaster I', '85869-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31458, 'Francisco Beltrão', 'Salete Traiano Apel', 'Sadia', '85606-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31459, 'Francisco Beltrão', 'Salgado Filho', 'Marrecas', '85601-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31460, 'Londrina', 'Salgado Filho', 'Califórnia', '86040-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31461, 'Guarapuava', 'Salgado Filho', 'Vila Bela', '85027-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31462, 'Paranavaí', 'Salgado Filho', 'Jardim Curitiba', '87708-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31463, 'Pato Branco', 'Salgado Filho', 'Brasília', '85504-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31464, 'Pinhais', 'Salgado Filho', 'Jardim Pedro Demeterco', '83324-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31465, 'Pinhais', 'Salgado Filho', 'Vila Esplanada', '83320-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31466, 'Maringá', 'Salgado Filho', 'Zona 09', '87050-480', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31467, 'Pinhais', 'Salgado Filho', 'Vila Amélia', '83330-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31468, 'Paranavaí', 'Salgado Filho', 'Jardim Santa Eugênia', '87705-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31469, 'Toledo', 'Salgado Filho', 'Vila Industrial', '85904-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31470, 'Telêmaco Borba', 'Salgado Filho', 'Centro', '84261-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31471, 'Apucarana', 'Salgado Filho', 'Vila Regina', '86801-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31472, 'Cascavel', 'Salgado Filho', 'Centro', '85801-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31473, 'Cascavel', 'Salgado Filho', 'Vila Tolentino', '85802-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31474, 'Cascavel', 'Salgado Filho', 'Centro', '85810-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31475, 'Cascavel', 'Salgado Filho', 'Cancelli', '85811-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31476, 'Cascavel', 'Salgado Filho', 'Canadá', '85813-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31477, 'Foz do Iguaçu', 'Salgueiro', 'Jardim Santa Rosa', '85869-250', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31478, 'Maringá', 'Salgueiro', 'Jardim Pinheiros', '87043-638', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31479, 'Piraquara', 'Salgueiro', 'Jardim Primavera', '83302-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31480, 'Telêmaco Borba', 'Salgueiro', 'Vila Gomes', '84272-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31481, 'Cascavel', 'Salgueiro', 'Parque Verde', '85807-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31482, 'Almirante Tamandaré', 'Salgueiros', 'Jardim Marize', '83507-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31483, 'Araucária', 'Saliba Merhi', 'Vila Nova', '83703-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31484, 'Francisco Beltrão', 'Salim Miguel', 'São Miguel', '85602-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31485, 'Londrina', 'Salim Sahao', 'Alto da Boa Vista', '86083-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31486, 'Curitiba', 'Salim Salomão', 'Sítio Cercado', '81925-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31487, 'Curitiba', 'Salim Tacla', 'Cajuru', '82940-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31488, 'Pinhais', 'Salinas', 'Loteamento Alphaville Graciosa', '83327-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31489, 'Foz do Iguaçu', 'Salmão', 'Profilurb I', '85855-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31490, 'Cambé', 'Salmos', 'Conjunto Habitacional Doutor José dos Santos Rocha', '86184-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31491, 'Curitiba', 'Salomão Elias Feder', 'Uberaba', '81570-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31492, 'Curitiba', 'Salomão Elias Feder', 'Uberaba', '81580-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31493, 'Londrina', 'Salomão Felipe da Silva', 'Parque Industrial José Belinati', '86039-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31494, 'Curitiba', 'Salomão Guelmann', 'Novo Mundo', '81050-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31495, 'Cambé', 'Salomão Jorge Hauli', 'Centro', '86181-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31496, 'Foz do Iguaçu', 'Salomão José Zagury', 'Conjunto Habitacional Fernanda', '85862-498', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31497, 'São José dos Pinhais', 'Salomão Miguel Nasser', 'Guatupê', '83060-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31498, 'Ponta Grossa', 'Salomão Tuma', 'Estrela', '84050-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31499, 'Foz do Iguaçu', 'Salto 3 Mosqueteiros', 'Jardim Residencial Cataratas', '85855-679', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31500, 'Foz do Iguaçu', 'Salto Adão e Eva', 'Jardim Residencial Cataratas', '85855-667', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31501, 'Telêmaco Borba', 'Salto Aparado', 'Área 07', '84267-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31502, 'Foz do Iguaçu', 'Salto Belgrado', 'Jardim Residencial Cataratas', '85855-666', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31503, 'Foz do Iguaçu', 'Salto Benjamin Constant', 'Jardim Residencial Cataratas', '85855-658', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31504, 'Foz do Iguaçu', 'Salto Bozeti', 'Jardim Residencial Cataratas', '85855-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31505, 'Telêmaco Borba', 'Salto da Conceição', 'Área 02', '84267-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31506, 'Foz do Iguaçu', 'Salto de Los Amores', 'Jardim Residencial Cataratas', '85855-677', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31507, 'Foz do Iguaçu', 'Salto Deodoro', 'Jardim Residencial Cataratas', '85855-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31508, 'Colombo', 'Salto do Itararé', 'Vila São José', '83410-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31509, 'Curitiba', 'Salto do Itararé', 'Cidade Industrial', '81250-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31510, 'Francisco Beltrão', 'Salto do Lontra', 'Marrecas', '85601-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31511, 'Curitiba', 'Salto do Lontra', 'Xaxim', '81810-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31512, 'Foz do Iguaçu', 'Salto Escondido', 'Jardim Residencial Cataratas', '85855-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31513, 'Foz do Iguaçu', 'Salto Floriano', 'Jardim Residencial Cataratas', '85855-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31514, 'Foz do Iguaçu', 'Salto Garganta do Diabo', 'Jardim Residencial Cataratas', '85855-668', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31515, 'Foz do Iguaçu', 'Salto Mitre', 'Jardim Residencial Cataratas', '85855-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31516, 'Foz do Iguaçu', 'Salto Penoni', 'Jardim Residencial Cataratas', '85855-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31517, 'Foz do Iguaçu', 'Salto Rivadávia', 'Jardim Residencial Cataratas', '85855-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31518, 'Foz do Iguaçu', 'Salto San Martin', 'Jardim Residencial Cataratas', '85855-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31519, 'Foz do Iguaçu', 'Salto Santa Maria', 'Jardim Residencial Cataratas', '85855-659', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31520, 'Laranjeiras do Sul', 'Salto Santiago', 'São Francisco', '85303-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31521, 'Maringá', 'Salto Santiago', 'Parque das Grevíleas', '87025-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31522, 'Foz do Iguaçu', 'Salto União', 'Jardim Residencial Cataratas', '85855-678', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31523, 'Curitiba', 'Salustiano Cordeiro', 'Água Verde', '80620-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31524, 'Foz do Iguaçu', 'Salvador', 'Conjunto C', '85870-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31525, 'Foz do Iguaçu', 'Salvador', 'Parque Presidente II', '85863-610', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31526, 'Laranjeiras do Sul', 'Salvador', 'Água Verde', '85302-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31527, 'Francisco Beltrão', 'Salvador', 'Alvorada', '85601-840', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31528, 'Foz do Iguaçu', 'Salvador', 'Jardim Duarte', '85861-480', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31529, 'Foz do Iguaçu', 'Salvador', 'Jardim Lancaster IV', '85869-590', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31530, 'Pato Branco', 'Salvador', 'Parzianello', '85504-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31531, 'Paranavaí', 'Salvador', 'Centro', '87702-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31532, 'Toledo', 'Salvador', 'Vila Becker', '85902-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31533, 'Almirante Tamandaré', 'Salvador', 'Jardim Gramados', '83504-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31534, 'Campo Largo', 'Salvador', 'Jardim Esmeralda', '83604-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31535, 'Cascavel', 'Salvador', 'Brasmadeira', '85814-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31536, 'Curitiba', 'Salvador', 'Cajuru', '82940-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31537, 'Castro', 'Salvador A. Sobrinho', 'Núcleo Habitacional Padre Piva', '84178-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31538, 'Curitiba', 'Salvador de Mauro', 'Pilarzinho', '82100-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31539, 'Ponta Grossa', 'Salvador de Mendonça', 'Nova Rússia', '84053-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31540, 'Almirante Tamandaré', 'Salvador dos Santos Lima', 'Jardim Josiane', '83504-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31541, 'Curitiba', 'Salvador Evangelista', 'Alto Boqueirão', '81770-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31542, 'Guarapuava', 'Salvador Félix Machado', 'Jardim das Américas', '85030-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31543, 'Curitiba', 'Salvador Ferrante', 'Boqueirão', '81670-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31544, 'Curitiba', 'Salvador Ferrante', 'Boqueirão', '81650-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31545, 'Guarapuava', 'Salvador Gomes', 'Vila Bela', '85027-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31546, 'Curitiba', 'Salvador Gonçalo de Christo', 'Cidade Industrial', '81270-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31547, 'Paranavaí', 'Salvador Gonçalves Padilha', 'Jardim Maravilha', '87703-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31548, 'Curitiba', 'Salvador Graciano', 'Tatuquara', '81470-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31549, 'Foz do Iguaçu', 'Salvador Guerra', 'Jardim Festugato', '85864-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31550, 'Curitiba', 'Salvador Herrera Requena', 'Santa Cândida', '82720-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31551, 'Sarandi', 'Salvador Jordano', 'Jardim Nova Paulista', '87111-151', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31552, 'Sarandi', 'Salvador Jordano', 'Centro', '87111-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31553, 'Curitiba', 'Salvador José Correia Coelho', 'Cidade Industrial', '81270-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31554, 'Sarandi', 'Salvador Martins', 'Jardim Nova Independência I', '87114-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31555, 'Araucária', 'Salvador Moreira Vidal', 'Barigui', '83707-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31556, 'Castro', 'Salvador Natucci', 'Jardim das Araucárias', '84174-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31557, 'Londrina', 'Salvador Sandaniel', 'Residencial Portal de Piza', '86041-298', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31558, 'Guarapuava', 'Salvador Scheneider', 'Boqueirão', '85020-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31559, 'Almirante Tamandaré', 'Salvador Teixeira de Faria', 'Vila Rachel', '83501-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31560, 'Londrina', 'Salvador Torres Peres', 'São Lourenço', '86043-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31561, 'Apucarana', 'Salvador Usso', 'Jardim Aviação', '86812-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31562, 'Londrina', 'Salvadora Sanches Canalez', 'Residencial José B Almeida', '86041-818', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31563, 'Londrina', 'Salvatina Maria Rosa', 'Roseira', '86041-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31564, 'Araucária', 'Salvia', 'Campina da Barra', '83709-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31565, 'Foz do Iguaçu', 'Samambaia', 'Conjunto B', '85867-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31566, 'Araucária', 'Samambaia', 'Campina da Barra', '83709-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31567, 'Cascavel', 'Samambaias', 'Guarujá', '85804-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31568, 'Londrina', 'Samaumeira', 'Santa Rita 1', '86071-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31569, 'Paranaguá', 'Sambaqui', 'Jardim América', '83209-465', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31570, 'Telêmaco Borba', 'Sambaquis', 'Fazenda Limeira', '84272-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31571, 'Paranaguá', 'Sambura', 'Santos Dumont', '83209-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31572, 'Colombo', 'Sampaio', 'Jardim Planalto', '83409-137', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31573, 'Londrina', 'Sampaio Vidal', 'Kase', '86026-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31574, 'Ponta Grossa', 'Samuel Albach', 'Uvaranas', '84031-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31575, 'Ponta Grossa', 'Samuel Berszacher', 'Uvaranas', '84025-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31576, 'Curitiba', 'Samuel Cézar', 'Água Verde', '80620-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31577, 'Curitiba', 'Samuel da Rocha Coelho', 'Cidade Industrial', '81290-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31578, 'Cascavel', 'Samuel de Paula', 'Região do Lago 3', '85819-779', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31579, 'Londrina', 'Samuel Faustino Romeiro Campoy', 'Coliseu', '86076-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31580, 'Maringá', 'Samuel Finley Breese Morse', 'Jardim Ipanema', '87053-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31581, 'Telêmaco Borba', 'Samuel Klabin', 'Centro', '84261-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31582, 'Londrina', 'Samuel Morse', 'Industrial', '86063-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31583, 'Paranaguá', 'Samuel Pires de Mello', 'Vila Paranaguá', '83221-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31584, 'Paranaguá', 'Samuel Pires de Mello', 'Estradinha', '83206-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31585, 'Londrina', 'Samuel Wainer', 'Mediterrâneo', '86047-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31586, 'Maringá', 'Samuel Wainer', 'Vila Esperança', '87020-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31587, 'Londrina', 'San Marino', 'Jardim Adriana I', '86046-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31588, 'Umuarama', 'San Marino', 'Parque Bonfim', '87507-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31589, 'Curitiba', 'San Martin', 'Santa Felicidade', '82410-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31590, 'Francisco Beltrão', 'Sananduva', 'Pinheirinho', '85603-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31591, 'Foz do Iguaçu', 'Sananduva', 'Jardim Cedro', '85862-366', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31592, 'Arapongas', 'Sana-vermelha', 'Jardim Colúmbia IV', '86707-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31593, 'Cascavel', 'Sandalio Santos', 'Região do Lago 3', '85819-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31594, 'Piraquara', 'Sandra da Cruz Bressan', 'Guarituba', '83311-316', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31595, 'Curitiba', 'Sandra Eliuisa Barberi', 'Pinheirinho', '81870-456', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31596, 'Londrina', 'Sandra Souza Pinho', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31597, 'Pinhais', 'Sandro Carlos Sarda', 'Prive Bois de Boulogne', '83330-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31598, 'Araucária', 'Sandro Fialla', 'Boqueirão', '83704-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31599, 'Piraquara', 'Sandro Pereira da Silva', 'Vila Franca', '83305-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31600, 'Foz do Iguaçu', 'Sanga Funda', 'Jardim Amazonas', '85857-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31601, 'Foz do Iguaçu', 'Sangue-de-boi', 'Portal da Foz', '85859-406', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31602, 'Campo Mourão', 'Sangue-de-boi', 'Conjunto Habitacional Milton Luiz Pereira', '87306-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31603, 'Arapongas', 'Sangue-de-boi', 'Vila Araponguinha', '86705-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31604, 'Foz do Iguaçu', 'Sanhaço', 'Portal da Foz', '85859-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31605, 'Pinhais', 'Sanhaço', 'Jardim Fênix', '83326-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31606, 'Campo Mourão', 'Sanhaço', 'Jardim Tropical I', '87310-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31607, 'Campo Largo', 'Sanhaço', 'Vila Gilcy', '83609-030', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31608, 'Arapongas', 'Sanhaço', 'Jardim São Cristóvão', '86709-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31609, 'Araucária', 'Sanhaço', 'Estação', '83705-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31610, 'Cambé', 'Sanhaço', 'Conjunto Habitacional Waldomiro M Gomes', '86182-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31611, 'Arapongas', 'Sanhaço-azul', 'Jardim Petrópolis', '86709-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31612, 'Arapongas', 'Sanhaço-de-coqueiro', 'Conjunto Águias', '86704-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31613, 'Arapongas', 'Sanhaço-de-fogo', 'Conjunto Flamingos III', '86703-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31614, 'Arapongas', 'Sanhaço-frade', 'Jardim Caravelle', '86702-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31615, 'Curitiba', 'Sanito Moser', 'Cidade Industrial', '81460-367', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31616, 'Curitiba', 'Sanito Rocha', 'Cristo Rei', '80050-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31617, 'Curitiba', 'Sanremo', 'Santa Felicidade', '82020-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31618, 'Londrina', 'Santa Adelaide', 'Pindorama', '86027-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31619, 'Curitiba', 'Santa Agueda', 'Cidade Industrial', '81310-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31620, 'Curitiba', 'Santa Alice', 'Cidade Industrial', '81450-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31621, 'Pinhais', 'Santa Alves Petra', 'Jardim Dona Joaquina I', '83325-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31622, 'Ponta Grossa', 'Santa Amélia', 'Olarias', '84026-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31623, 'Almirante Tamandaré', 'Santa Amélia', 'Parque São Jorge', '83503-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31624, 'Curitiba', 'Santa Amélia', 'Xaxim', '81810-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31625, 'Francisco Beltrão', 'Santa Ana', 'Jardim Novo Mundo', '85602-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31626, 'Londrina', 'Santa Ana', 'Espanha', '86027-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31627, 'Pinhais', 'Santa Ana', 'Planta Bairro Weissópolis', '83322-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31628, 'Colombo', 'Santa Ana', 'Jardim Nossa Senhora de Fátima', '83405-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31629, 'Cascavel', 'Santa Ana', 'Claudete', '85807-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31630, 'Curitiba', 'Santa Anastácia', 'Cajuru', '82900-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31631, 'Campo Largo', 'Santa Ângela', 'Jardim Keli Cristina', '83609-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31632, 'Curitiba', 'Santa Ângela de Foligno', 'Cidade Industrial', '81170-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31633, 'Curitiba', 'Santa Ângela de Mérici', 'Cidade Industrial', '81310-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31634, 'Londrina', 'Santa Apolônia', 'Helena', '86027-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31635, 'Francisco Beltrão', 'Santa Bárbara', 'Jardim Novo Mundo', '85602-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31636, 'Londrina', 'Santa Bárbara', 'Fraternidade', '86027-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31637, 'Ponta Grossa', 'Santa Bárbara', 'Uvaranas', '84033-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31638, 'Pato Branco', 'Santa Bárbara', 'Bortot', '85504-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31639, 'Umuarama', 'Santa Bárbara', 'Jardim Europa', '87502-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31640, 'Campo Mourão', 'Santa Bárbara', 'Conjunto Habitacional Mendes', '87306-388', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31641, 'Campo Largo', 'Santa Bárbara', 'Vila Dom Pedro II', '83608-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31642, 'Almirante Tamandaré', 'Santa Bárbara', 'Vila Alto Pinheiros', '83503-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31643, 'Cascavel', 'Santa Bárbara', 'Pioneiros Catarinenses', '85805-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31644, 'Curitiba', 'Santa Beatriz de Vicência', 'Cidade Industrial', '81310-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31645, 'Francisco Beltrão', 'Santa Bernadete', 'São Miguel', '85602-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31646, 'Curitiba', 'Santa Bernadethe', 'Lindóia', '81010-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31647, 'Curitiba', 'Santa Bernadethe', 'Fanny', '81030-270', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31648, 'Curitiba', 'Santa Bertila', 'Cidade Industrial', '81305-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31649, 'Curitiba', 'Santa Bertila Boscardin', 'Santa Felicidade', '82020-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31650, 'Londrina', 'Santa Boer', 'Jardim Paraty', '86081-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31651, 'Cascavel', 'Santa Brígida', 'Pioneiros Catarinenses', '85805-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31652, 'Curitiba', 'Santa Brígida', 'Uberaba', '81570-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31653, 'Curitiba', 'Santa Cacilda', 'Cidade Industrial', '81250-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31654, 'Apucarana', 'Santa Cândida', 'Jardim Menegazzo', '86802-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31655, 'Almirante Tamandaré', 'Santa Cândida', 'Parque São Jorge', '83503-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31656, 'Curitiba', 'Santa Cândida', 'Santa Cândida', '82620-390', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31657, 'Guarapuava', 'Santa Catarina', 'Dos Estados', '85035-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31658, 'Londrina', 'Santa Catarina', 'Centro', '86010-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31659, 'Laranjeiras do Sul', 'Santa Catarina', 'Água Verde', '85302-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31660, 'Francisco Beltrão', 'Santa Catarina', 'São Miguel', '85602-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31661, 'Paranavaí', 'Santa Catarina', 'Jardim Ouro Branco', '87704-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31662, 'Paranavaí', 'Santa Catarina', 'Centro', '87703-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31663, 'Piraquara', 'Santa Catarina', 'Jardim dos Estados 1', '83308-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31664, 'Piraquara', 'Santa Catarina', 'Jardim dos Estados 3', '83307-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31665, 'Piraquara', 'Santa Catarina', 'Jardim dos Estados 2', '83308-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31666, 'Paranavaí', 'Santa Catarina', 'Centro', '87702-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31667, 'Paranavaí', 'Santa Catarina', 'Vila City', '87709-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31668, 'Paranaguá', 'Santa Catarina', 'Vila do Povo', '83209-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31669, 'Toledo', 'Santa Catarina', 'Jardim Porto Alegre', '85906-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31670, 'São José dos Pinhais', 'Santa Catarina', 'Roseira', '83070-175', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31671, 'São José dos Pinhais', 'Santa Catarina', 'São Domingos', '83030-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31672, 'Umuarama', 'Santa Catarina', 'Zona II', '87502-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31673, 'Telêmaco Borba', 'Santa Catarina', 'Nossa Senhora de Fátima', '84264-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31674, 'Almirante Tamandaré', 'Santa Catarina', 'Vila Alto Pinheiros', '83503-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31675, 'Cascavel', 'Santa Catarina', 'Centro', '85801-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31676, 'Campo Mourão', 'Santa Catarina', 'Jardim Gutierres', '87300-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31677, 'Colombo', 'Santa Catarina', 'Vila Santa Catarina', '83412-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31678, 'Apucarana', 'Santa Catarina', 'Vila Santa Catarina', '86808-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31679, 'Campo Largo', 'Santa Catarina', 'Vila Itaqui', '83604-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31680, 'Campo Mourão', 'Santa Catarina', 'Centro', '87303-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31681, 'Cascavel', 'Santa Catarina', 'Centro', '85801-041', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31682, 'Cascavel', 'Santa Catarina', 'Alto Alegre', '85805-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31683, 'Araucária', 'Santa Catarina', 'Cachoeira', '83708-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31684, 'Araucária', 'Santa Catarina', 'Iguaçu', '83701-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31685, 'Apucarana', 'Santa Catarina', 'Jardim Apucarana', '86804-015', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31686, 'Curitiba', 'Santa Catarina', 'Água Verde', '80620-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31687, 'Curitiba', 'Santa Catarina', 'Água Verde', '80610-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31688, 'Curitiba', 'Santa Catarina', 'Guaíra', '80630-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31689, 'Ponta Grossa', 'Santa Catarina do Ceno', 'Uvaranas', '84033-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31690, 'Londrina', 'Santa Cecília', 'Fraternidade', '86027-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31691, 'Paranaguá', 'Santa Cecília', 'Emboguaçu', '83209-026', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31692, 'Ponta Grossa', 'Santa Cecília', 'Cará-cará', '84033-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31693, 'Toledo', 'Santa Cecília', 'Jardim Paulista', '85909-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31694, 'Telêmaco Borba', 'Santa Cecília', 'Macopa', '84261-450', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31695, 'Umuarama', 'Santa Cecília', 'Jardim São Cristóvão', '87507-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31696, 'Almirante Tamandaré', 'Santa Cecília', 'Vila Alto Pinheiros', '83503-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31697, 'Curitiba', 'Santa Cecília', 'Vista Alegre', '80820-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31698, 'Londrina', 'Santa Clara', 'Espanha', '86027-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31699, 'Piraquara', 'Santa Clara', 'Jardim Santa Mônica', '83302-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31700, 'Pato Branco', 'Santa Clara', 'Planalto', '85509-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31701, 'Ponta Grossa', 'Santa Clara', 'Cará-cará', '84033-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31702, 'Umuarama', 'Santa Clara', 'Jardim São Cristóvão', '87507-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31703, 'Toledo', 'Santa Clara', 'Boa Esperança', '85909-228', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31704, 'Cascavel', 'Santa Clara', 'Pioneiros Catarinenses', '85805-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31705, 'Colombo', 'Santa Clara', 'Vila Igasa', '83412-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31706, 'Curitiba', 'Santa Clara', 'Ahú', '82200-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31707, 'Londrina', 'Santa Cristina', 'Carlota', '86027-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31708, 'Londrina', 'Santa Cruz', 'Aeroporto', '86036-020', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31709, 'Londrina', 'Santa Cruz', 'Boa Vista', '86039-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31710, 'Ponta Grossa', 'Santa Cruz', 'Centro', '84010-530', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31711, 'Umuarama', 'Santa Cruz', 'Parque Dom Pedro II', '87508-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31712, 'Toledo', 'Santa Cruz', 'Vila Brasil', '85909-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31713, 'Castro', 'Santa Cruz', 'Jardim dos Bancários', '84172-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31714, 'Campo Largo', 'Santa Cruz', 'Bom Jesus', '83604-367', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31715, 'Campo Mourão', 'Santa Cruz', 'Centro', '87303-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31716, 'Campo Mourão', 'Santa Cruz', 'Jardim Flórida', '87300-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31717, 'Cascavel', 'Santa Cruz', 'Brasmadeira', '85814-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31718, 'Curitiba', 'Santa de Cândida', 'Santa Cândida', '82630-490', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31719, 'Curitiba', 'Santa Edwiges', 'Abranches', '82220-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31720, 'Maringá', 'Santa Edwirges', 'Parque Industrial', '87065-600', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31721, 'Toledo', 'Santa Edwirges', 'Parque Residencial Pancera', '85902-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31722, 'Londrina', 'Santa Efigênia', 'Amaral', '86027-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31723, 'Maringá', 'Santa Efigênia', 'Zona 06', '87080-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31724, 'Telêmaco Borba', 'Santa Efigênia', 'Vila São Vicente de Paula', '84262-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31725, 'São José dos Pinhais', 'Santa Efigênia', 'Roseira', '83070-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31726, 'Umuarama', 'Santa Efigênia', 'Conjunto Residencial Guarani I', '87509-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31727, 'Londrina', 'Santa Eliza', 'Fraternidade', '86027-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31728, 'Umuarama', 'Santa Eliza', 'Jardim Shangri-la', '87509-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31729, 'Toledo', 'Santa Eliza', 'Boa Esperança', '85909-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31730, 'Londrina', 'Santa Eloá', 'Pindorama', '86027-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31731, 'Curitiba', 'Santa Escolástica', 'Cidade Industrial', '81305-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31732, 'Londrina', 'Santa Ester', 'Carlota', '86027-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31733, 'Curitiba', 'Santa Eugênia', 'Cidade Industrial', '81305-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31734, 'Curitiba', 'Santa Eulália de Barcelona', 'Cidade Industrial', '81170-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31735, 'Colombo', 'Santa Faustina Kowauska', 'Jardim dos Eucaliptos', '83408-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31736, 'Foz do Iguaçu', 'Santa Fé', 'Jardim Belvedere I', '85867-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31737, 'Guarapuava', 'Santa Fé', 'Jardim das Américas', '85030-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31738, 'Londrina', 'Santa Fé', 'Helena', '86027-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31739, 'Pato Branco', 'Santa Fé', 'Industrial', '85506-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31740, 'Pinhais', 'Santa Fé', 'Jardim Pedro Demeterco', '83324-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31741, 'Toledo', 'Santa Fé', 'Boa Esperança', '85909-046', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31742, 'Almirante Tamandaré', 'Santa Fé', 'Jardim Santa Fé', '83511-350', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31743, 'Cascavel', 'Santa Fé', 'Pioneiros Catarinenses', '85805-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31744, 'Curitiba', 'Santa Fé', 'Cidade Industrial', '81170-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31745, 'Curitiba', 'Santa Felicidade', 'Santa Felicidade', '82020-475', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31746, 'Londrina', 'Santa Filomena', 'Carlota', '86027-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31747, 'Curitiba', 'Santa Filomena', 'Hugo Lange', '80040-300', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31748, 'Londrina', 'Santa Francisca', 'Pindorama', '86027-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31749, 'Curitiba', 'Santa Francisca Romana', 'Santa Felicidade', '82320-140', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31750, 'Toledo', 'Santa Gema', 'Boa Esperança', '85909-199', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31751, 'Curitiba', 'Santa Gema Galgani', 'Barreirinha', '82220-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31752, 'Curitiba', 'Santa Genoveva', 'Cidade Industrial', '81315-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31753, 'Maringá', 'Santa Guilhermina', 'Jardim São Jorge', '87080-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31754, 'Guarapuava', 'Santa Helena', 'Jardim das Américas', '85030-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31755, 'Laranjeiras do Sul', 'Santa Helena', 'São Francisco', '85303-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31756, 'Ponta Grossa', 'Santa Helena', 'Cará-cará', '84033-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31757, 'Pinhais', 'Santa Helena', 'Jardim Pedro Demeterco', '83324-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31758, 'Umuarama', 'Santa Helena', 'Jardim Paraíso', '87505-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31759, 'Apucarana', 'Santa Helena', 'Núcleo Habitacional das Indústrias', '86806-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31760, 'Almirante Tamandaré', 'Santa Helena', 'Jardim São Carlos', '83507-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31761, 'Cascavel', 'Santa Helena', 'Cataratas', '85818-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31762, 'Guarapuava', 'Santa Inês', 'Cascavel', '85025-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31763, 'Francisco Beltrão', 'Santa Inês', 'Cristo Rei', '85602-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31764, 'Ponta Grossa', 'Santa Inês', 'Uvaranas', '84033-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31765, 'Pinhais', 'Santa Inês', 'Jardim Pedro Demeterco', '83324-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31766, 'Telêmaco Borba', 'Santa Inês', 'Área 03', '84271-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31767, 'Cambé', 'Santa Inês', 'Jardim Santa Izabel', '86183-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31768, 'Curitiba', 'Santa Inês', 'Bacacheri', '82515-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31769, 'Paranaguá', 'Santa Isabel', 'Parque São João', '83212-080', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31770, 'Telêmaco Borba', 'Santa Isabel', 'Nossa Senhora de Fátima', '84264-230', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31771, 'Campo Largo', 'Santa Isabel', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-785', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31772, 'Laranjeiras do Sul', 'Santa Izabel', 'São Francisco', '85303-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31773, 'Maringá', 'Santa Izabel', 'Vila Santa Izabel', '87080-490', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31774, 'Sarandi', 'Santa Izabel', 'Centro', '87111-115', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31775, 'Curitiba', 'Santa Joana Ages', 'Cachoeira', '82220-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31776, 'Curitiba', 'Santa Joana d''Arc', 'Lindóia', '81010-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31777, 'Curitiba', 'Santa Joana Francisca de Chantal', 'Cidade Industrial', '81250-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31778, 'Curitiba', 'Santa Joana Maria', 'Cidade Industrial', '81305-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31779, 'Maringá', 'Santa Joaquina de Vedruna', 'Zona 05', '87015-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31780, 'Maringá', 'Santa Joaquina de Vedruna', 'Zona 05', '87015-151', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31781, 'Toledo', 'Santa Justina Sartori', 'Jardim Porto Alegre', '85906-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31782, 'Toledo', 'Santa Laura', 'Jardim Paulista', '85909-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31784, 'Ponta Grossa', 'Santa Lídia', 'Cará-cará', '84033-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31785, 'Ponta Grossa', 'Santa Lúcia', 'Cará-cará', '84033-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31786, 'Londrina', 'Santa Luiza', 'Franca', '86027-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31787, 'Francisco Beltrão', 'Santa Luzia', 'Cristo Rei', '85602-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31788, 'Londrina', 'Santa Luzia', 'Franca', '86027-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31789, 'Umuarama', 'Santa Luzia', 'Jardim São Cristóvão', '87507-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31790, 'Telêmaco Borba', 'Santa Luzia', 'Área 03', '84271-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31791, 'São José dos Pinhais', 'Santa Luzia', 'Roseira', '83070-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31792, 'Toledo', 'Santa Luzia', 'Boa Esperança', '85909-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31793, 'Cambé', 'Santa Luzia', 'Jardim Santa Izabel', '86183-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31794, 'Londrina', 'Santa Madalena', 'Fraternidade', '86027-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31795, 'Umuarama', 'Santa Madalena', 'Parque San Marino', '87509-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31796, 'Colombo', 'Santa Madalena', 'Jardim Nossa Senhora de Fátima', '83405-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31797, 'Curitiba', 'Santa Madalena de Piazzi', 'Seminário', '80240-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31798, 'Curitiba', 'Santa Madalena Sofia Barat', 'Bairro Alto', '82820-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31799, 'Londrina', 'Santa Margarida', 'Fraternidade', '86027-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31800, 'Guarapuava', 'Santa Maria', 'Industrial', '85045-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31801, 'Londrina', 'Santa Maria', 'Santa Terezinha', '86027-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31802, 'Francisco Beltrão', 'Santa Maria', 'Guanabara', '85604-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31803, 'Pato Branco', 'Santa Maria', 'Chaparral', '85507-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31804, 'Pinhais', 'Santa Maria', 'Planta Guilherme Weiss', '83322-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31805, 'Maringá', 'Santa Maria', 'Zona 02', '87010-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31806, 'Umuarama', 'Santa Maria', 'Parque San Marino', '87509-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31807, 'Telêmaco Borba', 'Santa Maria', 'Área 01', '84272-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31808, 'Toledo', 'Santa Maria', 'Jardim Santa Maria', '85902-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31809, 'Colombo', 'Santa Maria', 'Jardim Bandeirantes', '83408-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31810, 'Cascavel', 'Santa Maria', 'Cataratas', '85818-580', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31811, 'Almirante Tamandaré', 'Santa Maria', 'Jardim Santa Maria', '83511-380', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31812, 'Almirante Tamandaré', 'Santa Maria', 'Vila Alto Pinheiros', '83503-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31813, 'Curitiba', 'Santa Maria', 'Novo Mundo', '81030-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31814, 'Francisco Beltrão', 'Santa Maria Goretti', 'São Miguel', '85602-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31815, 'Sarandi', 'Santa Maria Madalena', 'Parque Residencial Bom Pastor', '87114-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31816, 'Guarapuava', 'Santa Mariana', 'Jardim das Américas', '85030-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31817, 'Ponta Grossa', 'Santa Mariana', 'Uvaranas', '84025-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31818, 'Telêmaco Borba', 'Santa Mariana', 'Vila São Vicente de Paula', '84262-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31819, 'Campo Largo', 'Santa Mariana', 'Vila Bancária', '83601-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31820, 'Curitiba', 'Santa Mariana', 'Cajuru', '82920-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31821, 'Londrina', 'Santa Marta', 'Espanha', '86027-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31822, 'Francisco Beltrão', 'Santa Marta', 'Cristo Rei', '85602-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31823, 'Ponta Grossa', 'Santa Marta', 'Colônia Dona Luiza', '84033-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31824, 'Sarandi', 'Santa Marta', 'Parque Residencial Bom Pastor', '87114-568', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31825, 'Toledo', 'Santa Marta', 'Jardim Piccinin', '85904-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31826, 'Guarapuava', 'Santa Matilde', 'Boqueirão', '85023-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31827, 'Londrina', 'Santa Matilde', 'Pindorama', '86027-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31828, 'Ponta Grossa', 'Santa Maura', 'Cará-cará', '84033-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31829, 'Londrina', 'Santa Mônica', 'Franca', '86027-610', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31830, 'Francisco Beltrão', 'Santa Mônica', 'Jardim Novo Mundo', '85602-785', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31831, 'Guarapuava', 'Santa Mônica', 'São Cristóvão', '85060-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31832, 'Londrina', 'Santa Mônica', 'Lupércio Luppi', '86030-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31833, 'Ponta Grossa', 'Santa Mônica', 'Cará-cará', '84033-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31834, 'São José dos Pinhais', 'Santa Mônica', 'Silveira da Motta', '83030-550', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31835, 'Curitiba', 'Santa Mônica', 'Capão Raso', '81110-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31836, 'Curitiba', 'Santa Olívia', 'Cidade Industrial', '81315-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31837, 'Ponta Grossa', 'Santa Regina', 'Cará-cará', '84033-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31838, 'Curitiba', 'Santa Regina', 'Capão Raso', '81110-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31839, 'Francisco Beltrão', 'Santa Rita', 'Guanabara', '85604-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31840, 'Londrina', 'Santa Rita', 'Fraternidade', '86027-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31841, 'Guarapuava', 'Santa Rita', 'São Cristóvão', '85060-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31842, 'Ponta Grossa', 'Santa Rita', 'Cará-cará', '84033-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31843, 'Pato Branco', 'Santa Rita', 'Sudoeste', '85507-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31844, 'São José dos Pinhais', 'Santa Rita', 'Cidade Jardim', '83035-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31845, 'Telêmaco Borba', 'Santa Rita', 'Jardim Bom Jesus', '84262-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31846, 'Campo Mourão', 'Santa Rita', 'Jardim Tropical II', '87310-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31847, 'Colombo', 'Santa Rita', 'Vila Igasa', '83412-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31848, 'Apucarana', 'Santa Rita', 'Vila Nossa Senhora da Aparecida', '86810-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31849, 'Londrina', 'Santa Rita de Cássia', 'Califórnia', '86040-075', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31850, 'Piraquara', 'Santa Rita de Cássia', 'Vila Juliana', '83306-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31851, 'Curitiba', 'Santa Rita de Cássia', 'Ahú', '80540-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31852, 'Curitiba', 'Santa Rita de Cássia dos Impossíveis', 'Tatuquara', '81470-086', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31853, 'Ponta Grossa', 'Santa Rita Durão', 'Colônia Dona Luiza', '84045-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31854, 'Curitiba', 'Santa Rita Durão', 'São Lourenço', '82210-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31855, 'Londrina', 'Santa Rosa', 'Pindorama', '86027-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31856, 'Francisco Beltrão', 'Santa Rosa', 'Pinheirinho', '85603-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31857, 'Ponta Grossa', 'Santa Rosa', 'Cará-cará', '84033-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31858, 'Telêmaco Borba', 'Santa Rosa', 'Fazenda Limeira', '84270-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31859, 'Toledo', 'Santa Rosa', 'Vila Industrial', '85904-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31860, 'Toledo', 'Santa Rosa', 'Jardim Arinela Grahl', '85905-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31861, 'Umuarama', 'Santa Rosa', 'Parque San Marino', '87509-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31862, 'Cascavel', 'Santa Rosa', 'Pioneiros Catarinenses', '85805-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31863, 'Londrina', 'Santa Ruth', 'Carlota', '86027-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31864, 'Londrina', 'Santa Sé', 'Helena', '86027-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31865, 'São José dos Pinhais', 'Santa Sílvia', 'Cidade Jardim', '83035-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31866, 'Londrina', 'Santa Sofia', 'Espanha', '86027-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31867, 'Paranavaí', 'Santa Teresa de Ávila', 'Parque Morumbi', '87703-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31868, 'Francisco Beltrão', 'Santa Tereza', 'Jardim Santa Fé', '85602-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31869, 'Toledo', 'Santa Tereza', 'Jardim Paulista', '85909-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31870, 'Londrina', 'Santa Terezinha', 'Santa Terezinha', '86027-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31871, 'Francisco Beltrão', 'Santa Terezinha', 'Cristo Rei', '85602-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31872, 'Ponta Grossa', 'Santa Terezinha', 'Uvaranas', '84033-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31873, 'Umuarama', 'Santa Terezinha', 'Jardim Shangri-la', '87509-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31874, 'Sarandi', 'Santa Terezinha', 'Jardim São Silvestre', '87112-120', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31875, 'Telêmaco Borba', 'Santa Terezinha', 'Área 03', '84271-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31876, 'Colombo', 'Santa Terezinha', 'Parque Residencial Santa Terezinha', '83408-740', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31877, 'Almirante Tamandaré', 'Santa Terezinha do Menino Jesus', 'Loteamento Nova Morada', '83504-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31878, 'Curitiba', 'Santa Zita', 'Guaíra', '80630-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31879, 'Laranjeiras do Sul', 'Santana', 'Getúlio Vargas', '85304-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31880, 'Laranjeiras do Sul', 'Santana', 'Centro', '85301-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31881, 'Sarandi', 'Santana', 'Parque Residencial Santana', '87112-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31882, 'Ponta Grossa', 'Sant''Ana', 'Centro', '84010-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31883, 'Maringá', 'Sant''Ana', 'Zona 06', '87080-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31884, 'Toledo', 'Sant''Ana', 'Jardim Planalto', '85904-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31885, 'Curitiba', 'Sant''Ana', 'Jardim Botânico', '80210-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31886, 'Londrina', 'Sant''Ana Devellis Ravali', 'Residencial Vila Romana', '86031-827', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31887, 'Curitiba', 'Sant''Ana do Itararé', 'Sítio Cercado', '81910-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31888, 'Curitiba', 'Sant''Ana do Itararé', 'Sítio Cercado', '81920-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31889, 'Francisco Beltrão', 'Santana do Livramento', 'Pinheirinho', '85603-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31890, 'Guarapuava', 'Santarem', 'Boqueirão', '85022-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31891, 'Telêmaco Borba', 'Santarém', 'Vila Esperança', '84272-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31892, 'Sarandi', 'Santarém', 'Jardim Cometa', '87112-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31893, 'Colombo', 'Santarém', 'Parque Residencial Santa Terezinha', '83408-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31894, 'Apucarana', 'Sante Formigoni', 'Vila Vera Cruz', '86804-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31895, 'Francisco Beltrão', 'Santiago', 'Miniguaçu', '85605-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31896, 'Londrina', 'Santiago', 'Guanabara', '86050-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31897, 'Pato Branco', 'Santiago', 'Chaparral', '85507-005', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31898, 'Paranaguá', 'Santiago', 'Parque Agari', '83215-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31899, 'Telêmaco Borba', 'Santiago', 'Área 01', '84272-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31900, 'Colombo', 'Santiago', 'Jardim Bela Vista', '83404-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31901, 'Foz do Iguaçu', 'Santiago Canhete', 'Vila Guarani', '85862-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31902, 'Londrina', 'Santiago Luiz Pereira', 'Santiago', '86071-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31903, 'Piraquara', 'Santim Bertassoni', 'Vila Franca', '83305-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31904, 'Londrina', 'Santin Peretti', 'Jardim Neman Sahyun', '86041-279', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31905, 'Toledo', 'Santina Binda Donassolo', 'Jardim Alta Floresta', '85905-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31906, 'Umuarama', 'Santina Colombo Bonora', 'Jardim União', '87508-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31907, 'São José dos Pinhais', 'Santina Manzoque Zen', 'Braga', '83020-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31908, 'Curitiba', 'Santina Peretti de Castro', 'Boqueirão', '81750-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31909, 'Londrina', 'Santini Gelini', 'Roseira', '86041-715', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31910, 'Almirante Tamandaré', 'Santino de Barros', 'Planta Mosacal', '83513-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31911, 'Curitiba', 'Santinor Pinto da Rocha', 'Boqueirão', '81850-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31912, 'Sarandi', 'Santíssima Trindade', 'Parque Residencial Bom Pastor', '87114-547', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31913, 'Curitiba', 'Santo Adriano', 'Cidade Industrial', '81315-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31914, 'Curitiba', 'Santo Afonso de Ligório', 'Cabral', '82200-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31915, 'Londrina', 'Santo Agostinho', 'Jardim Santo André', '86073-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31916, 'Maringá', 'Santo Agostinho', 'Conjunto Habitacional João de Barro Thaís', '87075-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31917, 'Ponta Grossa', 'Santo Agostinho', 'Uvaranas', '84033-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31918, 'São José dos Pinhais', 'Santo Agostinho', 'Roseira', '83070-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31919, 'Telêmaco Borba', 'Santo Agostinho', 'Área 03', '84271-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31920, 'Cascavel', 'Santo Agostinho', 'Pioneiros Catarinenses', '85805-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31921, 'Apucarana', 'Santo Agostinho', 'Núcleo Habitacional Dom Romeu Alberti', '86806-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31922, 'Curitiba', 'Santo Agostinho', 'Cajuru', '82900-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31923, 'Guarapuava', 'Santo Alberti', 'Boqueirão', '85022-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31924, 'Curitiba', 'Santo Albino', 'Cidade Industrial', '81305-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31925, 'Francisco Beltrão', 'Santo Amaro', 'São Cristóvão', '85601-341', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31926, 'Maringá', 'Santo Amaro', 'Zona 06', '87080-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31927, 'Maringá', 'Santo Amaro', 'Zona 06', '87015-585', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31928, 'Toledo', 'Santo Amaro', 'Boa Esperança', '85909-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31929, 'Almirante Tamandaré', 'Santo Amaro', 'Jardim Monte Santo', '83501-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31930, 'Curitiba', 'Santo Amaro', 'Água Verde', '80620-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31931, 'Umuarama', 'Santo Anastácio', 'Conjunto Residencial Guarani I', '87509-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31932, 'Curitiba', 'Santo Anastácio', 'Cidade Industrial', '81305-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31933, 'Londrina', 'Santo André', 'Champagnat', '86062-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31934, 'Guarapuava', 'Santo André', 'Jardim das Américas', '85031-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31935, 'Umuarama', 'Santo André', 'Jardim São Cristóvão', '87507-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31936, 'Apucarana', 'Santo André', 'Núcleo Habitacional Dom Romeu Alberti', '86806-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31937, 'Curitiba', 'Santo André', 'Cajuru', '82900-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31938, 'Toledo', 'Santo Ângelo', 'Vila Industrial', '85904-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31939, 'Toledo', 'Santo Ângelo', 'Jardim La Salle', '85905-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31940, 'Almirante Tamandaré', 'Santo Ângelo', 'Jardim Monte Santo', '83501-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31941, 'Curitiba', 'Santo Ângelo', 'Cidade Industrial', '81305-035', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31942, 'Ponta Grossa', 'Santo Anselmo', 'Uvaranas', '84033-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31943, 'Londrina', 'Santo Antônio', 'Messiânico', '86065-615', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31944, 'Francisco Beltrão', 'Santo Antônio', 'Cristo Rei', '85602-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31945, 'Laranjeiras do Sul', 'Santo Antônio', 'São Francisco', '85303-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31946, 'Maringá', 'Santo Antônio', 'Vila Santo Antônio', '87030-520', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31947, 'Pato Branco', 'Santo Antônio', 'La Salle', '85505-230', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31948, 'Ponta Grossa', 'Santo Antônio', 'Chapada', '84063-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31949, 'Piraquara', 'Santo Antônio', 'Jardim Santa Mônica', '83302-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31950, 'Paranaguá', 'Santo Antônio', 'Vila do Povo', '83209-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31951, 'Maringá', 'Santo Antônio', 'Zona 07', '87030-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31952, 'Umuarama', 'Santo Antônio', 'Jardim São Cristóvão', '87507-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31953, 'São José dos Pinhais', 'Santo Antônio', 'Roseira', '83070-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31954, 'Toledo', 'Santo Antônio', 'Boa Esperança', '85909-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31955, 'Telêmaco Borba', 'Santo Antônio', 'Bela Vista do Paraíso', '84262-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31956, 'Umuarama', 'Santo Antônio', 'Zona V', '87504-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31957, 'Cambé', 'Santo Antônio', 'Jardim Santa Izabel', '86183-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31958, 'Almirante Tamandaré', 'Santo Antônio', 'Jardim Monte Santo', '83501-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31959, 'Araucária', 'Santo Antônio', 'Centro', '83702-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31960, 'Almirante Tamandaré', 'Santo Antônio', 'Parque São Jorge', '83503-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31961, 'Cambé', 'Santo Antônio', 'Centro', '86181-060', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31962, 'Curitiba', 'Santo Antônio', 'Rebouças', '80230-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31963, 'Ponta Grossa', 'Santo Antônio da Platina', 'Contorno', '84052-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31964, 'Castro', 'Santo Antônio da Platina', 'Vila Santa Cruz', '84168-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31965, 'Curitiba', 'Santo Antônio da Platina', 'Augusta', '81290-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31966, 'Curitiba', 'Santo Antônio do Sudoeste', 'Cidade Industrial', '81310-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31967, 'Curitiba', 'Santo Antônio Tortato', 'Umbará', '81940-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31968, 'Curitiba', 'Santo Beato Otaviano', 'Cajuru', '82930-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31970, 'Ponta Grossa', 'Santo Bruno', 'Chapada', '84063-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31971, 'Toledo', 'Santo Campagnolo', 'Centro', '85905-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31972, 'Cambé', 'Santo Cassaro', 'Parque Residencial Cambé', '86191-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31973, 'Curitiba', 'Santo Celestino Coleto', 'Boa Vista', '82560-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31974, 'Curitiba', 'Santo Celestino Coleto', 'Boa Vista', '82540-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31975, 'Pato Branco', 'Santo Colla', 'Baixada', '85505-145', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31976, 'Colombo', 'Santo Corleto Milani', 'Jardim Palmital', '83408-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31977, 'Londrina', 'Santo Delalibera', 'Portal de Versalhes 3', '86055-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31978, 'Ponta Grossa', 'Santo Egídio', 'Chapada', '84063-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31979, 'Ponta Grossa', 'Santo Emílio', 'Chapada', '84063-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31980, 'Londrina', 'Santo Estevam', 'Lolata', '86039-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31981, 'Foz do Iguaçu', 'Santo Estevão', 'Novo Mundo', '85862-389', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31982, 'Sarandi', 'Santo Estevão', 'Parque Residencial Bom Pastor', '87114-528', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31983, 'Colombo', 'Santo Estevão', 'Jardim Santa Cândida', '83404-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31984, 'Ponta Grossa', 'Santo Fábio', 'Chapada', '84063-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31985, 'Curitiba', 'Santo Fabri', 'Mercês', '80710-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31986, 'Ponta Grossa', 'Santo Fausto', 'Chapada', '84063-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31987, 'Londrina', 'Santo Favoreto', 'Santa Joana', '86044-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31988, 'Francisco Beltrão', 'Santo Felipe', 'São Cristóvão', '85601-342', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31989, 'Francisco Beltrão', 'Santo Fregonese', 'Centro', '85601-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31990, 'Campo Largo', 'Santo Fressato', 'Vila Torres I', '83609-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31991, 'Paranaguá', 'Santo Gabriel', 'Vila do Povo', '83209-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31992, 'Curitiba', 'Santo Garbuio', 'Xaxim', '81710-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31993, 'Umuarama', 'Santo Guerrer', 'Parque Bandeirantes', '87504-678', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31994, 'Curitiba', 'Santo Higino', 'Cidade Industrial', '81315-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31995, 'Ponta Grossa', 'Santo Hilário', 'Chapada', '84063-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31996, 'Curitiba', 'Santo Hilário', 'Cidade Industrial', '81315-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31997, 'Ponta Grossa', 'Santo Hugo', 'Chapada', '84063-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31998, 'Guarapuava', 'Santo Inácio', 'Cascavel', '85025-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (31999, 'Pinhais', 'Santo Inácio', 'Jardim Pedro Demeterco', '83324-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32000, 'Ponta Grossa', 'Santo Inácio', 'Olarias', '84026-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32001, 'Telêmaco Borba', 'Santo Inácio', 'Área 03', '84271-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32002, 'Umuarama', 'Santo Inácio', 'Jardim São Cristóvão', '87507-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32003, 'Apucarana', 'Santo Inácio', 'Núcleo Habitacional Dom Romeu Alberti', '86806-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32004, 'Cascavel', 'Santo Inácio', 'Brasmadeira', '85814-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32005, 'Curitiba', 'Santo Inácio', 'Cidade Industrial', '81310-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32006, 'Francisco Beltrão', 'Santo Inácio de Loyola', 'São Miguel', '85602-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32007, 'Cambé', 'Santo Inácio de Loyola', 'Jardim Santa Izabel', '86183-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32008, 'Curitiba', 'Santo Inácio de Loyola', 'Guabirotuba', '81520-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32009, 'Curitiba', 'Santo Isidoro', 'Cidade Industrial', '81170-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32010, 'Apucarana', 'Santo Jacomini', 'Jardim Cidade Alta', '86803-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32011, 'Londrina', 'Santo Magrini', 'Conjunto Parigot de Souza 1', '86081-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32012, 'Ponta Grossa', 'Santo Mauro', 'Chapada', '84063-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32013, 'Londrina', 'Santo Menegazzo', 'Pantaneiro', '86072-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32014, 'Apucarana', 'Santo Menegazzo', 'Loteamento Santa Cândida', '86802-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32015, 'Francisco Beltrão', 'Santo Onofre', 'Cango', '85604-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32016, 'Pato Branco', 'Santo Onofre', 'Chaparral', '85507-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32017, 'Telêmaco Borba', 'Santo Onofre', 'Área 03', '84271-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32018, 'Cascavel', 'Santo Onofre', 'Santo Onofre', '85806-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32019, 'Curitiba', 'Santo Osvaldo', 'Cidade Industrial', '81305-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32020, 'Pato Branco', 'Santo Parzianello', 'Vila Isabel', '85504-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32021, 'Colombo', 'Santo Pascoal Franceschi', 'Jardim Osasco', '83403-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32022, 'Foz do Iguaçu', 'Santo Rafagnin', 'Vila Portes', '85865-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32023, 'Curitiba', 'Santo Rodrigues de Almeida', 'Santa Cândida', '82720-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32024, 'Ponta Grossa', 'Santo Rômulo', 'Chapada', '84063-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32025, 'Londrina', 'Santo Tamioso', 'Conjunto Habitacional José Giordano', '86082-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32026, 'Apucarana', 'Santo Tomás de Aquino', 'Núcleo Habitacional Dom Romeu Alberti', '86806-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32027, 'Curitiba', 'Santo Túlio', 'Santa Felicidade', '82320-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32028, 'Curitiba', 'Santo Ulrico', 'Cidade Industrial', '81305-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32029, 'Ponta Grossa', 'Santo Valério', 'Chapada', '84063-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32030, 'Curitiba', 'Santo Zonatto', 'São João', '82030-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32031, 'Londrina', 'Santos', 'Centro', '86020-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32032, 'Foz do Iguaçu', 'Santos', 'Jardim Canadá', '85861-290', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32033, 'Londrina', 'Santos', 'Centro', '86020-041', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32034, 'Pato Branco', 'Santos', 'São Roque', '85507-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32035, 'Cambé', 'Santos', 'Vila Salomé', '86192-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32036, 'Ponta Grossa', 'Santos Andrade', 'Centro', '84010-790', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32037, 'Sarandi', 'Santos Andrade', 'Jardim Panorama', '87113-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32038, 'Curitiba', 'Santos Andrade', 'Centro', '80020-300', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32039, 'Laranjeiras do Sul', 'Santos Dumont', 'Água Verde', '85302-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32040, 'Laranjeiras do Sul', 'Santos Dumont', 'Centro', '85301-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32041, 'Laranjeiras do Sul', 'Santos Dumont', 'São Francisco', '85303-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32042, 'Foz do Iguaçu', 'Santos Dumont', 'Centro', '85851-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32043, 'Londrina', 'Santos Dumont', 'Boa Vista', '86039-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32044, 'Guarapuava', 'Santos Dumont', 'Vila Carli', '85040-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32045, 'Maringá', 'Santos Dumont', 'Zona 01', '87013-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32046, 'Maringá', 'Santos Dumont', 'Zona 03', '87050-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32047, 'Ponta Grossa', 'Santos Dumont', 'Centro', '84010-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32048, 'Pato Branco', 'Santos Dumont', 'Chaparral', '85507-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32049, 'Umuarama', 'Santos Dumont', 'Zona I', '87501-260', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32050, 'Toledo', 'Santos Dumont', 'Centro', '85900-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32051, 'Sarandi', 'Santos Dumont', 'Jardim Independência II', '87113-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32052, 'Toledo', 'Santos Dumont', 'Jardim Planalto', '85904-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32053, 'Telêmaco Borba', 'Santos Dumont', 'Centro', '84261-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32054, 'Toledo', 'Santos Dumont', 'Centro', '85905-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32055, 'Araucária', 'Santos Dumont', 'Centro', '83702-000', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32056, 'Castro', 'Santos Dumont', 'Vila Rio Branco', '84172-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32057, 'Cascavel', 'Santos Dumont', 'Região do Lago 1', '85812-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32058, 'Campo Largo', 'Santos Dumont', 'Jardim Bela Vista', '83609-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32059, 'Campo Largo', 'Santos Dumont', 'Vila Operária', '83601-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32060, 'Campo Mourão', 'Santos Dumont', 'Centro', '87300-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32061, 'Almirante Tamandaré', 'Santos Dumont', 'Jardim São Carlos', '83507-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32062, 'Cambé', 'Santos Dumont', 'Parque Residencial Manela', '86185-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32063, 'Colombo', 'Santos Dumont', 'Jardim Santa Fé', '83403-500', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32064, 'Colombo', 'Santos Dumont', 'Planta Bom Jesus', '83404-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32065, 'Apucarana', 'Santos Dumont', 'Vila Shangri-La', '86812-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32066, 'Campo Mourão', 'Santos Dumont', 'Centro', '87303-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32067, 'Curitiba', 'Santos Dumont', 'Centro', '80410-190', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32068, 'Cambé', 'Santos Futebol Club', 'Conjunto Habitacional Collor de Melo', '86188-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32069, 'Curitiba', 'Santos Possolli', 'Tatuquara', '81940-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32070, 'Umuarama', 'Santos Reis Magos', 'Conjunto Residencial Independência', '87508-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32071, 'Almirante Tamandaré', 'São Bartolomeu', 'Jardim Monte Santo', '83501-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32072, 'Apucarana', 'São Bartolomeu', 'Núcleo Habitacional Dom Romeu Alberti', '86806-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32073, 'Curitiba', 'São Bartolomeu', 'Cajuru', '82900-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32074, 'Curitiba', 'São Basílio Magno', 'Seminário', '80440-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32075, 'Londrina', 'São Benedito', 'Jardim Santo André', '86073-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32076, 'Laranjeiras do Sul', 'São Benedito', 'São Francisco', '85303-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32077, 'Francisco Beltrão', 'São Benedito', 'Cango', '85604-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32078, 'Maringá', 'São Benedito', 'Vila Esperança', '87020-760', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32079, 'Cambé', 'São Benedito', 'Jardim Santa Izabel', '86183-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32080, 'Almirante Tamandaré', 'São Benedito', 'Jardim Monte Santo', '83501-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32081, 'Curitiba', 'São Benedito', 'Ahú', '80540-060', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32082, 'São José dos Pinhais', 'São Bento', 'Guatupê', '83065-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32083, 'Colombo', 'São Bento', 'Planta Vila Nova', '83404-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32084, 'Almirante Tamandaré', 'São Bento', 'Jardim Monte Santo', '83501-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32085, 'Curitiba', 'São Bento', 'Hauer', '81610-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32086, 'Curitiba', 'São Bento', 'Hauer', '81630-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32087, 'Almirante Tamandaré', 'São Bernardo', 'Jardim Monte Santo', '83501-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32088, 'Londrina', 'São Bernardo do Campo', 'Sumaré', '86062-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32089, 'Curitiba', 'São Bonifácio', 'Cidade Industrial', '81305-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32090, 'Piraquara', 'São Borja', 'Jardim Tropical', '83314-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32091, 'Cascavel', 'São Borja', 'Canadá', '85813-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32092, 'Curitiba', 'São Brás', 'Cidade Industrial', '81305-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32093, 'Telêmaco Borba', 'São Braz', 'Área 03', '84271-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32094, 'Londrina', 'São Caetano do Sul', 'Champagnat', '86062-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32095, 'Ponta Grossa', 'São Camilo', 'Chapada', '84063-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32096, 'Londrina', 'São Carlos', 'Sumaré', '86062-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32097, 'Francisco Beltrão', 'São Carlos', 'Cristo Rei', '85602-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32098, 'Ponta Grossa', 'São Carlos', 'Chapada', '84063-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32099, 'Campo Mourão', 'São Carlos', 'Jardim Flórida', '87300-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32100, 'Almirante Tamandaré', 'São Carlos', 'Jardim Monte Santo', '83501-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32101, 'Apucarana', 'São Carlos', 'Vila Apucaraninha', '86801-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32102, 'Curitiba', 'São Carlos', 'Santa Felicidade', '82410-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32103, 'Ponta Grossa', 'São Carlos do Ivai', 'Contorno', '84052-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32104, 'Londrina', 'São Cipriano', 'Jardim Santo André', '86073-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32105, 'Apucarana', 'São Clemente', 'Núcleo Habitacional Dom Romeu Alberti', '86806-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32106, 'Curitiba', 'São Clemente Hofbauer', 'Cidade Industrial', '81450-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32107, 'Paranaguá', 'São Cosme e Damião', 'Parque São João', '83212-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32108, 'Francisco Beltrão', 'São Cristóvão', 'Pinheirinho', '85603-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32109, 'Francisco Beltrão', 'São Cristóvão', 'São Cristóvão', '85601-710', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32110, 'Londrina', 'São Cristóvão', 'Jardim Santo André', '86073-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32111, 'Paranavaí', 'São Cristóvão', 'Jardim Santos Dumont', '87706-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32112, 'Maringá', 'São Cristóvão', 'Zona 08', '87050-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32113, 'Ponta Grossa', 'São Cristóvão', 'Uvaranas', '84033-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32114, 'São José dos Pinhais', 'São Cristóvão', 'Cidade Jardim', '83035-210', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32115, 'Curitiba', 'São Cristóvão', 'Guaíra', '80630-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32117, 'Sarandi', 'São Dimas', 'Parque Residencial Bom Pastor', '87114-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32118, 'Maringá', 'São Domingos', 'Vila Morangueira', '87040-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32119, 'Curitiba', 'São Domingos', 'Pilarzinho', '82100-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32120, 'Curitiba', 'São Domingos Savio', 'Cidade Industrial', '81170-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32121, 'Ponta Grossa', 'São Domingos Savio', 'Olarias', '84026-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32122, 'Sarandi', 'São Felipe', 'Parque Residencial Bom Pastor', '87114-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32123, 'Apucarana', 'São Felipe', 'Núcleo Habitacional Dom Romeu Alberti', '86806-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32124, 'Curitiba', 'São Felipe', 'Cajuru', '82900-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32125, 'Almirante Tamandaré', 'São Félix', 'Jardim Monte Santo', '83501-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32126, 'Almirante Tamandaré', 'São Fermino', 'Jardim Monte Santo', '83501-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32127, 'Guarapuava', 'São Francisco', 'São Cristóvão', '85060-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32128, 'Francisco Beltrão', 'São Francisco', 'São Miguel', '85602-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32129, 'Guarapuava', 'São Francisco', 'Conradinho', '85055-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32130, 'Foz do Iguaçu', 'São Francisco', 'Loteamento Campos do Iguaçu', '85857-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32131, 'Foz do Iguaçu', 'São Francisco', 'Conjunto C', '85870-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32132, 'Piraquara', 'São Francisco', 'Planta Guarituba Pequena', '83310-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32133, 'Pato Branco', 'São Francisco', 'Sudoeste', '85507-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32134, 'São José dos Pinhais', 'São Francisco', 'Guatupê', '83065-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32135, 'Sarandi', 'São Francisco', 'Jardim Califórnia', '87112-505', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32136, 'Umuarama', 'São Francisco', 'Jardim São Cristóvão', '87507-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32137, 'São José dos Pinhais', 'São Francisco', 'São Sebastião', '83075-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32138, 'Toledo', 'São Francisco', 'Jardim Porto Alegre', '85906-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32139, 'Colombo', 'São Francisco', 'Colônia Faria', '83411-520', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32140, 'Araucária', 'São Francisco', 'Centro', '83702-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32141, 'Almirante Tamandaré', 'São Francisco', 'Jardim Monte Santo', '83501-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32142, 'Curitiba', 'São Francisco', 'Centro', '80020-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32143, 'Francisco Beltrão', 'São Francisco de Assis', 'Guanabara', '85604-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32144, 'Londrina', 'São Francisco de Assis', 'Jardim Agari', '86020-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32145, 'Londrina', 'São Francisco de Assis', 'Sabará III', '86067-135', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32146, 'Pato Branco', 'São Francisco de Assis', 'Planalto', '85509-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32147, 'Ponta Grossa', 'São Francisco de Assis', 'Uvaranas', '84031-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32148, 'Sarandi', 'São Francisco de Assis', 'Parque Residencial Bom Pastor', '87114-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32149, 'Umuarama', 'São Francisco de Assis', 'Zona IV', '87504-025', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32150, 'Telêmaco Borba', 'São Francisco de Assis', 'Área 03', '84271-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32151, 'Cambé', 'São Francisco de Assis', 'Jardim Santa Izabel', '86183-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32152, 'Cascavel', 'São Francisco de Assis', 'Pioneiros Catarinenses', '85805-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32153, 'Curitiba', 'São Francisco de Assis', 'Tarumã', '82530-220', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32154, 'Guarapuava', 'São Francisco de Paula', 'Morro Alto', '85067-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32155, 'Curitiba', 'São Francisco de Sales', 'Alto Boqueirão', '81720-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32156, 'Toledo', 'São Francisco Falso', 'Jardim Porto Alegre', '85910-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32157, 'Toledo', 'São Francisco Falso', 'Panorama', '85911-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32158, 'Colombo', 'São Francisco Xavier', 'Jardim Nossa Senhora de Fátima', '83405-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32159, 'Curitiba', 'São Francisco Xavier', 'Pilarzinho', '82100-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32160, 'Francisco Beltrão', 'São Gabriel', 'São Miguel', '85602-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32161, 'Piraquara', 'São Gabriel', 'Jardim Santa Mônica', '83302-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32162, 'Almirante Tamandaré', 'São Gabriel', 'Parque São Jorge', '83503-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32163, 'Cascavel', 'São Gabriel', 'Brasília', '85815-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32164, 'Cascavel', 'São Gabriel', 'São Cristóvão', '85816-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32165, 'Almirante Tamandaré', 'São Gabriel', 'Jardim Monte Santo', '83501-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32166, 'Curitiba', 'São Gabriel', 'Cajuru', '82900-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32167, 'Curitiba', 'São Genaro', 'Cidade Industrial', '81450-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32168, 'Curitiba', 'São Geraldo', 'Pilarzinho', '82120-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32169, 'Curitiba', 'São Geraldo Majella', 'Cidade Industrial', '81260-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32170, 'Telêmaco Borba', 'São Gerônimo', 'Área 03', '84271-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32171, 'Almirante Tamandaré', 'São Gerônimo', 'Jardim Monte Santo', '83501-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32172, 'Londrina', 'São Gonçalo', 'Jardim Santo André', '86073-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32173, 'Colombo', 'São Gonçalo Amarante', 'Jardim Nossa Senhora de Fátima', '83405-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32174, 'Curitiba', 'São Gregório X', 'Cidade Industrial', '81315-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32175, 'Foz do Iguaçu', 'São Januário', 'Parque Morumbi II', '85859-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32176, 'Foz do Iguaçu', 'São Januário', 'Parque Morumbi II', '85858-727', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32177, 'Almirante Tamandaré', 'São Januário', 'Jardim Monte Santo', '83501-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32178, 'Curitiba', 'São Januário', 'Jardim Botânico', '80210-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32179, 'Apucarana', 'São Jeremias', 'Núcleo Habitacional Dom Romeu Alberti', '86806-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32180, 'Londrina', 'São Jerônimo', 'Centro', '86010-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32181, 'Apucarana', 'São Jerônimo', 'Barra Funda', '86800-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32182, 'Campo Largo', 'São Jerônimo', 'Vila David Antônio', '83609-340', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32183, 'Ponta Grossa', 'São Jerônimo da Serra', 'Nova Rússia', '84053-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32184, 'Curitiba', 'São Jerônimo da Serra', 'Santa Cândida', '82650-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32185, 'Curitiba', 'São Jerônimo Emiliano', 'Cidade Industrial', '81315-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32186, 'Francisco Beltrão', 'São João', 'Guanabara', '85604-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32187, 'Guarapuava', 'São João', 'São Cristóvão', '85060-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32188, 'Guarapuava', 'São João', 'Batel', '85015-320', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32189, 'Laranjeiras do Sul', 'São João', 'São Francisco', '85303-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32190, 'Maringá', 'São João', 'Zona 07', '87030-201', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32191, 'Maringá', 'São João', 'Zona 07', '87030-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32192, 'Ponta Grossa', 'São João', 'Chapada', '84063-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32193, 'Londrina', 'São João', 'Imperial', '86039-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32194, 'Londrina', 'São João', 'Antares', '86036-030', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32195, 'Toledo', 'São João', 'Centro', '85900-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32196, 'Umuarama', 'São João', 'Jardim São Cristóvão', '87507-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32197, 'Toledo', 'São João', 'Vila Industrial', '85905-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32198, 'Sarandi', 'São João', 'Parque Residencial Santana', '87112-578', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32199, 'Telêmaco Borba', 'São João', 'Área 03', '84271-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32200, 'São José dos Pinhais', 'São João', 'Roseira', '83070-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32201, 'Almirante Tamandaré', 'São João', 'Parque São Jorge', '83503-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32202, 'Almirante Tamandaré', 'São João', 'Jardim Monte Santo', '83501-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32203, 'Colombo', 'São João', 'São João', '83415-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32204, 'Almirante Tamandaré', 'São João', 'Planta São João', '83514-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32205, 'Almirante Tamandaré', 'São João', 'Planta Almirante', '83508-390', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32206, 'Cascavel', 'São João', 'Claudete', '85807-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32207, 'Apucarana', 'São João', 'Jardim Apucarana', '86804-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32208, 'Cambé', 'São João', 'Vila Atalaia', '86181-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32209, 'Curitiba', 'São João', 'Tingui', '82620-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32210, 'Sarandi', 'São João Batista', 'Parque Residencial Bom Pastor', '87114-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32211, 'Colombo', 'São João Batista', 'Jardim Nossa Senhora de Fátima', '83405-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32212, 'Curitiba', 'São João Bosco', 'Cidade Industrial', '81305-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32213, 'Curitiba', 'São João de Brito', 'Alto Boqueirão', '81830-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32214, 'Telêmaco Borba', 'São João Del Rey', 'Área 06', '84271-460', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32215, 'Ponta Grossa', 'São João do Caiua', 'Contorno', '84052-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32216, 'Apucarana', 'São João do Ivai', 'Núcleo Habitacional Nossa Senhora Aparecida', '86801-409', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32217, 'Curitiba', 'São João do Ivai', 'Xaxim', '81810-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32218, 'Guarapuava', 'São João do Triunfo', 'Boqueirão', '85020-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32219, 'Ponta Grossa', 'São João do Triunfo', 'Oficinas', '84036-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32220, 'São José dos Pinhais', 'São João do Triunfo', 'São Pedro', '83020-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32221, 'Telêmaco Borba', 'São João do Triunfo', 'Bela Vista do Paraíso', '84262-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32222, 'Curitiba', 'São João do Triunfo', 'São Braz', '82315-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32223, 'Curitiba', 'São João Eudes', 'Cajuru', '82930-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32224, 'Curitiba', 'São João Evangelista', 'Campina do Siqueira', '80740-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32225, 'Curitiba', 'São João Maria Vianney', 'Cidade Industrial', '81450-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32226, 'Curitiba', 'São João Nepomuceno Neumann', 'Cidade Industrial', '81260-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32227, 'Francisco Beltrão', 'São Joaquim', 'Cristo Rei', '85602-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32228, 'Campo Largo', 'São Joaquim', 'Jardim Carmela', '83607-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32229, 'Cascavel', 'São Joaquim', 'Morumbi', '85817-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32230, 'Colombo', 'São Joaquim', 'Vila Alto da Cruz II', '83405-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32231, 'Almirante Tamandaré', 'São Joaquim', 'Parque São Jorge', '83503-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32232, 'Almirante Tamandaré', 'São Joaquim', 'Jardim Monte Santo', '83501-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32233, 'Curitiba', 'São Joaquim', 'Jardim Botânico', '80210-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32234, 'Francisco Beltrão', 'São Jorge', 'Jardim Santa Fé', '85602-216', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32235, 'Londrina', 'São Jorge', 'Jardim Santo André', '86073-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32236, 'Guarapuava', 'São Jorge', 'São Cristóvão', '85060-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32237, 'Foz do Iguaçu', 'São Jorge', 'Parque Morumbi II', '85859-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32238, 'Ponta Grossa', 'São Jorge', 'Contorno', '84052-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32239, 'Paranavaí', 'São Jorge', 'Jardim Avaré', '87709-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32240, 'Maringá', 'São Jorge', 'Jardim Novo Horizonte', '87010-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32241, 'São José dos Pinhais', 'São Jorge', 'Roseira', '83070-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32242, 'Telêmaco Borba', 'São Jorge', 'Jardim Bom Jesus', '84262-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32243, 'Umuarama', 'São Jorge', 'Jardim São Cristóvão', '87507-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32244, 'Umuarama', 'São Jorge', 'Zona VII', '87503-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32245, 'Toledo', 'São Jorge', 'Boa Esperança', '85909-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32246, 'Apucarana', 'São Jorge', 'Núcleo Habitacional Dom Romeu Alberti', '86806-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32247, 'Campo Largo', 'São Jorge', 'Vila David Antônio', '83609-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32248, 'Almirante Tamandaré', 'São Jorge', 'Jardim Monte Santo', '83501-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32249, 'Almirante Tamandaré', 'São Jorge', 'Parque São Jorge', '83503-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32250, 'Castro', 'São Jorge', 'Jardim Bela Vista', '84165-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32251, 'Curitiba', 'São Jorge', 'Xaxim', '81710-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32252, 'Curitiba', 'São Jorge do Oeste', 'Cidade Industrial', '81260-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32253, 'Ponta Grossa', 'São Josafat', 'Nova Rússia', '84053-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32254, 'Campo Mourão', 'São Josafat', 'Centro', '87302-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32255, 'Campo Mourão', 'São Josafat', 'Jardim Capricórnio', '87301-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32256, 'Londrina', 'São José', 'Jardim Santo André', '86073-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32257, 'Francisco Beltrão', 'São José', 'Guanabara', '85604-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32258, 'Laranjeiras do Sul', 'São José', 'São Francisco', '85303-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32259, 'Ponta Grossa', 'São José', 'Uvaranas', '84025-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32260, 'Paranavaí', 'São José', 'Jardim São Jorge', '87710-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32261, 'Maringá', 'São José', 'Jardim Laodiceia', '87014-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32262, 'Pato Branco', 'São José', 'Sudoeste', '85507-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32263, 'Ponta Grossa', 'São José', 'Chapada', '84063-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32264, 'Piraquara', 'São José', 'Jardim Primavera', '83302-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32265, 'Piraquara', 'São José', 'Planta Guarituba Pequena', '83310-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32266, 'São José dos Pinhais', 'São José', 'São Cristóvão', '83040-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32267, 'Toledo', 'São José', 'Boa Esperança', '85909-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32268, 'Umuarama', 'São José', 'Jardim São Cristóvão', '87507-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32269, 'Apucarana', 'São José', 'Núcleo Habitacional Dom Romeu Alberti', '86806-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32270, 'Araucária', 'São José', 'Iguaçu', '83701-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32271, 'Cascavel', 'São José', 'Claudete', '85807-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32272, 'Colombo', 'São José', 'Planta Vila Nova', '83404-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32273, 'Almirante Tamandaré', 'São José', 'Jardim Monte Santo', '83501-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32274, 'Campo Mourão', 'São José', 'Jardim Flórida', '87300-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32275, 'Cambé', 'São José', 'Jardim Santa Izabel', '86183-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32276, 'Campo Mourão', 'São José', 'Centro', '87303-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32277, 'Almirante Tamandaré', 'São José', 'Parque São Jorge', '83503-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32278, 'Curitiba', 'São José', 'Cristo Rei', '80050-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32279, 'Curitiba', 'São José da Boa Vista', 'São Braz', '82315-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32280, 'Curitiba', 'São José de Arimateia', 'Sítio Cercado', '81910-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32281, 'Ponta Grossa', 'São José de Calazans', 'Cará-cará', '84033-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32282, 'Curitiba', 'São José de Calazans', 'Santa Felicidade', '82410-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32283, 'Guarapuava', 'São José dos Pinhais', 'Jardim das Américas', '85030-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32284, 'Ponta Grossa', 'São José dos Pinhais', 'Oficinas', '84036-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32285, 'Almirante Tamandaré', 'São José dos Pinhais', 'Jardim Roma', '83504-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32286, 'Curitiba', 'São José dos Pinhais', 'Sítio Cercado', '81910-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32287, 'Curitiba', 'São José dos Pinhais', 'Sítio Cercado', '81920-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32288, 'Sarandi', 'São José Operário', 'Parque Residencial Bom Pastor', '87114-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32289, 'Francisco Beltrão', 'São Judas Tadeu', 'Guanabara', '85604-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32290, 'Maringá', 'São Judas Tadeu', 'Parque Palmeiras', '87023-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32291, 'Ponta Grossa', 'São Judas Tadeu', 'Uvaranas', '84033-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32292, 'Pinhais', 'São Judas Tadeu', 'Planta Guilherme Weiss', '83322-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32293, 'Umuarama', 'São Judas Tadeu', 'Parque Dom Pedro II', '87508-059', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32294, 'Toledo', 'São Judas Tadeu', 'Jardim Planalto', '85904-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32295, 'Sarandi', 'São Judas Tadeu', 'Parque Residencial Bom Pastor', '87114-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32296, 'Cambé', 'São Judas Tadeu', 'Jardim Santa Izabel', '86183-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32297, 'Araucária', 'São Judas Tadeu', 'Fazenda Velha', '83703-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32298, 'Almirante Tamandaré', 'São Judas Tadeu', 'Jardim Monte Santo', '83501-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32299, 'Apucarana', 'São Judas Tadeu', 'Núcleo Habitacional Dom Romeu Alberti', '86806-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32300, 'Almirante Tamandaré', 'São Judas Tadeu', 'Parque São Jorge', '83503-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32301, 'Curitiba', 'São Judas Tadeu', 'Capão Raso', '81020-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32302, 'Sarandi', 'São Lázaro', 'Parque Residencial Bom Pastor', '87114-567', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32303, 'Francisco Beltrão', 'São Leopoldo', 'Cango', '85603-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32304, 'Piraquara', 'São Leopoldo', 'Jardim Tropical', '83314-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32305, 'Telêmaco Borba', 'São Leopoldo', 'Área 03', '84271-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32306, 'Apucarana', 'São Leopoldo', 'Núcleo Habitacional Dom Romeu Alberti', '86806-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32307, 'Almirante Tamandaré', 'São Leopoldo', 'Jardim Monte Santo', '83501-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32308, 'Curitiba', 'São Leopoldo', 'Seminário', '80310-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32309, 'Curitiba', 'São Leopoldo Mandic', 'Cidade Industrial', '81170-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32310, 'Maringá', 'São Lourenço', 'Jardim Alvorada', '87033-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32311, 'Laranjeiras do Sul', 'São Lucas', 'São Francisco', '85303-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32312, 'Londrina', 'São Lucas', 'Vila Siam', '86039-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32313, 'Francisco Beltrão', 'São Lucas', 'São Miguel', '85602-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32314, 'Ponta Grossa', 'São Lucas', 'Centro', '84010-285', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32315, 'São José dos Pinhais', 'São Lucas', 'Roseira', '83070-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32316, 'Umuarama', 'São Lucas', 'Jardim São Cristóvão', '87507-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32317, 'Almirante Tamandaré', 'São Lucas', 'Jardim Monte Santo', '83501-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32318, 'Cascavel', 'São Lucas', 'Claudete', '85807-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32319, 'Apucarana', 'São Lucas', 'Núcleo Habitacional Dom Romeu Alberti', '86806-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32320, 'Curitiba', 'São Lucas', 'Barreirinha', '82560-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32321, 'Curitiba', 'São Luciano', 'Cidade Industrial', '81315-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32322, 'Guarapuava', 'São Luís', 'Conradinho', '85055-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32323, 'Maringá', 'São Luís', 'Vila Morangueira', '87040-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32324, 'Colombo', 'São Luís', 'Jardim Nossa Senhora de Fátima', '83405-260', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32325, 'Londrina', 'São Luiz', 'Vila Shima Bokuro', '86020-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32326, 'Foz do Iguaçu', 'São Luiz', 'Conjunto C', '85870-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32327, 'Foz do Iguaçu', 'São Luiz', 'Jardim Ipê II', '85869-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32328, 'Laranjeiras do Sul', 'São Luiz', 'São Francisco', '85303-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32329, 'Francisco Beltrão', 'São Luiz', 'Jardim Santa Fé', '85602-217', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32330, 'Ponta Grossa', 'São Luiz', 'Chapada', '84063-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32331, 'Telêmaco Borba', 'São Luiz', 'Vila Santa Rita', '84263-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32332, 'Telêmaco Borba', 'São Luiz', 'Macopa', '84263-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32333, 'Umuarama', 'São Luiz', 'Jardim São Cristóvão', '87507-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32334, 'Umuarama', 'São Luiz', 'Zona V', '87504-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32335, 'São José dos Pinhais', 'São Luiz', 'Águas Belas', '83010-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32336, 'Almirante Tamandaré', 'São Luiz', 'Jardim Monte Santo', '83501-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32337, 'Araucária', 'São Luiz', 'Estação', '83705-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32338, 'Campo Mourão', 'São Luiz', 'Jardim Tropical II', '87310-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32339, 'Cascavel', 'São Luiz', 'Cancelli', '85811-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32340, 'Cascavel', 'São Luiz', 'Recanto Tropical', '85807-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32341, 'Curitiba', 'São Luiz', 'Cabral', '80035-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32342, 'Curitiba', 'São Macário', 'Cidade Industrial', '81250-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32343, 'Almirante Tamandaré', 'São Manoel', 'Jardim Monte Santo', '83501-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32344, 'Almirante Tamandaré', 'São Manoel', 'Parque São Jorge', '83503-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32345, 'Apucarana', 'São Manoel', 'Vila Regina', '86801-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32346, 'Almirante Tamandaré', 'São Marcelino', 'Parque São Jorge', '83503-280', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32347, 'Maringá', 'São Marcelino Champagnat', 'Zona 02', '87010-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32348, 'Londrina', 'São Marcos', 'Vila Siam', '86039-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32349, 'Francisco Beltrão', 'São Marcos', 'Guanabara', '85604-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32350, 'Foz do Iguaçu', 'São Marcos', 'Vila São João', '85862-376', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32351, 'Pinhais', 'São Marcos', 'Planta Bairro Weissópolis', '83322-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32352, 'Ponta Grossa', 'São Marcos', 'Chapada', '84063-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32353, 'Umuarama', 'São Marcos', 'Jardim São Cristóvão', '87507-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32354, 'Apucarana', 'São Marcos', 'Núcleo Habitacional Dom Romeu Alberti', '86806-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32355, 'Cascavel', 'São Marcos', 'Claudete', '85807-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32356, 'Almirante Tamandaré', 'São Marcos', 'Jardim Monte Santo', '83501-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32357, 'Almirante Tamandaré', 'São Marcos', 'Parque São Jorge', '83503-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32358, 'Curitiba', 'São Marino', 'Cidade Industrial', '81305-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32359, 'Ponta Grossa', 'São Mário', 'Chapada', '84063-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32360, 'Almirante Tamandaré', 'São Martin', 'Parque São Jorge', '83503-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32361, 'Londrina', 'São Mateus', 'Vila Siam', '86039-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32362, 'Francisco Beltrão', 'São Mateus', 'Industrial', '85601-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32363, 'Maringá', 'São Mateus', 'Jardim Laodiceia', '87014-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32364, 'Umuarama', 'São Mateus', 'Zona V', '87504-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32365, 'Apucarana', 'São Mateus', 'Núcleo Habitacional Dom Romeu Alberti', '86806-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32366, 'Almirante Tamandaré', 'São Mateus', 'Jardim Monte Santo', '83501-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32367, 'Curitiba', 'São Mateus', 'Portão', '81070-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32368, 'Guarapuava', 'São Mateus do Sul', 'Boqueirão', '85020-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32369, 'São José dos Pinhais', 'São Mateus do Sul', 'São Cristóvão', '83005-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32370, 'Toledo', 'São Matheus', 'Conjunto Habitacional São Francisco', '85915-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32371, 'Ponta Grossa', 'São Matheus do Sul', 'Contorno', '84052-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32372, 'Curitiba', 'São Matias', 'Cidade Industrial', '81250-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32373, 'Londrina', 'São Miguel', 'Jardim Santo André', '86073-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32374, 'Francisco Beltrão', 'São Miguel', 'São Miguel', '85602-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32375, 'Foz do Iguaçu', 'São Miguel', 'Jardim Curitibano III', '85869-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32376, 'Pato Branco', 'São Miguel', 'Sudoeste', '85507-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32377, 'Telêmaco Borba', 'São Miguel', 'Jardim Bom Jesus', '84262-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32378, 'Umuarama', 'São Miguel', 'Jardim São Cristóvão', '87507-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32379, 'Toledo', 'São Miguel', 'Boa Esperança', '85909-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32380, 'Apucarana', 'São Miguel', 'Núcleo Habitacional Dom Romeu Alberti', '86806-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32381, 'Araucária', 'São Miguel', 'São Miguel', '83707-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32382, 'Campo Largo', 'São Miguel', 'Vila David Antônio', '83609-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32383, 'Almirante Tamandaré', 'São Miguel', 'Jardim Monte Santo', '83501-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32384, 'Almirante Tamandaré', 'São Miguel', 'Parque São Jorge', '83503-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32385, 'Curitiba', 'São Miguel do Iguaçu', 'São Braz', '82315-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32386, 'Curitiba', 'São Miguel do Oeste', 'Cidade Industrial', '81240-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32387, 'Curitiba', 'São Miguel Febres Cordeiro', 'Cidade Industrial', '81305-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32388, 'Ponta Grossa', 'São Nicola', 'Chapada', '84063-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32389, 'Umuarama', 'São Nicolau', 'Jardim São Cristóvão', '87507-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32390, 'Foz do Iguaçu', 'São Paulo', 'Conjunto C', '85870-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32391, 'Londrina', 'São Paulo', 'Centro', '86010-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32392, 'Francisco Beltrão', 'São Paulo', 'Centro', '85601-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32393, 'Laranjeiras do Sul', 'São Paulo', 'Água Verde', '85302-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32394, 'Guarapuava', 'São Paulo', 'Dos Estados', '85035-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32395, 'Laranjeiras do Sul', 'São Paulo', 'São Francisco', '85303-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32396, 'Maringá', 'São Paulo', 'Zona 01', '87013-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32397, 'Piraquara', 'São Paulo', 'Jardim dos Estados 3', '83307-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32398, 'Piraquara', 'São Paulo', 'Jardim dos Estados 1', '83308-400', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32399, 'Ponta Grossa', 'São Paulo', 'Chapada', '84063-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32400, 'Pato Branco', 'São Paulo', 'São Roque', '85507-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32401, 'Paranaguá', 'São Paulo', 'Vila do Povo', '83209-639', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32402, 'Ponta Grossa', 'São Paulo', 'Uvaranas', '84025-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32403, 'Maringá', 'São Paulo', 'Zona 07', '87030-025', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32404, 'Paranavaí', 'São Paulo', 'Jardim Nakamura', '87701-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32405, 'Piraquara', 'São Paulo', 'Jardim dos Estados 2', '83308-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32406, 'Telêmaco Borba', 'São Paulo', 'Vila Ana Mari', '84263-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32407, 'Toledo', 'São Paulo', 'Jardim Porto Alegre', '85906-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32408, 'Umuarama', 'São Paulo', 'Zona II', '87501-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32409, 'Telêmaco Borba', 'São Paulo', 'Nossa Senhora de Fátima', '84264-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32410, 'São José dos Pinhais', 'São Paulo', 'São Domingos', '83030-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32411, 'Campo Mourão', 'São Paulo', 'Jardim Country Club', '87300-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32412, 'Araucária', 'São Paulo', 'Iguaçu', '83701-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32413, 'Apucarana', 'São Paulo', 'Vila Feliz', '86808-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32414, 'Campo Largo', 'São Paulo', 'Jardim Esmeralda', '83604-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32415, 'Almirante Tamandaré', 'São Paulo', 'Parque São Jorge', '83503-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32416, 'Campo Largo', 'São Paulo', 'Jardim Boa Vista', '83609-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32417, 'Campo Mourão', 'São Paulo', 'Centro', '87303-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32418, 'Cascavel', 'São Paulo', 'Centro', '85801-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32419, 'Cascavel', 'São Paulo', 'Centro', '85801-021', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32420, 'Colombo', 'São Paulo', 'Vila Guaraci', '83404-270', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32421, 'Cambé', 'São Paulo', 'Centro', '86181-250', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32422, 'Almirante Tamandaré', 'São Paulo', 'Jardim Monte Santo', '83501-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32423, 'Curitiba', 'São Paulo', 'Guaíra', '80630-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32424, 'Curitiba', 'São Paulo', 'Água Verde', '80610-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32425, 'Sarandi', 'São Paulo Apóstolo', 'Parque Residencial Bom Pastor', '87114-551', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32426, 'Ponta Grossa', 'São Paulo da Cruz', 'Boa Vista', '84072-008', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32427, 'Curitiba', 'São Paulo da Cruz', 'Juvevê', '80030-480', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32428, 'Cambé', 'São Paulo Futebol Club', 'Conjunto Habitacional Collor de Melo', '86188-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32429, 'Curitiba', 'São Paulo Miki', 'Cidade Industrial', '81315-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32430, 'Londrina', 'São Pedro', 'Vila Siam', '86039-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32431, 'Laranjeiras do Sul', 'São Pedro', 'São Francisco', '85303-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32432, 'Francisco Beltrão', 'São Pedro', 'Guanabara', '85604-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32433, 'Guarapuava', 'São Pedro', 'São Cristóvão', '85060-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32434, 'Maringá', 'São Pedro', 'Zona 07', '87030-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32435, 'Pato Branco', 'São Pedro', 'Sudoeste', '85507-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32436, 'Maringá', 'São Pedro', 'Zona 07', '87030-211', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32437, 'Toledo', 'São Pedro', 'Boa Esperança', '85909-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32438, 'Umuarama', 'São Pedro', 'Jardim São Cristóvão', '87507-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32439, 'Umuarama', 'São Pedro', 'Zona III', '87502-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32440, 'Apucarana', 'São Pedro', 'Jardim São José', '86809-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32441, 'Almirante Tamandaré', 'São Pedro', 'Parque São Jorge', '83503-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32442, 'Almirante Tamandaré', 'São Pedro', 'Jardim Monte Santo', '83501-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32443, 'Colombo', 'São Pedro', 'Vila Alto da Cruz III', '83405-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32444, 'Campo Largo', 'São Pedro', 'Vila David Antônio', '83609-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32445, 'Curitiba', 'São Pedro', 'Cabral', '80035-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32446, 'Ponta Grossa', 'São Pedro do Ivai', 'Oficinas', '84052-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32447, 'São José dos Pinhais', 'São Pedro do Ivai', 'São Pedro', '83020-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32448, 'Apucarana', 'São Pedro do Ivai', 'Núcleo Habitacional Nossa Senhora Aparecida', '86801-408', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32449, 'Curitiba', 'São Pedro do Ivai', 'Cidade Industrial', '81250-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32450, 'Ponta Grossa', 'São Pedro Julião', 'Uvaranas', '84033-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32451, 'Curitiba', 'São Pedro Maria Chanel', 'Cidade Industrial', '81450-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32452, 'Curitiba', 'São Perpétuo', 'Cidade Industrial', '81450-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32453, 'Curitiba', 'São Pio X', 'Ahú', '80540-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32454, 'Curitiba', 'São Policarpo', 'Cidade Industrial', '81315-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32455, 'Curitiba', 'São Porfírio', 'Cidade Industrial', '81305-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32456, 'Londrina', 'São Rafael', 'Jardim Santo André', '86073-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32457, 'Toledo', 'São Rafael', 'Jardim La Salle', '85903-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32458, 'Almirante Tamandaré', 'São Rafael', 'Jardim Monte Santo', '83501-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32459, 'Curitiba', 'São Romoaldo', 'Cidade Industrial', '81450-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32460, 'Francisco Beltrão', 'São Roque', 'Cango', '85604-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32461, 'Piraquara', 'São Roque', 'Jardim Santa Mônica', '83302-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32462, 'Telêmaco Borba', 'São Roque', 'Área 06', '84271-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32463, 'Almirante Tamandaré', 'São Roque', 'Jardim Monte Santo', '83501-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32464, 'Apucarana', 'São Roque', 'Núcleo Habitacional Dom Romeu Alberti', '86806-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32465, 'Cambé', 'São Roque', 'Jardim Santa Izabel', '86183-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32466, 'Cascavel', 'São Roque', 'Periolo', '85817-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32467, 'Curitiba', 'São Roque', 'Guabirotuba', '81510-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32468, 'Londrina', 'São Salvador', 'Vila Ziober', '86026-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32469, 'Curitiba', 'São Salvador', 'Pilarzinho', '82110-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32470, 'Curitiba', 'São Salvador', 'Pilarzinho', '82120-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32471, 'Pinhais', 'São Salvador', 'Vila Varginha', '83320-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32472, 'Paranavaí', 'São Salvador', 'Jardim Progresso', '87701-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32473, 'Maringá', 'São Salvador', 'Vila Emília', '87010-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32474, 'São José dos Pinhais', 'São Salvador', 'Costeira', '83015-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32475, 'Cambé', 'São Salvador', 'Vila Salomé', '86192-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32476, 'Apucarana', 'São Salvador', 'Loteamento Central', '86807-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32477, 'Francisco Beltrão', 'São Sebastião', 'Cristo Rei', '85602-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32478, 'Londrina', 'São Sebastião', 'Jardim Santo André', '86073-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32479, 'São José dos Pinhais', 'São Sebastião', 'Roseira', '83070-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32480, 'Umuarama', 'São Sebastião', 'Conjunto Residencial Independência', '87508-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32481, 'Telêmaco Borba', 'São Sebastião', 'Vila São Francisco de Assis', '84264-500', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32482, 'Almirante Tamandaré', 'São Sebastião', 'Jardim Monte Santo', '83501-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32483, 'Apucarana', 'São Sebastião', 'Núcleo Habitacional Dom Romeu Alberti', '86806-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32484, 'Colombo', 'São Sebastião', 'Vila São Lucas', '83404-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32485, 'Curitiba', 'São Sebastião', 'Ahú', '80540-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32486, 'Curitiba', 'São Sérgio', 'Cidade Industrial', '81315-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32487, 'Curitiba', 'São Severino', 'Cidade Industrial', '81315-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32488, 'Curitiba', 'São Sidônio Apolinário', 'Cidade Industrial', '81250-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32489, 'Maringá', 'São Silvestre', 'Zona 07', '87030-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32490, 'Curitiba', 'São Silvestre', 'Fazendinha', '81320-410', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32491, 'Apucarana', 'São Simão', 'Núcleo Habitacional Dom Romeu Alberti', '86806-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32492, 'Curitiba', 'São Simão', 'Cajuru', '82900-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32493, 'Londrina', 'São Sisto I', 'Jardim Albatroz', '86039-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32494, 'Curitiba', 'São Teotônio', 'Cidade Industrial', '81305-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32495, 'Sarandi', 'São Thiago', 'Parque Residencial Bom Pastor', '87114-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32496, 'Curitiba', 'São Thomaz de Aquino', 'Seminário', '80440-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32497, 'Apucarana', 'São Tiago', 'Núcleo Habitacional Dom Romeu Alberti', '86806-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32498, 'Curitiba', 'São Tiago', 'Cajuru', '82900-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32499, 'Curitiba', 'São Timóteo', 'Cidade Industrial', '81305-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32500, 'Cascavel', 'São Tomás', 'Claudete', '85807-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32501, 'Colombo', 'São Tomás de Aquino', 'Jardim Planalto', '83409-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32502, 'Guarapuava', 'São Tomé', 'Boqueirão', '85020-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32503, 'Pato Branco', 'São Tomé', 'Sudoeste', '85507-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32504, 'Pinhais', 'São Tomé', 'Jardim Dona Joaquina I', '83325-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32505, 'Telêmaco Borba', 'São Tomé', 'Área 03', '84271-030', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32506, 'Castro', 'São Tomé', 'Vila Santa Cruz', '84168-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32507, 'Almirante Tamandaré', 'São Tomé', 'Jardim Monte Santo', '83501-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32508, 'Apucarana', 'São Tomé', 'Núcleo Habitacional Dom Romeu Alberti', '86806-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32509, 'Curitiba', 'São Tomé', 'Jardim das Américas', '81540-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32510, 'Curitiba', 'São Valentin', 'Cidade Industrial', '81305-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32511, 'Curitiba', 'São Valério', 'Cidade Industrial', '81450-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32512, 'Foz do Iguaçu', 'São Vicente', 'Loteamento Mata Verde', '85853-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32513, 'Londrina', 'São Vicente', 'Centro', '86026-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32514, 'Laranjeiras do Sul', 'São Vicente', 'São Francisco', '85303-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32515, 'Londrina', 'São Vicente', 'Jardim Palmares', '86025-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32516, 'Maringá', 'São Vicente', 'Zona 08', '87050-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32517, 'Pato Branco', 'São Vicente', 'Menino Deus', '85502-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32518, 'Maringá', 'São Vicente', 'Jardim Alvorada', '87033-060', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32519, 'Pinhais', 'São Vicente', 'Planta Bairro Weissópolis', '83322-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32520, 'Umuarama', 'São Vicente', 'Jardim Europa', '87502-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32521, 'Umuarama', 'São Vicente', 'Jardim Birigüi', '87505-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32522, 'Apucarana', 'São Vicente', 'Núcleo Habitacional Vale Verde', '86805-258', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32523, 'Almirante Tamandaré', 'São Vicente', 'Jardim Monte Santo', '83501-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32524, 'Curitiba', 'São Vicente', 'Juvevê', '80030-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32525, 'Telêmaco Borba', 'São Vicente de Paula', 'Jardim Bom Jesus', '84262-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32526, 'Cambé', 'São Vicente de Paula', 'Jardim Santa Izabel', '86183-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32527, 'Almirante Tamandaré', 'São Vicente de Paula', 'Loteamento Nova Morada', '83504-678', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32528, 'Maringá', 'São Vicente de Paulo', 'Jardim São Jorge', '87080-640', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32529, 'Toledo', 'São Vicente de Paulo', 'Centro', '85900-215', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32530, 'Araucária', 'São Vicente de Paulo', 'Centro', '83702-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32531, 'Araucária', 'São Vicente de Paulo', 'Centro', '83702-055', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32532, 'Curitiba', 'São Vicente de Paulo', 'Campina do Siqueira', '80730-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32533, 'Umuarama', 'São Vicente Pallotti', 'Zona I-A', '87501-065', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32534, 'Curitiba', 'São Vicente Pallotti', 'Cajuru', '82900-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32535, 'Curitiba', 'São Victor', 'Cidade Industrial', '81305-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32536, 'Curitiba', 'São Vito', 'Cidade Industrial', '81450-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32537, 'Londrina', 'São Vítor I', 'Jardim Albatroz', '86039-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32538, 'Foz do Iguaçu', 'Sape', 'Jardim Canadá', '85861-280', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32539, 'Francisco Beltrão', 'Sapiranga', 'Pinheirinho', '85603-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32540, 'Arapongas', 'Sapitica', 'Vila Araponguinha', '86705-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32541, 'Guarapuava', 'Sapopema', 'Conradinho', '85055-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32542, 'Londrina', 'Sapopema', 'Lindóia', '86031-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32543, 'Telêmaco Borba', 'Sapopema', 'Área 02', '84269-060', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32544, 'Colombo', 'Sapopema', 'Jardim Cristina', '83410-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32545, 'Curitiba', 'Sapopema', 'Santa Cândida', '82650-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32546, 'Londrina', 'Sapoti', 'Glória', '86035-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32547, 'Curitiba', 'Sapoti', 'Uberaba', '81550-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32548, 'Foz do Iguaçu', 'Sapucaí', 'Conjunto C', '85870-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32549, 'Paranaguá', 'Sapucaí', 'Santos Dumont', '83209-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32550, 'Francisco Beltrão', 'Sapucaia', 'Pinheirinho', '85603-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32551, 'Toledo', 'Sapucaia', 'Walter Fontana', '85909-447', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32552, 'Guarapuava', 'Saquarema', 'Morro Alto', '85070-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32553, 'Foz do Iguaçu', 'Saquarema', 'Jardim Lancaster I', '85869-005', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32554, 'Francisco Beltrão', 'Saracura', 'Padre Ulrico', '85604-467', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32555, 'Araucária', 'Saracura', 'Capela Velha', '83706-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32556, 'Arapongas', 'Saracura', 'Jardim São Cristóvão', '86709-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32557, 'Arapongas', 'Saracura-açu', 'Parque Industrial', '86706-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32558, 'Arapongas', 'Saracura-pintada', 'Conjunto Del Condor', '86703-328', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32559, 'Arapongas', 'Saracura-preta', 'Conjunto Del Condor', '86703-316', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32560, 'Foz do Iguaçu', 'Saracuras', 'Portal da Foz', '85859-407', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32561, 'Guarapuava', 'Sarandi', 'Vila Bela', '85025-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32562, 'Francisco Beltrão', 'Sarandi', 'Pinheirinho', '85603-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32563, 'Foz do Iguaçu', 'Sarandi', 'Jardim Itamaraty', '85863-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32564, 'Maringá', 'Sarandi', 'Zona 08', '87050-560', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32565, 'Umuarama', 'Sarandi', 'Zona III', '87502-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32566, 'Toledo', 'Sarandi', 'Centro', '85900-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32567, 'Telêmaco Borba', 'Sarandi', 'Nossa Senhora do Perpétuo Socorro', '84265-145', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32569, 'Cascavel', 'Sarandi', 'Canadá', '85813-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32570, 'Campo Mourão', 'Sarandi', 'Conjunto Residencial Antilhas', '87308-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32571, 'Foz do Iguaçu', 'Sarapo', 'Conjunto A', '85860-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32572, 'Francisco Beltrão', 'Sardenha', 'Jardim Floresta', '85603-378', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32573, 'Foz do Iguaçu', 'Sardinha', 'Profilurb I', '85855-260', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32574, 'Cascavel', 'Sargento Abdiel Ribeiro dos Santos', 'Santa Felicidade', '85803-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32575, 'Curitiba', 'Sargento Alpendre', 'Bacacheri', '82515-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32576, 'Curitiba', 'Sargento Alvino Batista Fragoso', 'Cidade Industrial', '81230-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32577, 'Castro', 'Sargento Antônio Dias Cardoso', 'Jardim das Araucárias', '84174-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32578, 'Curitiba', 'Sargento Antônio Putrique', 'Boqueirão', '81650-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32579, 'Ponta Grossa', 'Sargento Argemiro Camargo', 'Neves', '84021-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32580, 'Curitiba', 'Sargento Carlos Argemiro de Camargo', 'Uberaba', '81570-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32581, 'Londrina', 'Sargento Chagas', 'San Remo', '86062-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32582, 'Londrina', 'Sargento Daniel Vicente da Silva', 'Jardim Bom Pastor', '86082-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32583, 'Curitiba', 'Sargento Durval Gomes', 'Cidade Industrial', '81240-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32747, 'Curitiba', 'Sebastião Moletta', 'Cajuru', '82970-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32584, 'Araucária', 'Sargento Ernesto Ferreira da Silva', 'Centro', '83702-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32585, 'Curitiba', 'Sargento Erwin', 'Bacacheri', '82515-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32586, 'Ponta Grossa', 'Sargento Francisco Arisilvio Ferreira', 'Olarias', '84026-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32587, 'Curitiba', 'Sargento Francisco da Silva Cotrin', 'Tatuquara', '81480-168', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32588, 'Curitiba', 'Sargento Haroldo Cordeiro Júnior', 'Augusta', '81290-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32589, 'Cascavel', 'Sargento Holembach', 'Região do Lago', '85812-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32590, 'Paranaguá', 'Sargento Ismail Ferreira da Silva', 'Cruzeiro', '83221-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32591, 'Laranjeiras do Sul', 'Sargento João Nascimento Lopes', 'Centro', '85301-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32592, 'Curitiba', 'Sargento José de Castro', 'Pilarzinho', '82120-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32593, 'Curitiba', 'Sargento Lafayette', 'Bacacheri', '82515-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32594, 'Curitiba', 'Sargento Lauro Pinto de Oliveira', 'São Braz', '82300-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32595, 'São José dos Pinhais', 'Sargento Lázaro Rodrigues', 'São Sebastião', '83075-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32596, 'Curitiba', 'Sargento Luiz Gonzaga Martins Ribas', 'Uberaba', '81560-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32597, 'Curitiba', 'Sargento Luiz Gonzaga Martins Ribas', 'Uberaba', '81550-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32598, 'Curitiba', 'Sargento Marcelino Gonçalves Filho', 'Cidade Industrial', '81315-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32599, 'Cascavel', 'Sargento Max Wolf', 'Região do Lago', '85812-350', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32600, 'Apucarana', 'Sargento Max Wolff Filho', 'Jardim Aviação', '86812-519', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32601, 'Curitiba', 'Sargento Miguel', 'Bacacheri', '82515-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32602, 'Curitiba', 'Sargento Milano', 'Bacacheri', '82515-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32603, 'Curitiba', 'Sargento Octávio Hoglund', 'Capão da Imbuia', '82810-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32604, 'Curitiba', 'Sargento Oswaldo Bond', 'Uberaba', '81560-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32605, 'Curitiba', 'Sargento Pedro Nunes Pereira', 'Bacacheri', '82515-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32606, 'Curitiba', 'Sargento Roberto Maciel', 'Bacacheri', '82515-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32607, 'Curitiba', 'Sargento Roberto Sabino', 'Bacacheri', '82515-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32608, 'Foz do Iguaçu', 'Sargento Rolembach', 'Centro', '85851-206', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32609, 'Maringá', 'Sargento Rui Alves', 'Vila Esperança', '87020-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32610, 'Curitiba', 'Sargento Tadeu Czocher', 'Uberaba', '81570-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32611, 'Curitiba', 'Sargento Valmor Nicoladelli', 'Xaxim', '81830-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32612, 'Ponta Grossa', 'Sassafrás', 'Neves', '84020-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32613, 'Apucarana', 'Sassafrás', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32614, 'Sarandi', 'Satélite', 'Jardim Universal', '87114-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32615, 'Piraquara', 'Satorino Alves da Rocha', 'Vila São Cristóvão', '83305-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32616, 'Guarapuava', 'Saturino Varela', 'Vila Bela', '85027-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32617, 'Curitiba', 'Saturnino Arruda dos Santos', 'Pilarzinho', '82110-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32618, 'Londrina', 'Saturnino de Brito', 'Kase', '86026-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32619, 'Curitiba', 'Saturnino Martins', 'Sítio Cercado', '81900-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32620, 'Curitiba', 'Saturnino Miranda', 'Santa Felicidade', '82030-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32621, 'Foz do Iguaçu', 'Saturnino Rolon', 'Novo Mundo', '85862-397', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32622, 'Curitiba', 'Saturnino Travisani', 'Cidade Industrial', '81315-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32623, 'Londrina', 'Saturno', 'Sol', '86070-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32624, 'Foz do Iguaçu', 'Saturno', 'Parque Residencial Três Fronteiras', '85859-678', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32625, 'Ponta Grossa', 'Saturno', 'Uvaranas', '84031-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32626, 'Maringá', 'Saturno', 'Jardim Imperial II', '87023-016', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32627, 'Sarandi', 'Saturno', 'Jardim Universal', '87114-516', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32628, 'Telêmaco Borba', 'Saturno', 'Nossa Senhora de Fátima', '84264-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32629, 'Toledo', 'Saturno', 'Parque Residencial Gisela', '85905-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32630, 'Apucarana', 'Saturno', 'Jardim Vale do Sol', '86803-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32631, 'Cambé', 'Saturno', 'Parque Maracanã', '86185-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32632, 'Curitiba', 'Saturno', 'Sítio Cercado', '81910-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32633, 'Curitiba', 'Satyrio Ferreira da Costa', 'Alto Boqueirão', '81860-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32634, 'Foz do Iguaçu', 'Saua', 'Conjunto A', '85866-290', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32635, 'Foz do Iguaçu', 'Saua', 'Conjunto A', '85860-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32636, 'Colombo', 'Saul Bento Nodari', 'Vila Santa Helena', '83406-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32637, 'Londrina', 'Saul Elkind', 'Conjunto Semiramis Barros Braga', '86088-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32638, 'Londrina', 'Saul Elkind', 'Conjunto Habitacional Violim', '86084-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32639, 'Londrina', 'Saul Elkind', 'Conjunto Vivi Xavier', '86082-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32640, 'Londrina', 'Saul Elkind', 'Sebastião de Melo César', '86085-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32641, 'Londrina', 'Saul Elkind', 'Aquilles Sthengel', '86086-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32642, 'Campo Mourão', 'Saul Ferreira Caldas', 'Jardim Francisco Ferreira Albuquerque', '87309-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32643, 'Apucarana', 'Saul Guimarães da Costa', 'Loteamento Santa Cândida', '86802-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32644, 'Curitiba', 'Saul Piccoli', 'Atuba', '82600-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32645, 'Pato Branco', 'Saul Vigano', 'Aeroporto', '85503-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32646, 'Arapongas', 'Saurá', 'Vila Bernardes', '86705-056', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32647, 'Arapongas', 'Saurá-fogo', 'Jardim Santo Antônio', '86705-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32648, 'Curitiba', 'Savigny', 'Barreirinha', '82700-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32649, 'Cascavel', 'Savino Campagnolo', 'Claudete', '85811-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32650, 'Cambé', 'Savona', 'Jardim Montecatini', '86186-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32651, 'Curitiba', 'Savona', 'São João', '82030-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32652, 'Ponta Grossa', 'Schafemberg de Quadros', 'Ronda', '84051-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32653, 'São José dos Pinhais', 'Scharfenberg de Quadros', 'Centro', '83005-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32654, 'Curitiba', 'Schiller', 'Alto da Rua XV', '80040-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32655, 'Curitiba', 'Schiller', 'Cristo Rei', '80050-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32656, 'Curitiba', 'Schirlei Solange Mantovani', 'Cidade Industrial', '81305-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32657, 'Curitiba', 'Schubert', 'Vista Alegre', '80820-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32658, 'Curitiba', 'Schumann', 'Vista Alegre', '80820-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32659, 'Cascavel', 'Scotton', 'Nova Cidade', '85803-176', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32660, 'Colombo', 'Sebastiana Antônia da Silva', 'Parque Residencial Santa Terezinha II', '83408-795', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32661, 'Apucarana', 'Sebastiana Basti Francisco Menegazzo', 'Jardim Menegazzo', '86802-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32662, 'Curitiba', 'Sebastiana Boesi Braga', 'Cidade Industrial', '81305-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32663, 'Pinhais', 'Sebastiana Camargo de Araújo', 'Jardim Cláudia', '83326-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32664, 'Curitiba', 'Sebastiana Cordeiro', 'Cidade Industrial', '81230-416', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32665, 'Apucarana', 'Sebastiana de Abreu Navas', 'Jardim Portal do Lago', '86802-069', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32666, 'Londrina', 'Sebastiana de Siqueira Monteiro', 'Jardim Strass', '86084-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32667, 'Curitiba', 'Sebastiana de Souza Roza', 'Xaxim', '81830-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32668, 'São José dos Pinhais', 'Sebastiana Laura de Souza', 'Guatupê', '83060-218', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32669, 'Almirante Tamandaré', 'Sebastiana Lustosa de Freitas', 'Jardim Dragão Verde', '83507-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32670, 'Foz do Iguaçu', 'Sebastiana Maria de Jesus', 'Jardim Porto Belo', '85867-357', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32671, 'Ponta Grossa', 'Sebastiana Martins Messias', 'Contorno', '84060-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32672, 'Almirante Tamandaré', 'Sebastiana P. Ribeiro', 'Jardim Dona Luiza', '83506-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32673, 'Curitiba', 'Sebastiana Rodrigues', 'Cidade Industrial', '81350-648', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32674, 'Londrina', 'Sebastiana Rodrigues Moreira', 'Jamile Dequech', '86048-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32675, 'São José dos Pinhais', 'Sebastiana Santana Fraga', 'Guatupê', '83060-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32676, 'Londrina', 'Sebastião A. S. Callero', 'Doutor Farid Libos', '86041-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32677, 'Campo Mourão', 'Sebastião Albino Ferreira', 'Jardim Flórida', '87300-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32678, 'Londrina', 'Sebastião Alcântara e Silva', 'Condomínio Royal Golf Residence', '86055-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32679, 'São José dos Pinhais', 'Sebastião Alcebíades Nogueira', 'Guatupê', '83065-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32680, 'Campo Largo', 'Sebastião Alves', 'Jardim Bela Vista', '83605-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32681, 'Curitiba', 'Sebastião Alves Ferreira', 'Bairro Alto', '82840-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32682, 'Curitiba', 'Sebastião Alves Ferreira', 'Bairro Alto', '82820-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32683, 'Guarapuava', 'Sebastião Alves Loures', 'Bonsucesso', '85045-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32684, 'Curitiba', 'Sebastião Antônio da Silva', 'Santa Cândida', '82650-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32685, 'São José dos Pinhais', 'Sebastião Antônio Foggiatto', 'Zaniolo', '83025-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32686, 'Umuarama', 'Sebastião Armando da Silva', 'Parque San Marino', '87509-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32687, 'Castro', 'Sebastião Augusto Querne', 'Jardim Colonial', '84178-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32688, 'Colombo', 'Sebastião Barbiot', 'Jardim dos Eucaliptos', '83408-498', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32689, 'Apucarana', 'Sebastião Barbosa de Souza', 'Vila Rural Nova Ukrania', '86810-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32690, 'Maringá', 'Sebastião Batista Zanin', 'Parque das Laranjeiras', '87083-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32691, 'Almirante Tamandaré', 'Sebastião Bonfim Alcântara', 'Planta Nossa Senhora de Lourdes', '83506-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32692, 'Curitiba', 'Sebastião Bordeaux de Oliveira', 'Barreirinha', '82700-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32693, 'Campo Largo', 'Sebastião Borges', 'Itaqui de Cima', '83605-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32694, 'Campo Largo', 'Sebastião Borges Beceloski', 'Vila Rivabem', '83605-236', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32695, 'Curitiba', 'Sebastião Braganholo', 'Santa Felicidade', '82320-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32696, 'Londrina', 'Sebastião Buzignani', 'Tarobá', '86042-325', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32697, 'Foz do Iguaçu', 'Sebastião Caldeira', 'Jardim das Flores', '85855-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32698, 'Foz do Iguaçu', 'Sebastião Caldeira', 'Jardim Iara', '85854-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32699, 'Paranavaí', 'Sebastião Cândido Freitas', 'Jardim Ibirapuera', '87705-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32700, 'Umuarama', 'Sebastião Canedo Gomes', 'Zona VII', '87503-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32701, 'Londrina', 'Sebastião Cardoso de Oliveira Júnior', 'Sabará III', '86066-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32702, 'Londrina', 'Sebastião Carneiro Lobo', 'João Paz', '86087-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32703, 'Londrina', 'Sebastião Carvalho da Silva', 'San Izidro', '86040-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32704, 'Londrina', 'Sebastião Cezário de Souza', 'Operária', '86038-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32705, 'Londrina', 'Sebastião Chapp Galindo', 'Parque Residencial do Lago', '86050-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32706, 'São José dos Pinhais', 'Sebastião Cordeiro Neneve', 'Ipê', '83055-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32707, 'Campo Largo', 'Sebastião Cosmo', 'Rondinha', '83607-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32708, 'Apucarana', 'Sebastião Damas Correia', 'Núcleo Habitacional Djalma Mendes de Oliveira', '86806-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32709, 'Guarapuava', 'Sebastião de Camargo Ribas', 'Bonsucesso', '85055-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32710, 'Guarapuava', 'Sebastião de Camargo Ribas', 'São Cristóvão', '85060-340', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32711, 'Londrina', 'Sebastião de Castro', 'Pinheiros', '86063-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32712, 'Londrina', 'Sebastião de Mello César', 'Amaro', '86062-485', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32713, 'São José dos Pinhais', 'Sebastião de Oliveira', 'Guatupê', '83065-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32714, 'Curitiba', 'Sebastião de Oliveira Torres', 'Cidade Industrial', '81170-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32715, 'São José dos Pinhais', 'Sebastião de Paula Alves', 'Colônia Rio Grande', '83020-635', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32716, 'Maringá', 'Sebastião de Paula e Silva', 'Parque Avenida', '87025-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32717, 'Londrina', 'Sebastião de Paulo Barbosa', 'Conjunto Habitacional  Alexandre Urbanas', '86037-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32718, 'Londrina', 'Sebastião de Sá Cavalcanti', 'Residencial José B Almeida', '86041-826', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32719, 'Cambé', 'Sebastião dos Santos de Jesus', 'Jardim Tarobá', '86191-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32720, 'Londrina', 'Sebastião Dutra de Siqueira', 'Jardim Europa', '86043-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32721, 'Curitiba', 'Sebastião Favaro', 'Barreirinha', '82210-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32722, 'Foz do Iguaçu', 'Sebastião Flor', 'Loteamento Witt', '85862-546', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32723, 'Curitiba', 'Sebastião Francisco Correia', 'Capão da Imbuia', '82810-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32724, 'Curitiba', 'Sebastião Francisco Cortiano', 'Cajuru', '82900-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32725, 'Londrina', 'Sebastião Geraldo', 'Cafezal', '86045-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32726, 'Curitiba', 'Sebastião Gomes Oliveira', 'Pinheirinho', '81825-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32727, 'Curitiba', 'Sebastião Gonçalves Pinto', 'Atuba', '82860-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32728, 'Colombo', 'Sebastião Guarise', 'Centro', '83414-540', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32729, 'Londrina', 'Sebastião Honorato Nascimento', 'Conjunto Professora Hilda Mandarino', '86080-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32730, 'Londrina', 'Sebastião Joaquim da Silva', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32731, 'Londrina', 'Sebastião José de Carvalho', 'San Conrado', '86038-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32732, 'Colombo', 'Sebastião José de Souza', 'Vila Maria do Rosário', '83413-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32733, 'Curitiba', 'Sebastião José Martins', 'Campo Comprido', '81200-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32734, 'Guarapuava', 'Sebastião Kramer', 'Bonsucesso', '85035-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32735, 'Pato Branco', 'Sebastião Lara', 'Bonatto', '85506-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32736, 'Piraquara', 'Sebastião Leonel', 'Planta Vila Lory', '83310-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32737, 'São José dos Pinhais', 'Sebastião Leonildo Fontana', 'Guatupê', '83060-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32738, 'Curitiba', 'Sebastião Lima', 'Alto Boqueirão', '81850-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32739, 'Guarapuava', 'Sebastião Lustosa de Siqueira', 'Santana', '85070-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32740, 'Curitiba', 'Sebastião Malucelli', 'Novo Mundo', '81050-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32741, 'Ponta Grossa', 'Sebastião Marcondes Ferreira', 'Oficinas', '84035-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32742, 'Curitiba', 'Sebastião Marcos Luiz', 'Cajuru', '82930-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32743, 'Curitiba', 'Sebastião Marcos Luiz', 'Cajuru', '82940-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32744, 'Londrina', 'Sebastião Marques Vieira', 'Conjunto Habitacional João Turquino', '86056-825', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32745, 'Curitiba', 'Sebastião Martins Vieira Lins', 'Boa Vista', '82540-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32746, 'Guarapuava', 'Sebastião Mendes Araújo', 'Bonsucesso', '85045-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32748, 'Londrina', 'Sebastião Montilha Garcia', 'Coliseu', '86076-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32749, 'Ponta Grossa', 'Sebastião Nascimento', 'Contorno', '84061-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32750, 'Londrina', 'Sebastião Naves Piconi', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32751, 'Londrina', 'Sebastião Palhares', 'Cafezal', '86045-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32752, 'Ponta Grossa', 'Sebastião Paraná', 'Ronda', '84051-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32753, 'São José dos Pinhais', 'Sebastião Paraná', 'São Sebastião', '83075-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32754, 'Londrina', 'Sebastião Pedroso de Moraes', 'Jardim Nova Esperança', '86044-639', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32755, 'Curitiba', 'Sebastião Pedrozo', 'Capão Raso', '81110-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32756, 'Cascavel', 'Sebastião Pereira Camargo', 'Santa Felicidade', '85803-328', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32757, 'Cascavel', 'Sebastião Pereira Camargo', 'Nova Cidade', '85803-137', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32758, 'Londrina', 'Sebastião Peres da Silva', 'Santiago', '86071-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32759, 'Apucarana', 'Sebastião Piassa', 'Parque Industrial Zona Sul', '86810-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32760, 'Apucarana', 'Sebastião Piassa', 'Parque Industrial Zona Oeste', '86802-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32761, 'Londrina', 'Sebastião Politi', 'Parque Residencial Elizabeth', '86077-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32762, 'Apucarana', 'Sebastião Rezende', 'Loteamento Sol Nascente', '86801-269', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32763, 'Ponta Grossa', 'Sebastião Ribas Martins', 'Nova Rússia', '84070-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32764, 'Curitiba', 'Sebastião Ribeiro Batista', 'Cidade Industrial', '81310-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32765, 'Londrina', 'Sebastião Ridão Ribeiro', 'Franciscato', '86043-185', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32766, 'Pato Branco', 'Sebastião Rodrigues', 'Vila Verde', '85506-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32767, 'Araucária', 'Sebastião Rodrigues de Souza', 'Thomaz Coelho', '83706-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32768, 'Curitiba', 'Sebastião Rodrigues dos Santos', 'Guabirotuba', '81510-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32769, 'Ponta Grossa', 'Sebastião Rolin Carneiro', 'Contorno', '84060-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32770, 'Curitiba', 'Sebastião Romão Damacena', 'Atuba', '82860-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32771, 'São José dos Pinhais', 'Sebastião Rosa de Moraes', 'Ipê', '83055-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32772, 'Curitiba', 'Sebastião Rosa Lima', 'Xaxim', '81720-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32773, 'São José dos Pinhais', 'Sebastião Rubens Nogueira', 'Planta Quississana', '83085-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32774, 'Piraquara', 'Sebastião Santo Gaio', 'Vila Juliana', '83306-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32775, 'Curitiba', 'Sebastião Santos', 'Santa Felicidade', '82030-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32776, 'Curitiba', 'Sebastião Scolaro', 'Cidade Industrial', '81170-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32777, 'Cascavel', 'Sebastião Silva', 'Santa Felicidade', '85803-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32778, 'Curitiba', 'Sebastião Silva', 'Bairro Alto', '82820-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32779, 'São José dos Pinhais', 'Sebastião Spejorin', 'Miringuava', '83090-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32780, 'Pinhais', 'Sebastião Stancki da Luz Júnior', 'Prive Bois de Boulogne', '83330-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32781, 'Ponta Grossa', 'Sebastião Tramontim', 'Boa Vista', '84072-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32782, 'Ponta Grossa', 'Sebastião Túlio', 'Colônia Dona Luiza', '84045-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32783, 'Curitiba', 'Sebastião Vendramin', 'Santa Felicidade', '82410-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32784, 'Curitiba', 'Sebastião Vieira da Rosa', 'Xaxim', '81820-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32785, 'Curitiba', 'Sebastião Zanardini Carneiro', 'Alto Boqueirão', '81850-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32786, 'Londrina', 'Sebatião Roberto', 'Colúmbia', '86057-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32787, 'Curitiba', 'Secondo Tedeschi', 'Ahú', '82200-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32788, 'Guarapuava', 'Sefora Maria Xavier Nunes', 'Morro Alto', '85063-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32789, 'Curitiba', 'Segesmundo Kozowski', 'Pilarzinho', '82115-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32790, 'Londrina', 'Segisfredo Gonçalves Mendes', 'Jardim Barcelona', '86073-346', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32791, 'Colombo', 'Segismundo Busato', 'Jardim Santa Cândida', '83402-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32792, 'Campo Mourão', 'Segismundo Dlugosz', 'Jardim Aeroporto', '87310-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32793, 'Curitiba', 'Segismundo Falarz', 'Cidade Industrial', '81270-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32794, 'Araucária', 'Segismundo Kuchenny', 'Costeira', '83708-736', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32795, 'São José dos Pinhais', 'Segismundo Lenkot', 'Guatupê', '83060-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32796, 'Curitiba', 'Segismundo Maiewski Filho', 'Sítio Cercado', '81910-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32797, 'Ponta Grossa', 'Segismundo Romanowski', 'Contorno', '84062-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32798, 'São José dos Pinhais', 'Segismundo Salata', 'Centro', '83005-115', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32799, 'Foz do Iguaçu', 'Segredo', 'Vila Carima', '85855-708', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32800, 'Londrina', 'Segundo Moretini', 'Avelino A Vieira', '86056-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32801, 'Londrina', 'Seigo Oda', 'Aragarça', '86038-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32802, 'Londrina', 'Seikichi Yogi', 'Residencial Vila Romana', '86031-807', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32803, 'Londrina', 'Seimu Oguido', 'Parque ABC', '86075-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32804, 'Curitiba', 'Seiro Nakamura', 'Xaxim', '81710-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32805, 'Foz do Iguaçu', 'Seis', 'Três Pinheiros', '85856-658', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32806, 'Paranavaí', 'Seis', 'Vila Prudêncio', '87702-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32807, 'Piraquara', 'Seis', 'Chácara Águas Claras', '83309-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32808, 'Ponta Grossa', 'Seis', 'Jardim Carvalho', '84016-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32809, 'Ponta Grossa', 'Seis', 'Chapada', '84064-569', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32810, 'Piraquara', 'Seis', 'Chácara Águas Claras', '83309-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32811, 'Piraquara', 'Seis', 'Chácara Águas Claras', '83309-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32812, 'Ponta Grossa', 'Seis', 'Contorno', '84060-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32813, 'Ponta Grossa', 'Seis', 'Chapada', '84063-419', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32814, 'Paranaguá', 'Seis', 'Vila Garcia', '83218-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32815, 'Ponta Grossa', 'Seis', 'Boa Vista', '84073-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32816, 'Paranavaí', 'Seis', 'Conjunto Dona Josefa', '87708-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32817, 'Ponta Grossa', 'Seis', 'Contorno', '84060-569', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32818, 'Ponta Grossa', 'Seis', 'Uvaranas', '84026-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32819, 'Ponta Grossa', 'Seis', 'Uvaranas', '84030-486', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32820, 'Ponta Grossa', 'Seis', 'Uvaranas', '84032-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32821, 'Ponta Grossa', 'Seis', 'Uvaranas', '84022-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32822, 'Paranaguá', 'Seis', 'Jardim Paraná', '83215-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32823, 'Ponta Grossa', 'Seis', 'Cará-cará', '84032-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32824, 'Sarandi', 'Seis', 'Jardim Nova Independência I', '87114-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32825, 'Umuarama', 'Seis', 'Jardim Beira Rio', '87507-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32826, 'Umuarama', 'Seis', 'Jardim Maria Lúcia', '87501-659', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32827, 'Telêmaco Borba', 'Seis', 'Vila Santa Rita', '84263-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32828, 'Umuarama', 'Seis', 'Jardim São Cristóvão', '87507-365', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32829, 'Campo Largo', 'Seis', 'Jardim Lorenzete', '83603-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32830, 'Almirante Tamandaré', 'Seis', 'Jardim das Oliveiras', '83502-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32831, 'Almirante Tamandaré', 'Seis', 'Jardim Tatiana', '83513-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32832, 'Campo Largo', 'Seis', 'Jardim Padre José de Anchieta', '83607-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32833, 'Campo Largo', 'Seis', 'Jardim das Acácias', '83603-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32834, 'Almirante Tamandaré', 'Seis', 'Jardim Gineste', '83505-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32835, 'Campo Largo', 'Seis', 'Moradias Bom Jesus', '83602-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32836, 'Campo Largo', 'Seis', 'Jardim Keli Cristina', '83609-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32837, 'Campo Largo', 'Seis', 'Vila Pompéia', '83608-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32838, 'Campo Largo', 'Seis', 'Vila São Luiz', '83608-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32839, 'Campo Largo', 'Seis', 'Vila Mariano Torres', '83608-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32840, 'Campo Largo', 'Seis', 'Núcleo Habitacional Mathias Batista', '83604-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32841, 'Almirante Tamandaré', 'Seis', 'Loteamento Marinoni', '83508-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32842, 'Campo Largo', 'Seis', 'Loteamento São Gerônimo', '83606-185', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32843, 'Maringá', 'Seis de Janeiro', 'Jardim Alamar', '87014-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32844, 'Telêmaco Borba', 'Seixas', 'Vila Rosa', '84272-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32845, 'Apucarana', 'Seizaburo Miyadi', 'Vila Santa Terezinha', '86802-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32846, 'Londrina', 'Seizo Yabe', 'Jamile Dequech', '86048-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32847, 'Cambé', 'Sella', 'Parque Residencial Ana Rosa', '86183-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32848, 'Curitiba', 'Selvino Caramori', 'Sítio Cercado', '81920-545', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32849, 'Cascavel', 'Selvino Casagrande', 'Alto Alegre', '85805-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32850, 'Pinhais', 'Selvino Gomes Nogueira', 'Planta Vila Bordignon', '83325-578', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32851, 'Apucarana', 'Seme Salomão', 'Parque Bela Vista', '86803-185', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32852, 'Curitiba', 'Semen Uniga', 'Santa Cândida', '82640-490', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32853, 'Maringá', 'Seminário', 'Zona 06', '87080-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32854, 'Londrina', 'Semiramis', 'Cambará', '86039-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32855, 'Apucarana', 'Semiramis Braga', 'Centro', '86800-086', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32856, 'Curitiba', 'Semíramis de Macedo Seiler', 'Cidade Industrial', '81290-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32857, 'Londrina', 'Sempre-viva', 'Indústrias', '86043-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32858, 'Foz do Iguaçu', 'Sempre-viva', 'Vila Adriana', '85854-555', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32859, 'Londrina', 'Sena Martins', 'Bela Vista', '86015-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32860, 'Apucarana', 'Senac', 'Parque Industrial Zona Norte', '86800-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32861, 'Paranaguá', 'Senador Abilon de Souza Naves', 'Vila Paranaguá', '83221-046', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32862, 'Maringá', 'Senador Abilon de Souza Naves', 'Zona 03', '87050-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32863, 'Maringá', 'Senador Accioly Filho', 'Vila Santa Izabel', '87080-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32864, 'Curitiba', 'Senador Accioly Filho', 'Cidade Industrial', '81310-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32865, 'Curitiba', 'Senador Accioly Filho', 'Cidade Industrial', '81350-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32866, 'São José dos Pinhais', 'Senador Acioly Filho', 'Afonso Pena', '83045-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32867, 'Toledo', 'Senador Acioly Filho', 'Panorama', '85911-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32868, 'Ponta Grossa', 'Senador Afonso Camargo', 'Uvaranas', '84026-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32869, 'Guarapuava', 'Senador Alberto Pascoalini', 'Vila Carli', '85040-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32870, 'Ponta Grossa', 'Senador Albuquerque Maranhão', 'Neves', '84020-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32871, 'Curitiba', 'Senador Alencar Guimarães', 'Centro', '80010-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32872, 'Curitiba', 'Senador Alo Guimarães', 'Uberaba', '81590-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32873, 'Maringá', 'Senador Alô Ticoulat Guimarães', 'Parque Residencial Aeroporto', '87055-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32874, 'Curitiba', 'Senador Antônio Jorge Machado de Lima', 'Pilarzinho', '82110-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32875, 'Telêmaco Borba', 'Senador Arthur Ferreira dos Santos', 'Centro', '84261-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32876, 'Paranaguá', 'Senador Attilio Fontana', 'Parque São João', '83212-250', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32877, 'Toledo', 'Senador Attilio Fontana', 'Panorama', '85911-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32878, 'Toledo', 'Senador Attilio Fontana', 'Conjunto Habitacional São Francisco', '85912-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32879, 'Toledo', 'Senador Attilio Fontana', 'Centro', '85901-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32880, 'Toledo', 'Senador Attilio Fontana', 'Jardim Bressan', '85913-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32881, 'Curitiba', 'Senador Batista de Oliveira', 'Jardim das Américas', '81530-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32882, 'Ponta Grossa', 'Senador Carneiro Leão', 'Olarias', '84035-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32883, 'Curitiba', 'Senador Correia', 'Centro', '80010-210', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32884, 'São José dos Pinhais', 'Senador Darci Ribeiro', 'Afonso Pena', '83065-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32885, 'Ponta Grossa', 'Senador Flávio Carvalho Guimarães', 'Boa Vista', '84070-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32886, 'Curitiba', 'Senador Flávio Guimarães', 'Ahú', '80540-170', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32887, 'Curitiba', 'Senador Gaspar Velloso', 'Boa Vista', '82560-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32888, 'Londrina', 'Senador Nereu Ramos', 'Campo Belo', '86062-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32889, 'Guarapuava', 'Senador Nereu Ramos', 'Bonsucesso', '85035-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32890, 'Ponta Grossa', 'Senador Nereu Ramos', 'Chapada', '84062-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32891, 'Curitiba', 'Senador Nereu Ramos', 'Guabirotuba', '81510-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32892, 'Maringá', 'Senador Nilo Coelho', 'Jardim Aclimação', '87050-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32893, 'Curitiba', 'Senador Othon Mader', 'Cidade Industrial', '81250-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32894, 'Maringá', 'Senador Petrônio Portela', 'Jardim Aclimação', '87050-720', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32895, 'Guarapuava', 'Senador Pinheiro Machado', 'Alto da XV', '85065-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32896, 'Guarapuava', 'Senador Pinheiro Machado', 'Centro', '85010-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32897, 'Ponta Grossa', 'Senador Pinheiro Machado', 'Centro', '84010-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32898, 'Curitiba', 'Senador Roberto Glaser', 'Jardim das Américas', '81540-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32899, 'Toledo', 'Senador Rúbens de Mello Braga', 'Panorama', '85911-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32900, 'Curitiba', 'Senador Salgado Filho', 'Uberaba', '81580-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32901, 'Curitiba', 'Senador Salgado Filho', 'Uberaba', '81570-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32902, 'Curitiba', 'Senador Salgado Filho', 'Prado Velho', '80215-270', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32903, 'Curitiba', 'Senador Salgado Filho', 'Uberaba', '81570-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32904, 'Curitiba', 'Senador Salgado Filho', 'Guabirotuba', '81510-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32905, 'Curitiba', 'Senador Salgado Filho', 'Guabirotuba', '81510-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32906, 'Curitiba', 'Senador Saraiva', 'São Francisco', '80510-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32907, 'Londrina', 'Senador Souza Naves', 'Centro', '86010-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32908, 'Londrina', 'Senador Souza Naves', 'Jardim Londrilar', '86015-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32909, 'São José dos Pinhais', 'Senador Souza Naves', 'Três Marias', '83030-630', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32910, 'São José dos Pinhais', 'Senador Souza Naves', 'Três Marias', '83030-620', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32911, 'Castro', 'Senador Souza Naves', 'Centro', '84165-550', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32912, 'Curitiba', 'Senador Souza Naves', 'Alto da Rua XV', '80050-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32913, 'Maringá', 'Senador Teotônio Brandão Vilela', 'Jardim Aclimação', '87050-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32914, 'Maringá', 'Senador Teotônio Brandão Vilela', 'Parque da Gávea', '87053-266', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32915, 'Pato Branco', 'Senador Teotônio Vilela', 'Fundabem', '85509-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32916, 'Toledo', 'Senador Teotônio Vilela', 'Panorama', '85913-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32917, 'Francisco Beltrão', 'Senador Vergueiro', 'Guanabara', '85604-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32918, 'Colombo', 'Senador Xavier da Silva', 'Jardim Mediterrâneo', '83401-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32919, 'Curitiba', 'Senador Xavier da Silva', 'São Francisco', '80530-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32920, 'Apucarana', 'Senai', 'Parque Industrial Zona Norte', '86800-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32921, 'Londrina', 'Sêneca', 'Universitário', '86050-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32922, 'São José dos Pinhais', 'Sêneca', 'Aristocrata', '83030-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32923, 'Curitiba', 'Sêneca', 'Barreirinha', '82700-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32924, 'Londrina', 'Senegal', 'Ouro Verde', '86080-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32925, 'Pinhais', 'Senegal', 'Vl Dona Guiomar', '83320-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32926, 'Telêmaco Borba', 'Senegal', 'Vila Cristina', '84272-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32927, 'Colombo', 'Senegalia', 'Walfrido do Rosário', '83413-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32928, 'Curitiba', 'Seneval Cardoso', 'Ahú', '80540-370', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32929, 'Ponta Grossa', 'Senges', 'Chapada', '84062-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32930, 'Colombo', 'Senges', 'Jardim Guaraituba', '83410-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32931, 'Toledo', 'Senhor dos Passos', 'Parque Residencial Pancera', '85902-196', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32932, 'Curitiba', 'Senhorinho Gonçalves Pedroso', 'Cajuru', '82960-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32933, 'Curitiba', 'Senta a Pua', 'Bacacheri', '82515-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32934, 'Ponta Grossa', 'Seon', 'Jardim Carvalho', '84016-699', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32935, 'Maringá', 'Sequóia', 'Jardim Pinheiros', '87043-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32936, 'Paranavaí', 'Serafim Afonso Costa', 'Centro', '87702-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32937, 'Paranavaí', 'Serafim Afonso Costa', 'Centro', '87704-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32938, 'Paranavaí', 'Serafim Afonso Costa', 'Jardim São João', '87709-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32939, 'Campo Largo', 'Serafim Amur Ferreira do Amaral', 'Jardim Social', '83606-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32940, 'Curitiba', 'Serafim Amur Ferreira do Amaral', 'Cidade Industrial', '81270-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32941, 'Telêmaco Borba', 'Serafim Colombo Gomes', 'Centro', '84261-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32942, 'Foz do Iguaçu', 'Serafim da Silva', 'Jardim Veraneio', '85855-649', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32943, 'Londrina', 'Serafim Franca', 'Três Marcos', '86046-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32944, 'São José dos Pinhais', 'Serafim Franca', 'São Sebastião', '83075-476', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32945, 'Curitiba', 'Serafim Franca', 'Novo Mundo', '81010-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32946, 'Foz do Iguaçu', 'Serafim José Portes', 'Conjunto Habitacional Plazza', '85862-235', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32947, 'Curitiba', 'Serafim Lucca', 'São Braz', '82320-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32948, 'Apucarana', 'Serafim Morsiani', 'Jardim Colonial II', '86812-556', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32949, 'Londrina', 'Serafim Perez', 'Conjunto Semiramis Barros Braga', '86088-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32950, 'Toledo', 'Serafina Corrêa', 'Jardim La Salle', '85902-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32951, 'Toledo', 'Serafina Corrêa', 'Jardim La Salle', '85903-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32952, 'Curitiba', 'Serafina Cumam Culpi', 'Butiatuvinha', '82400-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32953, 'Curitiba', 'Seraphim Lopes', 'Pilarzinho', '82115-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32954, 'Londrina', 'Seraphin de Almeida', 'Monte Belo', '86041-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32955, 'Curitiba', 'Serapião da Cruz', 'Santa Cândida', '82710-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32956, 'Curitiba', 'Serapião Mendes Soares', 'Capão da Imbuia', '82810-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32957, 'Cascavel', 'Sereia', 'Cataratas', '85818-757', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32958, 'Campo Largo', 'Sereia', 'Rondinha', '83607-310', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32959, 'Foz do Iguaçu', 'Serelepe', 'Conjunto A', '85860-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32960, 'Colombo', 'Serelepe', 'Parque Residencial Santa Terezinha II', '83408-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32961, 'Londrina', 'Sererino Alves da Silva', 'Ouro Branco', '86042-095', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32962, 'São José dos Pinhais', 'Sergino Webber Leite', 'São Sebastião', '83075-479', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32963, 'Araucária', 'Sérgio Aleixo Grebos', 'Barigui', '83707-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32964, 'Curitiba', 'Sérgio Alessandro Gonçalves', 'Cidade Industrial', '81450-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32965, 'Curitiba', 'Sérgio Ângelo Francisco Mattioli', 'Tatuquara', '81480-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32966, 'Londrina', 'Sérgio Augusto Peres da Silva', 'Estados', '86083-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32967, 'Londrina', 'Sérgio Bittencourt', 'Conjunto Vivi Xavier', '86082-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32968, 'Maringá', 'Sérgio Bittencourt', 'Jardim América', '87045-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32969, 'Foz do Iguaçu', 'Sérgio Buarque de Holanda', 'Jardim Dom Pedro I', '85856-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32970, 'Londrina', 'Sérgio Cardoso', 'Jardim São Francisco de Assis', '86067-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32971, 'Curitiba', 'Sérgio Carlos Martins Leal', 'Cidade Industrial', '81305-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32972, 'Apucarana', 'Sérgio Carlos Signolfi', 'Jardim Catuaí', '86802-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32973, 'Colombo', 'Sérgio d''Agostin', 'Jardim Baviera', '83403-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32974, 'Londrina', 'Sérgio Djalma de Holanda', 'Estados', '86083-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32975, 'Cascavel', 'Sérgio Djalma de Hollanda', 'Vila Tolentino', '85802-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32976, 'Cascavel', 'Sérgio Djalma de Hollanda', 'Maria Luiza', '85819-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32977, 'Pinhais', 'Sérgio Dubinski', 'Loteamento Pineville', '83325-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32978, 'Curitiba', 'Sérgio Dudeck', 'Jardim Botânico', '80215-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32979, 'Almirante Tamandaré', 'Sérgio Fernando de Siqueira', 'Jardim Cíntia Mara', '83513-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32980, 'Curitiba', 'Sérgio Fraga', 'Água Verde', '80620-480', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32981, 'Guarapuava', 'Sérgio Gasparetto', 'Vila Carli', '85040-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32982, 'Foz do Iguaçu', 'Sérgio Gasparetto', 'Parque Morumbi III', '85859-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32983, 'Curitiba', 'Sérgio Harris Queirolo', 'Novo Mundo', '81010-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32984, 'Francisco Beltrão', 'Sérgio João Janesko', 'São Cristóvão', '85601-352', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32985, 'Campo Mourão', 'Sérgio Lisa', 'Jardim Maia', '87301-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32986, 'Londrina', 'Sérgio Luís Alves', 'Alto da Boa Vista', '86083-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32987, 'Curitiba', 'Sérgio Luiz Otto', 'Cachoeira', '82710-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32988, 'Curitiba', 'Sérgio Mercer', 'Sítio Cercado', '81900-746', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32989, 'Curitiba', 'Sérgio Navarro', 'Fazendinha', '81320-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32990, 'Foz do Iguaçu', 'Sérgio Oliva', 'Jardim São Rafael II', '85858-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32991, 'Curitiba', 'Sérgio Pereira da Silva', 'Pilarzinho', '82100-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32992, 'Curitiba', 'Sérgio Ribeiro Batista', 'Cidade Industrial', '81170-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32993, 'Londrina', 'Sérgio Romano Macaxeira Montenegro', 'Dom Pedro II', '86073-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32994, 'Foz do Iguaçu', 'Sérgio Roncato', 'Conjunto Residencial Apora', '85869-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32995, 'Curitiba', 'Sérgio Venci', 'Rebouças', '80215-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32996, 'Curitiba', 'Sérgio Verges', 'Vila Izabel', '80240-600', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32997, 'Francisco Beltrão', 'Sergipe', 'Alvorada', '85601-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32998, 'Londrina', 'Sergipe', 'Centro', '86020-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (32999, 'Guarapuava', 'Sergipe', 'Vila Carli', '85045-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33000, 'Foz do Iguaçu', 'Sergipe', 'Vila Maracanã', '85852-230', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33001, 'Londrina', 'Sergipe', 'Centro', '86010-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33002, 'Piraquara', 'Sergipe', 'Jardim dos Estados 2', '83308-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33004, 'Pato Branco', 'Sergipe', 'La Salle', '85505-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33005, 'Paranaguá', 'Sergipe', 'Vila do Povo', '83209-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33006, 'Telêmaco Borba', 'Sergipe', 'Vila Ozorio', '84268-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33007, 'São José dos Pinhais', 'Sergipe', 'Boneca do Iguaçu', '83040-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33008, 'Umuarama', 'Sergipe', 'Zona II', '87501-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33009, 'Colombo', 'Sergipe', 'Vila Guaraci', '83404-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33010, 'Almirante Tamandaré', 'Sergipe', 'Jardim Formosa', '83511-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33011, 'Campo Largo', 'Sergipe', 'Vila Itaqui', '83604-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33012, 'Campo Largo', 'Sergipe', 'Jardim Boa Vista', '83609-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33013, 'Araucária', 'Sergipe', 'Iguaçu', '83701-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33014, 'Apucarana', 'Sergipe', 'Jardim Apucarana', '86804-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33015, 'Curitiba', 'Sergipe', 'Guaíra', '80630-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33016, 'Almirante Tamandaré', 'Seridó', 'Jardim Formosa', '83511-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33017, 'Guarapuava', 'Seriema', 'Conradinho', '85055-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33018, 'Pinhais', 'Seriema', 'Loteamento Alphaville Graciosa', '83327-159', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33019, 'São José dos Pinhais', 'Seriema', 'Colônia Rio Grande', '83025-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33020, 'Londrina', 'Seringueira', 'Charrua', '86071-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33021, 'Foz do Iguaçu', 'Seringueira', 'Jardim Tropical', '85855-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33022, 'Ponta Grossa', 'Seringueira', 'Contorno', '84061-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33023, 'Apucarana', 'Seringueira', 'Jardim Recanto dos Palmares', '86803-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33024, 'Cascavel', 'Seringueira', 'Recanto Tropical', '85807-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33025, 'Arapongas', 'Seringueiro', 'Vila Edio', '86705-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33026, 'Ponta Grossa', 'Serpentina', 'Neves', '84020-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33027, 'Cascavel', 'Serra Alegre', 'Cataratas', '85818-759', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33028, 'Londrina', 'Serra Azul', 'Bandeirantes', '86065-605', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33029, 'Cascavel', 'Serra Azul', 'Cataratas', '85818-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33030, 'Londrina', 'Serra Bonita', 'Messiânico', '86065-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33031, 'Ponta Grossa', 'Serra Clube de Ponta Grossa', 'Boa Vista', '84072-006', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33032, 'Londrina', 'Serra da Bocaina', 'Bandeirantes', '86065-595', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33033, 'Londrina', 'Serra da Borborema', 'Bandeirantes', '86065-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33034, 'Cascavel', 'Serra da Borborema', 'Periolo', '85817-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33035, 'Londrina', 'Serra da Canastra', 'Bandeirantes', '86065-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33036, 'Cascavel', 'Serra da Canastra', 'Periolo', '85817-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33037, 'Londrina', 'Serra da Carioca', 'Gavea', '86065-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33038, 'Londrina', 'Serra da Esperança', 'Bandeirantes', '86065-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33039, 'Apucarana', 'Serra da Esperança', 'Núcleo Habitacional Adriano Correia', '86813-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33040, 'Cascavel', 'Serra da Esperança', 'Morumbi', '85817-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33041, 'Londrina', 'Serra da Estrela', 'Bandeirantes', '86065-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33042, 'Londrina', 'Serra da Fartura', 'Bandeirantes', '86065-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33043, 'Londrina', 'Serra da Graciosa', 'Bandeirantes', '86065-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33044, 'Londrina', 'Serra da Juréia', 'Messiânico', '86065-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33045, 'Londrina', 'Serra da Jurema', 'Bandeirantes', '86065-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33046, 'Apucarana', 'Serra da Lagoa Bonita', 'Núcleo Habitacional Adriano Correia', '86813-270', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33047, 'Apucarana', 'Serra da Laranjinha', 'Núcleo Habitacional Adriano Correia', '86813-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33048, 'Londrina', 'Serra da Mantiqueira', 'Bandeirantes', '86065-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33049, 'Cascavel', 'Serra da Mantiqueira', 'Morumbi', '85817-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33050, 'Apucarana', 'Serra da Mantiqueira', 'Núcleo Habitacional Adriano Correia', '86813-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33051, 'Londrina', 'Serra da Mutuca', 'Messiânico', '86065-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33052, 'Apucarana', 'Serra da Ortigueira', 'Núcleo Habitacional Adriano Correia', '86813-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33053, 'Apucarana', 'Serra da Paranapiacaba', 'Núcleo Habitacional Adriano Correia', '86813-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33054, 'Londrina', 'Serra da Prata', 'Conjunto Habitacional Órion', '86065-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33055, 'Apucarana', 'Serra da Prata', 'Núcleo Habitacional Adriano Correia', '86813-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33056, 'Londrina', 'Serra da Raiz', 'Bandeirantes', '86065-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33057, 'Apucarana', 'Serra da Ribeira', 'Núcleo Habitacional Adriano Correia', '86813-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33058, 'Londrina', 'Serra da Taquara', 'Bandeirantes', '86065-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33059, 'Cascavel', 'Serra da Taquara', 'Periolo', '85817-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33060, 'Londrina', 'Serra D''Agua', 'Bandeirantes', '86065-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33061, 'Londrina', 'Serra das Araras', 'Bandeirantes', '86065-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33062, 'Apucarana', 'Serra das Araras', 'Núcleo Habitacional Adriano Correia', '86813-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33063, 'Londrina', 'Serra das Coroas', 'Messiânico', '86065-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33064, 'Londrina', 'Serra das Flores', 'Jockey Club', '86065-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33065, 'Londrina', 'Serra das Furnas', 'Bandeirantes', '86065-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33066, 'Cascavel', 'Serra das Furnas', 'Morumbi', '85817-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33067, 'Apucarana', 'Serra das Furnas', 'Núcleo Habitacional Adriano Correia', '86813-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33068, 'Londrina', 'Serra das Marrecas', 'Messiânico', '86065-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33069, 'Londrina', 'Serra das Palmeiras', 'Bandeirantes', '86065-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33070, 'Cascavel', 'Serra das Palmeiras', 'Periolo', '85817-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33071, 'Londrina', 'Serra das Vertentes', 'Rodocentro', '86065-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33072, 'Londrina', 'Serra de Bragança', 'Messiânico', '86065-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33073, 'Londrina', 'Serra de Itatiaia', 'Rodocentro', '86065-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33074, 'Londrina', 'Serra de Monte Carlo', 'Messiânico', '86065-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33075, 'Londrina', 'Serra de Roraima', 'Bandeirantes', '86065-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33076, 'Londrina', 'Serra de Santana', 'Messiânico', '86065-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33077, 'Cascavel', 'Serra de Santana', 'Morumbi', '85817-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33078, 'Londrina', 'Serra de Tabatinga', 'Bandeirantes', '86065-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33079, 'Londrina', 'Serra do Amparo', 'Bandeirantes', '86065-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33080, 'Apucarana', 'Serra do Apocarana', 'Núcleo Habitacional Adriano Correia', '86813-260', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33081, 'Londrina', 'Serra do Bedengó', 'Messiânico', '86065-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33082, 'Londrina', 'Serra do Boi', 'Bandeirantes', '86065-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33083, 'Cascavel', 'Serra do Boi', 'Periolo', '85817-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33084, 'Londrina', 'Serra do Cadeado', 'Bandeirantes', '86065-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33085, 'Cascavel', 'Serra do Cadeado', 'Periolo', '85817-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33086, 'Apucarana', 'Serra do Cadeado', 'Núcleo Habitacional Adriano Correia', '86813-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33087, 'Londrina', 'Serra do Cantu', 'Bandeirantes', '86065-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33088, 'Londrina', 'Serra do Caparaó', 'Bandeirantes', '86065-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33089, 'Londrina', 'Serra do Corumbá', 'Rodocentro', '86065-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33090, 'Londrina', 'Serra do Espigão', 'Bandeirantes', '86065-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33091, 'Telêmaco Borba', 'Serra do Facão', 'Área 02', '84267-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33092, 'Londrina', 'Serra do Flamengo', 'Bandeirantes', '86065-540', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33093, 'Londrina', 'Serra do Horizonte', 'Bandeirantes', '86065-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33094, 'Londrina', 'Serra do Inaja', 'Conjunto Habitacional Órion', '86065-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33095, 'Cascavel', 'Serra do Itatiaia', 'Periolo', '85817-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33096, 'Londrina', 'Serra do Jatobá', 'Conjunto Habitacional Órion', '86065-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33097, 'Apucarana', 'Serra do Leão', 'Núcleo Habitacional Adriano Correia', '86813-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33098, 'Londrina', 'Serra do Mar', 'Bandeirantes', '86065-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33099, 'Cascavel', 'Serra do Mar', 'Morumbi', '85817-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33100, 'Apucarana', 'Serra do Mar', 'Núcleo Habitacional Adriano Correia', '86813-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33101, 'Londrina', 'Serra do Maracaju', 'Bandeirantes', '86065-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33102, 'Londrina', 'Serra do Mel', 'Bandeirantes', '86065-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33103, 'Cascavel', 'Serra do Mel', 'Cataratas', '85817-456', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33104, 'Londrina', 'Serra do Mirador', 'Bandeirantes', '86065-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33105, 'Cascavel', 'Serra do Mirador', 'Cataratas', '85817-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33106, 'Apucarana', 'Serra do Mocambo', 'Núcleo Habitacional Adriano Correia', '86813-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33107, 'Londrina', 'Serra do Monte Alto', 'Messiânico', '86065-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33108, 'Londrina', 'Serra do Parati', 'Bandeirantes', '86065-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33109, 'Cascavel', 'Serra do Parati', 'Cataratas', '85817-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33110, 'Londrina', 'Serra do Parima', 'Gavea', '86065-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33111, 'Apucarana', 'Serra do Piquiri', 'Núcleo Habitacional Adriano Correia', '86813-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33112, 'Cascavel', 'Serra do Purunã', 'Morumbi', '85817-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33113, 'Londrina', 'Serra do Roncador', 'Bandeirantes', '86065-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33114, 'Apucarana', 'Serra do Tanguá', 'Núcleo Habitacional Adriano Correia', '86813-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33115, 'Londrina', 'Serra do Tubarão', 'Jockey Club', '86065-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33116, 'Londrina', 'Serra do Tumucumac', 'Bandeirantes', '86065-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33117, 'Londrina', 'Serra do Urucum', 'Rodocentro', '86065-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33118, 'Londrina', 'Serra do Vento', 'Bandeirantes', '86065-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33119, 'Cascavel', 'Serra do Vento', 'Periolo', '85817-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33120, 'Londrina', 'Serra do Xapecó', 'Bandeirantes', '86065-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33121, 'Londrina', 'Serra Dois Irmãos', 'Bandeirantes', '86065-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33122, 'Londrina', 'Serra dos Andes', 'Messiânico', '86065-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33123, 'Cascavel', 'Serra dos Andes', 'Periolo', '85817-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33124, 'Londrina', 'Serra dos Mangabeiros', 'Bandeirantes', '86065-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33125, 'Apucarana', 'Serra dos Mulatos', 'Núcleo Habitacional Adriano Correia', '86813-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33126, 'Londrina', 'Serra dos Órgãos', 'Bandeirantes', '86065-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33127, 'Londrina', 'Serra dos Parecis', 'Bandeirantes', '86065-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33128, 'Londrina', 'Serra dos Pirineus', 'Bandeirantes', '86065-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33129, 'Apucarana', 'Serra dos Porongos', 'Núcleo Habitacional Adriano Correia', '86813-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33130, 'Foz do Iguaçu', 'Serra Dourada', 'Parque Morumbi II', '85858-696', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33131, 'Foz do Iguaçu', 'Serra Dourada', 'Parque Morumbi II', '85859-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33132, 'Londrina', 'Serra Dourada', 'Bandeirantes', '86065-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33133, 'Cascavel', 'Serra Dourada', 'Periolo', '85817-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33134, 'Londrina', 'Serra Encantada', 'Conjunto Habitacional Órion', '86065-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33135, 'Cascavel', 'Serra Encantada', 'Cataratas', '85817-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33136, 'Londrina', 'Serra Formosa', 'Bandeirantes', '86065-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33137, 'Cascavel', 'Serra Formosa', 'Cataratas', '85817-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33138, 'Londrina', 'Serra Fria', 'Bandeirantes', '86065-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33139, 'Londrina', 'Serra Geral', 'Bandeirantes', '86065-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33140, 'Cascavel', 'Serra Geral', 'Cataratas', '85818-758', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33141, 'Londrina', 'Serra Grande', 'Bandeirantes', '86065-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33142, 'Telêmaco Borba', 'Serra Grande', 'Área 02', '84267-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33143, 'Cascavel', 'Serra Grande', 'Periolo', '85817-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33144, 'Londrina', 'Serra Jaire', 'Bandeirantes', '86065-545', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33145, 'Londrina', 'Serra Japuíra', 'Messiânico', '86065-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33146, 'Londrina', 'Serra Negra', 'Bandeirantes', '86065-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33147, 'Maringá', 'Serra Negra', 'Jardim Alvorada', '87033-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33148, 'Cascavel', 'Serra Negra', 'Morumbi', '85817-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33149, 'Londrina', 'Serra Nova', 'Bandeirantes', '86065-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33150, 'Cascavel', 'Serra Nova', 'Cataratas', '85817-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33151, 'Londrina', 'Serra Paranapiacaba', 'Bandeirantes', '86065-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33152, 'Londrina', 'Serra Pedra Selada', 'Rodocentro', '86065-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33153, 'Londrina', 'Serra Preta', 'Jockey Club', '86065-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33154, 'Londrina', 'Serra Redonda', 'Gavea', '86065-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33155, 'Cascavel', 'Serra Redonda', 'Periolo', '85817-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33156, 'Londrina', 'Serra Salitre', 'Gavea', '86065-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33157, 'Apucarana', 'Serra São João', 'Núcleo Habitacional Adriano Correia', '86813-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33158, 'Apucarana', 'Serra São Joaquim', 'Núcleo Habitacional Adriano Correia', '86813-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33159, 'Londrina', 'Serra Velha', 'Bandeirantes', '86065-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33160, 'Londrina', 'Serra Verde', 'Bandeirantes', '86065-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33161, 'Cascavel', 'Serra Verde', 'Periolo', '85817-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33162, 'Telêmaco Borba', 'Serradinho', 'Área 02', '84267-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33163, 'Foz do Iguaçu', 'Serrana', 'Jardim Curitibano IV', '85869-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33164, 'Arapongas', 'Serra-serra', 'Vila São João', '86708-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33165, 'Londrina', 'Serrita', 'Jockey Club', '86065-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33166, 'Ponta Grossa', 'Sertaneja', 'Contorno', '84052-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33167, 'Pinhais', 'Sertaneja', 'Jardim Pedro Demeterco', '83324-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33168, 'Colombo', 'Sertaneja', 'Jardim Cristina III', '83410-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33169, 'Arapongas', 'Sertaneja', 'Casa Família Arapongas II', '86706-406', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33170, 'Curitiba', 'Sertaneja', 'Sítio Cercado', '81900-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33171, 'Ponta Grossa', 'Sertanópolis', 'Contorno', '84052-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33172, 'Londrina', 'Sertanópolis', 'Lindóia', '86031-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33173, 'Ponta Grossa', 'Sertanópolis', 'Uvaranas', '84031-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33174, 'Umuarama', 'Sertanópolis', 'Parque Tarumã', '87508-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33175, 'Curitiba', 'Servidor Antônio Kaminski', 'Novo Mundo', '81050-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33176, 'Toledo', 'Servilio Boldrini', 'Residencial Santa Clara', '85908-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33177, 'Foz do Iguaçu', 'Servilio de Jesus', 'Parque Residencial Santa Rita', '85858-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33178, 'Londrina', 'Servino Freitas Soares', 'Parigot de Souza 2', '86082-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33179, 'Londrina', 'Sérvula Assumção', 'São Pedro', '86036-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33180, 'Ponta Grossa', 'Sérvulo dos Santos', 'Oficinas', '84035-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33181, 'Paranaguá', 'Sesinando Benckendorf', 'Emboguaçu', '83206-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33182, 'Curitiba', 'Sesinando Chaves', 'Cajuru', '82900-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33183, 'Campo Mourão', 'Sessenta e Cinco', 'Jardim Tropical I', '87310-186', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33184, 'Toledo', 'Sestilio Parizotto', 'Conjunto Habitacional São Francisco', '85915-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33185, 'Francisco Beltrão', 'Sete', 'Cristo Rei', '85602-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33186, 'Foz do Iguaçu', 'Sete', 'Três Pinheiros', '85856-659', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33187, 'Ponta Grossa', 'Sete', 'Chapada', '84063-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33188, 'Ponta Grossa', 'Sete', 'Uvaranas', '84032-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33189, 'Piraquara', 'Sete', 'Chácara Águas Claras', '83309-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33190, 'Ponta Grossa', 'Sete', 'Uvaranas', '84022-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33191, 'Paranaguá', 'Sete', 'Jardim Paraná', '83215-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33192, 'Ponta Grossa', 'Sete', 'Uvaranas', '84030-487', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33193, 'Paranavaí', 'Sete', 'Vila Prudêncio', '87702-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33194, 'Piraquara', 'Sete', 'Chácara Águas Claras', '83309-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33195, 'Ponta Grossa', 'Sete', 'Contorno', '84060-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33196, 'Paranavaí', 'Sete', 'Conjunto Dona Josefa', '87708-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33197, 'Ponta Grossa', 'Sete', 'Jardim Carvalho', '84016-516', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33198, 'Ponta Grossa', 'Sete', 'Uvaranas', '84026-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33199, 'Ponta Grossa', 'Sete', 'Uvaranas', '84030-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33200, 'Ponta Grossa', 'Sete', 'Contorno', '84060-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33201, 'Paranavaí', 'Sete', 'Parque Morumbi', '87703-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33202, 'Ponta Grossa', 'Sete', 'Chapada', '84064-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33203, 'Ponta Grossa', 'Sete', 'Chapada', '84063-106', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33204, 'Ponta Grossa', 'Sete', 'Oficinas', '84035-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33205, 'Umuarama', 'Sete', 'Jardim Maria Lúcia', '87501-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33206, 'Sarandi', 'Sete', 'Jardim Independência I', '87114-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33207, 'Umuarama', 'Sete', 'Jardim Beira Rio', '87507-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33208, 'Umuarama', 'Sete', 'Jardim São Cristóvão', '87507-366', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33209, 'Almirante Tamandaré', 'Sete', 'Jardim Tatiana', '83513-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33210, 'Campo Largo', 'Sete', 'Loteamento São Gerônimo', '83606-186', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33211, 'Almirante Tamandaré', 'Sete', 'Jardim das Oliveiras', '83502-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33212, 'Almirante Tamandaré', 'Sete', 'Jardim Cíntia Mara', '83513-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33213, 'Campo Largo', 'Sete', 'Moradias Bom Jesus', '83602-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33214, 'Campo Largo', 'Sete', 'Jardim Lorenzete', '83603-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33215, 'Campo Largo', 'Sete', 'Jardim Keli Cristina', '83609-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33216, 'Campo Largo', 'Sete', 'Vila Mariano Torres', '83608-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33217, 'Campo Largo', 'Sete', 'Núcleo Habitacional Mathias Batista', '83604-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33218, 'Campo Largo', 'Sete', 'Vila Pompéia', '83608-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33219, 'Campo Largo', 'Sete', 'Jardim Padre José de Anchieta', '83607-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33220, 'Campo Largo', 'Sete', 'Vila São Luiz', '83608-136', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33221, 'Campo Largo', 'Sete', 'Jardim das Acácias', '83603-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33222, 'Foz do Iguaçu', 'Sete Barras', 'Novo Mundo', '85862-388', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33223, 'Maringá', 'Sete de Abril', 'Parque Residencial Aeroporto', '87055-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33224, 'Curitiba', 'Sete de Abril', 'Alto da Rua XV', '80050-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33225, 'Curitiba', 'Sete de Abril', 'Alto da Rua XV', '80040-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33226, 'Laranjeiras do Sul', 'Sete de Setembro', 'Água Verde', '85302-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33227, 'Londrina', 'Sete de Setembro', 'Centro', '86010-430', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33228, 'Guarapuava', 'Sete de Setembro', 'Morro Alto', '85065-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33229, 'Laranjeiras do Sul', 'Sete de Setembro', 'Centro', '85301-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33230, 'Francisco Beltrão', 'Sete de Setembro', 'Cristo Rei', '85602-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33231, 'Ponta Grossa', 'Sete de Setembro', 'Centro', '84010-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33232, 'Paranavaí', 'Sete de Setembro', 'Jardim André Luiz', '87708-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33233, 'Maringá', 'Sete de Setembro', 'Jardim da Glória', '87047-130', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33234, 'Paranaguá', 'Sete de Setembro', 'Centro Histórico', '83203-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33235, 'Maringá', 'Sete de Setembro', 'Zona 05', '87015-290', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33236, 'Pato Branco', 'Sete de Setembro', 'Santa Terezinha', '85506-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33237, 'Pinhais', 'Sete de Setembro', 'Jardim Pinhais', '83323-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33238, 'Umuarama', 'Sete de Setembro', 'Jardim Panorama', '87501-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33239, 'Toledo', 'Sete de Setembro', 'Centro', '85900-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33240, 'Toledo', 'Sete de Setembro', 'Jardim La Salle', '85902-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33241, 'Sarandi', 'Sete de Setembro', 'Parque Industrial IV', '87111-706', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33242, 'Telêmaco Borba', 'Sete de Setembro', 'Nossa Senhora do Perpétuo Socorro', '84265-560', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33243, 'Umuarama', 'Sete de Setembro', 'Zona VI', '87503-190', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33244, 'São José dos Pinhais', 'Sete de Setembro', 'Centro', '83005-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33245, 'Colombo', 'Sete de Setembro', 'Jardim Palmares', '83412-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33246, 'Cascavel', 'Sete de Setembro', 'Ciro Nardi', '85802-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33247, 'Apucarana', 'Sete de Setembro', 'Vila Regina', '86801-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33248, 'Cascavel', 'Sete de Setembro', 'Independência', '85811-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33249, 'Cambé', 'Sete de Setembro', 'Vila Atalaia', '86181-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33250, 'Campo Largo', 'Sete de Setembro', 'Centro', '83601-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33251, 'Araucária', 'Sete de Setembro', 'Centro', '83702-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33252, 'Cascavel', 'Sete de Setembro', 'Centro', '85810-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33253, 'Cascavel', 'Sete de Setembro', 'Centro', '85801-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33254, 'Castro', 'Sete de Setembro', 'Vila Rio Branco', '84172-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33255, 'Cascavel', 'Sete de Setembro', 'Parque São Paulo', '85803-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33256, 'Curitiba', 'Sete de Setembro', 'Centro', '80250-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33257, 'Curitiba', 'Sete de Setembro', 'Batel', '80240-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33258, 'Curitiba', 'Sete de Setembro', 'Centro', '80230-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33259, 'Curitiba', 'Sete de Setembro', 'Centro', '80060-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33260, 'Curitiba', 'Sete de Setembro', 'Alto da Rua XV', '80050-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33261, 'Curitiba', 'Sete de Setembro', 'Batel', '80240-001', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33262, 'Foz do Iguaçu', 'Sete Lagoas', 'Jardim do Norte', '85854-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33263, 'Curitiba', 'Sete Lagoas', 'Campo Comprido', '81240-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33264, 'São José dos Pinhais', 'Sete Quedas', 'Ouro Fino', '83015-030', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33265, 'Telêmaco Borba', 'Sete Quedas', 'Área 07', '84270-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33266, 'Curitiba', 'Setembrino Portella Neto', 'Cidade Industrial', '81450-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33267, 'Almirante Tamandaré', 'Setenta', 'Jardim Roma', '83504-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33268, 'Ponta Grossa', 'Sete-Vila Leila Maria', 'Boa Vista', '84072-009', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33269, 'Curitiba', 'Sétimo Simionato', 'Capão da Imbuia', '82800-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33270, 'Maringá', 'Setúbal', 'Zona 08', '87050-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33271, 'Londrina', 'Seul', 'Cláudia', '86050-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33272, 'Maringá', 'Seul', 'Jardim Atlânta', '87045-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33273, 'Londrina', 'Severiano José de Souza', 'Milton Gavetti', '86078-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33274, 'Piraquara', 'Severino Alberti', 'Jardim Esmeralda', '83301-340', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33275, 'Londrina', 'Severino Aldigueri', 'São Lourenço', '86043-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33276, 'Maringá', 'Severino Antônio do Carmo', 'Conjunto Habitacional Requião', '87047-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33277, 'Toledo', 'Severino Barbieri', 'Independência', '85906-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33278, 'Curitiba', 'Severino Batista Furlan', 'Cidade Industrial', '81305-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33279, 'Francisco Beltrão', 'Severino Daros', 'Jardim Novo Mundo', '85602-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33280, 'São José dos Pinhais', 'Severino Fasolin', 'Braga', '83020-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33281, 'Curitiba', 'Severino Gonçalves', 'Alto Boqueirão', '81770-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33282, 'Paranavaí', 'Severino Gouveia Botelho', 'Parque Morumbi', '87703-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33283, 'Toledo', 'Severino Manosso', 'Independência', '85906-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33284, 'Pinhais', 'Severino Massignan', 'Planta Guilherme Weiss', '83322-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33285, 'Londrina', 'Severino Mendes de Almeida', 'Residencial Abussafe', '86037-785', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33286, 'Cascavel', 'Severino Miola', 'Cataratas', '85817-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33287, 'São José dos Pinhais', 'Severino Nunes da Rocha Rios', 'Ipê', '83055-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33288, 'Londrina', 'Severino Peba', 'Jardim Maracanã', '86056-876', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33289, 'Foz do Iguaçu', 'Severino Ramirez', 'Loteamento Universitário das Américas', '85870-607', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33290, 'Londrina', 'Severino Santini', 'Conjunto Semiramis Barros Braga', '86088-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33291, 'Piraquara', 'Severino Vieira da Silva', 'Guarituba', '83311-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33292, 'Colombo', 'Severo Camargo', 'Santa Gema', '83415-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33293, 'Maringá', 'Severo de Faria Franco', 'Conjunto João de Barro Cidade Canção', '87053-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33294, 'Londrina', 'Severo de Rudim Canziani', 'Jardim Acapulco', '86045-105', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33295, 'Campo Mourão', 'Severo Gomes', 'Jardim Santa Cruz', '87309-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33296, 'Colombo', 'Severo Ribeiro de Camargo', 'Jardim dos Eucaliptos', '83408-509', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33297, 'Colombo', 'Severo Taverna', 'Vila São Paulo', '83411-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33298, 'Maringá', 'Sevilha', 'Loteamento Madrid', '87053-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33299, 'Curitiba', 'Sezefredo Homann', 'Fazendinha', '81320-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33300, 'São José dos Pinhais', 'Sezefredo Portes de Brito', 'Braga', '83020-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33301, 'São José dos Pinhais', 'Sezinanda Borges Nogueira', 'Braga', '83020-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33302, 'São José dos Pinhais', 'Sezinando Cordeiro', 'Roseira', '83070-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33303, 'São José dos Pinhais', 'Sezinando Ferreira da Cruz', 'Miringuava', '83090-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33304, 'São José dos Pinhais', 'Sezinando Martinato da Cruz', 'Afonso Pena', '83045-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33305, 'Curitiba', 'Sezinando Martinho da Cruz', 'Fazendinha', '81330-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33306, 'Ponta Grossa', 'Sezinho Mattos de Souza', 'Orfãs', '84015-126', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33307, 'Araucária', 'Sezino Basso', 'Centro', '83702-610', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33308, 'Ponta Grossa', 'Sezino Mattos de Souza', 'Orfãs', '84015-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33309, 'Colombo', 'Sgoda', 'Jardim Santa Fé', '83403-525', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33310, 'Curitiba', 'Shakespeare', 'Barreirinha', '82700-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33311, 'Maringá', 'Shalon', 'Vila Cleópatra', '87010-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33312, 'Piraquara', 'Shalon', 'Planta Deodoro', '83304-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33313, 'Umuarama', 'Shalon', 'Parque Caiuá', '87508-236', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33314, 'Londrina', 'Shangai', 'Cláudia', '86050-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33315, 'Foz do Iguaçu', 'Shangrilá', 'Lago dos Cisnes', '85861-270', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33316, 'Apucarana', 'Sheila Cristiane Saragoza', 'Jardim Catuaí', '86802-606', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33317, 'Maringá', 'Shibazaburo Katazato', 'Jardim Alvorada', '87035-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33318, 'Curitiba', 'Shigeru Hayashi', 'Cidade Industrial', '81170-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33319, 'Apucarana', 'Shigueo Kuroda', 'Jardim Portal do Lago', '86802-067', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33320, 'Londrina', 'Shigueyasu Ymagawa', 'Gleba Fazenda Palhano', '86055-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33321, 'Colombo', 'Shirlei Boeira Souto', 'Centro Industrial Mauá', '83413-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33322, 'Toledo', 'Shirley Maria Lorandi Saurin', 'Jardim Planalto', '85904-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33323, 'Londrina', 'Shisei Toma', 'Colonial', '86047-256', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33324, 'Campo Mourão', 'Shuhei Uetsuka', 'Jardim Lar Paraná', '87305-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33325, 'Almirante Tamandaré', 'Sião', 'Jardim Santa Fé', '83511-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33326, 'Arapongas', 'Sibete', 'Conjunto Del Condor', '86703-327', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33327, 'Cascavel', 'Sibipiruna', 'Recanto Tropical', '85807-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33328, 'Apucarana', 'Sibipiruna', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33329, 'Francisco Beltrão', 'Sicília', 'Jardim Floresta', '85603-386', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33330, 'Londrina', 'Sicília', 'Parque Residencial João Piza', '86041-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33331, 'Ponta Grossa', 'Sidim', 'Jardim Carvalho', '84016-666', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33332, 'Maringá', 'Sidineia Maria Portes Name', 'Jardim Olímpico', '87070-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33333, 'Londrina', 'Sidnei José Franco', 'Jardim Strass', '86084-828', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33334, 'Curitiba', 'Sidnei Strafite de Oliveira', 'São Braz', '82310-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33335, 'Apucarana', 'Sidney Geraldo', 'Núcleo Habitacional Heitor S Pinheiro', '86806-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33336, 'Londrina', 'Sidney Miller', 'Colúmbia', '86057-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33337, 'Londrina', 'Sidrack Silva', 'Aeroporto', '86038-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33338, 'Londrina', 'Sidrak Silva Filho', 'Jardim Piza', '86073-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33339, 'Curitiba', 'Siegfried Rigler', 'São Lourenço', '82200-590', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33340, 'Curitiba', 'Sigfredo Day', 'Cidade Industrial', '81170-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33341, 'Ponta Grossa', 'Sigma', 'Cará-cará', '84043-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33342, 'Ponta Grossa', 'Silas Salem', 'Boa Vista', '84072-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33343, 'São José dos Pinhais', 'Silene Ribas Schilipake', 'Rio Pequeno', '83065-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33344, 'Paranaguá', 'Silfredo Veiga', 'Jardim Araçá', '83221-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33345, 'Apucarana', 'Silício', 'Parque Industrial Zona Norte', '86806-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33346, 'Pato Branco', 'Siliprandi', 'Alvorada', '85508-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33347, 'Foz do Iguaçu', 'Silmar Edson Rauber', 'Jardim Califórnia', '85858-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33348, 'Foz do Iguaçu', 'Silva Jardim', 'Jardim Boa Vista', '85864-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33349, 'Laranjeiras do Sul', 'Silva Jardim', 'São Francisco', '85303-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33350, 'Pato Branco', 'Silva Jardim', 'Vila Isabel', '85504-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33351, 'Maringá', 'Silva Jardim', 'Zona 01', '87013-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33352, 'Ponta Grossa', 'Silva Jardim', 'Centro', '84040-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33353, 'Toledo', 'Silva Jardim', 'Boa Esperança', '85909-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33354, 'Apucarana', 'Silva Jardim', 'Vila Santa Lorena', '86811-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33355, 'Curitiba', 'Silva Jardim', 'Rebouças', '80230-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33356, 'Curitiba', 'Silva Jardim', 'Rebouças', '80250-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33357, 'Curitiba', 'Silva Jardim', 'Água Verde', '80240-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33358, 'Curitiba', 'Silva Jardim', 'Água Verde', '80240-021', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33359, 'Campo Mourão', 'Silva Ribeiro', 'Jardim Fernando', '87305-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33360, 'Foz do Iguaçu', 'Silvano Benitez', 'Loteameto Budel', '85867-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33361, 'Londrina', 'Silvano Caramori Neto', 'Jardim Barcelona', '86073-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33362, 'Foz do Iguaçu', 'Silvano Gutierrez', 'Jardim Vasco da Gama', '85862-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33363, 'São José dos Pinhais', 'Silvano Moreschi', 'Aristocrata', '83025-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33364, 'Cascavel', 'Silveira', 'Universitário', '85819-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33365, 'Pato Branco', 'Silveira Martins', 'Brasília', '85504-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33366, 'Curitiba', 'Silveira Martins', 'Guabirotuba', '81510-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33367, 'Foz do Iguaçu', 'Silveira Neto', 'Jardim Veraneio', '85855-645', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33368, 'Pinhais', 'Silveira Neto', 'Planta Núcleo Colonial de Pinhais', '83321-370', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33369, 'Curitiba', 'Silveira Neto', 'Água Verde', '80620-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33370, 'Ponta Grossa', 'Silveira Netto', 'Chapada', '84062-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33371, 'Curitiba', 'Silveira Peixoto', 'Batel', '80240-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33372, 'Guarapuava', 'Silveira Silva', 'São Cristóvão', '85060-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33373, 'Umuarama', 'Silvério', 'Zona VI', '87503-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33374, 'Francisco Beltrão', 'Silvério Abdala', 'Água Branca', '85601-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33375, 'Londrina', 'Silvério Campana', 'Conjunto Habitacional Saltinho', '86042-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33376, 'Foz do Iguaçu', 'Silvério de Oliveira', 'Conjunto Habitacional Fernanda', '85862-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33377, 'Campo Mourão', 'Silvério Farago', 'Centro', '87301-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33378, 'Campo Largo', 'Silvério Martins da Silva', 'Jardim Rondinha', '83607-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33379, 'Londrina', 'Silvério Plagia', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33380, 'Cascavel', 'Silverstone', 'Interlagos', '85814-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33381, 'Cascavel', 'Silvestre Bonatto', 'Alto Alegre', '85805-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33382, 'Colombo', 'Silvestre Cavalari', 'Imbuial', '83415-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33383, 'Colombo', 'Silvestre Cavalari', 'São Gabriel', '83415-446', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33384, 'Curitiba', 'Silvestre Kalenetz', 'Tarumã', '82530-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33385, 'Curitiba', 'Silvestre Kloss', 'Santo Inácio', '82010-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33386, 'Londrina', 'Silvestre Sampieri', 'Jardim Nova Esperança', '86044-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33387, 'Curitiba', 'Silvestre Wichinievski', 'São Braz', '82315-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33388, 'Francisco Beltrão', 'Silvia Abdala', 'Água Branca', '85601-336', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33389, 'Curitiba', 'Sílvia Gomes de Mattos', 'Barreirinha', '82700-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33390, 'Ponta Grossa', 'Sílvia Machado de Souza', 'Estrela', '84050-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33391, 'Toledo', 'Sílvia Manica', 'Residencial Santa Clara', '85907-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33392, 'Curitiba', 'Sílvia Maria Lacerda', 'Sítio Cercado', '81910-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33393, 'Francisco Beltrão', 'Silvino Antônio Battin', 'Nova Petrópolis', '85601-149', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33394, 'Cascavel', 'Silvino Blender', 'Alto Alegre', '85805-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33395, 'Foz do Iguaçu', 'Silvino Dal''Bo', 'Jardim Polo Centro', '85863-759', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33396, 'Guarapuava', 'Silvino Pereira da Silva', 'Dos Estados', '85035-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33397, 'Castro', 'Sílvio Afonso Martins Marques de Souza', 'Jardim Social Arapongas', '84174-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33398, 'Foz do Iguaçu', 'Sílvio Américo Sasdelli', 'Conjunto A', '85869-580', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33399, 'Foz do Iguaçu', 'Sílvio Américo Sasdelli', 'Conjunto A', '85866-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33400, 'Curitiba', 'Sílvio Assumpção', 'Cidade Industrial', '81305-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33401, 'Londrina', 'Silvio Barto dos Santos', 'Dom Pedro II', '86073-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33402, 'Toledo', 'Sílvio Bresolin', 'Sachini', '85903-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33403, 'Curitiba', 'Sílvio Brunatto', 'Santa Felicidade', '82015-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33404, 'Londrina', 'Sílvio Bussadori', 'Jardim Tókio', '86063-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33405, 'Paranavaí', 'Sílvio Caldas', 'Jardim Ibirapuera', '87705-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33406, 'Paranavaí', 'Sílvio Caldas', 'Jardim Ouro Branco', '87704-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33407, 'Araucária', 'Sílvio Cantele', 'Capela Velha', '83706-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33408, 'Curitiba', 'Sílvio Colle', 'Bacacheri', '82515-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33409, 'Londrina', 'Sílvio Corrêa da Silva', 'Monterey', '86038-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33410, 'Ponta Grossa', 'Sílvio Cosmoski', 'Boa Vista', '84072-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33411, 'Curitiba', 'Sílvio da Maia Moreira', 'Uberaba', '81580-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33412, 'Campo Largo', 'Sílvio Dallagrana', 'Vila David Antônio', '83609-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33413, 'Cambé', 'Sílvio Dalmas', 'Novo Bandeirantes', '86188-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33414, 'São José dos Pinhais', 'Sílvio dal''Negro', 'Colônia Rio Grande', '83025-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33415, 'Londrina', 'Silvio de Souza Campos', 'Conjunto Habitacional José Garcia Molina', '86080-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33416, 'Curitiba', 'Sílvio Duarte', 'Cidade Industrial', '81310-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33417, 'Curitiba', 'Sílvio Duque Guimarães', 'Tatuquara', '81470-165', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33418, 'Curitiba', 'Sílvio Gusso', 'Capão Raso', '81110-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33419, 'Curitiba', 'Sílvio Heimbecker', 'Alto Boqueirão', '81850-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33420, 'Curitiba', 'Sílvio Izair Ferro', 'Boqueirão', '81750-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33421, 'Piraquara', 'Sílvio José Pereira', 'Planta Guarituba Pequena', '83310-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33422, 'Londrina', 'Sílvio Lamaneres de Oliveira', 'Lagoa Dourada', '86041-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33423, 'Campo Mourão', 'Sílvio Legnani', 'Jardim Francisco Ferreira Albuquerque', '87309-096', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33424, 'Londrina', 'Sílvio Lourenço Leite', 'Jardim dos Alpes III', '86045-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33425, 'Curitiba', 'Sílvio Manfron', 'Butiatuvinha', '82400-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33426, 'Londrina', 'Sílvio Mariano da Silva', 'Conjunto Ernani Moura Lima 1', '86043-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33427, 'Castro', 'Sílvio Marques de Souza', 'Água Suja', '84165-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33428, 'Apucarana', 'Silvio Miliari', 'Recanto Bom Retiro', '86803-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33429, 'Curitiba', 'Sílvio Neri Carcereri', 'Pilarzinho', '82120-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33430, 'Londrina', 'Sílvio Pegoraro', 'Petrópolis', '86015-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33431, 'Campo Mourão', 'Sílvio Perci Ferro', 'Jardim Izabel', '87309-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33432, 'Londrina', 'Silvio Pereira de Jesus', 'Parigot de Souza 2', '86082-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33433, 'São José dos Pinhais', 'Sílvio Pinto Ribeiro', 'Planta Quississana', '83085-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33434, 'Curitiba', 'Sílvio Piotto', 'Campo Comprido', '81200-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33435, 'Foz do Iguaçu', 'Sílvio Romero', 'Jardim Jupira', '85865-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33436, 'Ponta Grossa', 'Sílvio Romero', 'Oficinas', '84040-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33437, 'Curitiba', 'Sílvio Romero', 'Jardim Social', '82520-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33438, 'Maringá', 'Silvio Schenatto', 'Jardim Novo Horizonte', '87010-146', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33439, 'Foz do Iguaçu', 'Sílvio Sotomaior', 'Pilar Parque Campestre', '85862-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33440, 'Cambé', 'Sílvio Trova', 'Jardim Riviera', '86187-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33441, 'Pato Branco', 'Sílvio Vidal', 'Centro', '85505-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33442, 'Curitiba', 'Sílvio Zanatta', 'Santo Inácio', '82010-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33443, 'Londrina', 'Sílvio Zancarli', 'Espanha', '86027-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33444, 'Curitiba', 'Simão Bolivar', 'Alto da Glória', '80030-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33445, 'Curitiba', 'Simão Bolivar', 'Juvevê', '80040-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33446, 'Ponta Grossa', 'Simão Bolívar', 'Oficinas', '84045-470', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33447, 'Curitiba', 'Simão Brante', 'Uberaba', '81580-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33448, 'Curitiba', 'Simão Brante', 'Uberaba', '81570-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33449, 'Maringá', 'Simão Busato', 'Conjunto Habitacional Karina', '87047-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33450, 'Almirante Tamandaré', 'Simão Domacoski', 'Jardim Planalto', '83512-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33451, 'Curitiba', 'Simão Guebur', 'Uberaba', '81580-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33452, 'Curitiba', 'Simão Lissa', 'Santo Inácio', '82010-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33453, 'Curitiba', 'Simão Mansur', 'Boa Vista', '82540-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33454, 'Ponta Grossa', 'Simão Nasseh', 'Uvaranas', '84031-325', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33455, 'Curitiba', 'Simão Purkote', 'Santa Cândida', '82720-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33456, 'Apucarana', 'Simeão Carranza', 'Núcleo Habitacional Marcos Freire', '86805-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33457, 'Guarapuava', 'Simeao Varela de Sá', 'Vila Carli', '85040-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33458, 'Pato Branco', 'Simião', 'Santa Terezinha', '85506-045', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33459, 'Londrina', 'Simon Bolívar', 'Jardim São João', '86027-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33460, 'Maringá', 'Simon Bolívar', 'Vila Nova', '87045-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33461, 'Guarapuava', 'Simon Lundgren', 'Santana', '85070-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33462, 'Londrina', 'Simone Christina Juliani', 'Jardim Campos Verdes', '86085-247', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33463, 'Curitiba', 'Simone Dal Toso', 'Uberaba', '81570-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33464, 'Curitiba', 'Simplicio Ferreira Ribas', 'Tatuquara', '81470-140', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33465, 'Ponta Grossa', 'Sinai', 'Jardim Carvalho', '84016-696', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33466, 'Foz do Iguaçu', 'Sinamomo', 'Jardim Quinta do Sol', '85853-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33467, 'Ponta Grossa', 'Sinear', 'Jardim Carvalho', '84016-678', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33468, 'Foz do Iguaçu', 'Sinésio Hiheiss', 'Jardim Residencial Atlanta', '85856-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33469, 'Curitiba', 'Sinésio Simões de Oliveira', 'Sítio Cercado', '81935-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33470, 'Paranavaí', 'Sineval Fortes', 'Jardim Ipê', '87707-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33471, 'Castro', 'Sinezio Marques de Souza', 'Jardim das Araucárias', '84174-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33472, 'Curitiba', 'Sinfrônio Mesa Neto', 'Tatuquara', '81470-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33473, 'Ponta Grossa', 'Sinhara Natel de Paula', 'Orfãs', '84015-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33474, 'Curitiba', 'Sinibaldo Trombini', 'Santa Felicidade', '82410-385', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33475, 'Curitiba', 'Sinke Ferreira', 'Jardim das Américas', '81530-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33476, 'Londrina', 'Sinode Bighinatti', 'Avelino A Vieira', '86056-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33477, 'Londrina', 'Sinval da Silva Pedra', 'Cafezal 1', '86049-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33478, 'Guarapuava', 'Siqueira Campos', 'Jardim das Américas', '85030-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33479, 'Londrina', 'Siqueira Campos', 'Bancários', '86062-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33480, 'Ponta Grossa', 'Siqueira Campos', 'Uvaranas', '84031-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33481, 'Ponta Grossa', 'Siqueira Campos', 'Cará-cará', '84033-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33482, 'Telêmaco Borba', 'Siqueira Campos', 'Centro', '84261-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33483, 'Toledo', 'Siqueira Campos', 'Jardim Planalto', '85904-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33484, 'Cascavel', 'Siqueira Campos', 'São Cristóvão', '85812-340', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33485, 'Campo Largo', 'Siqueira Campos', 'Vila Rivabem', '83605-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33486, 'Cascavel', 'Siqueira Campos', 'Região do Lago 1', '85812-221', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33487, 'Cascavel', 'Siqueira Campos', 'São Cristóvão', '85813-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33488, 'Cascavel', 'Siqueira Campos', 'Centro', '85812-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33489, 'Colombo', 'Siqueira Campos', 'Jardim Guilhermina', '83410-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33490, 'Curitiba', 'Siqueira Campos', 'Cajuru', '82940-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33491, 'Foz do Iguaçu', 'Siri', 'Profilurb II', '85855-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33492, 'Guarapuava', 'Síria', 'São Cristóvão', '85063-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33493, 'Foz do Iguaçu', 'Siriema', 'Conjunto A', '85866-240', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33494, 'Francisco Beltrão', 'Siriema', 'Padre Eurico', '85604-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33495, 'Francisco Beltrão', 'Siriema', 'Padre Ulrico', '85604-468', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33496, 'Cascavel', 'Siriema', 'Floresta', '85814-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33497, 'Araucária', 'Siriema', 'Capela Velha', '83706-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33498, 'Campo Mourão', 'Siriema', 'Jardim Gutierres', '87300-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33499, 'Arapongas', 'Siriema', 'Vila Araponguinha', '86705-500', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33500, 'Telêmaco Borba', 'Sírio de Castro Ribas', 'Alto das Oliveiras', '84266-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33501, 'Francisco Beltrão', 'Siriri', 'Padre Ulrico', '85604-469', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33502, 'Araucária', 'Siriri', 'Capela Velha', '83706-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33503, 'Curitiba', 'Sirius', 'Sítio Cercado', '81910-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33504, 'Toledo', 'Sirlei Maria Lorandi', 'Parque Residencial Pancera', '85902-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33505, 'Londrina', 'Sirso Pedro da Silva', 'Jardim Perobal', '86043-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33506, 'Apucarana', 'Sisuko Miyamoto', 'Jardim Colonial II', '86812-546', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33507, 'Curitiba', 'Sítio Cercado', 'Sítio Cercado', '81910-085', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33508, 'São José dos Pinhais', 'Sleiman Fayad', 'Guatupê', '83060-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33509, 'Pato Branco', 'Soares Bento', 'Pagnoncelli', '85509-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33510, 'Paranaguá', 'Soares Gomes', 'Bockmann', '83206-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33511, 'Paranaguá', 'Soares Gomes', '29 de Julho', '83203-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33512, 'Foz do Iguaçu', 'Sobral', 'Vila Guarani', '85862-348', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33513, 'Guarapuava', 'Social', 'Santa Cruz', '85015-100', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33514, 'Cambé', 'Sociedade Esportiva Palmeiras', 'Conjunto Habitacional Collor de Melo', '86188-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33515, 'Telêmaco Borba', 'Socimbra', 'Área 02', '84267-150', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33516, 'Cascavel', 'Sociologia', 'Universitário', '85819-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33517, 'Curitiba', 'Sociólogo Gilberto Freyre', 'Santa Felicidade', '82410-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33518, 'Foz do Iguaçu', 'Soco', 'Conjunto A', '85866-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33519, 'Maringá', 'Soco', 'Parque Hortência', '87075-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33520, 'Ponta Grossa', 'Soco', 'Colônia Dona Luiza', '84046-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33521, 'Campo Mourão', 'Soco', 'Jardim Aeroporto', '87310-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33522, 'Arapongas', 'Soco', 'Jardim Aeroporto', '86702-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33523, 'Arapongas', 'Socó-de-boi', 'Jardim São Cristóvão', '86709-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33524, 'Arapongas', 'Socoi', 'Conjunto Padre Chico', '86707-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33525, 'Arapongas', 'Socó-mirim', 'Conjunto Del Condor', '86703-335', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33526, 'São José dos Pinhais', 'Sócrates', 'Aristocrata', '83030-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33527, 'Colombo', 'Sócrates', 'Jardim Campo Alto', '83408-140', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33528, 'Cascavel', 'Sócrates', 'Interlagos', '85814-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33529, 'Curitiba', 'Sócrates', 'Santa Cândida', '82720-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33530, 'Curitiba', 'Sócrates Silveira Mello', 'Boa Vista', '82650-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33531, 'Campo Mourão', 'Sócrates Stamato', 'Jardim Maia', '87301-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33532, 'Curitiba', 'Sofia Dubiella', 'Abranches', '82220-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33533, 'Londrina', 'Sofia Kloc', 'Jardim Imagawa', '86080-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33534, 'Araucária', 'Sofia Knapik', 'Estação', '83705-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33535, 'São José dos Pinhais', 'Sofia M. Moreschi', 'Ipê', '83055-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33536, 'Curitiba', 'Sofia Matitz', 'Pilarzinho', '82115-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33537, 'Ponta Grossa', 'Sofia Misiak', 'Chapada', '84062-676', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33538, 'Apucarana', 'Sófocles', 'Vila Nova', '86812-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33539, 'Londrina', 'Soiti Tarumã', 'Colúmbia', '86057-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33540, 'Maringá', 'Sol Nascente', 'Jardim Imperial', '87023-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33541, 'São José dos Pinhais', 'Sol Nascente', 'Guatupê', '83060-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33542, 'Cambé', 'Sol Nascente', 'Centro', '86181-260', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33543, 'Maringá', 'Sol Poente', 'Jardim Imperial', '87023-106', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33544, 'Curitiba', 'Solange Luiz Carlos', 'Pilarzinho', '82100-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33545, 'Curitiba', 'Solange Maestrelli', 'Cidade Industrial', '81310-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33546, 'Almirante Tamandaré', 'Solano Lopes', 'Vila Palmira', '83514-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33547, 'Arapongas', 'Soldado', 'Jardim Aeroporto', '86702-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33548, 'Maringá', 'Soldado Adivaldo Lopes da Silva', 'Jardim São Silvestre', '87055-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33549, 'Curitiba', 'Soldado Alfredo Gonçalves', 'Alto Boqueirão', '81850-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33550, 'Paranaguá', 'Soldado Alípio Ferreira de Amorim', 'Jardim Guaraituba', '83209-297', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33551, 'Curitiba', 'Soldado Benedito Padilha', 'Alto Boqueirão', '81850-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33552, 'Curitiba', 'Soldado Cipriano Pereira Bueno', 'Alto Boqueirão', '81850-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33553, 'Maringá', 'Soldado Edvaldo Pereira', 'Vila Nova', '87045-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33554, 'Londrina', 'Soldado Engracio Francisco de Andrade', 'Leste Oeste', '86037-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33555, 'São José dos Pinhais', 'Soldado Ermínio Cardoso', 'Cruzeiro', '83010-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33556, 'Paranaguá', 'Soldado Eulálio Cordeiro Bahia', 'Serraria do Rocha', '83221-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33557, 'São José dos Pinhais', 'Soldado Francisco Pereira dos Santos', 'Águas Belas', '83010-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33558, 'Curitiba', 'Soldado Francisco Riske', 'Alto Boqueirão', '81850-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33559, 'Curitiba', 'Soldado Gregório Kislek', 'Alto Boqueirão', '81850-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33560, 'Curitiba', 'Soldado Heber Domingos Alves Pinto', 'Cidade Industrial', '81350-647', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33561, 'Curitiba', 'Soldado Hercílio dos Santos Souza', 'Vista Alegre', '82100-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33562, 'Sarandi', 'Soldado Ivo', 'Jardim Primaverão', '87111-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33563, 'Curitiba', 'Soldado João José Ramires', 'Alto Boqueirão', '81850-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33564, 'Curitiba', 'Soldado Jorge Colaço Barros', 'Alto Boqueirão', '81850-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33565, 'Curitiba', 'Soldado José Bueno da Silva', 'Alto Boqueirão', '81850-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33566, 'Cascavel', 'Soldado Luiz Gonzaga', 'Santa Felicidade', '85803-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33567, 'Paranaguá', 'Soldado Manoel Rodrigues', 'Raia', '83206-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33568, 'Londrina', 'Soldado Marcos Antônio de Souza Salari', 'Indusville', '86031-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33569, 'Curitiba', 'Soldado Miguel Dromboski', 'Alto Boqueirão', '81850-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33570, 'Paranaguá', 'Soldado Rafael Muniz', 'Alboitt', '83221-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33571, 'Paranaguá', 'Soldado Santino Sabino', 'Jardim Araçá', '83221-097', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33572, 'Curitiba', 'Soldado Vicente P. Miranda', 'Uberaba', '81590-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33573, 'Guarapuava', 'Soledade', 'Vila Bela', '85027-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33574, 'Foz do Iguaçu', 'Soledade', 'Jardim Vale do Sol', '85862-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33575, 'Francisco Beltrão', 'Soledade', 'Pinheirinho', '85603-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33576, 'Telêmaco Borba', 'Soledade', 'Macopa', '84263-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33577, 'Cascavel', 'Soledade', 'Canadá', '85813-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33578, 'Curitiba', 'Soledade Regina Sanzovo Mourão', 'Butiatuvinha', '82410-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33579, 'Curitiba', 'Solieri', 'Prado Velho', '80215-290', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33580, 'Londrina', 'Solimões', 'Jardim Agari', '86025-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33581, 'Paranaguá', 'Solimões', 'Jardim Guaraituba', '83209-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33582, 'Telêmaco Borba', 'Solimões', 'Nossa Senhora de Fátima', '84264-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33583, 'Curitiba', 'Solimões', 'Mercês', '80810-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33584, 'Curitiba', 'Solimões', 'São Francisco', '80510-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33585, 'Londrina', 'Sólon', 'Maringá', '86060-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33586, 'Pinhais', 'Somália', 'Jardim Pinhais', '83323-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33587, 'Colombo', 'Somália', 'Vila Alto da Cruz II', '83405-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33588, 'Foz do Iguaçu', 'Somes de Feline', 'Parque Morumbi II', '85859-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33589, 'Telêmaco Borba', 'Sonda I', 'Fazenda Limeira', '84270-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33590, 'Araucária', 'Sônia Bodziak', 'Capela Velha', '83706-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33591, 'Curitiba', 'Sônia Maria', 'Hauer', '81630-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33592, 'Londrina', 'Sônia Maria Marenga Garcia', 'Lago Juliana', '86038-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33593, 'Colombo', 'Sonir Gonçalves da Luz', 'Jardim Nova Esperança', '83413-138', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33594, 'Campo Largo', 'Sophia Busmeyer Vidal', 'Parque Lagoa', '83606-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33595, 'Curitiba', 'Sophia Cosloski Fiala', 'Alto Boqueirão', '81850-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33596, 'Colombo', 'Sophia Socher Jardeveski', 'Jardim Santa Fé', '83403-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33597, 'São José dos Pinhais', 'Sophia Suota Toczek', 'Planta Quississana', '83085-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33598, 'Londrina', 'Sorocaba', 'Coroados', '86062-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33599, 'Francisco Beltrão', 'Sorocaba', 'Pinheirinho', '85603-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33600, 'Guarapuava', 'Sorocaba', 'Conradinho', '85055-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33601, 'Pato Branco', 'Sorocaba', 'São Roque', '85507-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33602, 'Ponta Grossa', 'Sorocaba', 'Uvaranas', '84025-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33603, 'Cambé', 'Sorocaba', 'Jardim São Paulo', '86191-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33604, 'Curitiba', 'Soroptimismo Internacional', 'Hugo Lange', '80040-370', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33605, 'Ponta Grossa', 'Sotero dos Reis', 'Colônia Dona Luiza', '84045-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33606, 'Londrina', 'Souza Caldas', 'Shangri-La', '86070-420', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33607, 'Ponta Grossa', 'Souza Caldas', 'Uvaranas', '84031-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33608, 'Ponta Grossa', 'Souza Dantas', 'Orfãs', '84070-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33609, 'Ponta Grossa', 'Souza Franco', 'Jardim Carvalho', '84016-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33610, 'Ponta Grossa', 'Souza Guedes', 'Boa Vista', '84073-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33611, 'Curitiba', 'Souza Mello', 'Pilarzinho', '82110-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33612, 'Laranjeiras do Sul', 'Souza Naves', 'Getúlio Vargas', '85304-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33613, 'Francisco Beltrão', 'Souza Naves', 'Centro', '85601-640', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33614, 'Francisco Beltrão', 'Souza Naves', 'Luther King', '85605-536', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33615, 'Laranjeiras do Sul', 'Souza Naves', 'Centro', '85301-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33616, 'Guarapuava', 'Souza Naves', 'Alto da XV', '85065-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33617, 'Paranavaí', 'Souza Naves', 'Jardim São Cristóvão', '87702-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33618, 'Paranavaí', 'Souza Naves', 'Centro', '87708-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33619, 'Ponta Grossa', 'Souza Naves', 'Chapada', '84063-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33620, 'Ponta Grossa', 'Souza Naves', 'Chapada', '84064-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33621, 'Paranavaí', 'Souza Naves', 'Centro', '87701-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33622, 'Ponta Grossa', 'Souza Naves', 'Chapada', '84062-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33623, 'Toledo', 'Souza Naves', 'Centro', '85900-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33624, 'Cascavel', 'Souza Naves', 'Ciro Nardi', '85802-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33625, 'Cascavel', 'Souza Naves', 'Centro', '85801-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33626, 'Cascavel', 'Souza Naves', 'Parque São Paulo', '85803-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33627, 'Apucarana', 'Souza Naves', 'Barra Funda', '86800-570', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33628, 'Campo Mourão', 'Souza Naves', 'Jardim Corinthias', '87309-066', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33629, 'Cascavel', 'Souza Naves', 'Centro', '85810-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33630, 'Cascavel', 'Souza Naves Sul', '14 de Novembro', '85804-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33631, 'Foz do Iguaçu', 'Sovi', 'Conjunto A', '85866-020', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33632, 'Arapongas', 'Sovi', 'Parque Industrial', '86706-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33633, 'Maringá', 'Sparcaco Bambi', 'Zona 08', '87050-360', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33634, 'Londrina', 'Spartaco Ferraresi', 'Jardim Santa Cruz', '86084-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33635, 'Ponta Grossa', 'Spartaco Gambassi', 'Uvaranas', '84030-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33636, 'Telêmaco Borba', 'Speranto', 'Nossa Senhora do Perpétuo Socorro', '84265-220', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33637, 'Ponta Grossa', 'Spix', 'Colônia Dona Luiza', '84045-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33638, 'Cambé', 'Sport Club Corinthians Paulista', 'Conjunto Habitacional Collor de Melo', '86188-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33639, 'Curitiba', 'Stanislau Felibrante', 'Augusta', '81260-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33640, 'Londrina', 'Stanislaw Jan Los', 'Conjunto Parigot de Souza 1', '86081-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33641, 'Curitiba', 'Stefan Kida', 'Cidade Industrial', '81305-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33642, 'Londrina', 'Stefan Kuzienko', 'Roseira', '86041-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33643, 'Cambé', 'Stefan Mondek', 'Recanto Santa Andréa', '86189-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33644, 'Cambé', 'Stefano Paranzini', 'Conjunto Residencial Roberto Conceição', '86183-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33645, 'Ponta Grossa', 'Steferson', 'Oficinas', '84036-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33646, 'Ponta Grossa', 'Steffano Kozar', 'Boa Vista', '84072-297', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33647, 'Curitiba', 'Stelinha Egg', 'Santa Felicidade', '82015-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33648, 'Curitiba', 'Stellamaris da Silva R. Mello', 'Cidade Industrial', '81315-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33649, 'Castro', 'Stephano Rudeck', 'Jardim dos Bancários', '84172-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33650, 'Apucarana', 'Stephano Zshoka', 'Vila Shangri-La', '86812-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33651, 'Maringá', 'Stévia', 'Parque Industrial Bandeirantes', '87070-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33652, 'Curitiba', 'Suboficial Sebastião de Freitas', 'Pilarzinho', '82100-778', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33653, 'Curitiba', 'Subtenente Antônio Pinto Portugal', 'Santa Felicidade', '82020-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33654, 'Curitiba', 'Subtenente Francisco Hierro', 'Uberaba', '81560-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33655, 'Curitiba', 'Subtenente José Makahin', 'Cidade Industrial', '81280-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33656, 'Ponta Grossa', 'Sucara', 'Neves', '84020-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33657, 'Londrina', 'Sucre', 'Santa Rosa', '86050-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33658, 'Ponta Grossa', 'Sucupira', 'Uvaranas', '84033-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33659, 'Cascavel', 'Sucuri', 'Pioneiros Catarinenses', '85805-437', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33660, 'Londrina', 'Sudão', 'Ouro Verde', '86080-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33661, 'Pinhais', 'Sudão', 'Vila Palmital', '83320-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33662, 'Colombo', 'Sudão', 'Jardim Rio Verde', '83405-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33663, 'Curitiba', 'Sudão', 'Cajuru', '82960-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33664, 'Londrina', 'Sudeste', 'Leste Oeste', '86072-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33665, 'Ponta Grossa', 'Sudoeste', 'Chapada', '84064-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33666, 'Pato Branco', 'Sudoeste', 'Trevo Patinhos', '85504-006', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33667, 'Londrina', 'Suécia', 'Igapó', '86046-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33668, 'Guarapuava', 'Suécia', 'São Cristóvão', '85063-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33669, 'Toledo', 'Suécia', 'Jardim Porto Alegre', '85906-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33670, 'Cambé', 'Suécia', 'Vila Guarani', '86182-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33671, 'Cascavel', 'Suécia', 'Cascavel Velho', '85818-255', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33672, 'Apucarana', 'Suécia', 'Vila Maria Eliza', '86808-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33673, 'Cascavel', 'Suécia', 'Cascavel Velho', '85818-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33674, 'Colombo', 'Suécia', 'Jardim Nossa Senhora de Fátima', '83405-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33675, 'Curitiba', 'Suécia', 'Tarumã', '82800-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33676, 'Pato Branco', 'Sueli Biazus', 'Vila Verde', '85506-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33677, 'Curitiba', 'Sueli Rodrigues Camelo', 'Cidade Industrial', '81350-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33678, 'Maringá', 'Sueo Toda', 'Vila Esperança', '87020-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33679, 'Arapongas', 'Suia', 'Jardim São Cristóvão', '86709-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33680, 'Foz do Iguaçu', 'Suíça', 'Jardim Europa', '85859-328', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33681, 'Londrina', 'Suíça', 'Jardim Adriana II', '86046-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33682, 'Ponta Grossa', 'Suíça', 'Oficinas', '84036-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33683, 'Toledo', 'Suíça', 'Jardim Porto Alegre', '85906-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33684, 'Umuarama', 'Suíça', 'Parque Bonfim', '87507-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33685, 'Almirante Tamandaré', 'Suíça', 'Vila Graziela', '83505-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33686, 'Cascavel', 'Suíça', 'Cascavel Velho', '85818-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33687, 'Foz do Iguaçu', 'Suidara', 'Conjunto A', '85866-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33688, 'Cascavel', 'Suinã', 'Santa Cruz', '85806-136', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33689, 'Londrina', 'Suindara', 'Yara', '86027-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33690, 'Maringá', 'Suindara', 'Conjunto Habitacional João de Barro Thaís', '87075-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33691, 'Arapongas', 'Suindara', 'Jardim São Cristóvão', '86709-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33692, 'Arapongas', 'Suiriri', 'Centro', '86701-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33693, 'Foz do Iguaçu', 'Suirirí', 'Conjunto A', '85866-140', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33694, 'Cambé', 'Suissa', 'Centro', '86181-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33695, 'Apucarana', 'Sukesaku Yamamura', 'Parque de Exposições', '86803-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33696, 'Londrina', 'Sul', 'Leste Oeste', '86072-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33697, 'Sarandi', 'Sul', 'Jardim Perimetral', '87111-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33698, 'Laranjeiras do Sul', 'Sulina', 'São Francisco', '85303-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33699, 'Foz do Iguaçu', 'Sulinas', 'Jardim Vale do Sol', '85862-456', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33700, 'Paranaguá', 'Sully da Rosa Vilarinho', 'Centro Histórico', '83203-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33701, 'Guarapuava', 'Sumaré', 'Vila Bela', '85027-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33702, 'Londrina', 'Sumaré', 'Castelo', '86027-310', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33703, 'Paranavaí', 'Sumaré', 'Jardim Santos Dumont', '87706-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33704, 'Umuarama', 'Sumaré', 'Zona VII', '87503-710', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33705, 'Londrina', 'Sumatra', 'Cláudia', '86050-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33706, 'Cambé', 'Sumatra', 'Jardim do Café', '86186-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33707, 'Arapongas', 'Supi', 'Jardim Imperial', '86708-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33708, 'Francisco Beltrão', 'Suriname', 'Aeroporto', '85603-845', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33709, 'Colombo', 'Suriname', 'Jardim Rio Verde', '83405-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33710, 'Apucarana', 'Suriname', 'Núcleo Habitacional Vale Verde', '86805-246', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33711, 'Foz do Iguaçu', 'Surubí', 'Profilurb I', '85855-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33712, 'Maringá', 'Surubim', 'Jardim Itaipu', '87065-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33713, 'Pinhais', 'Surubim', 'Loteamento Alphaville Graciosa', '83327-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33714, 'Foz do Iguaçu', 'Surucua', 'Conjunto A', '85866-190', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33715, 'Maringá', 'Surucua', 'Conjunto Residencial Ney Braga', '87083-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33716, 'Ponta Grossa', 'Surucua', 'Colônia Dona Luiza', '84046-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33717, 'Arapongas', 'Surucua', 'Conjunto Centauro', '86709-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33718, 'Arapongas', 'Surucuá-açu', 'Vila Araponguinha', '86705-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33719, 'Arapongas', 'Surucuá-amarelo', 'Conjunto Flamingos III', '86703-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33720, 'Foz do Iguaçu', 'Surumanha', 'Conjunto A', '85860-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33721, 'Arapongas', 'Sururina', 'Conjunto Tropical', '86702-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33722, 'Campo Mourão', 'Sussuarana', 'Jardim Aeroporto', '87310-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33723, 'Apucarana', 'Sussumu Shimura', 'Vila Santa Helena', '86802-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33724, 'Cascavel', 'Suyas', 'Santa Cruz', '85806-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33725, 'Apucarana', 'Suzana Pacheco', 'Vila Suzana', '86804-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33726, 'Araucária', 'Suzana Suckow', 'Centro', '83702-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33727, 'Foz do Iguaçu', 'Suzano', 'Vila Guarani', '85862-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33728, 'Curitiba', 'Swami Vivekananda', 'Uberaba', '81560-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33729, 'Curitiba', 'Sydnei Antônio Rangel', 'Santo Inácio', '82010-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33730, 'Curitiba', 'Sylseu Pereira Alves', 'Pilarzinho', '82100-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33731, 'Curitiba', 'Sylvano Alves da Rocha Loures', 'Riviera', '81290-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33732, 'Londrina', 'Sylvio Barros', 'Milton Gavetti', '86078-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33733, 'Londrina', 'Sylvio Carlos Silva', 'Jamile Dequech', '86048-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33734, 'Londrina', 'Sylvio Valente Sabóia', 'Portal de Versalhes 3', '86055-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33735, 'Curitiba', 'Sylvio Zeny', 'Portão', '80320-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33736, 'Curitiba', 'Syro Simão', 'Abranches', '82220-225', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33737, 'Curitiba', 'Syrth Requião Pereira', 'Uberaba', '81570-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33738, 'Umuarama', 'T', 'Parque das Jaboticabeiras', '87509-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33739, 'Londrina', 'Taba', 'Portuguesa', '86026-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33740, 'Maringá', 'Tabaetê', 'Jardim Tabaete', '87005-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33741, 'Francisco Beltrão', 'Tabajara', 'São Miguel', '85602-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33742, 'Paranaguá', 'Tabajara', 'Vila Guarani', '83221-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33743, 'Londrina', 'Tabajaras', 'Vila Ziober', '86026-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33744, 'Cascavel', 'Tabajaras', 'Brasmadeira', '85814-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33745, 'Cambé', 'Tabajaras', 'Jardim Tupi', '86183-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33746, 'Curitiba', 'Tabajaras', 'Vila Izabel', '80320-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33747, 'Foz do Iguaçu', 'Tabarana', 'Conjunto A', '85860-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33748, 'Curitiba', 'Taboão', 'Taboão', '82130-580', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33749, 'Londrina', 'Taca', 'Sol', '86070-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33750, 'Ponta Grossa', 'Tacha', 'Colônia Dona Luiza', '84046-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33751, 'Arapongas', 'Tacha', 'Vila Triângulo', '86702-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33752, 'Curitiba', 'Taciana Marczak', 'Cidade Industrial', '81170-718', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33753, 'Curitiba', 'Tácito Cordeiro Costa', 'Atuba', '82630-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33754, 'Londrina', 'Tadao Kanayama', 'Jardim Tókio', '86063-025', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33755, 'Londrina', 'Tadão Ohira', 'Jardim Perobal', '86043-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33756, 'Apucarana', 'Tadeu Baruti', 'Vila Cinco Irmãos', '86808-345', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33757, 'Ponta Grossa', 'Tadeu Mikoski', 'Uvaranas', '84025-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33758, 'Araucária', 'Tadeu Milan', 'Sabiá', '83708-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33759, 'Curitiba', 'Tadeu Morozowicz', 'Santa Felicidade', '82010-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33760, 'Araucária', 'Tadeu Rizio Wach', 'Vila Nova', '83703-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33761, 'Curitiba', 'Tadeu Rogério Pamplona', 'Santo Inácio', '82010-115', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33762, 'Foz do Iguaçu', 'Tadeu Trompschinski', 'Vila Itajubá', '85852-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33763, 'Curitiba', 'Tadeu Wasilewski', 'Abranches', '82220-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33764, 'Ponta Grossa', 'Tagage', 'Oficinas', '84036-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33765, 'Foz do Iguaçu', 'Taguapetingal', 'Jardim Manaus', '85857-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33766, 'Guarapuava', 'Taguatinga', 'Boqueirão', '85022-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33767, 'Foz do Iguaçu', 'Taguatinga', 'Lago dos Cisnes', '85861-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33768, 'Londrina', 'Tahi', 'Antares', '86036-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33769, 'Sarandi', 'Tai', 'Centro', '87111-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33770, 'Guarapuava', 'Tailândia', 'São Cristóvão', '85063-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33771, 'Francisco Beltrão', 'Tailândia', 'Pinheirinho', '85606-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33772, 'Colombo', 'Tailândia', 'Planta Santo Agostinho', '83404-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33773, 'Curitiba', 'Tailândia', 'Cajuru', '82960-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33774, 'Londrina', 'Takabumi Murata', 'Gleba Fazenda Palhano', '86055-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33775, 'Almirante Tamandaré', 'Takeo Oyama', 'Jardim Dona Luiza', '83506-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33776, 'Paranavaí', 'Takeshi Mitsuyasu', 'Jardim Panorama', '87707-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33777, 'Paranavaí', 'Takeshi Mitsuyasu', 'Jardim Ipê', '87706-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33778, 'Curitiba', 'Tala Raul Miguel Elias', 'Sítio Cercado', '81925-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33779, 'Maringá', 'Talavera', 'Loteamento Madrid', '87053-519', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33780, 'Arapongas', 'Talha-mar', 'Conjunto Centauro', '86709-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33781, 'Maringá', 'Tamandaré', 'Zona 01', '87013-210', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33782, 'Apucarana', 'Tamandaré', 'Barra Funda', '86800-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33783, 'Foz do Iguaçu', 'Tamanduá', 'Conjunto A', '85860-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33784, 'Campo Mourão', 'Tamanduá', 'Jardim Lar Paraná', '87306-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33785, 'Londrina', 'Tamanduatei', 'Recreio', '86025-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33786, 'Foz do Iguaçu', 'Tamanduazinho', 'Loteamento Campos do Iguaçu', '85857-450', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33787, 'Maringá', 'Tamarindo', 'Jardim Pinheiros III', '87043-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33788, 'Foz do Iguaçu', 'Tambaqui', 'Parque Ouro Verde', '85855-565', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33789, 'Pinhais', 'Tambaquis', 'Loteamento Alphaville Graciosa', '83327-109', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33790, 'Foz do Iguaçu', 'Tambiú', 'Conjunto A', '85860-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33791, 'Guarapuava', 'Tamboara', 'Boqueirão', '85020-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33792, 'Ponta Grossa', 'Tamboara', 'Olarias', '84026-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33793, 'Paranavaí', 'Tamboara', 'Jardim São Jorge', '87711-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33794, 'Telêmaco Borba', 'Tamboara', 'Jardim Margarida', '84263-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33795, 'Curitiba', 'Tamboara', 'Capão da Imbuia', '82810-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33796, 'Foz do Iguaçu', 'Tamboata', 'Conjunto A', '85860-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33797, 'Londrina', 'Tamekishi Hara', 'Jardim Tókio', '86063-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33798, 'Pato Branco', 'Tamoio', 'Centro', '85501-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33799, 'Paranaguá', 'Tamoio', 'Vila Guarani', '83221-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33800, 'Umuarama', 'Tamoio', 'Zona VI', '87503-100', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33801, 'Cascavel', 'Tamoio Fedumenti', 'Santa Felicidade', '85803-338', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33802, 'Foz do Iguaçu', 'Tamoios', 'Jardim Tarobá', '85856-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33803, 'Londrina', 'Tamoios', 'Barra Grande', '86026-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33804, 'Guarapuava', 'Tamoios', 'Vila Carli', '85040-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33805, 'Ponta Grossa', 'Tamoios', 'Uvaranas', '84030-379', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33806, 'Cambé', 'Tamoios', 'Jardim Tupi', '86183-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33807, 'Cascavel', 'Tamoios', 'Santa Cruz', '85806-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33808, 'Apucarana', 'Tamoios', 'Núcleo Habitacional Colonial', '86812-419', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33809, 'Curitiba', 'Tamoios', 'Vila Izabel', '80320-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33810, 'Sarandi', 'Tampa', 'Jardim Califórnia', '87112-465', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33811, 'Londrina', 'Tamuro Hironaka', 'Jardim Império do Sol', '86073-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33812, 'Colombo', 'Tanagildo Berlesi', 'Jardim Panorama', '83412-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33813, 'Pinhais', 'Tanagra', 'Jardim Fênix', '83326-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33814, 'Pinhais', 'Tanagra', 'Conjunto Residencial Renato Bonilauri', '83325-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33815, 'Arapongas', 'Tanatau', 'Casa Família Arapongas II', '86706-407', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33816, 'Campo Mourão', 'Tancredo de Almeida Neves', 'Jardim Constantino', '87303-040', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33817, 'Campo Mourão', 'Tancredo de Almeida Neves', 'Centro', '87302-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33818, 'Campo Mourão', 'Tancredo de Almeida Neves', 'Jardim Alvorada', '87308-440', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33819, 'Londrina', 'Tancredo Neves', 'Conjunto Semiramis Barros Braga', '86088-075', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33820, 'Francisco Beltrão', 'Tancredo Neves', 'Alvorada', '85601-567', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33821, 'Foz do Iguaçu', 'Tancredo Neves', 'Conjunto B', '85867-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33822, 'Cascavel', 'Tancredo Neves', 'Santo Onofre', '85806-470', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33823, 'Cascavel', 'Tancredo Neves', 'Centro', '85805-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33824, 'Ponta Grossa', 'Tandios', 'Uvaranas', '84030-376', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33825, 'Londrina', 'Tanganica', 'Ouro Verde', '86080-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33826, 'Foz do Iguaçu', 'Tangará', 'Jardim Nacional', '85862-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33827, 'Francisco Beltrão', 'Tangará', 'Miniguaçu', '85605-490', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33828, 'Guarapuava', 'Tangará', 'Conradinho', '85055-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33829, 'Ponta Grossa', 'Tangará', 'Colônia Dona Luiza', '84046-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33830, 'Londrina', 'Tangará', 'Yara', '86027-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33831, 'Umuarama', 'Tangará', 'Jardim Tangará', '87501-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33832, 'Arapongas', 'Tangará', 'Centro', '86701-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33833, 'Cascavel', 'Tangará', 'Floresta', '85814-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33834, 'Arapongas', 'Tangará', 'Vila Triângulo', '86709-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33835, 'Araucária', 'Tangará', 'Capela Velha', '83706-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33836, 'Cambé', 'Tangará', 'Conjunto Habitacional Waldomiro M Gomes', '86182-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33837, 'Campo Mourão', 'Tangará', 'Jardim Pio XII', '87306-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33838, 'Curitiba', 'Tangará', 'São Braz', '82320-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33839, 'Arapongas', 'Tangarazinho', 'Jardim do Sol', '86705-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33840, 'Arapongas', 'Tanguá', 'Aricanduva', '86706-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33841, 'Arapongas', 'Tangurupará', 'Jardim do Sol', '86705-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33842, 'Curitiba', 'Tanimatsu Hamasaki', 'Uberaba', '81550-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33843, 'São José dos Pinhais', 'Tanus Latuf', 'Cruzeiro', '83010-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33844, 'Londrina', 'Tanzânia', 'Ouro Verde', '86080-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33845, 'Pinhais', 'Tanzânia', 'Jardim Pinhais', '83323-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33846, 'Pato Branco', 'Taobá', 'São Vicente', '85506-325', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33847, 'Francisco Beltrão', 'Tapajós', 'São Miguel', '85602-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33848, 'Londrina', 'Tapajós', 'Casoni', '86026-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33849, 'Guarapuava', 'Tapajós', 'Vila Carli', '85040-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33850, 'Foz do Iguaçu', 'Tapajós', 'Loteamento Campos do Iguaçu', '85857-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33851, 'Paranaguá', 'Tapajós', 'Vila Guarani', '83221-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33852, 'Pato Branco', 'Tapajós', 'Centro', '85501-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33853, 'São José dos Pinhais', 'Tapajós', 'Colônia Rio Grande', '83025-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33854, 'Campo Largo', 'Tapajós', 'Jardim Rivabem', '83605-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33855, 'Colombo', 'Tapajós', 'Jardim Central', '83409-610', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33856, 'Cascavel', 'Tapajós', 'Santa Cruz', '85806-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33857, 'Curitiba', 'Tapajós', 'Bom Retiro', '80520-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33858, 'Curitiba', 'Tapajós', 'São Francisco', '80510-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33859, 'Foz do Iguaçu', 'Tapejara', 'Jardim Belvedere I', '85867-245', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33860, 'Paranavaí', 'Tapejara', 'Jardim São Jorge', '87710-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33861, 'Pato Branco', 'Tapejara', 'Centro', '85501-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33862, 'Telêmaco Borba', 'Tapejara', 'Jardim Margarida', '84263-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33863, 'São José dos Pinhais', 'Tapejara', 'Águas Belas', '83010-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33864, 'Campo Mourão', 'Tapejara', 'Conjunto Habitacional Parigot de Souza', '87310-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33865, 'Cascavel', 'Tapejara', 'Canadá', '85813-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33866, 'Curitiba', 'Tapejara', 'Boqueirão', '81750-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33867, 'Arapongas', 'Tapera', 'Vila Nova', '86707-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33868, 'Arapongas', 'Taperá-açu', 'Vila Sampaio', '86705-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33869, 'Arapongas', 'Tapera-de-garganta-branca', 'Jardim Nova Baroneza', '86706-686', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33870, 'Arapongas', 'Tapereira', 'Jardim Aeroporto', '86702-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33871, 'Foz do Iguaçu', 'Tapes', 'Jardim Lancaster I', '85869-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33872, 'Arapongas', 'Tapicuru', 'Vila Triângulo', '86702-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33873, 'Foz do Iguaçu', 'Tapir', 'Conjunto A', '85860-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33874, 'Pato Branco', 'Tapir', 'Jardim Primavera', '85502-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33875, 'Pato Branco', 'Tapir', 'Centro', '85501-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33876, 'Pato Branco', 'Tapir', 'Centro', '85504-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33877, 'Telêmaco Borba', 'Tapira', 'Jardim Margarida', '84263-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33878, 'Curitiba', 'Tapira', 'Xaxim', '81720-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33879, 'Curitiba', 'Tapiranga', 'São Braz', '82015-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33880, 'Ponta Grossa', 'Tapirapes', 'Uvaranas', '84030-366', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33881, 'Foz do Iguaçu', 'Tapiti', 'Conjunto A', '85861-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33882, 'Paranaguá', 'Tapuia', 'Vila Guarani', '83221-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33883, 'Pato Branco', 'Tapuia', 'Industrial', '85506-546', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33884, 'Umuarama', 'Tapuia', 'Zona IV', '87504-520', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33885, 'Londrina', 'Tapuias', 'Guaratuba', '86026-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33886, 'Londrina', 'Tapuias', 'João Paz', '86027-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33887, 'Foz do Iguaçu', 'Tapuias', 'Jardim Tarobá', '85856-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33888, 'Ponta Grossa', 'Tapuias', 'Uvaranas', '84030-368', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33889, 'Apucarana', 'Tapuias', 'Núcleo Habitacional Colonial', '86812-406', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33890, 'Maringá', 'Taquari', 'Parque Avenida', '87025-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33891, 'Paranaguá', 'Taquari', 'Jardim Guaraituba', '83209-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33892, 'Pinhais', 'Taquari', 'Loteamento Alphaville Graciosa', '83327-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33893, 'Sarandi', 'Taquari', 'Parque Residencial Bela Vista', '87112-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33894, 'Foz do Iguaçu', 'Taquarí', 'Jardim Santa Rosa', '85869-240', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33895, 'Londrina', 'Taquarí', 'Pietraroia', '86025-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33896, 'Ponta Grossa', 'Taquarí', 'Contorno', '84052-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33897, 'Londrina', 'Taquaritinga', 'Champagnat', '86062-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33898, 'Curitiba', 'Taranto', 'Santa Felicidade', '82020-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33899, 'Apucarana', 'Taras Andraski', 'Jardim Flamingos', '86811-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33900, 'Cascavel', 'Tarcílio Wagner', 'Alto Alegre', '85805-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33901, 'São José dos Pinhais', 'Tarcilio Zoelner', 'Cidade Jardim', '83035-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33902, 'Umuarama', 'Tarcilo Alves de Freitas', 'Conjunto Residencial Porto Belo', '87506-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33903, 'Londrina', 'Tarcisa Kikuti', 'Cafezal', '86045-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33904, 'Curitiba', 'Targino da Silva', 'Jardim das Américas', '81540-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33905, 'Piraquara', 'Targino da Silva', 'Jardim Primavera', '83302-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33906, 'Araucária', 'Targino Silva', 'Barigui', '83704-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33907, 'Foz do Iguaçu', 'Tarobá', 'Centro', '85851-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33908, 'Foz do Iguaçu', 'Tarobá', 'Vila Paraguaia', '85864-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33909, 'Toledo', 'Tarobá', 'Walter Fontana', '85909-448', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33910, 'Cascavel', 'Tarobá', 'Maria Luiza', '85819-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33911, 'Foz do Iguaçu', 'Tarquinio Joslin dos Santos', 'Loteamento Universitário das Américas', '85870-650', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33912, 'Cascavel', 'Tarquinio Joslin Santos', 'Maria Luiza', '85819-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33913, 'Curitiba', 'Tarquínio Marchiorato', 'Campina do Siqueira', '80740-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33914, 'Curitiba', 'Tarquínio Santos', 'Cajuru', '82900-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33915, 'Londrina', 'Tarquino de Almeida Camargo', 'Armindo Guazzi', '86037-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33916, 'Cascavel', 'Tarsila do Amaral', 'Independência', '85813-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33917, 'Guarapuava', 'Tarumã', 'Industrial', '85045-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33918, 'Piraquara', 'Tarumã', 'Vila Santa Maria', '83306-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33919, 'Ponta Grossa', 'Tarumã', 'Contorno', '84061-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33920, 'Telêmaco Borba', 'Tarumã', 'Fazenda Limeira', '84272-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33921, 'Toledo', 'Tarumã', 'Boa Esperança', '85909-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33922, 'Campo Mourão', 'Tarumã', 'Jardim Lar Paraná', '87305-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33923, 'Campo Largo', 'Tarumã', 'Jardim Guairacá', '83608-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33924, 'Araucária', 'Tarumã', 'Estação', '83705-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33925, 'Londrina', 'Tassiano Barrios', 'Jardim dos Alpes III', '86045-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33926, 'Curitiba', 'Tasso Azevedo da Silveira', 'Jardim das Américas', '81540-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33927, 'Pinhais', 'Tasso da Silveira', 'Planta Núcleo Colonial de Pinhais', '83321-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33928, 'Foz do Iguaçu', 'Tatu', 'Conjunto A', '85860-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33929, 'Francisco Beltrão', 'Tatuaí', 'Miniguaçu', '85605-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33930, 'Cambé', 'Tatuapé', 'Jardim Morumbi', '86191-768', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33931, 'Curitiba', 'Tatugura', 'Cidade Industrial', '81315-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33932, 'Arapongas', 'Tauató', 'Parque Industrial', '86704-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33933, 'Guarapuava', 'Taubaté', 'Bonsucesso', '85035-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33934, 'Francisco Beltrão', 'Taubaté', 'Pinheirinho', '85603-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33935, 'Londrina', 'Taubaté', 'Veraliz', '86062-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33936, 'Foz do Iguaçu', 'Taubaté', 'Novo Mundo', '85862-427', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33937, 'Pato Branco', 'Taubaté', 'São Roque', '85507-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33938, 'Cambé', 'Taubaté', 'Jardim São Paulo', '86191-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33939, 'Londrina', 'Taufik Tauil', 'Conjunto Habitacional  Alexandre Urbanas', '86037-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33940, 'Londrina', 'Taurus', 'Sol', '86070-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33941, 'Maringá', 'Tavares', 'Residencial Regente', '87045-737', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33942, 'São José dos Pinhais', 'Tavares de Lyra', 'Afonso Pena', '83065-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33943, 'São José dos Pinhais', 'Tavares de Lyra', 'Afonso Pena', '83050-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33944, 'Arapongas', 'Taxuri', 'Jardim do Sol', '86705-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33945, 'Cambé', 'Tchecoslováquia', 'Jardim Morada do Sol', '86181-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33946, 'Cascavel', 'Tchucarramães', 'Santa Cruz', '85806-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33947, 'Colombo', 'Tebas', 'Jardim Central', '83409-660', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33948, 'Arapongas', 'Tecelão', 'Vila Cascata', '86703-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33949, 'Londrina', 'Tefé', 'Aparecida', '86025-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33950, 'Pinhais', 'Tefé', 'Loteamento Alphaville Graciosa', '83327-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33951, 'Curitiba', 'Teffe', 'Bom Retiro', '80520-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33952, 'Londrina', 'Teilhard de Chardin', 'Cidadela', '86072-120', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33953, 'Curitiba', 'Teixeira Coelho', 'Batel', '80420-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33954, 'Ponta Grossa', 'Teixeira de Freitas', 'Nova Rússia', '84053-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33955, 'Maringá', 'Teixeira de Freitas', 'Zona 05', '87015-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33956, 'Curitiba', 'Teixeira de Freitas', 'São Francisco', '80410-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33957, 'Colombo', 'Teixeira de Lara', 'Vila São Lucas', '83404-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33958, 'Ponta Grossa', 'Teixeira de Macedo', 'Uvaranas', '84026-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33959, 'Ponta Grossa', 'Teixeira de Macedo', 'Olarias', '84035-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33960, 'Laranjeiras do Sul', 'Teixeira de Souza', 'São Francisco', '85303-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33961, 'Ponta Grossa', 'Teixeira Mendes', 'Uvaranas', '84031-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33962, 'Campo Largo', 'Teixeira Mendes', 'São Marcos', '83602-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33963, 'Curitiba', 'Teixeira Mendes', 'Jardim Social', '82520-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33964, 'Londrina', 'Teixeira Soares', 'Paulista', '86079-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33965, 'Guarapuava', 'Teixeira Soares', 'Boqueirão', '85020-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33966, 'Piraquara', 'Teixeira Soares', 'Jardim Santa Mônica', '83302-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33967, 'Telêmaco Borba', 'Teixeira Soares', 'Jardim Margarida', '84263-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33968, 'São José dos Pinhais', 'Teixeira Soares', 'Cruzeiro', '83010-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33969, 'Cascavel', 'Teixeira Soares', 'Região do Lago 1', '85812-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33970, 'Campo Largo', 'Teixeira Soares', 'Jardim São Vicente', '83602-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33971, 'Colombo', 'Teixeira Soares', 'Jardim Cristina III', '83410-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33972, 'Curitiba', 'Teixeira Soares', 'Seminário', '80240-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33973, 'Cascavel', 'Teixerinha', 'Brasília', '85815-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33974, 'Curitiba', 'Telange Telon Alves', 'Cidade Industrial', '81350-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33975, 'Almirante Tamandaré', 'Telaviv', 'Jardim Santa Fé', '83511-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33976, 'Colombo', 'Telécio Marcondes', 'Jardim Maria José', '83403-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33977, 'Arapongas', 'Telegala', 'Vila Dalva', '86708-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33978, 'São José dos Pinhais', 'Telêmaco Augusto Enéas Morocines Borba', 'Roseira', '83070-146', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33979, 'Londrina', 'Telêmaco Borba', 'Bom Retiro', '86025-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33980, 'Guarapuava', 'Telêmaco Borba', 'Vila Bela', '85027-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33981, 'Piraquara', 'Telêmaco Borba', 'Chácara Águas Claras', '83308-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33982, 'Colombo', 'Telêmaco Borba', 'Jardim Cristina', '83410-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33983, 'Almirante Tamandaré', 'Telêmaco Borba', 'Jardim Santa Fé', '83511-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33984, 'Cambé', 'Telêmaco Borba', 'Novo Bandeirantes', '86188-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33985, 'Curitiba', 'Telêmaco Borba', 'Pinheirinho', '81880-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33986, 'Curitiba', 'Telêmaco da Silva Quadros', 'Cidade Industrial', '81260-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33987, 'Laranjeiras do Sul', 'Telepar', 'São Francisco', '85303-026', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33988, 'Maringá', 'Teles Pires', 'Parque Avenida', '87025-600', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33989, 'Castro', 'Telles', 'Água Suja', '84165-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33990, 'Apucarana', 'Telmiro Ribeiro Silva', 'Parque Bela Vista', '86803-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33991, 'Cascavel', 'Telvino Gallina', 'Nova Cidade', '85803-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33992, 'Londrina', 'Tembés', 'Portuguesa', '86026-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33993, 'Ponta Grossa', 'Tembés', 'Uvaranas', '84030-367', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33994, 'Curitiba', 'Temístocles Chalegre dos Anjos', 'Tatuquara', '81480-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33995, 'Piraquara', 'Tenente Adolfo Schuartz', 'Vila Ipanema', '83301-025', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33996, 'Maringá', 'Tenente Afonso Pinheiro Camargo', 'Jardim Monte Belo', '87080-016', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33997, 'Ponta Grossa', 'Tenente Agripino Firmino de Souza Câmara', 'Uvaranas', '84030-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33998, 'Curitiba', 'Tenente Álvaro de Jesus Oliveira', 'Santa Quitéria', '80310-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (33999, 'Piraquara', 'Tenente Antônio Cardona de Aguiar', 'Centro', '83301-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34000, 'Curitiba', 'Tenente Antônio Emílio Vaz Lobo', 'Tatuquara', '81480-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34001, 'Curitiba', 'Tenente Antônio Miranda Marques', 'Uberaba', '81580-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34002, 'Curitiba', 'Tenente Antônio Pupo', 'Xaxim', '81830-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34003, 'Curitiba', 'Tenente Arailton Vicente Alves', 'Sítio Cercado', '81900-738', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34004, 'Curitiba', 'Tenente Argemiro Franca Pereira', 'São Braz', '82015-820', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34005, 'Curitiba', 'Tenente Armando Perdigão', 'Bacacheri', '82520-535', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34006, 'Curitiba', 'Tenente Arthur Sprenger', 'Bacacheri', '82600-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34007, 'Castro', 'Tenente Benedito Alves da Silva', 'Jardim Samambaia', '84182-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34008, 'Araucária', 'Tenente Benedito Nepomuceno', 'Estação', '83705-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34009, 'Francisco Beltrão', 'Tenente Camargo', 'Centro', '85601-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34010, 'Francisco Beltrão', 'Tenente Camargo', 'Vila Maria Delani', '85605-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34011, 'Cascavel', 'Tenente Camargo', 'Região do Lago', '85812-390', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34012, 'Piraquara', 'Tenente Celso Soares', 'Vila Juliana', '83306-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34013, 'Ponta Grossa', 'Tenente Claro Alexandre Fernandes', 'Uvaranas', '84031-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34014, 'Curitiba', 'Tenente Demosthénes Machado', 'Uberaba', '81550-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34015, 'São José dos Pinhais', 'Tenente Djalma Dutra', 'Centro', '83005-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34016, 'São José dos Pinhais', 'Tenente Djalma Dutra', 'Bom Jesus', '83025-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34017, 'Curitiba', 'Tenente do Campo', 'Alto Boqueirão', '81860-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34018, 'Curitiba', 'Tenente Douglas Acácio Benetolo', 'Portão', '80320-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34019, 'Foz do Iguaçu', 'Tenente Eduardo Roberto Olmedo', 'Parque Morumbi II', '85858-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34020, 'Curitiba', 'Tenente Ernani Vidal', 'Alto da Rua XV', '80050-060', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34021, 'Laranjeiras do Sul', 'Tenente Eugênio Martins', 'Centro', '85301-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34022, 'Laranjeiras do Sul', 'Tenente Eugênio Martins', 'São Francisco', '85303-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34023, 'Curitiba', 'Tenente Ewerton Diógenes de Oliveira', 'Bacacheri', '82510-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34024, 'Curitiba', 'Tenente Ferdinando Ernesto G. Liegel', 'Juvevê', '80030-405', 'Área', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34025, 'Curitiba', 'Tenente Francisco Ferreira de Souza', 'Hauer', '81630-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34026, 'Curitiba', 'Tenente Francisco Ferreira de Souza', 'Boqueirão', '81670-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34027, 'Ponta Grossa', 'Tenente Hinon Silva', 'Centro', '84010-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34028, 'Araucária', 'Tenente Ivan Madureira Guimarães', 'Boqueirão', '83704-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34029, 'Curitiba', 'Tenente João Cortiano', 'Alto Boqueirão', '81860-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34030, 'Curitiba', 'Tenente João Gomes da Silva', 'Vista Alegre', '80810-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34031, 'Curitiba', 'Tenente João Konig', 'Tatuquara', '81480-226', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34032, 'Londrina', 'Tenente João Maurício Medeiros', 'Aeroporto', '86039-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34033, 'Londrina', 'Tenente Joaquim Corrêa', 'Parque Residencial Liberdade', '86077-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34034, 'Araucária', 'Tenente José Jerônimo Batista', 'Boqueirão', '83704-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34035, 'Cascavel', 'Tenente José Joaquim Fermino', '14 de Novembro', '85804-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34036, 'Curitiba', 'Tenente José Lopes de Oliveira', 'Sítio Cercado', '81900-786', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34037, 'Curitiba', 'Tenente José Mendes Magno', 'Sítio Cercado', '81920-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34038, 'Curitiba', 'Tenente José Ribas Kendrick', 'Cajuru', '82970-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34039, 'Castro', 'Tenente José Santiago da Silva', 'Morada do Sol', '84172-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34040, 'Almirante Tamandaré', 'Tenente José Tenório de Albuquerque', 'Loteamento Recanto dos Papagaios', '83512-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34041, 'Curitiba', 'Tenente Júlio Jacoboski', 'Sítio Cercado', '81925-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34042, 'São José dos Pinhais', 'Tenente Luiz de Campos Valejo', 'São Cristóvão', '83005-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34043, 'São José dos Pinhais', 'Tenente Luiz de Oliveira Quadros', 'Boneca do Iguaçu', '83040-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34044, 'Curitiba', 'Tenente Manoel de Lima', 'Cidade Industrial', '81310-435', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34045, 'São José dos Pinhais', 'Tenente Manoel de Lima', 'Guatupê', '83060-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34046, 'Curitiba', 'Tenente Manoel Gomes de Britto', 'Boqueirão', '81670-490', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34047, 'Curitiba', 'Tenente Manoel João dos Santos', 'Vista Alegre', '80820-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34048, 'Curitiba', 'Tenente Manoel Oliveira de Souza', 'Barreirinha', '82650-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34049, 'Curitiba', 'Tenente Mário Rosseto', 'Campo Comprido', '81270-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34050, 'Curitiba', 'Tenente Max Wolf Filho', 'Água Verde', '80240-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34051, 'Curitiba', 'Tenente Miguel A. R. Cubas', 'Capão Raso', '81110-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34052, 'Curitiba', 'Tenente Miguel Anselmo da Silva', 'Pilarzinho', '82120-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34053, 'São José dos Pinhais', 'Tenente Nelson Rodrigues Antunes', 'Braga', '83020-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34054, 'Piraquara', 'Tenente Newton Lima', 'Vila São Cristóvão', '83305-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34055, 'Ponta Grossa', 'Tenente Nicoluzzi', 'Uvaranas', '84025-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34056, 'Curitiba', 'Tenente Olderico Gabardo', 'Xaxim', '81710-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34057, 'Ponta Grossa', 'Tenente Pinto Duarte', 'Centro', '84010-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34058, 'Curitiba', 'Tenente Ricardo Kirch', 'Jardim das Américas', '81530-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34060, 'São José dos Pinhais', 'Tenente Sandro Luiz Kampa', 'Afonso Pena', '83050-695', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34061, 'Castro', 'Tenente Sérgio Luiz de Mello', 'Jardim das Araucárias', '84174-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34062, 'Curitiba', 'Tenente Tito Teixeira de Castro', 'Boqueirão', '81650-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34063, 'Curitiba', 'Tenente Tito Teixeira de Castro', 'Boqueirão', '81670-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34064, 'Campo Largo', 'Tenente Valdemar da Silva Miranda', 'Popular Nova', '83602-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34065, 'São José dos Pinhais', 'Tenente Walfrido Alves de Souza', 'Cidade Jardim', '83035-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34066, 'Pinhais', 'Tenente Wandick Pottier Becker', 'Jardim Dona Joaquina II', '83325-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34067, 'Curitiba', 'Tenente-Brigadeiro Francisco de Assis C. de Mello', 'Jardim das Américas', '81540-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34068, 'Curitiba', 'Tenente-Coronel Arlindo Cândido Molina', 'Campo de Santana', '81490-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34069, 'Curitiba', 'Tenente-Coronel Benjamin Lage', 'Uberaba', '81580-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34070, 'Curitiba', 'Tenente-Coronel Deocleciano G. Miranda', 'Alto Boqueirão', '81860-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34071, 'Curitiba', 'Tenente-Coronel João Antônio Ramalho', 'Jardim das Américas', '81530-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34072, 'Curitiba', 'Tenente-Coronel Manoel Eufrásio de Assumpção', 'Tatuquara', '81480-206', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34073, 'Curitiba', 'Tenente-Coronel Manoel Eufrásio de Assumpção', 'Tatuquara', '81470-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34074, 'Curitiba', 'Tenente-Coronel Manoel Miguel Ribeiro', 'Bom Retiro', '80520-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34075, 'Curitiba', 'Tenente-Coronel Muniz de Aragão', 'Barreirinha', '82220-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34076, 'Curitiba', 'Tenente-Coronel Servando de Loyola e Silva', 'Barreirinha', '82220-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34077, 'Curitiba', 'Tenente-Coronel Viligran Cabrita', 'Alto Boqueirão', '81770-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34078, 'Curitiba', 'Tenente-Coronel Viligran Cabrita', 'Boqueirão', '81750-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34079, 'Curitiba', 'Tenente-Coronel-Aviador Alberto Valeixo', 'Sítio Cercado', '81920-769', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34080, 'Maringá', 'Tenri', 'Jardim Pinheiros II', '87043-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34081, 'Curitiba', 'Teodomiro Furtado', 'Xaxim', '81830-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34082, 'Curitiba', 'Teodoro Czyr', 'Jardim das Américas', '81540-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34083, 'São José dos Pinhais', 'Teodoro Franco de Oliveira', 'Afonso Pena', '83065-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34084, 'Campo Mourão', 'Teodoro Metchko', 'Jardim Copacabana', '87302-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34085, 'Cascavel', 'Teodoro Nardi', 'Pioneiros Catarinenses', '85805-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34086, 'Curitiba', 'Teodoro Nardi', 'Umbará', '81930-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34087, 'Londrina', 'Teodoro Packo', 'Vale das Araucárias', '86047-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34088, 'Almirante Tamandaré', 'Teodoro Pinto de Lara', 'Jardim Bela Vista', '83506-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34089, 'Colombo', 'Teodoro Pronosquio', 'Vila Campo Alto', '83408-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34090, 'Londrina', 'Teodoro Sampaio', 'Lago Parque', '86015-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34091, 'Araucária', 'Teodoro Santini Pietrowski', 'Porto das Laranjeiras', '83703-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34092, 'Colombo', 'Teodoro Soppa', 'Jardim Guarujá', '83407-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34093, 'Almirante Tamandaré', 'Teodozia Zap', 'Colônia Vila Prado', '83504-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34094, 'Ponta Grossa', 'Teófilo Cunha', 'Uvaranas', '84026-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34095, 'Araucária', 'Teófilo Druszcz', 'Thomaz Coelho', '83707-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34096, 'São José dos Pinhais', 'Teófilo Negosek', 'Colônia Zacarias', '83020-836', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34097, 'Ponta Grossa', 'Teófilo Otoni', 'Jardim Carvalho', '84016-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34098, 'Curitiba', 'Teófilo Otoni', 'Cajuru', '82940-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34099, 'Curitiba', 'Teófilo Otoni', 'Cajuru', '82930-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34100, 'Curitiba', 'Teófilo Sade Neto', 'Capão da Imbuia', '82810-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34101, 'Curitiba', 'Teófilo Soares Gomes', 'Jardim Social', '82530-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34102, 'Curitiba', 'Teófilo Treicik', 'Orleans', '82310-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34103, 'Curitiba', 'Teófilo Wisniewski', 'Cidade Industrial', '81270-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34104, 'Pato Branco', 'Teóphilo Augusto Loiola', 'Sambugaro', '85502-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34105, 'Londrina', 'Teotônio Gonçalves', 'Conjunto Habitacional José Giordano', '86082-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34106, 'Ponta Grossa', 'Teotônio Jorge', 'Nova Rússia', '84053-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34107, 'Ponta Grossa', 'Teotônio Jorge', 'Uvaranas', '84020-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34108, 'Castro', 'Teotônio Marcondes', 'Centro', '84165-270', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34109, 'Araucária', 'Teotônio Pires de Souza', 'Boqueirão', '83704-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34110, 'Londrina', 'Teque-Teque', 'Conjunto Habitacional Violim', '86084-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34111, 'Arapongas', 'Teque-teque', 'Vila São João', '86708-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34112, 'Arapongas', 'Tere', 'Jardim Coroados', '86707-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34113, 'Apucarana', 'Terenas', 'Núcleo Habitacional Colonial', '86812-427', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34114, 'Ponta Grossa', 'Teresa Alves', 'Palmeirinha', '84071-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34115, 'Curitiba', 'Teresa de Freitas Tavares', 'Campo de Santana', '81490-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34116, 'Foz do Iguaçu', 'Teresina', 'Jardim Karla', '85868-120', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34117, 'Foz do Iguaçu', 'Teresina', 'Conjunto C', '85870-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34118, 'Telêmaco Borba', 'Teresina', 'Macopa', '84263-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34119, 'Cambé', 'Teresina', 'Vila Salomé', '86192-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34120, 'Maringá', 'Teresinha de Oliveira Costa', 'Conjunto Habitacional Requião', '87047-467', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34121, 'Pato Branco', 'Tereza Cadorin', 'Bancários', '85504-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34122, 'São José dos Pinhais', 'Tereza Caetano de Lima', 'Afonso Pena', '83050-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34123, 'Londrina', 'Tereza Caetano Soares', 'Jardim Imagawa', '86080-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34124, 'Guarapuava', 'Tereza Cristina', 'Dos Estados', '85035-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34125, 'Londrina', 'Tereza de Ávila', 'Gayon', '86039-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34126, 'Londrina', 'Tereza de Souza', 'Conjunto Residencial Doutor Alberto João Zortea', '86042-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34127, 'Curitiba', 'Tereza Delminda da Silva Costa', 'Cidade Industrial', '81315-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34128, 'Almirante Tamandaré', 'Tereza Fonseca Camargo', 'Jardim Dourados', '83507-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34129, 'São José dos Pinhais', 'Tereza Francisca Dissenha Conque', 'Silveira da Motta', '83030-495', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34130, 'Curitiba', 'Tereza Haisi Lupinski', 'Uberaba', '81590-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34131, 'Londrina', 'Tereza Kuhn Heringer', 'Conjunto Residencial Vale do Arvoredo', '86047-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34132, 'Piraquara', 'Tereza Liberato Ricardo', 'Planta Vera Cruz', '83314-326', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34133, 'Curitiba', 'Tereza Luka', 'Santa Felicidade', '82020-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34134, 'São José dos Pinhais', 'Tereza M. da Silva', 'Ipê', '83055-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34135, 'Curitiba', 'Tereza Magrin Buso', 'Sítio Cercado', '81900-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34136, 'Foz do Iguaçu', 'Tereza Marcon de Nadai', 'Novo Mundo', '85862-407', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34137, 'Piraquara', 'Tereza Maria Miara', 'Planta Santa Clara', '83306-297', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34138, 'Piraquara', 'Tereza Moreira', 'Jardim dos Eucaliptos', '83311-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34139, 'São José dos Pinhais', 'Tereza Nester', 'Afonso Pena', '83045-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34140, 'Curitiba', 'Tereza Olineck', 'Cajuru', '82930-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34141, 'Curitiba', 'Tereza Pellanda Nichelle', 'Sítio Cercado', '81925-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34142, 'Piraquara', 'Tereza Priscim', 'Jardim Monte Líbano', '83311-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34143, 'Foz do Iguaçu', 'Tereza Rufino Brofos', 'Porto Belo', '85867-635', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34144, 'Curitiba', 'Tereza Zacot Nicco', 'Campo Comprido', '81200-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34145, 'Piraquara', 'Tereziano Esteves da Silva', 'Jardim Alterosa', '83314-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34146, 'Guarapuava', 'Terezina', 'Conradinho', '85055-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34147, 'Londrina', 'Terezina', 'Vila Shima Bokuro', '86020-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34148, 'Maringá', 'Terezina', 'Vila Morangueira', '87040-400', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34149, 'Piraquara', 'Terezina', 'Jardim Tropical', '83314-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34150, 'São José dos Pinhais', 'Terezina', 'Costeira', '83015-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34151, 'Cascavel', 'Terezina', 'Cancelli', '85811-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34152, 'Cascavel', 'Terezina', 'Recanto Tropical', '85807-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34153, 'Curitiba', 'Terezina', 'Cajuru', '82920-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34154, 'Curitiba', 'Terezina', 'Cajuru', '82930-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34155, 'Campo Largo', 'Terezinha Colaço da Silveira', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34156, 'Londrina', 'Terezinha de Jesus Carreri', 'Jardim das Américas', '86076-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34157, 'Colombo', 'Terezinha de Jesus Lopes', 'Jardim Nova Esperança', '83413-139', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34158, 'Almirante Tamandaré', 'Terezinha de Matos', 'Vila Joly', '83505-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34159, 'São José dos Pinhais', 'Terezinha Emídia Farias da Silva', 'São Sebastião', '83075-468', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34160, 'Paranavaí', 'Terezinha Fortes Martins', 'Jardim Paulista', '87709-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34161, 'São José dos Pinhais', 'Terezinha Ivanir de Morais', 'Afonso Pena', '83040-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34162, 'Araucária', 'Terezinha Olívia Casanova', 'Costeira', '83708-757', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34163, 'Almirante Tamandaré', 'Terezinha Pereira da Silva', 'Jardim Campo Verde', '83502-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34164, 'Londrina', 'Terezinha Pereira Trindade', 'Jardim São Jorge', '86082-807', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34165, 'Curitiba', 'Terezinha Ramos Ferreira', 'Cajuru', '82980-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34166, 'Curitiba', 'Terezinha Schlivinski', 'Cristo Rei', '80050-590', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34167, 'Curitiba', 'Terézio Porto', 'Jardim Botânico', '80210-240', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34168, 'Francisco Beltrão', 'Terezópolis', 'Pinheirinho', '85603-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34169, 'Maringá', 'Terra', 'Jardim Universo', '87060-540', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34170, 'Sarandi', 'Terra', 'Jardim Universal', '87114-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34171, 'Cambé', 'Terra', 'Parque Maracanã', '86185-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34172, 'Ponta Grossa', 'Terra Boa', 'Chapada', '84062-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34173, 'Pinhais', 'Terra Boa', 'Jardim Pedro Demeterco', '83324-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34174, 'Maringá', 'Terra Boa', 'Zona 08', '87050-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34175, 'Curitiba', 'Terra Boa', 'Santa Felicidade', '82030-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34176, 'Pinhais', 'Terra Rica', 'Vila Emiliano Perneta', '83324-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34177, 'Ponta Grossa', 'Terra Rica', 'Contorno', '84052-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34178, 'São José dos Pinhais', 'Terra Rica', 'São Cristóvão', '83040-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34179, 'Curitiba', 'Terra Rica', 'São Braz', '82315-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34180, 'Pinhais', 'Terra Roxa', 'Planta Portal da Serra', '83325-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34181, 'Toledo', 'Terra Roxa', 'Jardim La Salle', '85903-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34182, 'Toledo', 'Terra Roxa', 'Jardim La Salle', '85902-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34183, 'Cascavel', 'Terra Roxa', 'Região do Lago 2', '85816-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34184, 'Curitiba', 'Terra Roxa', 'São Braz', '82315-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34185, 'Cascavel', 'Tersilio Salgo', 'Santa Cruz', '85806-076', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34186, 'Paranaguá', 'Tertuliana da Cruz dos Santos', 'Parque São João', '83212-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34187, 'Londrina', 'Tertuliano', 'Califórnia', '86040-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34188, 'Cambé', 'Tertuliano Jucelin Vivan', 'Jardim Riviera', '86187-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34189, 'Curitiba', 'Tertuliano Müller', 'Alto da Glória', '80030-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34190, 'Maringá', 'Tertuliano Ribeiro dos Santos', 'Conjunto Residencial Cidade Alta', '87053-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34191, 'Arapongas', 'Tesoura', 'Jardim Bandeirantes', '86703-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34192, 'Araucária', 'Tesoureiro', 'Capela Velha', '83706-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34193, 'Pinhais', 'Tesourinha', 'Jardim Fênix', '83326-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34194, 'Arapongas', 'Tesourinha', 'Conjunto Centauro', '86709-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34195, 'Arapongas', 'Tetraz', 'Vila Industrial', '86706-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34196, 'Curitiba', 'Tetsuo Okahara', 'Bacacheri', '82520-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34197, 'Arapongas', 'Teu-teu', 'Jardim Aeroporto', '86702-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34198, 'Francisco Beltrão', 'Texas', 'Pinheirinho', '85603-075', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34199, 'Sarandi', 'Texas', 'Jardim Califórnia', '87112-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34200, 'Maringá', 'Thadeu Schalkoski', 'Jardim Botânico', '87060-538', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34201, 'Curitiba', 'Thadeu Wasilewski', 'Abranches', '82220-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34202, 'Pinhais', 'Thaíza Fernanda Cunha Escarcel', 'Loteamento Pineville', '83325-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34203, 'Curitiba', 'Thales da Costa e Silva', 'Campo Comprido', '81220-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34204, 'Curitiba', 'Thales Saldanha', 'Uberaba', '81580-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34205, 'Apucarana', 'Tharcisio Cardoso Lemos', 'Jardim Aeroporto', '86812-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34206, 'Ponta Grossa', 'Thaumaturgo de Azevedo', 'Oficinas', '84036-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34207, 'Almirante Tamandaré', 'Thecla Pieckes Antôniacomi', 'Jardim Novo Horizonte da Cachoeira', '83502-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34208, 'Umuarama', 'Thelmo Galvão Moreira', 'Parque Bandeirantes', '87504-679', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34209, 'Toledo', 'Theobaldo Dreyer', 'Jardim Modelo', '85906-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34210, 'Foz do Iguaçu', 'Theodomiro Luiz de Souza', 'Jardim Porto Belo', '85867-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34211, 'Londrina', 'Theodore Roosevelt', 'Eldorado', '86040-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34212, 'Paranaguá', 'Theodorico dos Santos', 'Costeira', '83203-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34213, 'Curitiba', 'Theodorico Ricetti', 'Alto Boqueirão', '81850-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34214, 'Londrina', 'Theodoro Brauko', 'Sabará III', '86066-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34215, 'Curitiba', 'Theodoro Bruno Breithaupt', 'Abranches', '82130-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34216, 'Cambé', 'Theodoro Conceição', 'Jardim Planalto Verde', '86192-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34217, 'Curitiba', 'Theodoro de Bona', 'Cidade Industrial', '81260-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34218, 'Guarapuava', 'Theodoro Echeverria', 'Jardim das Américas', '85030-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34219, 'Colombo', 'Theodoro Gaida', 'Jardim Samambaia', '83407-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34220, 'Curitiba', 'Theodoro Gbur', 'Tingui', '82600-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34221, 'Ponta Grossa', 'Theodoro Guimarães', 'Boa Vista', '84070-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34222, 'Curitiba', 'Theodoro Javorski', 'Cidade Industrial', '81460-348', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34223, 'Ponta Grossa', 'Theodoro Kluppel', 'Olarias', '84035-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34224, 'Curitiba', 'Theodoro Locker', 'Cidade Industrial', '81270-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34225, 'Castro', 'Theodoro Lopes de Oliveira', 'Jardim das Araucárias', '84174-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34226, 'Curitiba', 'Theodoro Makiolka', 'Barreirinha', '82710-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34227, 'Curitiba', 'Theodoro Makiolka', 'Santa Cândida', '82640-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34228, 'Curitiba', 'Theodoro Makiolka', 'Santa Cândida', '82650-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34229, 'Curitiba', 'Theodoro Martins', 'Uberaba', '81580-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34230, 'Ponta Grossa', 'Theodoro Peckolt', 'Ronda', '84051-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34231, 'Ponta Grossa', 'Theodoro Pinheiro Machado', 'Jardim Carvalho', '84015-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34232, 'Curitiba', 'Theodoro Prazmoski', 'Atuba', '82860-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34233, 'Foz do Iguaçu', 'Theodoro Risden', 'Parque Residencial Três Bandeiras', '85862-269', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34234, 'Ponta Grossa', 'Theodoro Rosas', 'Centro', '84010-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34235, 'Ponta Grossa', 'Theodoro Sampaio', 'Oficinas', '84036-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34236, 'Ponta Grossa', 'Theodoro Sampaio', 'Oficinas', '84035-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34237, 'Curitiba', 'Theodoro Schneider', 'Portão', '81070-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34238, 'Londrina', 'Theodoro Skiba', 'Barbeta', '86078-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34239, 'Londrina', 'Theodoro Victorelli', 'Damasco', '86035-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34240, 'Londrina', 'Theodoro Victorelli', 'Helena', '86027-750', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34241, 'Francisco Beltrão', 'Theodoro Zanatta', 'Antônio de Paiva Cantelmo', '85603-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34242, 'Curitiba', 'Theodoro Zubinski', 'Abranches', '82220-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34243, 'Cascavel', 'Theofanio Maltezo', 'Claudete', '85811-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34244, 'Castro', 'Theofilo Condessa Villela', 'Jardim Social Arapongas', '84174-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34245, 'Ponta Grossa', 'Theófilo Cunha', 'Uvaranas', '84026-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34246, 'São José dos Pinhais', 'Theolindo Franco da Cruz', 'Cidade Jardim', '83035-410', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34247, 'Curitiba', 'Theophilo Augusto Loyola Guimarães', 'Atuba', '82630-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34248, 'Curitiba', 'Theophilo Benato', 'São Braz', '82320-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34249, 'Curitiba', 'Theophilo Mansur', 'Novo Mundo', '81050-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34250, 'Araucária', 'Theophilo Schaikoski', 'Campina da Barra', '83709-840', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34251, 'Foz do Iguaçu', 'Theophilo Vakin', 'Conjunto Habitacional Fernanda', '85862-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34252, 'Francisco Beltrão', 'Thercilio Camera', 'Pinheirinho', '85606-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34253, 'Ponta Grossa', 'Thercizo Manfron', 'Chapada', '84063-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34254, 'Curitiba', 'Thereza Darif', 'Pilarzinho', '82100-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34255, 'Curitiba', 'Thereza Fontana Alves', 'Capão Raso', '81110-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34256, 'Curitiba', 'Thereza Mouro Peinado', 'Cidade Industrial', '81315-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34257, 'Curitiba', 'Thereza Passerino Moura', 'Pilarzinho', '82100-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34258, 'Maringá', 'Thereza Rosa Barriquelli Covre', 'Jardim da Glória', '87047-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34259, 'Curitiba', 'Thereza Slongo Furlan', 'Cidade Industrial', '81450-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34260, 'Curitiba', 'Thereza Thomazzi', 'Sítio Cercado', '81900-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34261, 'Londrina', 'Thereza Viventin Salvador', 'Jardim Imagawa', '86080-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34262, 'Cambé', 'Thiago de Freitas Falcão', 'Planta São Francisco', '86182-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34263, 'Ponta Grossa', 'Thiago Peixoto', 'Ronda', '84051-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34264, 'Curitiba', 'Thiago Sudan Soares', 'Alto Boqueirão', '81830-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34265, 'Londrina', 'Thimóteo', 'Vila Siam', '86039-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34266, 'Curitiba', 'Thomas Antônio Gonzaga', 'Cajuru', '82900-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34267, 'Paranaguá', 'Thomas Cheedan', 'Rocio', '83221-525', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34268, 'Colombo', 'Thomas Edison', 'Planta Maracanã', '83408-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34269, 'Curitiba', 'Thomas Edison', 'Prado Velho', '80215-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34270, 'Campo Mourão', 'Thomas Edison de Andrade Vieira', 'Jardim Aeroporto', '87310-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34271, 'Curitiba', 'Thomas Mann', 'Barreirinha', '82700-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34272, 'São José dos Pinhais', 'Thomas Morus', 'Aristocrata', '83030-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34273, 'Londrina', 'Thomaz Alva Edson', 'Industrial', '86063-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34274, 'São José dos Pinhais', 'Thomaz Carmeliano de Miranda', 'Guatupê', '83060-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34275, 'Araucária', 'Thomaz Coelho', 'Thomaz Coelho', '83707-080', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34276, 'Curitiba', 'Thomaz David Borges', 'Cajuru', '82980-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34277, 'Londrina', 'Thomaz Fabrício', 'Conjunto Habitacional Saltinho', '86042-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34278, 'Ponta Grossa', 'Thomaz Gonzaga', 'Nova Rússia', '84070-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34279, 'São José dos Pinhais', 'Thomaz Hobbes', 'Aristocrata', '83030-290', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34280, 'Curitiba', 'Thomaz Ivankio', 'Tatuquara', '81880-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34281, 'Colombo', 'Thomaz Liss', 'Vila Miracema', '83408-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34282, 'Ponta Grossa', 'Thomaz Migdalski', 'Estrela', '84050-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34283, 'Curitiba', 'Thomaz Otto', 'Pilarzinho', '82100-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34284, 'Londrina', 'Thomaz Pereira Machado', 'Parigot de Souza 2', '86082-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34285, 'São José dos Pinhais', 'Thomaz Stonoga', 'Miringuava', '83090-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34286, 'Araucária', 'Thomaz Wolski', 'Boqueirão', '83704-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34287, 'Apucarana', 'Thomaz Zanbonini', 'Residencial Parque da Raposa', '86812-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34288, 'Guarapuava', 'Thome Cebulski', 'Morro Alto', '85067-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34289, 'Guarapuava', 'Thome de Souza', 'Alto Cascavel', '85031-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34290, 'Ponta Grossa', 'Thome de Souza', 'Uvaranas', '84032-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34291, 'Ponta Grossa', 'Tião Domingos', 'Colônia Dona Luiza', '84046-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34292, 'Almirante Tamandaré', 'Tiatuba', 'Vila Alto Pinheiros', '83503-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34293, 'Foz do Iguaçu', 'Tibagi', 'Campos do Iguaçu', '85857-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34294, 'Londrina', 'Tibagi', 'Recreio', '86025-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34295, 'Guarapuava', 'Tibagi', 'Boqueirão', '85020-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34296, 'Paranavaí', 'Tibagi', 'Jardim Ouro Branco', '87704-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34297, 'Piraquara', 'Tibagi', 'Planta Araçatuba', '83301-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34298, 'Toledo', 'Tibagi', 'Jardim Bressan', '85913-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34299, 'São José dos Pinhais', 'Tibagi', 'Silveira da Motta', '83030-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34300, 'Telêmaco Borba', 'Tibagi', 'Vila São José', '84263-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34301, 'Colombo', 'Tibagi', 'Jardim Ouro Verde', '83405-720', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34302, 'Araucária', 'Tibagi', 'Iguaçu', '83701-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34303, 'Curitiba', 'Tibagi', 'Centro', '80060-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34304, 'Curitiba', 'Tibério Gracco', 'Barreirinha', '82700-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34305, 'Londrina', 'Tibet', 'Cláudia', '86050-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34306, 'Colombo', 'Tibiriçá', 'Jardim Quitandinha', '83409-250', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34307, 'Toledo', 'Tibúrcio Antunes', 'Vila Becker', '85902-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34308, 'Curitiba', 'Tibúrcio Brasil', 'Jardim das Américas', '81520-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34309, 'Pinhais', 'Tibúrcio G. de Oliveira', 'Jardim Atuba II', '83326-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34310, 'Ponta Grossa', 'Tibúrcio Pedro Ferreira', 'Centro', '84010-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34311, 'Curitiba', 'Tibúrcio Pereira de Lima', 'Capão Raso', '81130-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34312, 'São José dos Pinhais', 'Ticiano Prendin', 'Costeira', '83015-295', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34313, 'Francisco Beltrão', 'Tico-tico', 'Padre Ulrico', '85604-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34314, 'Foz do Iguaçu', 'Tico-tico', 'Portal da Foz', '85859-408', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34315, 'Maringá', 'Tico-tico', 'Jardim Olímpico', '87070-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34316, 'Ponta Grossa', 'Tico-tico', 'Chapada', '84064-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34317, 'Pinhais', 'Tico-tico', 'Jardim Fênix', '83326-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34318, 'Apucarana', 'Tico-Tico', 'Núcleo Habitacional Michel Soni', '86813-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34319, 'Araucária', 'Tico-tico', 'Estação', '83705-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34320, 'Arapongas', 'Tico-Tico', 'Vila Natal', '86707-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34321, 'Arapongas', 'Tico-Tico', 'Centro', '86701-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34322, 'Arapongas', 'Tico-tico-de-crista-negra', 'Jardim Nova Baroneza', '86706-687', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34323, 'Arapongas', 'Tico-tico-do-bico-amarelo', 'Jardim Universitário', '86702-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34324, 'Arapongas', 'Tico-tico-do-campo', 'Jardim Petrópolis', '86709-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34325, 'Arapongas', 'Tico-tico-rei', 'Jardim Caravelle', '86702-666', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34326, 'Ponta Grossa', 'Ticunas', 'Uvaranas', '84030-369', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34327, 'Arapongas', 'Tié-da-mata', 'Conjunto Tropical', '86702-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34328, 'Arapongas', 'Tié-de-topete', 'Conjunto Padre Chico', '86707-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34329, 'Arapongas', 'Tié-do-serrado', 'Jardim Primavera', '86702-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34330, 'Arapongas', 'Tié-galo', 'Jardim dos Pássaros', '86702-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34331, 'Curitiba', 'Tiepolo Severino', 'Campo Comprido', '81200-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34332, 'Arapongas', 'Tié-preto', 'Parque Veneza', '86701-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34333, 'Foz do Iguaçu', 'Tietê', 'Jardim Manaus', '85857-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34334, 'Guarapuava', 'Tietê', 'Boqueirão', '85022-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34335, 'Francisco Beltrão', 'Tietê', 'Pinheirinho', '85603-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34336, 'Londrina', 'Tietê', 'Nóbrega', '86025-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34337, 'Maringá', 'Tietê', 'Zona 07', '87020-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34338, 'Umuarama', 'Tietê', 'Jardim América', '87502-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34339, 'Campo Largo', 'Tietê', 'Vila Dom Pedro', '83608-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34340, 'Cascavel', 'Tietê', 'Cancelli', '85811-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34341, 'Maringá', 'Tietei', 'Parque Hortência', '87075-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34342, 'Foz do Iguaçu', 'Tietinga', 'Conjunto A', '85866-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34343, 'Arapongas', 'Tietinga', 'Vila Araponguinha', '86705-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34344, 'Arapongas', 'Tifli', 'Jardim Imperial', '86708-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34345, 'Londrina', 'Tijuca', 'Juliana', '86015-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34346, 'Curitiba', 'Tijuca', 'Santa Cândida', '82630-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34347, 'Foz do Iguaçu', 'Tijucas', 'Jardim Cedro', '85862-367', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34348, 'Piraquara', 'Tijucas', 'Planta São Tiago', '83307-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34349, 'São José dos Pinhais', 'Tijucas', 'Guatupê', '83060-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34350, 'Ponta Grossa', 'Tijucas do Sul', 'Oficinas', '84036-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34351, 'São José dos Pinhais', 'Tijucas do Sul', 'Afonso Pena', '83045-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34352, 'Colombo', 'Tijucas do Sul', 'Jardim São José', '83410-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34353, 'Curitiba', 'Tijucas do Sul', 'Sítio Cercado', '81900-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34354, 'Curitiba', 'Tijucas do Sul', 'Sítio Cercado', '81925-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34355, 'Piraquara', 'Tilburg', 'Holandez', '83312-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34356, 'Cascavel', 'Timbira', 'Santa Cruz', '85806-256', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34357, 'Guarapuava', 'Timbiras', 'Vila Carli', '85040-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34358, 'Paranaguá', 'Timbiras', 'Vila Guarani', '83221-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34359, 'Pato Branco', 'Timbiras', 'Menino Deus', '85502-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34360, 'Apucarana', 'Timbiras', 'Núcleo Habitacional Colonial', '86812-448', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34361, 'Pato Branco', 'Timbo', 'Chaparral', '85507-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34362, 'Almirante Tamandaré', 'Timbo', 'Jardim Apucarana', '83505-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34363, 'Colombo', 'Timbú', 'Vila Campo Alto', '83408-337', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34364, 'Apucarana', 'Timburi', 'Núcleo Habitacional Afonso Alves de Camargo', '86803-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34365, 'Campo Mourão', 'Timburi', 'Conjunto Residencial Ilha Bela', '87309-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34366, 'Almirante Tamandaré', 'Timoneira', 'Vila Alto Pinheiros', '83503-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34367, 'Paranaguá', 'Timóteo Alves Marinho', 'Jardim Guaraituba', '83209-295', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34368, 'Curitiba', 'Timóteo José Ferreira', 'Bacacheri', '82600-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34369, 'Araucária', 'Tindiquera', 'Tindiquera', '83708-090', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34370, 'Arapongas', 'Tinguacu', 'Vila Industrial', '86705-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34371, 'Curitiba', 'Tinguacu', 'Cajuru', '82940-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34372, 'Curitiba', 'Tingui', 'São João', '82030-585', 'Parque', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34373, 'Londrina', 'Tinguis', 'Vila Goes', '86026-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34374, 'Londrina', 'Tinguis', 'Eliza', '86026-580', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34375, 'Ponta Grossa', 'Tinguis', 'Oficinas', '84035-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34376, 'Cascavel', 'Tinguis', 'Santa Cruz', '85806-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34377, 'Cambé', 'Tinguis', 'Jardim Tupi', '86183-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34378, 'Guarapuava', 'Tio Abe', 'Vila Jordão', '85015-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34379, 'Arapongas', 'Tio-tio', 'Jardim Paulista', '86707-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34380, 'Guarapuava', 'Tipuana', 'Conradinho', '85055-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34381, 'Cascavel', 'Tipuana', 'Parque Verde', '85807-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34382, 'Araucária', 'Tipuana', 'Campina da Barra', '83709-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34383, 'Francisco Beltrão', 'Tiradentes', 'Cristo Rei', '85602-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34384, 'Londrina', 'Tiradentes', 'Guanabara', '86050-155', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34385, 'Londrina', 'Tiradentes', 'Jardim Shangri-la A', '86070-550', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34386, 'Guarapuava', 'Tiradentes', 'Trianon', '85012-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34387, 'Laranjeiras do Sul', 'Tiradentes', 'Centro', '85301-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34388, 'Londrina', 'Tiradentes', 'Jardim Shangri-la A', '86070-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34389, 'Laranjeiras do Sul', 'Tiradentes', 'Água Verde', '85302-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34390, 'Londrina', 'Tiradentes', 'Rodocentro', '86071-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34391, 'Foz do Iguaçu', 'Tiradentes', 'Centro', '85851-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34392, 'Guarapuava', 'Tiradentes', 'Centro', '85010-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34393, 'Londrina', 'Tiradentes', 'Jardim Rosicler', '86072-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34394, 'Paranavaí', 'Tiradentes', 'Jardim São Jorge', '87710-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34395, 'Paranavaí', 'Tiradentes', 'Jardim São Jorge', '87711-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34396, 'Maringá', 'Tiradentes', 'Vila Ipiranga', '87045-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34397, 'Maringá', 'Tiradentes', 'Zona 01', '87013-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34398, 'Pato Branco', 'Tiradentes', 'Santo Antônio', '85507-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34399, 'Piraquara', 'Tiradentes', 'Jardim Bela Vista', '83301-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34400, 'Ponta Grossa', 'Tiradentes', 'Centro', '84010-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34401, 'Telêmaco Borba', 'Tiradentes', 'Centro', '84261-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34402, 'Sarandi', 'Tiradentes', 'Jardim Panorama', '87113-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34403, 'Umuarama', 'Tiradentes', 'Jardim Paraíso', '87505-090', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34404, 'Sarandi', 'Tiradentes', 'Jardim Independência I', '87114-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34405, 'Toledo', 'Tiradentes', 'Centro', '85900-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34406, 'São José dos Pinhais', 'Tiradentes', 'Afonso Pena', '83050-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34407, 'Telêmaco Borba', 'Tiradentes', 'Centro', '84262-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34408, 'Almirante Tamandaré', 'Tiradentes', 'Jardim Buenos Aires', '83507-268', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34409, 'Cascavel', 'Tiradentes', 'São Cristóvão', '85813-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34410, 'Apucarana', 'Tiradentes', 'Vila Operária Stabile', '86811-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34411, 'Castro', 'Tiradentes', 'Centro', '84165-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34412, 'Cascavel', 'Tiradentes', 'Região do Lago 1', '85812-201', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34413, 'Cascavel', 'Tiradentes', 'Centro', '85812-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34414, 'Curitiba', 'Tiradentes', 'Centro', '80020-100', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34415, 'Arapongas', 'Tirano', 'Vila Brasil', '86705-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34416, 'Arapongas', 'Tiriba', 'Jardim Baroneza', '86706-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34417, 'Arapongas', 'Tiriba-pérola', 'Casa Família Arapongas IV', '86709-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34418, 'Arapongas', 'Tiriba-pintada', 'Jardim Imperial', '86708-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34419, 'Ponta Grossa', 'Tirios', 'Uvaranas', '84030-378', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34420, 'Foz do Iguaçu', 'Tiriva', 'Conjunto A', '85866-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34421, 'Ponta Grossa', 'Tiriva', 'Colônia Dona Luiza', '84043-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34422, 'Pinhais', 'Tiriva', 'Jardim Fênix', '83326-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34423, 'Araucária', 'Tiriva', 'Capela Velha', '83706-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34424, 'Foz do Iguaçu', 'Tisiu', 'Portal da Foz', '85859-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34425, 'Ponta Grossa', 'Titanita', 'Neves', '84021-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34426, 'Maringá', 'Titanita', 'Jardim Santa Helena', '87083-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34427, 'Curitiba', 'Tito Calderari', 'Campina do Siqueira', '80740-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34428, 'Londrina', 'Tito Carneiro Leal', 'Tucano', '86047-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34429, 'Curitiba', 'Tito Galvão Filho', 'Cidade Industrial', '81315-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34430, 'Foz do Iguaçu', 'Tito Muffato', 'Jardim Itamaraty', '85863-070', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34431, 'Cascavel', 'Tito Muffato', 'Santa Cruz', '85806-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34432, 'Curitiba', 'Tito Schier', 'Portão', '81070-200', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34433, 'Londrina', 'Tiyome Kawabata', 'Itapoã', '86043-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34434, 'Londrina', 'Tiziu', 'Jacomo Violin', '86088-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34435, 'Pinhais', 'Tiziu', 'Jardim Fênix', '83326-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34436, 'Arapongas', 'Tiziu', 'Conjunto Centauro', '86709-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34437, 'Campo Mourão', 'Tiziu', 'Jardim Nossa Senhora Aparecida', '87309-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34438, 'Araucária', 'Tiziu', 'Capela Velha', '83706-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34439, 'Ponta Grossa', 'Tobias Amin', 'Boa Vista', '84072-298', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34440, 'São José dos Pinhais', 'Tobias Baptista da Cruz', 'Zaniolo', '83025-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34441, 'Ponta Grossa', 'Tobias Barreto', 'Uvaranas', '84025-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34442, 'Curitiba', 'Tobias Barreto', 'Jardim Social', '82520-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34443, 'Curitiba', 'Tobias Bueno Arruda', 'Seminário', '80310-540', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34444, 'São José dos Pinhais', 'Tobias da Cruz', 'Colônia Rio Grande', '83020-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34445, 'Curitiba', 'Tobias de Macedo', 'Centro', '80020-210', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34446, 'Curitiba', 'Tobias de Macedo Júnior', 'Santo Inácio', '82010-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34447, 'Ponta Grossa', 'Tobias Gumercindo do Valle', 'Colônia Dona Luiza', '84046-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34448, 'Ponta Grossa', 'Tobias Monteiro', 'Centro', '84010-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34449, 'Ponta Grossa', 'Tobias Moscoso', 'Ronda', '84051-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34450, 'Guarapuava', 'Tocantins', 'Boqueirão', '85020-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34451, 'Foz do Iguaçu', 'Tocantins', 'Loteamento Campos do Iguaçu', '85857-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34452, 'Francisco Beltrão', 'Tocantins', 'São Miguel', '85602-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34453, 'Pato Branco', 'Tocantins', 'Baixada', '85505-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34454, 'Pato Branco', 'Tocantins', 'Centro', '85501-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34455, 'Pato Branco', 'Tocantins', 'São Vicente', '85506-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34456, 'Pato Branco', 'Tocantins', 'Brasília', '85504-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34457, 'Paranaguá', 'Tocantins', 'Vila Guarani', '83221-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34458, 'Londrina', 'Tocantins', 'Portuguesa', '86025-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34459, 'Ponta Grossa', 'Tocantins', 'Cará-cará', '84043-610', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34460, 'Paranaguá', 'Tocantins', 'Vila do Povo', '83209-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34461, 'Umuarama', 'Tocantins', 'Zona V', '87504-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34462, 'Araucária', 'Tocantins', 'Campina da Barra', '83709-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34463, 'Curitiba', 'Tocantins', 'Cristo Rei', '80050-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34464, 'Maringá', 'Todos os Santos', 'Zona 02', '87010-500', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34465, 'Pinhais', 'Todos os Santos', 'Planta Guilherme Weiss', '83322-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34466, 'Londrina', 'Togo', 'Ouro Verde', '86080-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34467, 'Londrina', 'Tokio', 'Guanabara', '86050-385', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34468, 'Paranaguá', 'Tokio', 'Parque Agari', '83215-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34469, 'Paranavaí', 'Tokio', 'Vila São Vicente', '87709-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34470, 'Maringá', 'Tokio', 'Jardim Imperial II', '87023-026', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34471, 'Apucarana', 'Tokio', 'Jardim Ponta Grossa', '86805-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34472, 'Guarapuava', 'Toledo', 'Vila Bela', '85027-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34473, 'Foz do Iguaçu', 'Toledo', 'Jardim Paraná', '85867-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34474, 'Laranjeiras do Sul', 'Toledo', 'Água Verde', '85302-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34475, 'Pinhais', 'Toledo', 'Jardim Alto Tarumã', '83325-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34476, 'Maringá', 'Toledo', 'Loteamento Madrid', '87053-518', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34477, 'Ponta Grossa', 'Toledo', 'Chapada', '84062-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34478, 'Paranaguá', 'Toledo', 'Emboguaçu', '83209-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34479, 'São José dos Pinhais', 'Toledo', 'São Pedro', '83020-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34480, 'Colombo', 'Toledo', 'Jardim Cristina', '83410-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34481, 'Cascavel', 'Toledo', 'Periolo', '85817-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34482, 'Cascavel', 'Toledo', 'Centro', '85810-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34483, 'Cascavel', 'Toledo', 'Claudete', '85811-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34484, 'Cascavel', 'Tom Jobim', 'Country', '85813-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34485, 'Guarapuava', 'Tomás Antônio Gonzaga', 'São Cristóvão', '85060-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34486, 'Londrina', 'Tomás Antônio Gonzaga', 'Lago Parque', '86015-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34487, 'Maringá', 'Tomás Antônio Gonzaga', 'Jardim Liberdade', '87047-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34488, 'Umuarama', 'Tomás Antônio Gonzaga', 'Zona V', '87504-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34489, 'Colombo', 'Tomás Antônio Gonzaga', 'Jardim Alvorada', '83409-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34490, 'Cambé', 'Tomás Antônio Gonzaga', 'Parque Residencial Manela', '86185-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34491, 'São José dos Pinhais', 'Tomás de Aquino', 'Aristocrata', '83030-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34492, 'Toledo', 'Tomás de Aquino', 'Boa Esperança', '85909-097', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34493, 'Curitiba', 'Tomás Morus', 'Barreirinha', '82700-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34494, 'Cascavel', 'Tomaz Édison', 'Interlagos', '85814-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34495, 'Pinhais', 'Tomaz Edison de Andrade Vieira', 'Loteamento Alphaville Graciosa', '83327-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34496, 'Toledo', 'Tomaz Edson', 'Pacaembu', '85910-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34497, 'Toledo', 'Tomaz Gonzaga', 'Boa Esperança', '85909-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34498, 'Toledo', 'Tomaz Gonzaga', 'Boa Esperança', '85909-285', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34499, 'Ponta Grossa', 'Tomaz Nogueira de Jesus', 'Olarias', '84026-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34500, 'Curitiba', 'Tomaz Paris', 'São Braz', '82315-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34501, 'São José dos Pinhais', 'Tomaz Sochaczewski', 'Afonso Pena', '83050-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34502, 'Curitiba', 'Tomaz Tessari', 'Lamenha Pequena', '82410-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34503, 'Londrina', 'Tomazina', 'Vitória', '86060-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34504, 'Londrina', 'Tomazina', 'Jardim do Norte', '86060-650', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34505, 'Foz do Iguaçu', 'Tomazina', 'Jardim Residencial São Roque', '85853-698', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34506, 'Ponta Grossa', 'Tomazina', 'Uvaranas', '84025-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34507, 'Pinhais', 'Tomazina', 'Planta Portal da Serra', '83325-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34508, 'São José dos Pinhais', 'Tomazina', 'Bom Jesus', '83025-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34509, 'Telêmaco Borba', 'Tomazina', 'Nossa Senhora de Fátima', '84264-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34510, 'São José dos Pinhais', 'Tomazina', 'Braga', '83020-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34511, 'Almirante Tamandaré', 'Tomazina', 'Vila Tefé', '83503-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34512, 'Colombo', 'Tomazina', 'Jardim Curitiba', '83406-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34513, 'Curitiba', 'Tomazina', 'Ahú', '80540-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34514, 'Londrina', 'Tomé de Souza', 'Vila Monteiro', '86025-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34515, 'Foz do Iguaçu', 'Tomé de Souza', 'Vila Paraguaia', '85864-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34516, 'Paranavaí', 'Tomé de Souza', 'Jardim São Jorge', '87710-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34517, 'Maringá', 'Tomé de Souza', 'Zona 02', '87010-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34518, 'Pato Branco', 'Tomé de Souza', 'Alvorada', '85508-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34519, 'Telêmaco Borba', 'Tomé de Souza', 'Centro', '84261-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34520, 'Umuarama', 'Tomé de Souza', 'Zona VI', '87503-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34521, 'Cascavel', 'Tomé de Souza', 'Presidente', '85818-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34522, 'Curitiba', 'Tomé de Souza', 'Lindóia', '81010-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34523, 'Ponta Grossa', 'Tomio Kawamura', 'Estrela', '84050-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34524, 'Apucarana', 'Tomio Nakamura', 'Núcleo Habitacional das Indústrias', '86806-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34525, 'Curitiba', 'Tommaso Campanella', 'Barreirinha', '82700-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34526, 'Londrina', 'Tommaso Rotondo', 'Condomínio Royal Golf Residence', '86055-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34527, 'Curitiba', 'Toni Buso', 'Parolin', '80220-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34528, 'Londrina', 'Topázio', 'Waldemar Hauer', '86030-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34529, 'Ponta Grossa', 'Topázio', 'Neves', '84021-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34530, 'Maringá', 'Topázio', 'Jardim Real', '87083-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34531, 'Umuarama', 'Topázio', 'Conjunto Residencial Ouro Branco', '87508-256', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34532, 'Telêmaco Borba', 'Topázio', 'Núcleo Bandeirantes', '84269-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34533, 'Cambé', 'Topázio', 'Conjunto Habitacional Cristal', '86182-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34534, 'Campo Mourão', 'Topázio', 'Jardim Tropical I', '87310-228', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34535, 'Cascavel', 'Topázio', 'Esmeralda', '85806-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34536, 'Apucarana', 'Topázio', 'Jardim Aclimação', '86808-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34537, 'Arapongas', 'Topázio-de-fogo', 'Casa Família Arapongas IV', '86709-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34538, 'Arapongas', 'Topázio-vermelho', 'Casa Família Arapongas IV', '86709-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34539, 'Guarapuava', 'Tóquio', 'Morro Alto', '85070-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34540, 'Foz do Iguaçu', 'Tóquio', 'Beverly Falls Park', '85858-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34541, 'Telêmaco Borba', 'Tordesilhas', 'Nossa Senhora de Fátima', '84264-600', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34542, 'Curitiba', 'Torino', 'Tatuquara', '81480-217', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34543, 'Maringá', 'Toronto', 'Jardim Canadá', '87080-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34544, 'Arapongas', 'Tororó', 'Conjunto Novo Centauro', '86709-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34545, 'Curitiba', 'Torquato Tasso', 'Xaxim', '81810-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34546, 'Foz do Iguaçu', 'Torres', 'Jardim Cedro', '85862-368', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34547, 'Maringá', 'Torres', 'Portal das Torres', '87025-650', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34548, 'Colombo', 'Torriceli', 'Jardim Campo Alto', '83408-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34549, 'Francisco Beltrão', 'Toscana', 'Jardim Floresta', '85603-377', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34550, 'Londrina', 'Toshio Sanada', 'Jacutinga', '86087-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34551, 'Curitiba', 'Toufic Raad', 'Cajuru', '82900-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34552, 'Londrina', 'Toulouse', 'Parque Residencial João Piza', '86041-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34553, 'Arapongas', 'Tovaçu', 'Vila Triângulo', '86702-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34554, 'Foz do Iguaçu', 'Traíra', 'Profilurb I', '85855-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34555, 'Piraquara', 'Trajano B. Bueno', 'Planta Laranjeiras', '83301-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34556, 'Piraquara', 'Trajano Batista Bueno', 'Planta Laranjeiras', '83307-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34557, 'Curitiba', 'Trajano da Costa Pereira', 'Bacacheri', '82515-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34558, 'Guarapuava', 'Trajano Reis', 'Alto da XV', '85065-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34559, 'Curitiba', 'Trajano Reis', 'São Francisco', '80510-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34560, 'Cascavel', 'Tramandai', 'Canadá', '85813-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34561, 'Londrina', 'Tranquilo de Piva Botega', 'Jardim Burle Marx', '86047-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34562, 'Castro', 'Tranqüilo Gardinal', 'Vila Farias', '84178-040', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34563, 'Pinhais', 'Transpalmital', 'Chácara Paulivinas', '83320-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34564, 'Toledo', 'Travessa', 'Centro', '85901-046', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34565, 'Telêmaco Borba', 'Tremedal', 'Área 06', '84271-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34566, 'Guarapuava', 'Tremembes', 'Vila Carli', '85040-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34567, 'Londrina', 'Tremembes', 'Castelo', '86027-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34568, 'Londrina', 'Tremembes', 'Ideal', '86030-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34569, 'Londrina', 'Tremembes', 'Casoni', '86026-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34570, 'Cascavel', 'Trento', 'Cascavel Velho', '85818-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34571, 'Cambé', 'Trento', 'Jardim Montecatini', '86186-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34572, 'Curitiba', 'Trento', 'São Braz', '82320-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34573, 'Foz do Iguaçu', 'Três', 'Portal da Foz', '85859-535', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34574, 'Foz do Iguaçu', 'Três', 'Conjunto Residencial Yang Ming', '85854-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34575, 'Foz do Iguaçu', 'Três', 'Três Pinheiros', '85856-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34576, 'Paranavaí', 'Três', 'Conjunto Dona Josefa', '87708-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34577, 'Piraquara', 'Três', 'Chácara Águas Claras', '83309-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34578, 'Paranavaí', 'Três', 'Jardim Maringá', '87709-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34579, 'Ponta Grossa', 'Três', 'Neves', '84020-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34580, 'Paranaguá', 'Três', 'Jardim Paraná', '83215-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34581, 'Ponta Grossa', 'Três', 'Contorno', '84060-587', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34582, 'Ponta Grossa', 'Três', 'Chapada', '84064-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34583, 'Ponta Grossa', 'Três', 'Uvaranas', '84026-587', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34584, 'Ponta Grossa', 'Três', 'Uvaranas', '84022-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34585, 'Ponta Grossa', 'Três', 'Contorno', '84060-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34586, 'Ponta Grossa', 'Três', 'Jardim Carvalho', '84016-507', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34587, 'Piraquara', 'Três', 'Chácara Águas Claras', '83309-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34588, 'Londrina', 'Três', 'Residencial Vila Romana', '86031-825', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34589, 'Piraquara', 'Três', 'Chácara Águas Claras', '83309-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34590, 'Paranavaí', 'Três', 'Vila City', '87709-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34591, 'Ponta Grossa', 'Três', 'Uvaranas', '84030-737', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34592, 'Ponta Grossa', 'Três', 'Oficinas', '84043-006', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34593, 'Ponta Grossa', 'Três', 'Uvaranas', '84032-457', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34594, 'Ponta Grossa', 'Três', 'Chapada', '84063-416', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34595, 'Paranaguá', 'Três', 'Vila Garcia', '83218-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34596, 'Ponta Grossa', 'Três', 'Uvaranas', '84030-478', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34597, 'Maringá', 'Três', 'Parque Industrial 200', '87035-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34598, 'Paranaguá', 'Três', 'Vila dos Comerciários', '83215-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34599, 'Umuarama', 'Três', 'Jardim Maria Lúcia', '87501-656', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34600, 'Umuarama', 'Três', 'Jardim São Cristóvão', '87507-357', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34601, 'Telêmaco Borba', 'Três', 'Vila Santa Rita', '84263-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34602, 'Umuarama', 'Três', 'Jardim Monte Carlo', '87506-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34603, 'Umuarama', 'Três', 'Jardim Beira Rio', '87507-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34604, 'Sarandi', 'Três', 'Jardim Independência I', '87114-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34605, 'Cambé', 'Três', 'Jardim Morada do Sol', '86181-345', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34606, 'Almirante Tamandaré', 'Três', 'São Miguel', '83511-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34607, 'Campo Largo', 'Três', 'Vila São Luiz', '83608-236', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34608, 'Campo Largo', 'Três', 'Jardim Florestal', '83602-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34609, 'Almirante Tamandaré', 'Três', 'Jardim Planalto', '83514-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34610, 'Campo Largo', 'Três', 'Jardim Santa Luzia', '83606-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34611, 'Campo Largo', 'Três', 'Loteamento São Gerônimo', '83606-177', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34612, 'Almirante Tamandaré', 'Três', 'Jardim Cíntia Mara', '83513-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34613, 'Almirante Tamandaré', 'Três', 'Parque Uracap', '83505-137', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34614, 'Almirante Tamandaré', 'Três', 'Vila Grécia', '83502-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34615, 'Campo Largo', 'Três', 'Jardim Keli Cristina', '83609-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34616, 'Almirante Tamandaré', 'Três', 'Planta Bela Vista', '83514-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34617, 'Campo Largo', 'Três', 'Vila Conceição', '83608-296', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34618, 'Campo Largo', 'Três', 'Jardim das Palmeiras', '83602-036', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34619, 'Campo Largo', 'Três', 'Jardim Paraíso Mineral', '83606-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34620, 'Campo Largo', 'Três', 'Núcleo Habitacional Mathias Batista', '83604-156', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34621, 'Campo Largo', 'Três', 'Jardim das Palmas', '83602-046', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34622, 'Campo Largo', 'Três', 'Jardim Clímax', '83608-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34623, 'Almirante Tamandaré', 'Três', 'Loteamento Marinoni', '83508-556', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34624, 'Campo Largo', 'Três', 'Jardim Guarany I', '83608-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34625, 'Campo Largo', 'Três', 'Vila Pompéia', '83608-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34626, 'Campo Largo', 'Três', 'Vila Mariano Torres', '83608-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34627, 'Almirante Tamandaré', 'Três', 'Jardim Maria Luiza', '83514-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34628, 'Almirante Tamandaré', 'Três', 'Jardim Ipanema', '83507-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34629, 'Campo Largo', 'Três', 'Jardim das Acácias', '83603-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34630, 'Campo Largo', 'Três', 'Jardim Lorenzete', '83603-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34631, 'Almirante Tamandaré', 'Três', 'Jardim Valença', '83512-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34632, 'Almirante Tamandaré', 'Três', 'Jardim das Oliveiras', '83502-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34633, 'Almirante Tamandaré', 'Três', 'Jardim Tatiana', '83513-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34634, 'Almirante Tamandaré', 'Três', 'Vila Santa Edwiges', '83504-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34635, 'Campo Largo', 'Três', 'Loteamento Chulik', '83608-085', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34636, 'Almirante Tamandaré', 'Três', 'Jardim Areias', '83514-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34637, 'Campo Largo', 'Três', 'Loteamento Helvidia', '83605-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34638, 'Ponta Grossa', 'Três - Jardim Vitória', 'Chapada', '84064-416', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34639, 'Paranavaí', 'Três Amigos', 'Jardim Guanabara', '87706-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34640, 'Cascavel', 'Três Amigos', 'Universitário', '85819-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34641, 'Cascavel', 'Três Barras', 'Universitário', '85819-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34642, 'Umuarama', 'Três Corações', 'Jardim América', '87502-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34643, 'Curitiba', 'Três Corações', 'Santa Felicidade', '82410-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34644, 'Londrina', 'Três de Dezembro', 'Centro', '86020-310', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34645, 'Foz do Iguaçu', 'Três de Maio', 'Jardim do Norte', '85854-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34646, 'Francisco Beltrão', 'Três de Maio', 'Centro', '85601-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34647, 'Toledo', 'Três de Outubro', 'Vila Industrial', '85904-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34648, 'Foz do Iguaçu', 'Três Fronteiras', 'Parque Residencial Três Fronteiras', '85855-616', 'Acesso', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34649, 'Maringá', 'Três Irmãos', 'Parque das Grevíleas', '87025-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34650, 'Sarandi', 'Três Lagoas', 'Jardim Gralha Azul', '87112-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34651, 'Maringá', 'Três Marias', 'Residencial Regente', '87045-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34652, 'Curitiba', 'Três Marias', 'Orleans', '82310-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34653, 'Foz do Iguaçu', 'Três Passos', 'Jardim do Norte', '85854-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34654, 'Almirante Tamandaré', 'Três Pinheiros', 'Loteamento Chico Mendes', '83505-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34655, 'Londrina', 'Três Poderes', 'Erotildes', '86015-665', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34656, 'Cascavel', 'Três Poderes', 'Presidente', '85818-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34657, 'Foz do Iguaçu', 'Três Pontas', 'Lago dos Cisnes', '85861-260', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34658, 'Cambé', 'Treviso', 'Jardim Montecatini', '86186-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34659, 'Curitiba', 'Treviso', 'Santa Felicidade', '82020-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34660, 'Francisco Beltrão', 'Trevizol', 'São Cristóvão', '85601-353', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34661, 'Pato Branco', 'Trevo Patinhos', 'Trevo Patinhos', '85504-665', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34662, 'Paranaguá', 'Treze', 'Vila Garcia', '83218-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34663, 'Ponta Grossa', 'Treze', 'Contorno', '84060-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34664, 'Ponta Grossa', 'Treze', 'Contorno', '84060-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34665, 'Ponta Grossa', 'Treze', 'Uvaranas', '84030-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34666, 'Ponta Grossa', 'Treze', 'Chapada', '84064-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34667, 'Ponta Grossa', 'Treze', 'Jardim Carvalho', '84016-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34668, 'Ponta Grossa', 'Treze', 'Colônia Dona Luiza', '84046-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34669, 'Ponta Grossa', 'Treze', 'Uvaranas', '84030-508', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34670, 'Ponta Grossa', 'Treze', 'Uvaranas', '84022-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34671, 'Umuarama', 'Treze', 'Jardim Maria Lúcia', '87501-670', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34672, 'Almirante Tamandaré', 'Treze', 'Loteamento Marinoni', '83508-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34673, 'Campo Largo', 'Treze', 'Jardim Guarany I', '83608-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34674, 'Almirante Tamandaré', 'Treze', 'Jardim Silvana', '83512-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34675, 'Almirante Tamandaré', 'Treze', 'Jardim Tatiana', '83513-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34676, 'Campo Largo', 'Treze', 'Jardim Lorenzete', '83603-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34677, 'Campo Largo', 'Treze', 'Loteamento São Gerônimo', '83606-249', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34678, 'Almirante Tamandaré', 'Treze', 'Jardim Paraíso', '83512-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34679, 'Toledo', 'Treze de Abril', 'Vila Industrial', '85904-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34680, 'Umuarama', 'Treze de Agosto', 'Conjunto Residencial Vinte e Oito de Outubro', '87509-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34681, 'Guarapuava', 'Treze de Junho', 'Morro Alto', '85065-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34682, 'Maringá', 'Treze de Junho', 'Jardim Alamar', '87014-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34683, 'Cambé', 'Treze de Junho', 'Jardim União', '86185-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34684, 'Francisco Beltrão', 'Treze de Maio', 'Vila Nova', '85605-050', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34685, 'Guarapuava', 'Treze de Maio', 'Vila Bela', '85027-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34686, 'Paranavaí', 'Treze de Maio', 'Jardim Guanabara', '87706-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34687, 'Paranaguá', 'Treze de Maio', 'Estradinha', '83206-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34688, 'Pinhais', 'Treze de Maio', 'Vila Tarumã', '83323-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34689, 'Telêmaco Borba', 'Treze de Maio', 'Nossa Senhora do Perpétuo Socorro', '84265-520', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34690, 'Toledo', 'Treze de Maio', 'Jardim Paulista', '85909-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34691, 'Umuarama', 'Treze de Maio', 'Zona IV', '87504-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34692, 'Umuarama', 'Treze de Maio', 'Jardim Colibri', '87506-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34693, 'Apucarana', 'Treze de Maio', 'Vila São Jorge', '86800-527', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34694, 'Cambé', 'Treze de Maio', 'Jardim União', '86185-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34695, 'Castro', 'Treze de Maio', 'Centro', '84165-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34696, 'Cascavel', 'Treze de Maio', 'Região do Lago 1', '85812-191', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34697, 'Cascavel', 'Treze de Maio', 'Centro', '85812-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34698, 'Cascavel', 'Treze de Maio', 'São Cristóvão', '85813-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34699, 'Almirante Tamandaré', 'Treze de Maio', 'Jardim Formosa', '83511-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34700, 'Curitiba', 'Treze de Maio', 'São Francisco', '80510-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34701, 'Curitiba', 'Treze de Maio', 'Centro', '80020-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34702, 'Arapongas', 'Tricodomo', 'Vila Edio', '86705-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34703, 'Curitiba', 'Trieste', 'São Braz', '82320-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34704, 'Arapongas', 'Trinca-ferro', 'Jardim Panorama', '86708-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34705, 'Foz do Iguaçu', 'Trindade', 'Loteamento Menger', '85862-528', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34706, 'São José dos Pinhais', 'Trindade', 'Guatupê', '83060-515', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34707, 'Maringá', 'Trinidad', 'Vila Morangueira', '87040-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34708, 'Pinhais', 'Trinidad Tobago', 'Vila Varginha', '83320-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34709, 'Ponta Grossa', 'Trinta', 'Uvaranas', '84022-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34710, 'Ponta Grossa', 'Trinta', 'Chapada', '84064-609', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34711, 'Sarandi', 'Trinta', 'Parque Alvamar II', '87113-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34712, 'Sarandi', 'Trinta', 'Jardim Nova Independência I', '87114-765', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34713, 'Ponta Grossa', 'Trinta e Cinco', 'Chapada', '84064-618', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34714, 'Sarandi', 'Trinta e Cinco', 'Jardim Nova Independência I', '87114-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34715, 'Ponta Grossa', 'Trinta e Dois', 'Chapada', '84064-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34716, 'Ponta Grossa', 'Trinta e Dois', 'Uvaranas', '84022-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34717, 'Sarandi', 'Trinta e Dois', 'Jardim Nova Independência I', '87114-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34718, 'Ponta Grossa', 'Trinta e Nove', 'Chapada', '84064-626', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34719, 'Sarandi', 'Trinta e Nove', 'Jardim Nova Independência I', '87114-810', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34720, 'Ponta Grossa', 'Trinta e Oito', 'Chapada', '84064-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34721, 'Sarandi', 'Trinta e Oito', 'Jardim Nova Independência I', '87114-805', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34722, 'Ponta Grossa', 'Trinta e Quatro', 'Chapada', '84064-617', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34723, 'Sarandi', 'Trinta e Quatro', 'Jardim Nova Independência I', '87114-785', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34724, 'Ponta Grossa', 'Trinta e Seis', 'Chapada', '84064-619', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34725, 'Sarandi', 'Trinta e Seis', 'Jardim Nova Independência I', '87114-795', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34726, 'Ponta Grossa', 'Trinta e Sete', 'Chapada', '84064-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34727, 'Sarandi', 'Trinta e Sete', 'Jardim Nova Independência I', '87114-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34728, 'Ponta Grossa', 'Trinta e Três', 'Uvaranas', '84022-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34729, 'Ponta Grossa', 'Trinta e Três', 'Chapada', '84064-616', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34730, 'Ponta Grossa', 'Trinta e Três', 'Jardim Carvalho', '84016-708', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34731, 'Sarandi', 'Trinta e Três', 'Jardim Nova Independência I', '87114-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34732, 'Ponta Grossa', 'Trinta e Um', 'Uvaranas', '84022-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34733, 'Ponta Grossa', 'Trinta e Um', 'Chapada', '84064-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34734, 'Sarandi', 'Trinta e Um', 'Jardim Nova Independência I', '87114-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34735, 'Ponta Grossa', 'Trinta e Um de Marco', 'Estrela', '84050-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34736, 'Pato Branco', 'Trinta e Um de Marco', 'Vila Isabel', '85504-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34737, 'Ponta Grossa', 'Trinta e Um de Março', 'Uvaranas', '84030-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34738, 'Umuarama', 'Trinta e Um de Março', 'Jardim Colibri', '87506-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34739, 'Telêmaco Borba', 'Trinta e Um de Março', 'Nossa Senhora do Perpétuo Socorro', '84265-540', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34740, 'Cambé', 'Trinta e Um de Março', 'Jardim União', '86185-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34741, 'Curitiba', 'Trinta e Um de Março', 'Pinheirinho', '81150-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34742, 'Foz do Iguaçu', 'Trinta Reis', 'Conjunto A', '85866-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34743, 'Arapongas', 'Triste-pia', 'Jardim Primavera', '86702-008', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34744, 'Campo Largo', 'Tritec', 'Fazendinha', '83607-430', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34745, 'Maringá', 'Triunfo', 'Residencial Ibirapuera', '87045-727', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34746, 'Toledo', 'Triunfo', 'Jardim Alto Alegre', '85910-136', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34747, 'Curitiba', 'Trofi André Aquim', 'Uberaba', '81560-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34748, 'Arapongas', 'Trogão', 'Vila Trinta e Três', '86705-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34749, 'Foz do Iguaçu', 'Trombetas', 'Loteamento Campos do Iguaçu', '85857-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34750, 'Araucária', 'Trombetas', 'Campina da Barra', '83709-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34751, 'Campo Mourão', 'Trombetas', 'Jardim Izabel', '87309-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34752, 'Curitiba', 'Trombudo Central', 'Sítio Cercado', '81910-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34753, 'Arapongas', 'Tropeiro', 'Vila Triângulo', '86702-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34754, 'Paranavaí', 'Trophimo Alves Budal', 'Jardim Simara', '87707-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34755, 'Paranavaí', 'Trophimo Alves Budal', 'Jardim Aeroporto', '87705-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34756, 'Umuarama', 'Tropical', 'Jardim San Martim', '87508-117', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34757, 'Arapongas', 'Trovoada', 'Jardim Coroados', '86707-556', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34758, 'Ponta Grossa', 'Trumis', 'Uvaranas', '84030-377', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34759, 'Guarapuava', 'Truríbio Gomes', 'Vila Bela', '85025-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34760, 'Ponta Grossa', 'Truríbio Lopes de Lara', 'Ronda', '84052-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34761, 'Curitiba', 'Tsunessaburo Makiguti', 'Uberaba', '81540-610', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34762, 'Londrina', 'Tsuro Oguido', 'Conjunto Habitacional Bronzzetti', '86037-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34763, 'Foz do Iguaçu', 'Tubarão', 'Jardim Lancaster II', '85869-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34764, 'Maringá', 'Tubarão', 'Parque das Grevíleas', '87025-200', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34765, 'Piraquara', 'Tubarão', 'Planta São Tiago', '83307-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34766, 'Ponta Grossa', 'Tubarão', 'Cará-cará', '84043-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34767, 'São José dos Pinhais', 'Tubarão', 'São Sebastião', '83075-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34768, 'Campo Mourão', 'Tubarão', 'Conjunto Habitacional Montes Claros', '87310-657', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34769, 'Francisco Beltrão', 'Tucano', 'Miniguaçu', '85605-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34770, 'Francisco Beltrão', 'Tucano', 'Padre Ulrico', '85604-475', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34771, 'Ponta Grossa', 'Tucano', 'Colônia Dona Luiza', '84043-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34772, 'Araucária', 'Tucano', 'Capela Velha', '83706-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34773, 'Campo Largo', 'Tucano', 'Vila Dona Fina', '83609-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34774, 'Cambé', 'Tucano', 'Conjunto Habitacional Waldomiro M Gomes', '86182-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34775, 'Arapongas', 'Tucano-bico-verde', 'Parque Industrial V', '86702-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34776, 'Foz do Iguaçu', 'Tucanos', 'Portal da Foz', '85859-409', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34777, 'Arapongas', 'Tucanos', 'Centro', '86701-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34778, 'Arapongas', 'Tucanuçu', 'Conjunto Novo Centauro', '86709-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34779, 'Foz do Iguaçu', 'Tuco-tuco', 'Conjunto A', '85861-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34780, 'Curitiba', 'Tucum', 'Uberaba', '81550-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34781, 'Maringá', 'Tucuman', 'Vila Morangueira', '87040-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34782, 'Foz do Iguaçu', 'Tucunaré', 'Profilurb I', '85855-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34783, 'Pinhais', 'Tucunaré', 'Loteamento Alphaville Graciosa', '83327-106', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34784, 'Maringá', 'Tucurui', 'Parque das Grevíleas', '87025-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34785, 'Guarapuava', 'Tucuruí', 'Bonsucesso', '85045-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34786, 'Foz do Iguaçu', 'Tucuruí', 'Vila Guarani', '85862-351', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34787, 'Francisco Beltrão', 'Tucuruí', 'São Cristóvão', '85601-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34788, 'Curitiba', 'Tuffi Gariba', 'Barreirinha', '82700-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34789, 'Paranaguá', 'Tufi Maron', 'Correia Velho', '83206-395', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34790, 'Paranaguá', 'Tufi Maron', 'Serraria do Rocha', '83221-636', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34791, 'Curitiba', 'Tufik José Guérios', 'Jardim Botânico', '80210-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34792, 'Curitiba', 'Tufy Nass Cury', 'Xaxim', '81830-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34793, 'Maringá', 'Tuim', 'Parque Hortência', '87075-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34794, 'Foz do Iguaçu', 'Tuím', 'Conjunto A', '85866-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34795, 'Arapongas', 'Tuím', 'Vila Triângulo', '86709-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34796, 'Arapongas', 'Tuim-santo', 'Jardim Paulista', '86707-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34797, 'Maringá', 'Tuiuiú', 'Jardim Olímpico', '87070-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34798, 'Apucarana', 'Tuiuiú', 'Núcleo Habitacional Michel Soni', '86813-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34799, 'Foz do Iguaçu', 'Tuiuti', 'Jardim Itamaraty', '85863-030', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34800, 'Londrina', 'Tuiuti', 'Canadá', '86020-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34801, 'Maringá', 'Tuiuti', 'Parque Residencial Tuiuti', '87043-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34802, 'Pato Branco', 'Tuiuti', 'Pinheirinho', '85506-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34803, 'Maringá', 'Tuiuti', 'Vila Morangueira', '87040-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34804, 'Sarandi', 'Tuiuti', 'Parque Residencial Nova Aliança', '87111-748', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34805, 'Cascavel', 'Tuiuti', 'Claudete', '85811-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34806, 'Cambé', 'Tuiuti', 'Jardim Alvorada', '86191-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34807, 'Ponta Grossa', 'Tulipa', 'Contorno', '84060-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34808, 'Maringá', 'Tulipa', 'Jardim Industrial', '87065-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34809, 'Telêmaco Borba', 'Tulipa', 'Socomim', '84266-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34810, 'Apucarana', 'Tulipa', 'Jardim das Flores I', '86810-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34811, 'Curitiba', 'Tullio Sá Pereira de Souza', 'Bacacheri', '82510-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34812, 'Maringá', 'Tunas', 'Parque das Laranjeiras', '87083-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34813, 'Curitiba', 'Tuneiras do Oeste', 'Cidade Industrial', '81260-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34814, 'Pinhais', 'Tunísia', 'Vila Esplanada', '83320-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34815, 'Telêmaco Borba', 'Tunísia', 'Vila Cristina', '84272-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34816, 'Colombo', 'Tunísia', 'Vila Alto da Cruz II', '83405-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34817, 'Curitiba', 'Tunísia', 'Cajuru', '82960-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34818, 'Londrina', 'Tupã', 'Antares', '86036-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34819, 'Foz do Iguaçu', 'Tupã', 'Jardim Lancaster II', '85869-350', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34820, 'Maringá', 'Tupã', 'Zona 09', '87014-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34821, 'Maringá', 'Tupã', 'Jardim Itaipu', '87060-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34822, 'Maringá', 'Tupã', 'Zona 04', '87014-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34823, 'Toledo', 'Tupã', 'Jardim La Salle', '85903-276', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34824, 'São José dos Pinhais', 'Tupã', 'Colônia Rio Grande', '83025-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34825, 'Umuarama', 'Tupã', 'Parque Tarumã', '87508-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34826, 'Cambé', 'Tupã', 'Jardim São Paulo', '86191-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34827, 'Apucarana', 'Tupã', 'Jardim Eldorado', '86802-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34828, 'Maringá', 'Tupanssi', 'Parque das Laranjeiras', '87083-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34829, 'Londrina', 'Tupi', 'Centro', '86020-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34830, 'Foz do Iguaçu', 'Tupi', 'Jardim Tarobá', '85856-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34831, 'Guarapuava', 'Tupi', 'Vila Carli', '85040-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34832, 'Paranaguá', 'Tupi', 'Vila Guarani', '83221-510', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34833, 'São José dos Pinhais', 'Tupi', 'Colônia Rio Grande', '83025-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34834, 'Umuarama', 'Tupi', 'Zona VI', '87503-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34835, 'Laranjeiras do Sul', 'Tupinambá', 'São Francisco', '85303-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34836, 'Guarapuava', 'Tupinambá', 'Vila Carli', '85040-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34837, 'Piraquara', 'Tupinambá', 'Vila Dalila', '83303-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34838, 'Pato Branco', 'Tupinambá', 'Parzianello', '85504-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34839, 'Paranaguá', 'Tupinambá', 'Vila Guarani', '83221-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34840, 'São José dos Pinhais', 'Tupinambá', 'Colônia Rio Grande', '83025-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34841, 'Araucária', 'Tupinambá', 'Centro', '83702-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34842, 'Apucarana', 'Tupinambá', 'Núcleo Habitacional Colonial', '86812-405', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34843, 'Londrina', 'Tupinambás', 'Casoni', '86026-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34844, 'Paranavaí', 'Tupinambás', 'Jardim São Jorge', '87710-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34845, 'Cascavel', 'Tupinambás', 'Santa Cruz', '85806-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34846, 'Cambé', 'Tupinambás', 'Jardim Tupi', '86183-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34847, 'Francisco Beltrão', 'Tupiniquim', 'São Miguel', '85602-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34848, 'Paranaguá', 'Tupiniquim', 'Vila Guarani', '83221-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34849, 'Londrina', 'Tupiniquins', 'Vila Goes', '86026-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34850, 'Guarapuava', 'Tupiniquins', 'Vila Carli', '85040-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34851, 'Ponta Grossa', 'Tupiniquins', 'Oficinas', '84035-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34852, 'Telêmaco Borba', 'Tupiniquins', 'Nossa Senhora do Perpétuo Socorro', '84265-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34853, 'Apucarana', 'Tupiniquins', 'Núcleo Habitacional Colonial', '86812-418', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34854, 'Cambé', 'Tupiniquins', 'Jardim Tupi', '86183-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34855, 'Cascavel', 'Tupiniquins', 'Santa Cruz', '85806-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34856, 'Ponta Grossa', 'Tupis', 'Uvaranas', '84030-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34857, 'Cascavel', 'Tupis', 'Santa Cruz', '85806-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34858, 'Laranjeiras do Sul', 'Tupy', 'São Francisco', '85303-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34859, 'Maringá', 'Tupy', 'Jardim Laodiceia', '87014-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34860, 'Pato Branco', 'Tupy', 'São Cristóvão', '85508-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34861, 'Pato Branco', 'Tupy', 'Pinheirinho', '85507-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34862, 'Pato Branco', 'Tupy', 'Centro', '85505-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34863, 'Pato Branco', 'Tupy', 'Centro', '85501-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34864, 'Pato Branco', 'Tupy', 'Trevo Patinhos', '85504-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34865, 'Paranavaí', 'Tupy', 'Jardim São Jorge', '87710-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34866, 'Pato Branco', 'Tupy', 'Baixada', '85506-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34867, 'Colombo', 'Tupy', 'Vila Campo Alto', '83408-328', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34868, 'Foz do Iguaçu', 'Tupy-guarani', 'Vila Paraguaia', '85864-036', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34869, 'Arapongas', 'Turaco', 'Vila Bernardes', '86705-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34870, 'Londrina', 'Turiacu', 'Jardim Agari', '86025-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34871, 'Umuarama', 'Turiacu', 'Zona VII', '87503-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34872, 'Curitiba', 'Turiacu', 'Cidade Industrial', '81305-315', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34873, 'Guarapuava', 'Turibinho Pereira Biscaia', 'São Cristóvão', '85063-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34874, 'Londrina', 'Turim', 'Parque Residencial João Piza', '86041-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34875, 'Cascavel', 'Turim', 'Cascavel Velho', '85818-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34876, 'Francisco Beltrão', 'Turin', 'Jardim Floresta', '85603-347', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34877, 'Londrina', 'Turmalina', 'São José', '86027-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34878, 'Londrina', 'Turmalina', 'Lupércio Luppi', '86027-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34879, 'Ponta Grossa', 'Turmalina', 'Neves', '84021-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34880, 'Maringá', 'Turmalina', 'Jardim Real', '87083-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34881, 'Umuarama', 'Turmalina', 'Conjunto Residencial Ouro Branco', '87508-257', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34882, 'Telêmaco Borba', 'Turmalina', 'Área 04', '84266-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34883, 'Campo Mourão', 'Turmalina', 'Jardim Tropical I', '87310-236', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34884, 'Cascavel', 'Turmalina', 'Esmeralda', '85806-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34885, 'Francisco Beltrão', 'Turmina', 'Presidente Kennedy', '85605-095', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34886, 'Foz do Iguaçu', 'Turquesa', 'Parque Ouro Verde', '85854-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34887, 'Ponta Grossa', 'Turquesa', 'Neves', '84021-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34888, 'Maringá', 'Turquesa', 'Jardim Real', '87083-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34889, 'Umuarama', 'Turquesa', 'Conjunto Residencial Ouro Branco', '87508-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34890, 'Telêmaco Borba', 'Turquesa', 'Área 04', '84266-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34891, 'Campo Mourão', 'Turquesa', 'Jardim Tropical I', '87310-225', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34892, 'Cascavel', 'Turquesa', 'Esmeralda', '85806-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34893, 'Francisco Beltrão', 'Turquia', 'Aeroporto', '85603-846', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34894, 'Londrina', 'Turquia', 'Jardim São Paulo', '86046-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34895, 'Umuarama', 'Turquia', 'Parque Bonfim', '87507-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34896, 'Guarapuava', 'Turvo', 'Vila Bela', '85027-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34897, 'Maringá', 'Turvo', 'Parque das Laranjeiras', '87083-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34898, 'Foz do Iguaçu', 'Tuvira', 'Conjunto A', '85860-430', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34899, 'Cascavel', 'Txikaos', 'Santa Cruz', '85806-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34900, 'Umuarama', 'U', 'Parque das Jaboticabeiras', '87509-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34901, 'Foz do Iguaçu', 'Uacarí', 'Conjunto A', '85861-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34902, 'Foz do Iguaçu', 'Uba', 'Jardim Lancaster II', '85862-208', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34903, 'Foz do Iguaçu', 'Ubaitaba', 'Jardim Santa Rosa', '85869-230', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34904, 'Colombo', 'Ubaldino Ceccon', 'Vila Santa Helena', '83406-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34905, 'Ponta Grossa', 'Ubaldino do Amaral', 'Uvaranas', '84030-660', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34906, 'Curitiba', 'Ubaldino do Amaral', 'Alto da Glória', '80060-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34907, 'Curitiba', 'Ubaldino Leal Fontoura', 'Cidade Industrial', '81230-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34908, 'Almirante Tamandaré', 'Ubaldino Teixeira', 'Jardim Areias', '83514-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34909, 'Curitiba', 'Ubaldo Brunatti', 'Orleans', '82300-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34910, 'Maringá', 'Ubaldo Soares', 'Jardim Dourados', '87040-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34911, 'Foz do Iguaçu', 'Ubatã', 'Jardim Lancaster II', '85869-340', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34912, 'Foz do Iguaçu', 'Ubatuba', 'Jardim Dona Fátima Osman', '85856-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34913, 'Foz do Iguaçu', 'Uberaba', 'Conjunto A', '85860-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34914, 'Londrina', 'Uberaba', 'Jardim Alvorada', '86062-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34915, 'Guarapuava', 'Uberaba', 'Jardim das Américas', '85030-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34916, 'Foz do Iguaçu', 'Uberaba', 'Jardim Lancaster II', '85869-260', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34917, 'Londrina', 'Uberlândia', 'Jardim Alvorada', '86062-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34918, 'Guarapuava', 'Uberlândia', 'Jardim das Américas', '85030-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34919, 'Cascavel', 'Uberlândia', 'Periolo', '85817-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34920, 'Curitiba', 'Uberlândia', 'Abranches', '82220-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34921, 'Londrina', 'Ubirajara', 'São José', '86027-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34922, 'Maringá', 'Ubirajara', 'Jardim Lucianópolis', '87080-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34923, 'Campo Mourão', 'Ubirajara Giani', 'Jardim Pio XII', '87306-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34924, 'Londrina', 'Ubiratã', 'Jardim São João', '86027-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34925, 'Foz do Iguaçu', 'Ubiratã', 'Vila Carima', '85855-699', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34926, 'Piraquara', 'Ubiratã', 'Planta Belvedere', '83311-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34927, 'Pato Branco', 'Ubiratã', 'Menino Deus', '85502-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34928, 'Curitiba', 'Ubiratã', 'Alto Boqueirão', '81720-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34929, 'Paranaguá', 'Uchi', 'Vila São Vicente', '83209-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34930, 'Londrina', 'Ucrânia', 'Vilas Boas', '86046-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34931, 'Ponta Grossa', 'Ucrânia', 'Uvaranas', '84025-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34932, 'Cambé', 'Ucrânia', 'Jardim Morada do Sol', '86181-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34933, 'Curitiba', 'Udine', 'Santa Felicidade', '82030-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34934, 'Londrina', 'Uganda', 'Ouro Verde', '86080-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34935, 'Pinhais', 'Uganda', 'Vl Dona Guiomar', '83320-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34936, 'Londrina', 'Ugolino Ferreira', 'Cristal', '86044-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34937, 'Arapongas', 'Uiracu', 'Casa Família Arapongas I', '86706-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34938, 'Foz do Iguaçu', 'Uirapuru', 'Portal da Foz', '85859-415', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34939, 'Francisco Beltrão', 'Uirapuru', 'Luther King', '85605-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34940, 'Francisco Beltrão', 'Uirapuru', 'Miniguaçu', '85605-220', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34941, 'Ponta Grossa', 'Uirapuru', 'Chapada', '84064-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34942, 'Maringá', 'Uirapuru', 'Jardim Olímpico', '87070-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34943, 'Pinhais', 'Uirapuru', 'Jardim Fênix', '83326-430', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34944, 'Ponta Grossa', 'Uirapuru', 'Colônia Dona Luiza', '84046-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34945, 'Umuarama', 'Uirapuru', 'Jardim Alphavile', '87504-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34946, 'Umuarama', 'Uirapuru', 'Parque Bandeirantes', '87504-686', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34947, 'São José dos Pinhais', 'Uirapuru', 'Colônia Rio Grande', '83025-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34948, 'Cascavel', 'Uirapuru', 'Floresta', '85814-740', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34949, 'Arapongas', 'Uirapuru', 'Centro', '86701-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34950, 'Campo Largo', 'Uirapuru', 'Vila Gilcy', '83609-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34951, 'Araucária', 'Uirapuru', 'Capela Velha', '83706-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34952, 'Campo Mourão', 'Uirapuru', 'Vila Teixeira', '87300-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34953, 'Cambé', 'Uirapuru', 'Conjunto Habitacional Waldomiro M Gomes', '86182-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34954, 'Apucarana', 'Uirapuru', 'Vila Formosa', '86802-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34955, 'Arapongas', 'Uirapuru-melodioso', 'Conjunto Del Condor', '86703-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34956, 'Laranjeiras do Sul', 'Uirapurus', 'Vila Industrial', '85303-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34957, 'Arapongas', 'Uiratatá', 'Conjunto Tropical', '86702-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34958, 'Pinhais', 'Ulda Pereira da Silva', 'Jardim Marumby', '83327-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34959, 'Curitiba', 'Ulisses Aurélio Visinoni', 'São Miguel', '81260-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34960, 'São José dos Pinhais', 'Ulisses Cordeiro', 'Miringuava', '83090-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34961, 'Curitiba', 'Ulisses Faria de Brito', 'Bacacheri', '82600-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34962, 'Curitiba', 'Ulisses Gavazzoni', 'Xaxim', '81710-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34963, 'Curitiba', 'Ulisses Geraldo Moro', 'Alto Boqueirão', '81770-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34964, 'Campo Mourão', 'Ulisses Guimarães', 'Jardim Santa Cruz', '87309-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34965, 'Curitiba', 'Ulisses José Ribeiro', 'Jardim das Américas', '81530-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34966, 'Curitiba', 'Ulisses Kendrick de Moraes', 'Portão', '81070-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34967, 'Londrina', 'Ulisses Rodrigues da Silva', 'Milton Gavetti', '86046-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34968, 'Campo Largo', 'Ulisses Severino de Lima', 'Vila Cilka', '83606-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34969, 'Toledo', 'Ulisses Toldo', 'Conjunto Habitacional São Francisco', '85912-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34970, 'Pato Branco', 'Ulisses Vigano', 'Industrial', '85504-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34971, 'Londrina', 'Ulisses Xavier da Silva', 'Santiago', '86071-615', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34972, 'Londrina', 'Ulrico Zuimglio', 'Gleba Fazenda Palhano', '86055-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34973, 'São José dos Pinhais', 'Ulysses Ângelo Ferraro', 'São Sebastião', '83075-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34974, 'Francisco Beltrão', 'Ulysses Guimarães', 'Antônio de Paiva Cantelmo', '85603-544', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34975, 'Curitiba', 'Ulysses Percegona', 'Boa Vista', '82560-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34976, 'Foz do Iguaçu', 'Um', 'Três Pinheiros', '85856-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34977, 'Foz do Iguaçu', 'Um', 'Conjunto Residencial Yang Ming', '85854-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34978, 'Guarapuava', 'Um', 'São Cristóvão', '85060-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34979, 'Francisco Beltrão', 'Um', 'São Cristóvão', '85601-745', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34980, 'Maringá', 'Um', 'Chácaras Aeroporto', '87053-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34981, 'Piraquara', 'Um', 'Chácara Águas Claras', '83309-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34982, 'Paranaguá', 'Um', 'Vila Garcia', '83218-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34983, 'Pinhais', 'Um', 'Jardim Pio XII', '83328-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34984, 'Ponta Grossa', 'Um', 'Uvaranas', '84020-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34985, 'Maringá', 'Um', 'Jardim Alamar', '87014-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34986, 'Maringá', 'Um', 'Parque Industrial', '87065-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34987, 'Paranavaí', 'Um', 'Jardim Maringá', '87709-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34988, 'Piraquara', 'Um', 'Chácara Águas Claras', '83309-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34989, 'Paranavaí', 'Um', 'Conjunto Dona Josefa', '87708-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34990, 'Ponta Grossa', 'Um', 'Uvaranas', '84020-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34991, 'Paranavaí', 'Um', 'Jardim Marcela', '87706-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34992, 'Paranavaí', 'Um', 'Vila Prudêncio', '87702-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34993, 'Piraquara', 'Um', 'Chácara Águas Claras', '83309-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34994, 'Ponta Grossa', 'Um', 'Uvaranas', '84022-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34995, 'Ponta Grossa', 'Um', 'Uvaranas', '84030-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34996, 'Maringá', 'Um', 'Chácara Paulista', '87005-105', 'Estrada', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34997, 'Ponta Grossa', 'Um', 'Uvaranas', '84030-386', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34998, 'Ponta Grossa', 'Um', 'Chapada', '84063-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (34999, 'Ponta Grossa', 'Um', 'Contorno', '84060-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35000, 'Paranaguá', 'Um', 'Jardim Paraná', '83215-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35001, 'Ponta Grossa', 'Um', 'Contorno', '84060-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35002, 'Londrina', 'Um', 'Residencial Vila Romana', '86031-805', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35003, 'Ponta Grossa', 'Um', 'Uvaranas', '84032-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35004, 'Ponta Grossa', 'Um', 'Ronda', '84051-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35005, 'Ponta Grossa', 'Um', 'Uvaranas', '84030-476', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35006, 'Ponta Grossa', 'Um', 'Uvaranas', '84026-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35007, 'Ponta Grossa', 'Um', 'Jardim Carvalho', '84016-505', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35008, 'Ponta Grossa', 'Um', 'Oficinas', '84035-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35009, 'Ponta Grossa', 'Um', 'Oficinas', '84036-025', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35010, 'Ponta Grossa', 'Um', 'Chapada', '84064-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35011, 'Ponta Grossa', 'Um', 'Chapada', '84064-007', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35012, 'Maringá', 'Um', 'Parque Industrial 200', '87035-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35013, 'Umuarama', 'Um', 'Jardim Beira Rio', '87507-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35014, 'Umuarama', 'Um', 'Jardim Monte Carlo', '87506-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35015, 'Umuarama', 'Um', 'Jardim Maria Lúcia', '87501-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35016, 'Umuarama', 'Um', 'Jardim São Cristóvão', '87507-355', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35017, 'Sarandi', 'Um', 'Jardim Nova Independência I', '87114-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35018, 'Sarandi', 'Um', 'Jardim Jaqueline', '87112-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35019, 'Toledo', 'Um', 'Jardim Parizzotto', '85914-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35020, 'Telêmaco Borba', 'Um', 'Vila Santa Rita', '84263-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35021, 'Campo Largo', 'Um', 'Vila São Luiz', '83608-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35022, 'Campo Largo', 'Um', 'Jardim Santa Luzia', '83606-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35023, 'Campo Largo', 'Um', 'Jardim das Palmas', '83602-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35024, 'Campo Largo', 'Um', 'Núcleo Habitacional Mathias Batista', '83604-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35025, 'Campo Largo', 'Um', 'Vila Conceição', '83608-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35026, 'Campo Largo', 'Um', 'Jardim Florestal', '83602-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35027, 'Campo Largo', 'Um', 'Jardim Clímax', '83608-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35028, 'Campo Largo', 'Um', 'Jardim Lorenzete', '83603-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35029, 'Almirante Tamandaré', 'Um', 'Planta Bela Vista', '83514-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35030, 'Campo Largo', 'Um', 'Jardim Guarany I', '83608-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35031, 'Campo Largo', 'Um', 'Vila Pompéia', '83608-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35032, 'Campo Largo', 'Um', 'Vila Mariano Torres', '83608-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35033, 'Cascavel', 'Um', 'Santa Felicidade', '85803-327', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35034, 'Almirante Tamandaré', 'Um', 'Parque Uracap', '83505-139', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35035, 'Campo Largo', 'Um', 'Jardim Paraíso Mineral', '83606-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35036, 'Almirante Tamandaré', 'Um', 'Jardim Dona Wanda', '83514-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35037, 'Campo Largo', 'Um', 'Jardim das Palmeiras', '83602-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35038, 'Campo Largo', 'Um', 'Loteamento São Gerônimo', '83606-175', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35039, 'Almirante Tamandaré', 'Um', 'São Miguel', '83511-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35040, 'Almirante Tamandaré', 'Um', 'Jardim das Oliveiras', '83502-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35041, 'Campo Largo', 'Um', 'Loteamento Helvidia', '83605-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35042, 'Almirante Tamandaré', 'Um', 'Jardim Tatiana', '83513-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35043, 'Almirante Tamandaré', 'Um', 'Jardim Planalto', '83514-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35044, 'Almirante Tamandaré', 'Um', 'Jardim Gerhusa', '83502-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35045, 'Almirante Tamandaré', 'Um', 'Jardim Valença', '83512-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35046, 'Londrina', 'Umbelina Cândida da Silva de Oiliveira', 'Aníbal de Siqueira Cabral', '86089-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35047, 'Londrina', 'Umbelina Diz Mansano', 'Jardim dos Alpes I', '86075-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35048, 'Umuarama', 'Umberto Gavassi', 'Parque Bandeirantes', '87504-696', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35049, 'Paranaguá', 'Umbu', 'Vila São Vicente', '83209-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35050, 'Londrina', 'Ume Goya', 'Sabará III', '86066-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35051, 'Maringá', 'Umeno Tokuda', 'Jardim Pinheiros II', '87043-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35052, 'Foz do Iguaçu', 'Umuarama', 'Jardim Cedro', '85862-353', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35053, 'Londrina', 'Umuarama', 'Santo Antônio', '86060-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35054, 'Guarapuava', 'Umuarama', 'Vila Bela', '85025-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35055, 'Maringá', 'Umuarama', 'Zona 08', '87050-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35056, 'Pinhais', 'Umuarama', 'Planta Portal da Serra', '83325-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35057, 'Telêmaco Borba', 'Umuarama', 'Centro', '84261-280', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35058, 'Umuarama', 'Umuarama', 'Parque Industrial I', '87507-055', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35059, 'Campo Largo', 'Umuarama', 'Jardim Rivabem', '83605-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35060, 'Cambé', 'Umuarama', 'Jardim Silvino', '86187-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35061, 'Campo Mourão', 'União Comunitária', 'Conjunto Habitacional Mendes', '87306-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35062, 'Francisco Beltrão', 'União da Vitória', 'Vila Nova', '85605-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35063, 'Guarapuava', 'União da Vitória', 'Vila Bela', '85027-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35064, 'Francisco Beltrão', 'União da Vitória', 'Vila Nova', '85601-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35065, 'Piraquara', 'União da Vitória', 'Jardim Tropical', '83314-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35066, 'Ponta Grossa', 'União da Vitória', 'Oficinas', '84036-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35067, 'São José dos Pinhais', 'União da Vitória', 'Silveira da Motta', '83030-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35068, 'Cambé', 'União da Vitória', 'Jardim Ana Eliza', '86188-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35069, 'Cascavel', 'União da Vitória', 'Cataratas', '85818-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35070, 'Curitiba', 'União da Vitória', 'Barreirinha', '82560-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35071, 'Ponta Grossa', 'União Pan-americana', 'Colônia Dona Luiza', '84045-310', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35072, 'Londrina', 'União Soviética', 'Jerumenha', '86046-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35073, 'Pinhais', 'Uniflor', 'Jardim Pedro Demeterco', '83324-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35074, 'São José dos Pinhais', 'Uniflor', 'Águas Belas', '83010-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35075, 'Sarandi', 'Universal', 'Jardim Universal', '87114-280', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35076, 'Sarandi', 'Universitária', 'Parque Residencial Nova Aliança', '87111-485', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35077, 'Cascavel', 'Universitária', 'Universitário', '85819-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35078, 'Londrina', 'Universo', 'Jardim Tatiani', '86070-710', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35079, 'Maringá', 'Universo', 'Jardim Universo', '87060-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35080, 'Sarandi', 'Universo', 'Jardim Nova Paulista', '87111-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35082, 'Foz do Iguaçu', 'Urai', 'Jardim Residencial São Roque', '85853-697', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35083, 'Ponta Grossa', 'Urai', 'Nova Rússia', '84053-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35084, 'Pinhais', 'Urai', 'Vila Emiliano Perneta', '83324-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35085, 'Curitiba', 'Urai', 'Sítio Cercado', '81900-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35086, 'Apucarana', 'Urânio', 'Vila São Carlos', '86800-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35087, 'Londrina', 'Urano', 'Sol', '86070-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35088, 'Foz do Iguaçu', 'Urano', 'Parque Residencial Três Fronteiras', '85859-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35089, 'Ponta Grossa', 'Urano', 'Uvaranas', '84031-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35090, 'Maringá', 'Urano', 'Jardim Imperial II', '87023-008', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35091, 'Telêmaco Borba', 'Urano', 'Nossa Senhora de Fátima', '84264-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35092, 'Cambé', 'Urano', 'Parque Maracanã', '86185-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35093, 'Curitiba', 'Urano', 'Sítio Cercado', '81910-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35094, 'Castro', 'Urbano Borges Martins', 'Água Suja', '84165-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35095, 'Foz do Iguaçu', 'Urbano Caldeira', 'Parque Morumbi III', '85859-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35096, 'Ponta Grossa', 'Urbano Caldeira', 'Neves', '84020-650', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35097, 'Foz do Iguaçu', 'Urbano Costa Araújo', 'Parque Presidente I', '85863-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35098, 'Guarapuava', 'Urbano da Costa Araújo', 'Morro Alto', '85067-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35099, 'Londrina', 'Urbano Duarte', 'Nova Londres', '86015-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35100, 'Curitiba', 'Urbano Lopes', 'Cristo Rei', '80050-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35101, 'Ponta Grossa', 'Urbano Pianaro', 'Boa Vista', '84071-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35102, 'Maringá', 'Urbano Pinhata', 'Conjunto Residencial Rodolpho Bernardi', '87035-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35103, 'Laranjeiras do Sul', 'Urceni Machado', 'Vila Industrial', '85303-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35104, 'Colombo', 'Urides Alves Ribeiro', 'Jardim Cristina', '83410-575', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35105, 'Campo Largo', 'Uriel dos Reis Pereira', 'Vila Bancária', '83601-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35106, 'Campo Largo', 'Uriel Reis', 'Vila Bancária', '83601-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35107, 'Francisco Beltrão', 'Urio', 'Antônio de Paiva Cantelmo', '85603-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35108, 'Sarandi', 'Ursa Maior', 'Jardim Universal', '87114-517', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35109, 'Curitiba', 'Úrsula Elizabeth Henriette de Mari', 'Tarumã', '82530-530', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35110, 'Colombo', 'Úrsula Toniolo Taverna', 'Roseira', '83415-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35111, 'Curitiba', 'Ursulina Visinoni', 'Cidade Industrial', '81350-608', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35112, 'Foz do Iguaçu', 'Uru', 'Portal da Foz', '85859-416', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35113, 'Londrina', 'Uru', 'Jacomo Violin', '86088-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35114, 'Arapongas', 'Uru', 'Centro', '86701-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35115, 'Campo Mourão', 'Uru', 'Jardim Izabel', '87309-210', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35116, 'Arapongas', 'Uru', 'Centro', '86701-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35117, 'Francisco Beltrão', 'Urubici', 'Centro', '85601-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35118, 'Maringá', 'Urubupungá', 'Parque das Grevíleas', '87025-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35119, 'Piraquara', 'Urucanga', 'Planta Urucanga', '83311-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35120, 'Arapongas', 'Uru-capoeira', 'Parque Veneza', '86701-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35121, 'Ponta Grossa', 'Urucum', 'Neves', '84020-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35122, 'Arapongas', 'Uru-do-campo', 'Conjunto Palmares', '86706-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35123, 'Laranjeiras do Sul', 'Uruguai', 'Cristo Rei', '85304-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35124, 'Foz do Iguaçu', 'Uruguai', 'Jardim América', '85864-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35125, 'Londrina', 'Uruguai', 'Centro', '86010-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35126, 'Francisco Beltrão', 'Uruguai', 'Vila Nova', '85605-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35127, 'Guarapuava', 'Uruguai', 'Morro Alto', '85067-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35128, 'Ponta Grossa', 'Uruguai', 'Centro', '84010-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35129, 'Maringá', 'Uruguai', 'Jardim Alvorada', '87033-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35130, 'Pato Branco', 'Uruguai', 'Jardim América', '85502-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35131, 'São José dos Pinhais', 'Uruguai', 'Cidade Jardim', '83035-020', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35132, 'Toledo', 'Uruguai', 'Parque Residencial Gisela', '85905-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35133, 'Telêmaco Borba', 'Uruguai', 'Macopa', '84261-460', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35134, 'Cascavel', 'Uruguai', 'Alto Alegre', '85805-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35135, 'Castro', 'Uruguai', 'Vila do Rosário', '84168-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35136, 'Almirante Tamandaré', 'Uruguai', 'Jardim Monte Santo', '83501-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35137, 'Almirante Tamandaré', 'Uruguai', 'Vila Graziela', '83505-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35138, 'Colombo', 'Uruguai', 'Jardim Rio Verde', '83405-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35139, 'Apucarana', 'Uruguai', 'Jardim Diamantina', '86804-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35140, 'Curitiba', 'Uruguai', 'Bacacheri', '82510-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35141, 'Guarapuava', 'Uruguaiana', 'Boqueirão', '85020-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35142, 'Pato Branco', 'Uruguaiana', 'Novo Horizonte', '85507-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35143, 'Piraquara', 'Uruguaiana', 'Jardim Tropical', '83314-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35144, 'Cascavel', 'Uruguaiana', 'Canadá', '85813-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35145, 'Arapongas', 'Urumutum', 'Vila Cascata', '86701-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35146, 'Foz do Iguaçu', 'Urupês', 'Jardim Residencial São Roque', '85853-707', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35147, 'Londrina', 'Urupês', 'Oriente', '86027-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35148, 'Maringá', 'Urupês', 'Vila Santo Antônio', '87030-350', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35149, 'Foz do Iguaçu', 'Urussanga', 'Jardim Aurora', '85862-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35150, 'Londrina', 'Urutau', 'Paraíso', '86078-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35151, 'Maringá', 'Urutau', 'Conjunto Residencial Ney Braga', '87083-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35152, 'Ponta Grossa', 'Urutau', 'Colônia Dona Luiza', '84046-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35153, 'Arapongas', 'Urutau', 'Vila Cascata', '86701-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35154, 'Campo Mourão', 'Urutau', 'Jardim Pio XII', '87306-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35155, 'Arapongas', 'Urutau-pardo', 'Conjunto Novo Centauro', '86709-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35156, 'Cascavel', 'Urutu', 'Pioneiros Catarinenses', '85805-425', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35157, 'Londrina', 'Utah', 'Quebec', '86060-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35158, 'Piraquara', 'Utrecht', 'Holandez', '83312-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35159, 'Telêmaco Borba', 'Uvaranal', 'Área 02', '84267-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35160, 'Ponta Grossa', 'Uvas', 'Chapada', '84064-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35161, 'Toledo', 'Uwe Greggersen', 'Parque Residencial Pancera', '85902-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35162, 'Colombo', 'Uzires Pavin', 'Jardim Florença', '83414-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35163, 'Umuarama', 'V', 'Parque das Jaboticabeiras', '87509-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35164, 'Curitiba', 'Vadeco Suit', 'Uberaba', '81560-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35165, 'Piraquara', 'Vagner Luis Boscardin', 'Planta Laranjeiras', '83307-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35166, 'Piraquara', 'Vagner Luis Boscardin', 'Chácara Águas Claras', '83309-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35167, 'Curitiba', 'Valdeci dos Santos', 'Pinheirinho', '81150-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35168, 'Curitiba', 'Valdecir dos Santos', 'Cidade Industrial', '81460-158', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35169, 'São José dos Pinhais', 'Valdemar Adam', 'Afonso Pena', '83050-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35170, 'Cascavel', 'Valdemar Bonn', 'Coqueiral', '85807-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35171, 'Maringá', 'Valdemar Cambarotto', 'Parque Tarumã', '87053-659', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35172, 'Curitiba', 'Valdemar de Andrade', 'Santo Inácio', '82010-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35173, 'Pinhais', 'Valdemar de Siqueira', 'Vila Tarumã', '83323-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35174, 'Campo Largo', 'Valdemar Faustino de Oliveira', 'Vila Andreassa Miranda', '83605-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35175, 'Pato Branco', 'Valdemar Ferraza', 'Amadori', '85502-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35176, 'Foz do Iguaçu', 'Valdemar Leonardo Matte', 'Conjunto Residencial Sol de Maio', '85862-577', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35177, 'Pato Branco', 'Valdemar Schuler', 'Vila Verde', '85506-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35178, 'Apucarana', 'Valdemir Mathias', 'Vila Izabella', '86812-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35179, 'Curitiba', 'Valdemiro Cislinsky', 'Sítio Cercado', '81925-265', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35180, 'Umuarama', 'Valdemiro Sandri', 'Jardim Petrópolis', '87506-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35181, 'São José dos Pinhais', 'Valdemiro Valaski', 'Guatupê', '83065-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35182, 'Francisco Beltrão', 'Valdir Folleto', 'Pinheirinho', '85606-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35183, 'Curitiba', 'Valdir Mazzuco', 'Sítio Cercado', '81910-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35184, 'Pinhais', 'Valdir Oneda', 'Conjunto Residencial Áquila', '83326-045', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35185, 'Curitiba', 'Valdiva Pereira Lima', 'Pilarzinho', '82100-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35186, 'Curitiba', 'Valdivia', 'Hugo Lange', '80040-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35187, 'Apucarana', 'Valdivo José Teixeira', 'Parque Residencial Milani', '86811-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35188, 'Laranjeiras do Sul', 'Valdomira Amaral', 'São Francisco', '85303-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35189, 'Curitiba', 'Valdomiro Buhrer', 'Cidade Industrial', '81315-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35190, 'Foz do Iguaçu', 'Valdomiro Estanislau Jung', 'Jardim Porto Belo', '85867-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35191, 'Foz do Iguaçu', 'Valdomiro Faremberger', 'Três Lagoas', '85862-420', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35192, 'Pato Branco', 'Valdomiro Pastro', 'Pagnoncelli', '85509-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35193, 'Curitiba', 'Valdomiro Poppi', 'Sítio Cercado', '81925-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35194, 'Curitiba', 'Valdomiro Ribeiro da Fonseca', 'Capão da Imbuia', '82810-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35195, 'Curitiba', 'Valdomiro Rodrigues', 'Tatuquara', '81940-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35196, 'Apucarana', 'Valdomiro Serediuk', 'Jardim Trabalhista', '86807-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35197, 'Curitiba', 'Valdomiro Silveira', 'Boa Vista', '82560-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35198, 'São José dos Pinhais', 'Valdomiro Svidnicki', 'Colônia Rio Grande', '83025-339', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35199, 'Londrina', 'Valdomiro Turini', 'Conjunto Novo Amparo 2', '86056-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35200, 'Londrina', 'Valdy Jardim Machado', 'Residencial José B Almeida', '86041-815', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35201, 'Curitiba', 'Valdyr Grando', 'Cidade Industrial', '81310-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35202, 'Foz do Iguaçu', 'Vale do Sol', 'Lago dos Cisnes', '85861-240', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35203, 'Maringá', 'Vale do Sol', 'Jardim Imperial', '87023-107', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35204, 'Curitiba', 'Vale dos Pássaros', 'Cidade Industrial', '81450-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35205, 'Foz do Iguaçu', 'Valença', 'Jardim Residencial São Roque', '85853-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35206, 'Maringá', 'Valença', 'Jardim Laodiceia', '87014-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35207, 'Curitiba', 'Valentim Antônio Ribeiro', 'Atuba', '82860-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35208, 'Castro', 'Valentim Bannach Júnior', 'Jardim das Araucárias', '84174-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35209, 'Curitiba', 'Valentim Bokowski', 'Guabirotuba', '81510-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35210, 'Campo Largo', 'Valentim Fedalto', 'Jardim Santa Luzia', '83606-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35211, 'Ponta Grossa', 'Valentim Guzzo', 'Chapada', '84061-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35212, 'Londrina', 'Valentim Onofrio da Silva', 'Conjunto Habitacional Maria Cecília Serrano de Oliveira', '86085-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35213, 'Colombo', 'Valentim Stempinhack', 'Vila Campo Alto', '83408-326', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35214, 'Campo Largo', 'Valentim Stroparo', 'Loteamento Itaboa', '83605-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35215, 'Araucária', 'Valentim Wall', 'Tindiquera', '83708-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35216, 'São José dos Pinhais', 'Valentim Zem', 'Ouro Fino', '83015-015', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35217, 'Foz do Iguaçu', 'Valentin Agostini', 'Alto São Francisco', '85863-766', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35218, 'Curitiba', 'Valentin Bosa Filho', 'Santa Felicidade', '82400-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35219, 'Colombo', 'Valentin Ceccon', 'Vila Ana Maria', '83413-110', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35220, 'Curitiba', 'Valentin Darú', 'Novo Mundo', '81050-638', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35221, 'Curitiba', 'Valentin Deda', 'Capão Raso', '81130-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35222, 'Ponta Grossa', 'Valentin Favarin', 'Jardim Carvalho', '84016-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35223, 'Curitiba', 'Valentin Guedes', 'Santa Felicidade', '82015-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35224, 'Curitiba', 'Valentin Gulin', 'Atuba', '82630-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35225, 'Curitiba', 'Valentin Harkot', 'Campina do Siqueira', '80740-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35226, 'Curitiba', 'Valentin Klinczak', 'São Lourenço', '82210-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35227, 'Almirante Tamandaré', 'Valentin Kokot', 'Jardim Naturama', '83505-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35228, 'Curitiba', 'Valentin Nichele', 'Pinheirinho', '81150-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35229, 'Curitiba', 'Valentin Pedro Zanon', 'Tatuquara', '81940-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35230, 'Colombo', 'Valentin Scrok', 'Jardim Itambé', '83403-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35231, 'Curitiba', 'Valentin Trevisan', 'Bom Retiro', '80520-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35232, 'Cascavel', 'Valentin Viechoski', '14 de Novembro', '85804-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35233, 'Curitiba', 'Valentina Bailo Geronasso', 'Boa Vista', '82560-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35234, 'Curitiba', 'Valentino Guzzo', 'Santa Felicidade', '82015-655', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35235, 'Colombo', 'Valenza', 'Centro Industrial Mauá', '83413-576', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35236, 'Maringá', 'Valeriana', 'Jardim Pinheiros', '87043-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35237, 'Curitiba', 'Valério Haisi', 'Santa Felicidade', '82020-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35238, 'Piraquara', 'Valério Kovalczuck', 'Vila Izabel', '83305-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35239, 'Toledo', 'Valério Lambare', 'Jardim Europa', '85908-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35240, 'Ponta Grossa', 'Valério Rouchi', 'Uvaranas', '84030-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35241, 'Colombo', 'Valfrido Cavalli', 'Uvarana', '83415-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35242, 'Maringá', 'Valladolid', 'Loteamento Madrid', '87053-536', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35243, 'Curitiba', 'Valmir Luiz Gubert', 'Cidade Industrial', '81460-168', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35244, 'Toledo', 'Valmir Zanetti', 'Conjunto Barão do Rio Branco II', '85905-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35245, 'Londrina', 'Valparaíso', 'Guanabara', '86050-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35246, 'Foz do Iguaçu', 'Valparaíso', 'Lago dos Cisnes', '85861-250', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35247, 'Maringá', 'Valparaíso', 'Vila Morangueira', '87040-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35248, 'Campo Mourão', 'Valparaíso', 'Jardim Pio XII', '87306-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35249, 'Curitiba', 'Valparaizo', 'Bacacheri', '82510-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35250, 'Curitiba', 'Valtemir Suhevits', 'Tatuquara', '81470-216', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35251, 'Londrina', 'Valter Athos Vanzo', 'Catuai', '86086-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35252, 'Londrina', 'Valter Fantini Pruner', 'Jardim Alemanha', '86031-025', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35253, 'Toledo', 'Valternei Ramos Zaleski', 'Conjunto Residencial Tocantins', '85903-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35254, 'Curitiba', 'Van Dick', 'Bacacheri', '82520-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35255, 'Curitiba', 'Van Gogh', 'Bacacheri', '82520-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35256, 'Umuarama', 'Van Gogh', 'Conjunto Residencial Ouro Preto', '87504-606', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35257, 'Curitiba', 'Vanaflores de Lima Kern', 'Umbará', '81930-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35258, 'Arapongas', 'Vanaquiá', 'Jardim Primavera', '86702-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35259, 'São José dos Pinhais', 'Vanda Muhlsted Barbosa', 'Guatupê', '83060-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35260, 'Londrina', 'Vanderlea Delalibera', 'Indusville', '86031-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35261, 'Campo Mourão', 'Vani Borges de Macedo', 'Jardim Cidade Nova', '87308-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35262, 'Colombo', 'Vanira Borato Poly', 'Capivari', '83415-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35263, 'Curitiba', 'Vansolino Granato', 'Pilarzinho', '82115-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35264, 'Londrina', 'Vantuil Frisselli', 'Jardim Primavera', '86086-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35265, 'Telêmaco Borba', 'Varginha', 'Fazenda Limeira', '84271-580', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35266, 'Ponta Grossa', 'Varnhagem', 'Boa Vista', '84070-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35267, 'Curitiba', 'Varnhagen', 'Uberaba', '81530-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35268, 'Colombo', 'Varsóvia', 'Vila Alto da Cruz', '83405-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35269, 'Guarapuava', 'Várzea Grande', 'Industrial', '85045-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35270, 'Londrina', 'Vasco Cinquini', 'Santos Dumont', '86039-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35271, 'Londrina', 'Vasco da Gama', 'Áurea', '86038-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35272, 'Londrina', 'Vasco da Gama', 'Aeroporto', '86036-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35273, 'Maringá', 'Vasco da Gama', 'Vila Marumby', '87005-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35274, 'Telêmaco Borba', 'Vasco da Gama', 'Nossa Senhora de Fátima', '84264-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35275, 'Toledo', 'Vasco da Gama', 'Jardim Paulista', '85910-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35276, 'Cascavel', 'Vasco da Gama', 'Pioneiros Catarinenses', '85805-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35277, 'Campo Mourão', 'Vassilio Boiko', 'Jardim Aeroporto', '87310-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35278, 'Foz do Iguaçu', 'Vassouras', 'Jardim Santa Rosa', '85869-220', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35279, 'Londrina', 'Vaticano', 'Jardim Adriana I', '86046-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35280, 'Guarapuava', 'Vaticano', 'Industrial', '85053-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35281, 'Umuarama', 'Vaticano', 'Parque Bonfim', '87507-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35282, 'Maringá', 'Vaz Caminha', 'Zona 02', '87010-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35283, 'Sarandi', 'Vaz Caminha', 'Novo Panorama', '87113-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35284, 'Sarandi', 'Vaz Caminha', 'Parque Pioneiros', '87114-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35285, 'Foz do Iguaçu', 'Veiga', 'Jardim Irmã', '85867-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35286, 'Curitiba', 'Velcy Bolívar Grando', 'Uberaba', '81560-615', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35287, 'Curitiba', 'Venâncio Alves Pereira', 'Pilarzinho', '82120-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35288, 'Londrina', 'Venâncio Bernardo da Silva', 'Vila Rodrigues', '86010-805', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35289, 'Pato Branco', 'Venâncio de Andrade', 'Bonatto', '85506-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35290, 'Castro', 'Venâncio Lopes', 'Jardim Social Primavera', '84174-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35291, 'Colombo', 'Venâncio Trevisan', 'Centro', '83414-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35292, 'Curitiba', 'Venâncio Trevisan Netto', 'Santa Felicidade', '82020-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35293, 'Foz do Iguaçu', 'Venceslau Braz', 'Parque Presidente', '85863-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35294, 'Pato Branco', 'Venceslau Braz', 'Jardim América', '85502-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35295, 'Curitiba', 'Veneto', 'Butiatuvinha', '82400-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35296, 'Londrina', 'Veneza', 'Parque Residencial João Piza', '86041-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35297, 'Francisco Beltrão', 'Veneza', 'Jardim Floresta', '85603-375', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35298, 'Foz do Iguaçu', 'Veneza', 'Jardim Norma', '85869-626', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35299, 'Maringá', 'Veneza', 'Jardim Novo Horizonte', '87010-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35300, 'Umuarama', 'Veneza', 'Jardim San Martim', '87508-118', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35301, 'Cambé', 'Veneza', 'Residencial Monte Castelo', '86186-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35302, 'Cascavel', 'Veneza', 'Cascavel Velho', '85818-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35303, 'Curitiba', 'Venezia', 'Santa Felicidade', '82030-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35304, 'Laranjeiras do Sul', 'Venezuela', 'Cristo Rei', '85304-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35305, 'Londrina', 'Venezuela', 'Vila Brasil', '86010-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35306, 'Guarapuava', 'Venezuela', 'Morro Alto', '85065-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35307, 'Foz do Iguaçu', 'Venezuela', 'Jardim América', '85864-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35308, 'Francisco Beltrão', 'Venezuela', 'Luther King', '85605-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35309, 'Paranaguá', 'Venezuela', 'Jardim América', '83209-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35310, 'Ponta Grossa', 'Venezuela', 'Oficinas', '84035-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35311, 'Maringá', 'Venezuela', 'Jardim Alvorada', '87033-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35312, 'Pato Branco', 'Venezuela', 'Jardim América', '85502-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35313, 'São José dos Pinhais', 'Venezuela', 'Cidade Jardim', '83035-180', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35314, 'Umuarama', 'Venezuela', 'Jardim Campo Belo', '87507-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35315, 'Telêmaco Borba', 'Venezuela', 'Socomim', '84266-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35316, 'Cascavel', 'Venezuela', 'Pacaembu', '85816-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35317, 'Colombo', 'Venezuela', 'Jardim Rio Verde', '83405-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35318, 'Apucarana', 'Venezuela', 'Jardim Diamantina', '86804-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35319, 'Curitiba', 'Venezuela', 'Bacacheri', '82510-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35320, 'Londrina', 'Venicio Arestrup Pimentel', 'Jamile Dequech', '86048-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35321, 'Londrina', 'Vênus', 'Sol', '86070-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35322, 'Foz do Iguaçu', 'Vênus', 'Parque Residencial Três Fronteiras', '85859-685', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35323, 'Maringá', 'Vênus', 'Jardim Universo', '87060-560', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35324, 'Ponta Grossa', 'Vênus', 'Uvaranas', '84031-625', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35325, 'Sarandi', 'Vênus', 'Jardim Universal', '87114-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35326, 'Apucarana', 'Vênus', 'Jardim Vale do Sol', '86803-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35327, 'Cascavel', 'Vênus', 'Universitário', '85819-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35328, 'Cambé', 'Vênus', 'Parque Maracanã', '86185-775', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35329, 'Curitiba', 'Vênus', 'Sítio Cercado', '81910-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35330, 'Cascavel', 'Vera Cruz', 'Periolo', '85818-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35331, 'Campo Mourão', 'Vera Cruz', 'Jardim Pio XII', '87306-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35332, 'Guarapuava', 'Vera Haugge Neves', 'São Cristóvão', '85063-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35333, 'Almirante Tamandaré', 'Vera Lúcia Carvalho', 'Jardim Novo Horizonte da Cachoeira', '83502-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35334, 'São José dos Pinhais', 'Vera Lúcia Gomes Duarte', 'Colônia Rio Grande', '83020-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35335, 'Londrina', 'Vera Lúcia Taborda', 'Residencial Abussafe', '86037-777', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35336, 'Curitiba', 'Vera Lúcia Vieira Bartenick', 'Santa Cândida', '82720-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35337, 'Sarandi', 'Verão', 'Jardim Primaverão', '87111-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35338, 'Pato Branco', 'Veraqueta', 'Menino Deus', '85502-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35339, 'Sarandi', 'Verbo Divino', 'Parque Residencial Bom Pastor', '87114-529', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35340, 'Toledo', 'Verbo Divino', 'Jardim Santa Maria', '85903-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35341, 'Maringá', 'Verde', 'Parque Industrial Bandeirantes', '87070-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35342, 'Cascavel', 'Verde', 'Brasília', '85815-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35343, 'Arapongas', 'Verdelha', 'Vila Rugna', '86705-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35344, 'Arapongas', 'Verdelhão', 'Vila Araponguinha', '86705-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35345, 'Curitiba', 'Verdi', 'São Braz', '82300-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35346, 'Francisco Beltrão', 'Vere', 'Sadia', '85606-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35347, 'Curitiba', 'Vereador Adeodato Volpi', 'Capão Raso', '81110-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35348, 'Laranjeiras do Sul', 'Vereador Alberto Benvenutti', 'Cristo Rei', '85304-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35349, 'Pato Branco', 'Vereador Alberto Geron', 'Bortot', '85501-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35350, 'Apucarana', 'Vereador Albino Mareze', 'Recanto Estoril', '86813-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35351, 'Laranjeiras do Sul', 'Vereador Alfredo Badoti', 'Cristo Rei', '85304-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35352, 'São José dos Pinhais', 'Vereador Altivir Stoco', 'São Sebastião', '83075-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35353, 'Londrina', 'Vereador Amélio Viecelli', 'Eldorado', '86040-170', 'Ponte', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35354, 'Curitiba', 'Vereador Ângelo Burbello', 'Umbará', '81940-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35355, 'Curitiba', 'Vereador Antenor Pamphilo dos Santos', 'Vista Alegre', '80820-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35356, 'Curitiba', 'Vereador Antônio Carnasciali', 'Boqueirão', '81670-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35357, 'Foz do Iguaçu', 'Vereador Antônio Carvalho', 'Loteamento Paraguaçu', '85865-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35358, 'Almirante Tamandaré', 'Vereador Antônio Dalazuana', 'Parque Timbu', '83514-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35359, 'Telêmaco Borba', 'Vereador Antônio Dalécio', 'Centro', '84261-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35360, 'Curitiba', 'Vereador Antônio dos Reis Cavalheiro', 'Cabral', '80035-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35361, 'Curitiba', 'Vereador Antônio Giacomassi', 'Alto Boqueirão', '81770-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35362, 'Laranjeiras do Sul', 'Vereador Antônio R. Oliveira', 'São Francisco', '85303-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35363, 'Pinhais', 'Vereador Antônio Romeu Simoni', 'Prive Bois de Boulogne', '83330-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35364, 'Campo Largo', 'Vereador Arlindo Chemin', 'Centro', '83601-070', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35365, 'Maringá', 'Vereador Arlindo de Souza', 'Jardim Monte Carlo', '87080-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35366, 'Maringá', 'Vereador Arlindo Planas', 'Zona 06', '87080-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35367, 'Campo Mourão', 'Vereador Augusto M. dos Santos', 'Jardim Nossa Senhora Aparecida', '87309-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35368, 'Curitiba', 'Vereador Augusto Staben', 'Bacacheri', '82515-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35369, 'Curitiba', 'Vereador Aurelino Mader Gonçalves', 'Xaxim', '81830-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35370, 'Maringá', 'Vereador Ayres Aniceto de Andrade', 'Conjunto Habitacional Sanenge III', '87055-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35371, 'Laranjeiras do Sul', 'Vereador Bacilides André Fae', 'Cristo Rei', '85304-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35372, 'Maringá', 'Vereador Basílio Sautchuk', 'Zona 01', '87013-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35373, 'Pato Branco', 'Vereador Cacique Ângelo Creta', 'Jardim América', '85501-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35374, 'Maringá', 'Vereador Carlos Alberto Paula', 'Conjunto Habitacional Requião', '87047-406', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35375, 'Campo Mourão', 'Vereador Carlos Stalman', 'Jardim Bandeirantes', '87308-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35376, 'Paranaguá', 'Vereador Chafic Farah', 'Vila Paranaguá', '83221-048', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35377, 'Curitiba', 'Vereador Constante Pinto', 'Bacacheri', '82510-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35378, 'Apucarana', 'Vereador Cornélio B. Farias', 'Jardim Paraíso', '86807-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35379, 'Laranjeiras do Sul', 'Vereador Cyro Pellizari', 'Cristo Rei', '85304-245', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35380, 'Guarapuava', 'Vereador Darci Penteado', 'Boqueirão', '85015-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35381, 'Maringá', 'Vereador David Rabello de Oliveira', 'Jardim Seminário', '87080-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35382, 'Curitiba', 'Vereador Dilo de Oliveira Godoy', 'Butiatuvinha', '82400-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35383, 'Curitiba', 'Vereador Dino Gasparin', 'Vila Izabel', '80320-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35384, 'Curitiba', 'Vereador Dorgelo Antônio Biazzeto', 'Ahú', '80540-070', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35385, 'Ponta Grossa', 'Vereador Dorival de Arruda Moura', 'Uvaranas', '84030-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35386, 'Curitiba', 'Vereador Douglas Godoy', 'Uberaba', '81590-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35387, 'Curitiba', 'Vereador Edward de Menezes Caldas', 'Bacacheri', '82520-810', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35388, 'Curitiba', 'Vereador Elias Karam', 'Fazendinha', '81330-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35389, 'Cascavel', 'Vereador Eliseu Shimidth', 'Nucleo de Produção III', '85811-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35390, 'Ponta Grossa', 'Vereador Engenheiro Ernâni Batista Rosas', 'Jardim Carvalho', '84015-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35391, 'Foz do Iguaçu', 'Vereador Estevan Charon', 'Jardim São Rafael II', '85858-636', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35392, 'Foz do Iguaçu', 'Vereador Eugênio Robert', 'Vila Portes', '85865-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35393, 'Maringá', 'Vereador Eurico Vieira Guido', 'Vila Marumby', '87005-230', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35394, 'Paranaguá', 'Vereador Felipe Antunes', 'Campo Grande', '83203-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35395, 'Laranjeiras do Sul', 'Vereador Félix Chrusciak', 'Cristo Rei', '85304-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35396, 'Toledo', 'Vereador Francisco Galdino de Lima', 'Conjunto Cohapar', '85910-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35397, 'Laranjeiras do Sul', 'Vereador Francisco Mieizva', 'Cristo Rei', '85304-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35398, 'Guarapuava', 'Vereador Francisco Morozini', 'São Cristóvão', '85063-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35399, 'Guarapuava', 'Vereador Frontino Lima', 'Industrial', '85053-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35400, 'Paranavaí', 'Vereador Fued Abdalla Tapxure', 'Jardim São Jorge', '87710-200', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35401, 'Curitiba', 'Vereador Garcia Rodrigues Velho', 'Cabral', '80035-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35402, 'Guarapuava', 'Vereador Generoso F. da Costa', 'Cascavel', '85025-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35403, 'Campo Mourão', 'Vereador Geremias Cilião de Araújo', 'Jardim Francisco Ferreira Albuquerque', '87309-086', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35404, 'Laranjeiras do Sul', 'Vereador Geremias Zaleski', 'Cristo Rei', '85304-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35405, 'Laranjeiras do Sul', 'Vereador Gilio Macarini', 'Cristo Rei', '85304-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35406, 'Guarapuava', 'Vereador Hailton Jaskulski', 'Vila Bela', '85025-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35407, 'Laranjeiras do Sul', 'Vereador Heitor Safraider', 'Getúlio Vargas', '85304-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35408, 'Laranjeiras do Sul', 'Vereador Hildebrando Nunes', 'Cristo Rei', '85304-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35409, 'Cascavel', 'Vereador Horalino Bilibiu', 'Região do Lago 2', '85816-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35410, 'Telêmaco Borba', 'Vereador Hugo Adamowski', 'Centro', '84261-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35411, 'Foz do Iguaçu', 'Vereador Jacinto Palacin', 'Jardim Tropical', '85855-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35412, 'Ponta Grossa', 'Vereador João Abrahão Maia', 'Uvaranas', '84026-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35413, 'Campo Largo', 'Vereador João Augusto de Almeida Barbosa', 'Vila Otto', '83607-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35414, 'Maringá', 'Vereador João Batista Sanches', 'Distrito Industrial 2', '87065-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35415, 'Apucarana', 'Vereador João Bertoli', 'Jardim Tibagi', '86813-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35416, 'Almirante Tamandaré', 'Vereador João Chevonica', 'Jardim Maria Luiza', '83514-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35417, 'Laranjeiras do Sul', 'Vereador João Chrusciak', 'Cristo Rei', '85304-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35418, 'Laranjeiras do Sul', 'Vereador João da Costa Cristo', 'Cristo Rei', '85304-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35419, 'Laranjeiras do Sul', 'Vereador João Rocha Loures', 'Centro', '85301-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35420, 'Laranjeiras do Sul', 'Vereador João Rodrigues da Silva', 'Cristo Rei', '85304-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35421, 'Campo Largo', 'Vereador João Vieira Tigrinho', 'Vila Bancária', '83601-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35422, 'Maringá', 'Vereador Joaquim Pereira de Castro', 'Vila Santo Antônio', '87030-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35423, 'Curitiba', 'Vereador Jobar Cassou', 'Santa Felicidade', '82020-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35424, 'Guarapuava', 'Vereador Joel Vicentin', 'Primavera', '85050-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35425, 'Apucarana', 'Vereador Jorge Amin Maia', 'Jardim Paraíso', '86807-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35426, 'Laranjeiras do Sul', 'Vereador Jorge Pio Gonçalves', 'Cristo Rei', '85304-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35427, 'Paranaguá', 'Vereador Jorge Vasilakis', 'Tuiuti', '83203-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35428, 'Pato Branco', 'Vereador José Antônio da Silva', 'Morro da Cruz', '85505-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35429, 'Laranjeiras do Sul', 'Vereador José Ayres de Oliveira', 'Centro', '85301-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35430, 'Cascavel', 'Vereador José de Oliveira', 'Brasília', '85815-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35431, 'Sarandi', 'Vereador José Fernandes', 'Jardim Panorama', '87113-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35432, 'Apucarana', 'Vereador José Humeniuk', 'Vila Marigilda', '86800-085', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35433, 'Ponta Grossa', 'Vereador José Luiz de Souza Netto', 'Colônia Dona Luiza', '84046-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35434, 'Telêmaco Borba', 'Vereador José Ozorio de Camargo', 'Socomim', '84266-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35435, 'Toledo', 'Vereador José Pedro Brum', 'Conjunto Cohapar', '85910-105', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35436, 'Apucarana', 'Vereador José Ribeiro de Souza', 'Jardim Tarobá', '86813-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35437, 'Laranjeiras do Sul', 'Vereador José Vieira', 'Getúlio Vargas', '85304-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35438, 'Curitiba', 'Vereador Jurandir de Azevedo e Silva', 'Barreirinha', '82700-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35439, 'Almirante Tamandaré', 'Vereador Lauro Batista de Siqueira', 'Jardim São José', '83501-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35440, 'Apucarana', 'Vereador Lázaro P. Rodrigues', 'Recanto Estoril', '86813-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35441, 'Laranjeiras do Sul', 'Vereador Leopoldo Marochi', 'Cristo Rei', '85304-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35442, 'Laranjeiras do Sul', 'Vereador Leopoldo Pietroski', 'Cristo Rei', '85304-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35443, 'Londrina', 'Vereador Liminski', 'Casa do Trabalhador', '86026-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35444, 'Telêmaco Borba', 'Vereador Luiz Loiola', 'Jardim Bom Jesus', '84262-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35445, 'Cascavel', 'Vereador Luiz Picoli', 'Centro', '85810-235', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35446, 'Maringá', 'Vereador Malaquias de Abreu', 'Zona 02', '87010-535', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35447, 'Londrina', 'Vereador Manoel de Oliveira Branco', 'Rica', '86025-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35448, 'Apucarana', 'Vereador Manoel O. Proença', 'Recanto Estoril', '86813-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35449, 'Ponta Grossa', 'Vereador Marcos Tozetto', 'Contorno', '84062-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35450, 'Paranaguá', 'Vereador Mário Macaggi', 'Correia Velho', '83206-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35451, 'Apucarana', 'Vereador Menotti Bolinelli', 'Recanto Estoril', '86813-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35452, 'Curitiba', 'Vereador Miguel Aicar de Suss', 'Pinheirinho', '81150-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35453, 'Colombo', 'Vereador Miguel Costacurta', 'Jardim Bandeirantes', '83408-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35454, 'Foz do Iguaçu', 'Vereador Moacir Pereira', 'Vila Yolanda', '85853-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35455, 'São José dos Pinhais', 'Vereador Narciso Mendes', 'Cidade Jardim', '83035-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35456, 'Maringá', 'Vereador Nelson Abrão', 'Zona 05', '87015-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35457, 'Curitiba', 'Vereador Nicolau Lange', 'Tarumã', '82820-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35458, 'Guarapuava', 'Vereador Olinto Rosa Pimentel', 'São Cristóvão', '85060-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35459, 'Laranjeiras do Sul', 'Vereador Onofrio Babinski', 'Centro', '85301-270', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35460, 'Pato Branco', 'Vereador Orestes Pagliosa', 'Industrial', '85506-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35461, 'Guarapuava', 'Vereador Orlando Casagrande', 'São Cristóvão', '85063-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35462, 'Piraquara', 'Vereador Orlando Santander Francisco', 'Vila Ipanema', '83301-048', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35463, 'Almirante Tamandaré', 'Vereador Osvaldo Trevisan', 'Planta Maria Clara', '83513-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35464, 'Curitiba', 'Vereador Oswaldo Nascimento Bittencourt', 'Xaxim', '81710-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35465, 'Maringá', 'Vereador Oswaldo Vieira', 'Zona 07', '87030-220', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35466, 'Laranjeiras do Sul', 'Vereador Otávio Folda', 'Cristo Rei', '85304-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35467, 'Francisco Beltrão', 'Vereador Paulo Borguezan', 'Pinheirinho', '85603-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35468, 'Laranjeiras do Sul', 'Vereador Paulo Palinski', 'Cristo Rei', '85304-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35469, 'Laranjeiras do Sul', 'Vereador Pedro Guimarães Cordeiro', 'Cristo Rei', '85304-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35470, 'Laranjeiras do Sul', 'Vereador Pedro Piaceski', 'Cristo Rei', '85304-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35471, 'Colombo', 'Vereador Pio José Broto', 'Sapopema', '83414-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35472, 'Maringá', 'Vereador Primo Monteschio', 'Zona 02', '87005-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35473, 'Londrina', 'Vereador Rafael Lamastra', 'Barbeta', '86078-520', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35474, 'Ponta Grossa', 'Vereador Raul Beraldi', 'Orfãs', '84015-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35475, 'Apucarana', 'Vereador Romeu Beligni', 'Recanto Estoril', '86813-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35476, 'Francisco Beltrão', 'Vereador Romeu Lauro Werlang', 'Centro', '85601-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35477, 'Guarapuava', 'Vereador Rubem Siqueira Ribas', 'Santa Cruz', '85015-080', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35478, 'Curitiba', 'Vereador Salim Chede', 'São Lourenço', '82210-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35479, 'Paranaguá', 'Vereador Salim Jorge Chede', 'João Gualberto', '83203-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35480, 'Pato Branco', 'Vereador Santos Vigano', 'Menino Deus', '85502-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35481, 'Laranjeiras do Sul', 'Vereador Sebastião Dambroski', 'Cristo Rei', '85304-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35482, 'Guarapuava', 'Vereador Sebastião de C. Ribas', 'Industrial', '85045-796', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35483, 'Guarapuava', 'Vereador Serafim Ribas', 'Boqueirão', '85022-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35484, 'Guarapuava', 'Vereador Serafim Ribas', 'Boqueirão', '85023-500', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35485, 'Laranjeiras do Sul', 'Vereador Silvindo A. Perachi', 'Cristo Rei', '85304-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35486, 'Laranjeiras do Sul', 'Vereador Thadeu Folda', 'Cristo Rei', '85304-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35487, 'Curitiba', 'Vereador Toaldo Túlio', 'Santa Felicidade', '82320-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35488, 'Curitiba', 'Vereador Toaldo Túlio', 'São Braz', '82300-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35489, 'Laranjeiras do Sul', 'Vereador Ulisses Rodrigues da Costa', 'Cristo Rei', '85304-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35490, 'Almirante Tamandaré', 'Vereador Valdir Dalazuana', 'Jardim Casa Blanca', '83513-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35491, 'Campo Mourão', 'Vereador Valdomiro Cilião de Araújo', 'Jardim Gutierres', '87300-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35492, 'Araucária', 'Vereador Valentin Volski', 'Porto das Laranjeiras', '83703-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35493, 'Curitiba', 'Vereador Victório José Roda', 'Cidade Industrial', '81460-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35494, 'Almirante Tamandaré', 'Vereador Wadislau Bugalski', 'Botiatuba', '83511-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35495, 'Almirante Tamandaré', 'Vereador Wadislau Bugalski', 'Jardim Silvana', '83512-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35496, 'Almirante Tamandaré', 'Vereador Wadislau Bugalski', 'Jardim Marize', '83507-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35497, 'Laranjeiras do Sul', 'Vereador Waldemar Becker', 'Vila Industrial', '85303-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35498, 'Toledo', 'Vereador Waldomiro Franco de Souza', 'Conjunto Barão do Rio Branco II', '85915-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35499, 'Curitiba', 'Vereador Washington Mansur', 'Ahú', '82200-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35500, 'Curitiba', 'Vereador Washington Mansur', 'Ahú', '80540-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35501, 'Curitiba', 'Vereador Yrlan Cavet', 'Alto Boqueirão', '81720-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35502, 'Apucarana', 'Vereadora Ana M. de A. Oliveira Kuke', 'Jardim Cidade Alta', '86803-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35503, 'Curitiba', 'Vereadora Laís Peretti', 'Tatuquara', '81480-305', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35504, 'Londrina', 'Vergília Abreu Fernandes', 'Roseira', '86041-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35505, 'Campo Mourão', 'Vergílio Alves de Oliveira', 'Jardim Paulista II', '87310-425', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35506, 'Araucária', 'Vergílio Alves Pinto', 'Fazenda Velha', '83703-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35507, 'Araucária', 'Vergílio Cantele', 'Barigui', '83707-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35508, 'Curitiba', 'Vergílio Carneiro Martins', 'Pilarzinho', '82120-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35509, 'Campo Largo', 'Vergílio Castagnoli', 'Vila Elizabeth', '83607-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35510, 'Toledo', 'Vergílio Comerlatto', 'Jardim Concórdia', '85906-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35511, 'Toledo', 'Vergílio Diel', 'Jardim Concórdia', '85906-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35512, 'Londrina', 'Vergílio Perin', 'Aquilles Sthengel', '86086-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35513, 'Cambé', 'Vergílio Sgobero', 'Gleba Patrimônio Cambé', '86192-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35514, 'Curitiba', 'Vergínia Bressan', 'Vista Alegre', '80810-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35515, 'Piraquara', 'Vergínio Batista de Souza', 'Planta Guarituba Pequena', '83310-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35516, 'Campo Largo', 'Vergínio Camillo', 'Jardim das Acácias', '83603-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35517, 'Piraquara', 'Verginio Senter', 'Vila Ipanema', '83301-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35518, 'Curitiba', 'Vergy Caggiano', 'Cidade Industrial', '81310-406', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35519, 'Curitiba', 'Veriano Pereira', 'Alto Boqueirão', '81860-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35520, 'Toledo', 'Verilio Nazzari', 'Jardim Alta Floresta', '85905-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35521, 'Curitiba', 'Veríssimo Becker Cordeiro', 'Sítio Cercado', '81925-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35522, 'São José dos Pinhais', 'Veríssimo Marques', 'Centro', '83005-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35523, 'Pato Branco', 'Veríssimo Rizzi', 'Fraron', '85503-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35524, 'Cascavel', 'Vermelha', 'Brasília', '85815-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35525, 'Londrina', 'Verona', 'Parque Residencial João Piza', '86041-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35526, 'Francisco Beltrão', 'Verona', 'Jardim Floresta', '85603-376', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35527, 'Cambé', 'Verona', 'Residencial Monte Castelo', '86186-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35528, 'Colombo', 'Verona', 'Walfrido do Rosário', '83413-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35529, 'Curitiba', 'Verona', 'Cascatinha', '82020-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35530, 'Londrina', 'Verônica', 'Ouro Branco', '86042-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35531, 'Maringá', 'Verônica', 'Jardim Verônica', '87060-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35532, 'Curitiba', 'Verônica Mickosz Bodzinski', 'Taboão', '82130-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35533, 'Francisco Beltrão', 'Verônica Opolski', 'Pinheirinho', '85606-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35534, 'Curitiba', 'Verônica Szeremeta', 'São Braz', '82320-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35535, 'Curitiba', 'Verônica Tribek Moro', 'Cidade Industrial', '81230-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35536, 'Curitiba', 'Vespasiano Carneiro de Mello', 'Santa Felicidade', '82300-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35537, 'Curitiba', 'Vespasiano Gomes Martins', 'Taboão', '82130-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35538, 'Ponta Grossa', 'Vespasiano Madureira', 'Orfãs', '84015-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35539, 'Londrina', 'Vespertino Ferreira Pimpão', 'Santa Rita 3', '86072-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35540, 'Curitiba', 'Vespertino Ferreira Pimpão', 'Barreirinha', '82710-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35541, 'Cascavel', 'Véu de Noiva', 'Cataratas', '85818-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35542, 'Curitiba', 'Via Del Molino', 'Vista Alegre', '80820-415', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35543, 'Campo Mourão', 'Via do Trabalhador', 'Parque Industrial I', '87306-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35544, 'Curitiba', 'Via Firenze', 'Vista Alegre', '80820-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35545, 'São José dos Pinhais', 'Via Fornecedores', 'Roseira', '83070-147', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35546, 'Londrina', 'Via Láctea', 'Sol', '86070-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35547, 'Telêmaco Borba', 'Via Láctea', 'Fazenda Limeira', '84270-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35548, 'Sarandi', 'Via Láctea', 'Jardim Universal', '87114-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35549, 'Curitiba', 'Via Veneto', 'Santa Felicidade', '82020-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35550, 'Curitiba', 'Via Veneto', 'Santa Felicidade', '82400-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35551, 'Campo Largo', 'Via Veneza', 'Jardim Padre José de Anchieta', '83607-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35552, 'Curitiba', 'Via Vicenza', 'Vista Alegre', '82100-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35553, 'Foz do Iguaçu', 'Viamão', 'Jardim Nacional', '85862-220', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35554, 'Cascavel', 'Viamão', 'Canadá', '85813-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35555, 'Colombo', 'Viana do Castelo', 'Parque Residencial Santa Terezinha', '83408-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35556, 'Pinhais', 'Viana Moog', 'Núcleo Colonial de Pinhais', '83321-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35557, 'Londrina', 'Vianna de Carvalho', 'Conjunto Residencial Vale do Arvoredo', '86047-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35558, 'Foz do Iguaçu', 'Vice-Cônsul Eduardo Ramon Bianchi', 'Centro', '85851-270', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35559, 'Curitiba', 'Vicente Albertino Marchalek', 'Cidade Industrial', '81250-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35560, 'Curitiba', 'Vicente Alves Padilha', 'Umbará', '81930-545', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35561, 'Curitiba', 'Vicente Antônio de Oliveira', 'Barreirinha', '82650-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35562, 'São José dos Pinhais', 'Vicente Augusto', 'Miringuava', '83090-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35563, 'Ponta Grossa', 'Vicente Barbur', 'Boa Vista', '84071-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35564, 'Colombo', 'Vicente Betinardi', 'Roseira', '83415-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35565, 'Araucária', 'Vicente Calderari', 'Thomaz Coelho', '83707-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35566, 'Colombo', 'Vicente Canestraro', 'Jardim Paraná', '83412-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35567, 'Apucarana', 'Vicente Canezin', 'Núcleo Habitacional Djalma Mendes de Oliveira', '86806-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35568, 'Cambé', 'Vicente Carnelossi', 'Parque Residencial Ana Rosa', '86183-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35569, 'Toledo', 'Vicente Carvalho', 'Jardim Paulista', '85909-416', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35570, 'Londrina', 'Vicente Celestino', 'Ideal', '86027-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35571, 'Foz do Iguaçu', 'Vicente Celestino', 'Jardim Guarapuava I', '85853-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35660, 'São José dos Pinhais', 'Vicente Tozo', 'Afonso Pena', '83065-485', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35572, 'Maringá', 'Vicente Celestino', 'Conjunto Residencial Cidade Alta', '87053-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35573, 'Apucarana', 'Vicente Celestino', 'Núcleo Habitacional Castelo Branco', '86812-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35574, 'Curitiba', 'Vicente Celestino', 'Fazendinha', '81330-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35575, 'Curitiba', 'Vicente Ciccarino', 'Boa Vista', '82540-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35576, 'Curitiba', 'Vicente Ciccarino', 'Boa Vista', '82560-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35577, 'Londrina', 'Vicente Cioffi', 'Armindo Guazzi', '86037-370', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35578, 'Curitiba', 'Vicente Coradi', 'Capão da Imbuia', '82810-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35579, 'Curitiba', 'Vicente Costa', 'Alto Boqueirão', '81720-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35580, 'Cambé', 'Vicente Damião', 'Parque Residencial Ana Rosa', '86183-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35581, 'Pinhais', 'Vicente d''Andrea', 'Vila Tarumã', '83323-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35582, 'Curitiba', 'Vicente das Neves', 'Cajuru', '82950-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35583, 'Foz do Iguaçu', 'Vicente de Carvalho', 'Jardim Jupira', '85865-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35584, 'Londrina', 'Vicente de Carvalho', 'Jardim Bandeirantes', '86061-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35585, 'Ponta Grossa', 'Vicente de Carvalho', 'Chapada', '84064-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35586, 'Maringá', 'Vicente de Carvalho', 'Zona 05', '87015-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35587, 'Curitiba', 'Vicente de Carvalho', 'Cajuru', '82940-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35588, 'Pato Branco', 'Vicente de Col', 'Pagnoncelli', '85509-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35589, 'Pato Branco', 'Vicente de Col', 'Vila Esperança', '85503-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35590, 'Curitiba', 'Vicente de Cristo', 'Uberaba', '81590-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35591, 'Curitiba', 'Vicente Dionysio', 'Sítio Cercado', '81925-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35592, 'Almirante Tamandaré', 'Vicente Domakoski', 'Jardim Dona Belizaria', '83513-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35593, 'Campo Mourão', 'Vicente Domanski', 'Jardim Santa Cruz', '87309-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35594, 'Curitiba', 'Vicente dos Santos', 'Umbará', '81930-546', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35595, 'Campo Largo', 'Vicente Druziki', 'Conjunto Águas Claras', '83602-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35596, 'Apucarana', 'Vicente Edgard Caccuri', 'Loteamento Sanches dos Santos', '86806-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35597, 'Pato Branco', 'Vicente Eliseu Ampessam', 'Amadori', '85502-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35598, 'Londrina', 'Vicente Escobar Franco', 'Portal de Versalhes 3', '86055-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35599, 'Londrina', 'Vicente Fachinelli', 'Aquilles Sthengel', '86086-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35600, 'Londrina', 'Vicente Feijó', 'Progresso', '86079-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35601, 'Foz do Iguaçu', 'Vicente Feola', 'Parque Morumbi I', '85858-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35602, 'Londrina', 'Vicente Feola', 'Oriente', '86027-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35603, 'Umuarama', 'Vicente Ferraz de Campos', 'Parque Industrial I', '87507-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35604, 'Castro', 'Vicente Fiorillo', 'Castroville', '84178-330', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35605, 'Curitiba', 'Vicente Geronasso', 'Boa Vista', '82560-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35606, 'Curitiba', 'Vicente Geronasso', 'Boa Vista', '82650-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35607, 'Londrina', 'Vicente Gonsales', 'Residencial Quadra Norte', '86087-566', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35608, 'Colombo', 'Vicente Gorski', 'Planta Santa Úrsula', '83405-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35609, 'Curitiba', 'Vicente Greboge', 'Boqueirão', '81730-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35610, 'Guarapuava', 'Vicente José Ferreira', 'Vila Jordão', '85015-646', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35611, 'Curitiba', 'Vicente José Palazzo', 'Santa Cândida', '82640-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35612, 'Ponta Grossa', 'Vicente Kapp', 'Contorno', '84060-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35613, 'Colombo', 'Vicente Knaut', 'Jardim Eldorado', '83402-758', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35614, 'Curitiba', 'Vicente Laginestra', 'Bacacheri', '82600-565', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35615, 'Londrina', 'Vicente Leporace', 'San Remo', '86062-425', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35616, 'Laranjeiras do Sul', 'Vicente Lourenço Ruths', 'São Francisco', '85303-780', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35617, 'Colombo', 'Vicente Luiz Lemes Filho', 'Jardim Eldorado', '83402-759', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35618, 'Guarapuava', 'Vicente Machado', 'Dos Estados', '85035-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35619, 'Guarapuava', 'Vicente Machado', 'Centro', '85010-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35620, 'Guarapuava', 'Vicente Machado', 'Trianon', '85012-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35621, 'Pato Branco', 'Vicente Machado', 'Menino Deus', '85502-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35622, 'Telêmaco Borba', 'Vicente Machado', 'Centro', '84261-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35623, 'Cascavel', 'Vicente Machado', 'Canadá', '85813-251', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35624, 'Cascavel', 'Vicente Machado', 'Centro', '85812-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35625, 'Cascavel', 'Vicente Machado', 'Região do Lago 1', '85812-151', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35626, 'Cascavel', 'Vicente Machado', 'Country', '85813-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35627, 'Curitiba', 'Vicente Machado', 'Batel', '80420-011', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35628, 'Curitiba', 'Vicente Machado', 'Batel', '80440-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35629, 'Curitiba', 'Vicente Machado', 'Centro', '80420-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35630, 'Colombo', 'Vicente Machioski', 'Jardim Santa Cândida', '83402-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35631, 'Colombo', 'Vicente Manika', 'Jardim Esplanada', '83402-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35632, 'Curitiba', 'Vicente Marcos Brusamolin', 'Cascatinha', '82020-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35633, 'Guarapuava', 'Vicente Mário Amorim', 'Conradinho', '85055-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35634, 'Almirante Tamandaré', 'Vicente Martins dos Santos', 'Jardim Campo Verde', '83502-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35635, 'Curitiba', 'Vicente Michelotto', 'Cidade Industrial', '81460-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35636, 'Curitiba', 'Vicente Montanha', 'Cajuru', '82900-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35637, 'Campo Largo', 'Vicente Nalepa', 'Vila Dom Pedro II', '83608-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35638, 'Curitiba', 'Vicente Negrello', 'Umbará', '81930-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35639, 'Curitiba', 'Vicente Nicolau Kopytowski', 'Xaxim', '81710-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35640, 'Colombo', 'Vicente Otto', 'Vila Santa Maria', '83402-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35641, 'Curitiba', 'Vicente Paulo Domakowski', 'Santo Inácio', '82010-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35642, 'Londrina', 'Vicente Pereira de Miranda', 'Milton Gavetti', '86078-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35643, 'Londrina', 'Vicente Pinzon', 'Novo Antares', '86036-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35644, 'Londrina', 'Vicente Poletti', 'Rui Barbosa', '86031-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35645, 'Curitiba', 'Vicente Pontarolla', 'Seminário', '80740-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35646, 'Londrina', 'Vicente Quessada Agea', 'Avelino A Vieira', '86056-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35647, 'Toledo', 'Vicente Roos', 'Coopagro', '85903-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35648, 'São José dos Pinhais', 'Vicente Rutelionis', 'Afonso Pena', '83050-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35649, 'Curitiba', 'Vicente Rutelionis', 'Cajuru', '82940-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35650, 'Apucarana', 'Vicente Sanches', 'Residencial Parque da Raposa', '86812-598', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35651, 'Campo Largo', 'Vicente Saqueto', 'Vila David Antônio', '83609-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35652, 'Colombo', 'Vicente Schena', 'Roseira', '83411-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35653, 'Maringá', 'Vicente Simino', 'Jardim Alvorada', '87035-410', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35654, 'Curitiba', 'Vicente Soluchinski', 'São Braz', '82320-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35655, 'Curitiba', 'Vicente Spisla', 'Santa Cândida', '82640-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35656, 'Ponta Grossa', 'Vicente Sposito', 'Uvaranas', '84031-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35657, 'Araucária', 'Vicente Strugala', 'Costeira', '83708-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35658, 'Araucária', 'Vicente Szczerbowski', 'Barigui', '83707-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35659, 'Londrina', 'Vicente Torres', 'Portal de Versalhes 3', '86055-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35661, 'São José dos Pinhais', 'Vicente Vahovicz', 'Ipê', '83055-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35662, 'Pato Branco', 'Vicente Vieira Ferreira', 'Cristo Rei', '85506-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35663, 'Campo Mourão', 'Vicente Zawadniaki', 'Jardim Aeroporto', '87310-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35664, 'Londrina', 'Vicenti Bocuti', 'Santa Rita 1', '86072-380', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35665, 'Maringá', 'Vicentina Batista de Oliveira Paiva', 'Conjunto Residencial Cidade Alta', '87053-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35666, 'Foz do Iguaçu', 'Vicentina Chevallier', 'Jardim Iguaçu', '85853-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35667, 'São José dos Pinhais', 'Vicentina dos Santos Sobral', 'Rio Pequeno', '83065-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35668, 'Curitiba', 'Vicenza', 'Santa Felicidade', '82020-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35669, 'Guarapuava', 'Vice-Prefeito Luís F. de Oliveira', 'Morro Alto', '85065-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35670, 'Telêmaco Borba', 'Vice-Prefeito Reginaldo Guedes Nocera', 'Centro', '84261-020', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35671, 'Foz do Iguaçu', 'Viçosa', 'Parque Residencial Três Fronteiras', '85855-605', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35672, 'Umuarama', 'Viçosa', 'Jardim América', '87502-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35673, 'Curitiba', 'Victalina Strapasson Hecke', 'Novo Mundo', '81050-687', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35674, 'Curitiba', 'Victalina Veiga', 'Tatuquara', '81470-277', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35675, 'Curitiba', 'Victo Pavim Johnsson', 'Hugo Lange', '80040-390', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35676, 'Curitiba', 'Victor Benato', 'Pilarzinho', '82120-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35677, 'Curitiba', 'Victor Burda', 'Mercês', '80710-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35678, 'Curitiba', 'Victor Camargo', 'Fazendinha', '81330-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35679, 'Ponta Grossa', 'Victor Contim', 'Colônia Dona Luiza', '84046-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35680, 'Londrina', 'Victor Cornélio', 'Cafezal 1', '86049-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35681, 'Campo Largo', 'Victor de Almeida Barbosa', 'Vila Elizabeth', '83607-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35682, 'Curitiba', 'Victor Ferreira do Amaral', 'Tarumã', '82800-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35683, 'Curitiba', 'Victor Ferreira do Amaral', 'Tarumã', '82810-350', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35684, 'Curitiba', 'Victor Ferreira do Amaral', 'Tarumã', '82530-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35685, 'Curitiba', 'Victor Gabardo', 'Umbará', '81940-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35686, 'Londrina', 'Victor Hugo', 'Eldorado', '86040-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35687, 'Toledo', 'Victor Hugo', 'Jardim Porto Alegre', '85906-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35688, 'Cascavel', 'Victor Hugo', 'Nova Cidade', '85803-046', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35689, 'Curitiba', 'Victor Hugo', 'Lindóia', '81010-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35690, 'Curitiba', 'Victor Kotovis', 'Abranches', '82220-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35691, 'Telêmaco Borba', 'Victor Lourenço de Oliveira', 'Macopa', '84263-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35692, 'Curitiba', 'Victor Luiz Maganhoto', 'Uberaba', '81590-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35693, 'Ponta Grossa', 'Victor Maluceli', 'Uvaranas', '84031-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35694, 'Ponta Grossa', 'Victor Meireles', 'Ronda', '84051-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35695, 'Cascavel', 'Victor Meireles', 'Country', '85813-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35696, 'Curitiba', 'Victor Meireles', 'Uberaba', '81580-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35697, 'Curitiba', 'Victor Modesto de Oliveira', 'Pinheirinho', '81870-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35698, 'Curitiba', 'Victor Neto Toschio', 'Cidade Industrial', '81460-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35699, 'Londrina', 'Victor Salvador', 'Jardim Imagawa', '86080-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35700, 'Colombo', 'Victor Tosin', 'Centro', '83414-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35701, 'Curitiba', 'Victor Vasco Garcia', 'Pinheirinho', '81820-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35702, 'Londrina', 'Victória Karam Abib', 'Londres', '86081-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35703, 'Curitiba', 'Victória Pilatti Gava', 'Pilarzinho', '82120-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35704, 'Toledo', 'Victoriano Garigoi', 'Conjunto Habitacional São Francisco', '85915-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35705, 'Piraquara', 'Victório Bevervanso', 'Vila Juliana', '83306-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35706, 'Curitiba', 'Victório Celli', 'Cajuru', '82980-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35707, 'Londrina', 'Victório Franciolli', 'Conjunto Habitacional Saltinho', '86042-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35708, 'Curitiba', 'Victório Gabardo', 'Pilarzinho', '82115-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35709, 'Curitiba', 'Victório Gasparin', 'Pilarzinho', '82110-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35710, 'Londrina', 'Victório Gavetti', 'Monte Carlo', '86040-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35711, 'Cambé', 'Victorio Gorla', 'Jardim Itália', '86192-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35712, 'Piraquara', 'Victório Luiz Zambao', 'Planta São Tiago', '83307-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35713, 'Londrina', 'Victório Magnani', 'Jardim Kase', '86026-325', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35714, 'Curitiba', 'Victório Malucelli', 'Hauer', '81630-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35715, 'Almirante Tamandaré', 'Victório Prosdócimo', 'Vila Prosdócimo', '83506-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35716, 'Londrina', 'Victório Ridão', 'Jardim Marízia II', '86079-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35717, 'Londrina', 'Victorio Sinegalia', 'Jardim dos Alpes III', '86045-595', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35718, 'Curitiba', 'Victório Viezzer', 'Vista Alegre', '80810-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35719, 'Curitiba', 'Victório Vizinoni', 'Capão da Imbuia', '82800-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35720, 'Londrina', 'Victório Zaggato', 'Conjunto Habitacional Saltinho', '86042-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35721, 'Londrina', 'Victorio Zanoni', 'Roseira', '86041-545', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35722, 'Francisco Beltrão', 'Vida Nova', 'Nossa Senhora Aparecida', '85601-817', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35723, 'Ponta Grossa', 'Vidal de Negreiros', 'Oficinas', '84040-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35724, 'Maringá', 'Vidal de Negreiros', 'Zona 03', '87050-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35725, 'Telêmaco Borba', 'Vidal de Negreiros', 'Centro', '84261-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35726, 'Curitiba', 'Vidal Henrique Mengue', 'Pinheirinho', '81880-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35727, 'Curitiba', 'Vidal Natividade da Silva', 'Cajuru', '82900-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35728, 'Piraquara', 'Vidal Ramos', 'Planta São Tiago', '83307-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35729, 'Paranaguá', 'Vidal Vanhoni', 'Vila dos Comerciários', '83215-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35730, 'Colombo', 'Vidal Zonta', 'Vila São Gabriel', '83406-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35731, 'Foz do Iguaçu', 'Videira', 'Jardim Aurora', '85862-207', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35732, 'Toledo', 'Videira', 'Jardim Panambi', '85904-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35733, 'São José dos Pinhais', 'Videira', 'São Sebastião', '83075-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35734, 'Cascavel', 'Videira', 'Universitário', '85819-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35735, 'Castro', 'Vieira', 'Jardim Bela Vista', '84165-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35736, 'Pato Branco', 'Vieira da Costa', 'Pinheirinho', '85506-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35737, 'Pato Branco', 'Vieira da Costa', 'Chaparral', '85507-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35738, 'Paranaguá', 'Vieira dos Santos', 'Centro Histórico', '83203-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35739, 'Curitiba', 'Vieira dos Santos', 'Centro Cívico', '80540-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35740, 'Ponta Grossa', 'Vieira Fazenda', 'Uvaranas', '84032-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35741, 'Curitiba', 'Vieira Fazenda', 'Portão', '80330-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35742, 'Foz do Iguaçu', 'Viena', 'Beverly Falls Park', '85858-230', 'Beco', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35743, 'Telêmaco Borba', 'Viena', 'Nossa Senhora do Perpétuo Socorro', '84265-070', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35744, 'Colombo', 'Viena', 'Planta Boros', '83413-360', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35745, 'Francisco Beltrão', 'Vietnã', 'Pinheirinho', '85606-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35746, 'Londrina', 'Vigilato José da Cunha', 'Jardim dos Alpes I', '86075-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35747, 'Maringá', 'Vila dos Remédios', 'Jardim Social', '87010-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35748, 'Curitiba', 'Vila Hauer', 'Hauer', '81610-200', 'Terminal', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35749, 'Telêmaco Borba', 'Vila Preta', 'Área 02', '84267-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35750, 'Colombo', 'Vila Real', 'Parque Residencial Santa Terezinha', '83408-620', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35751, 'Foz do Iguaçu', 'Vila Rica', 'Jardim Petropólis', '85868-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35752, 'Maringá', 'Vila Rica', 'Jardim Liberdade', '87047-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35753, 'Maringá', 'Vila Rica', 'Jardim Alvorada', '87025-390', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35754, 'Telêmaco Borba', 'Vila Rica', 'Centro', '84261-650', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35755, 'Campo Mourão', 'Vila Rica', 'Jardim Flórida', '87300-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35756, 'Curitiba', 'Vila Torres', 'Prado Velho', '80215-380', 'Conjunto', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35757, 'Foz do Iguaçu', 'Vila Velha', 'Conjunto C', '85870-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35758, 'Foz do Iguaçu', 'Vila Velha', 'Jardim Petropólis', '85868-265', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35759, 'Guarapuava', 'Vila Velha', 'Boqueirão', '85022-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35760, 'Telêmaco Borba', 'Vila Velha', 'Jardim Alegre', '84268-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35761, 'Cascavel', 'Vila Velha', 'Universitário', '85819-005', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35762, 'Curitiba', 'Vila Velha', 'Campo Comprido', '81230-180', 'Conjunto', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35764, 'Toledo', 'Vila-Lobos', 'Jardim Santa Maria', '85903-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35765, 'Almirante Tamandaré', 'Vila-Lobos', 'Planta Nossa Senhora do Pilar', '83508-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35766, 'Cascavel', 'Vilhena', 'São Cristóvão', '85816-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35767, 'Curitiba', 'Villa Lobos', 'Jardim Social', '82520-010', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35768, 'Guarapuava', 'Villafrança', 'Vila Bela', '85025-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35769, 'Paranaguá', 'Vilmar Gomes', 'Porto dos Padres', '83221-195', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35770, 'Paranaguá', 'Vilson Brito', 'Ponta do Caju', '83206-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35771, 'Pato Branco', 'Vilson Valdir Amadori', 'La Salle', '85505-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35772, 'Guarapuava', 'Vilson Vicentin Guimarães', 'Boqueirão', '85023-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35773, 'Londrina', 'Vime', 'Leonor', '86071-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35774, 'Foz do Iguaçu', 'Vinhedo', 'Jardim do Norte', '85854-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35775, 'Pato Branco', 'Vinícius Cadorin', 'Bancários', '85504-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35776, 'Almirante Tamandaré', 'Vinicius de Moraes', 'Vila Marta', '83508-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35777, 'Londrina', 'Vinícius de Moraes', 'Colúmbia', '86057-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35778, 'Francisco Beltrão', 'Vinícius de Moraes', 'Jardim Novo Mundo', '85602-768', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35779, 'Pinhais', 'Vinícius de Moraes', 'Planta Núcleo Colonial de Pinhais', '83321-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35780, 'Toledo', 'Vinícius de Moraes', 'Parque Residencial Pancera', '85902-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35781, 'Cascavel', 'Vinícius de Moraes', 'Brasília', '85815-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35782, 'Colombo', 'Vinícius de Moraes', 'Jardim das Perdizes', '83409-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35783, 'Foz do Iguaçu', 'Vinícius de Morais', 'Jardim Comercial das Bandeiras', '85864-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35784, 'Guarapuava', 'Vinícius de Morais', 'São Cristóvão', '85060-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35785, 'Maringá', 'Vinícius de Morais', 'Conjunto Habitacional Itatiaia', '87045-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35786, 'Pato Branco', 'Vinícius de Morais', 'Aeroporto', '85503-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35787, 'São José dos Pinhais', 'Vinícius de Morais', 'Colônia Rio Grande', '83025-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35788, 'Curitiba', 'Vinícius de Morais', 'Pilarzinho', '82115-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35789, 'Maringá', 'Vinícius de Morais II', 'Zona 36', '87045-585', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35790, 'Ponta Grossa', 'Vinte', 'Chapada', '84064-595', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35791, 'Ponta Grossa', 'Vinte', 'Jardim Carvalho', '84016-539', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35792, 'Ponta Grossa', 'Vinte', 'Uvaranas', '84022-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35793, 'Sarandi', 'Vinte', 'Jardim Nova Independência I', '87114-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35794, 'Almirante Tamandaré', 'Vinte', 'Loteamento Marinoni', '83508-586', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35795, 'Curitiba', 'Vinte de Janeiro', 'Bacacheri', '82515-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35796, 'Curitiba', 'Vinte de Julho', 'Bacacheri', '82515-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35797, 'Toledo', 'Vinte de Setembro', 'Centro', '85900-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35798, 'Ponta Grossa', 'Vinte e Cinco', 'Uvaranas', '84022-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35799, 'Ponta Grossa', 'Vinte e Cinco', 'Chapada', '84064-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35800, 'Sarandi', 'Vinte e Cinco', 'Jardim Nova Independência I', '87114-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35801, 'Curitiba', 'Vinte e Cinco de Abril', 'Pilarzinho', '82100-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35802, 'Pinhais', 'Vinte e Cinco de Agosto', 'Jardim Pinhais', '83323-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35803, 'Cascavel', 'Vinte e Cinco de Agosto', 'Centro', '85801-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35804, 'Curitiba', 'Vinte e Cinco de Agosto', 'Boqueirão', '81670-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35805, 'Londrina', 'Vinte e Cinco de Dezembro', 'Yara', '86027-090', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35806, 'Pinhais', 'Vinte e Cinco de Dezembro', 'Vila Tarumã', '83323-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35807, 'Umuarama', 'Vinte e Cinco de Dezembro', 'Conjunto Residencial Vinte e Oito de Outubro', '87509-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35808, 'Sarandi', 'Vinte e Cinco de Dezembro', 'Parque Industrial II', '87111-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35809, 'Cambé', 'Vinte e Cinco de Dezembro', 'Jardim União', '86185-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35810, 'Curitiba', 'Vinte e Cinco de Dezembro', 'Cidade Industrial', '81450-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35811, 'Umuarama', 'Vinte e Cinco de Janeiro', 'Conjunto Residencial Vinte e Oito de Outubro', '87509-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35812, 'Toledo', 'Vinte e Cinco de Julho', 'Boa Esperança', '85909-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35813, 'Umuarama', 'Vinte e Cinco de Julho', 'Conjunto Residencial Vinte e Oito de Outubro', '87509-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35814, 'Toledo', 'Vinte e Cinco de Julho', 'Jardim Toretta', '85901-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35815, 'Piraquara', 'Vinte e Cinco de Marco', 'Planta Guarituba Pequena', '83310-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35816, 'Ponta Grossa', 'Vinte e Dois', 'Boa Vista', '84073-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35817, 'Ponta Grossa', 'Vinte e Dois', 'Uvaranas', '84022-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35818, 'Ponta Grossa', 'Vinte e Dois', 'Chapada', '84064-597', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35819, 'Sarandi', 'Vinte e Dois', 'Jardim Nova Independência I', '87114-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35820, 'Toledo', 'Vinte e Dois', 'Boa Esperança', '85909-256', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35821, 'Pinhais', 'Vinte e Dois de Abril', 'Planta Estância Pinhais', '83323-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35822, 'Cambé', 'Vinte e Dois de Abril', 'Jardim União', '86185-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35823, 'Ponta Grossa', 'Vinte e Nove', 'Chapada', '84064-608', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35824, 'Ponta Grossa', 'Vinte e Nove', 'Uvaranas', '84022-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35825, 'Maringá', 'Vinte e Nove', 'Conjunto Habitacional Hermann Moraes Barros', '87023-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35826, 'Sarandi', 'Vinte e Nove', 'Jardim Nova Independência I', '87114-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35827, 'Maringá', 'Vinte e Nove de Dezembro', 'Jardim Alamar', '87014-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35828, 'Piraquara', 'Vinte e Nove de Janeiro', 'Vila Juliana', '83306-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35829, 'Paranaguá', 'Vinte e Nove de Julho', 'Centro Histórico', '83203-075', 'Ladeira', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35830, 'Curitiba', 'Vinte e Nove de Junho', 'Bacacheri', '82620-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35831, 'Curitiba', 'Vinte e Nove de Março', 'Mercês', '80430-090', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35832, 'Ponta Grossa', 'Vinte e Oito', 'Chapada', '84064-607', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35833, 'Maringá', 'Vinte e Oito', 'Copacabana Residencial', '87023-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35834, 'Ponta Grossa', 'Vinte e Oito', 'Uvaranas', '84022-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35835, 'Sarandi', 'Vinte e Oito', 'Jardim Nova Independência I', '87114-755', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35836, 'Apucarana', 'Vinte e Oito de Janeiro', 'Vila São Jorge', '86800-528', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35837, 'Maringá', 'Vinte e Oito de Junho', 'Jardim Tupinambá', '87040-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35838, 'Curitiba', 'Vinte e Oito de Outubro', 'Santa Felicidade', '82020-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35839, 'Ponta Grossa', 'Vinte e Quatro', 'Boa Vista', '84072-015', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35840, 'Ponta Grossa', 'Vinte e Quatro', 'Chapada', '84064-599', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35841, 'Ponta Grossa', 'Vinte e Quatro', 'Uvaranas', '84022-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35842, 'Sarandi', 'Vinte e Quatro', 'Jardim Nova Independência I', '87114-735', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35843, 'Pinhais', 'Vinte e Quatro de Maio', 'Jardim Pinhais', '83323-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35844, 'Ponta Grossa', 'Vinte e Quatro de Maio', 'Centro', '84010-770', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35845, 'Curitiba', 'Vinte e Quatro de Maio', 'Centro', '80230-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35846, 'Curitiba', 'Vinte e Quatro de Maio', 'Rebouças', '80220-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35847, 'Curitiba', 'Vinte e Quatro de Maio', 'Parolin', '80220-061', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35848, 'Foz do Iguaçu', 'Vinte e Quatro de Marco', 'Centro', '85852-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35849, 'Francisco Beltrão', 'Vinte e Seis', 'Seminário', '85605-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35850, 'Ponta Grossa', 'Vinte e Seis', 'Uvaranas', '84022-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35851, 'Ponta Grossa', 'Vinte e Seis', 'Chapada', '84064-605', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35852, 'Sarandi', 'Vinte e Seis', 'Jardim Nova Independência I', '87114-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35853, 'Umuarama', 'Vinte e Seis de Junho', 'Zona IV', '87504-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35854, 'Ponta Grossa', 'Vinte e Sete', 'Uvaranas', '84022-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35855, 'Ponta Grossa', 'Vinte e Sete', 'Chapada', '84064-606', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35856, 'Sarandi', 'Vinte e Sete', 'Jardim Nova Independência I', '87114-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35857, 'Campo Mourão', 'Vinte e Sete de Dezembro', 'Jardim Pio XII', '87306-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35858, 'Ponta Grossa', 'Vinte e Três', 'Uvaranas', '84030-535', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35859, 'Ponta Grossa', 'Vinte e Três', 'Chapada', '84064-598', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35860, 'Ponta Grossa', 'Vinte e Três', 'Uvaranas', '84022-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35861, 'Sarandi', 'Vinte e Três', 'Jardim Nova Independência I', '87114-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35862, 'Cascavel', 'Vinte e Três de Agosto', 'Presidente', '85818-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35863, 'Curitiba', 'Vinte e Três de Outubro', 'Bacacheri', '82515-170', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35864, 'Ponta Grossa', 'Vinte e Um', 'Uvaranas', '84022-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35865, 'Ponta Grossa', 'Vinte e Um', 'Chapada', '84064-596', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35866, 'Ponta Grossa', 'Vinte e Um', 'Uvaranas', '84030-655', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35867, 'Almirante Tamandaré', 'Vinte e Um', 'Loteamento Marinoni', '83508-587', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35868, 'Foz do Iguaçu', 'Vinte e Um de Abril', 'Jardim Ipanema', '85862-309', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35869, 'Londrina', 'Vinte e Um de Abril', 'Bancários', '86062-085', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35870, 'Paranavaí', 'Vinte e Um de Abril', 'Jardim André Luiz', '87708-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35871, 'Maringá', 'Vinte e Um de Abril', 'Zona 05', '87015-070', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35872, 'Pato Branco', 'Vinte e Um de Abril', 'Alvorada', '85508-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35873, 'Pinhais', 'Vinte e Um de Abril', 'Jardim Pinhais', '83323-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35874, 'Telêmaco Borba', 'Vinte e Um de Abril', 'Socomim', '84265-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35875, 'Toledo', 'Vinte e Um de Abril', 'Jardim Paulista', '85909-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35876, 'Umuarama', 'Vinte e Um de Abril', 'Jardim Colibri', '87506-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35877, 'Sarandi', 'Vinte e um de Abril', 'Parque Industrial IV', '87111-705', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35878, 'Cambé', 'Vinte e Um de Abril', 'Jardim União', '86185-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35879, 'Cascavel', 'Vinte e Um de Abril', 'Presidente', '85818-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35880, 'Castro', 'Vinte e Um de Abril', 'Vila Rio Branco', '84172-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35881, 'Curitiba', 'Vinte e Um de Abril', 'Alto da Rua XV', '80060-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35882, 'Guarapuava', 'Vinte e Um de Dezembro', 'Morro Alto', '85065-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35883, 'Curitiba', 'Vinte e Um de Junho', 'Capão da Imbuia', '82810-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35884, 'Telêmaco Borba', 'Vinte e Um de Março', 'Nossa Senhora do Perpétuo Socorro', '84265-500', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35885, 'Umuarama', 'Vinte e Um de Setembro', 'Conjunto Residencial Vinte e Oito de Outubro', '87509-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35886, 'Ponta Grossa', 'Violeta', 'Contorno', '84060-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35887, 'Apucarana', 'Violeta', 'Jardim das Flores I', '86810-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35888, 'Curitiba', 'Violeta Maranhão', 'Jardim das Américas', '81530-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35889, 'Cascavel', 'Viracopos', 'Santos Dumont', '85804-790', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35890, 'Arapongas', 'Vireo-verde', 'Parque Veneza', '86701-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35891, 'Curitiba', 'Virgílio', 'Barreirinha', '82700-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35892, 'Colombo', 'Virgílio Arcie', 'Capivari', '83415-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35893, 'Ponta Grossa', 'Virgílio Carneiro Gomes', 'Uvaranas', '84020-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35894, 'Campo Largo', 'Virgílio Costa Cruzara', 'Vila Torres I', '83609-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35895, 'Cascavel', 'Virgílio Formighieri', 'Ciro Nardi', '85802-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35896, 'Londrina', 'Virgílio Giacomini', 'Jardim dos Alpes III', '86045-575', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35897, 'Curitiba', 'Virgílio Gomes Pinheiro', 'Guabirotuba', '81520-320', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35898, 'Londrina', 'Virgílio Jorge', 'San Remo', '86062-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35899, 'Maringá', 'Virgílio José de Oliveira', 'Cidade Jardim', '87020-517', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35900, 'Maringá', 'Virgílio Manilia', 'Jardim Ouro Cola', '87070-170', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35901, 'Colombo', 'Virgílio Mezzomo', 'Jardim Palmares', '83412-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35902, 'Toledo', 'Virgílio Toretta', 'Centro', '85901-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35903, 'Apucarana', 'Virgílio Zanon', 'Loteamento Residencial Cazarin', '86802-418', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35904, 'Londrina', 'Virgínia', 'Kennedy', '86060-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35905, 'Maringá', 'Virgínia', 'Vila Morangueira', '87040-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35906, 'Curitiba', 'Virgínia da Silva Gomes', 'Alto Boqueirão', '81850-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35907, 'Curitiba', 'Virgínia Dalabona', 'Orleans', '82310-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35908, 'Toledo', 'Virgínia Deparis', 'Parque Residencial Pancera', '85902-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35909, 'Almirante Tamandaré', 'Virgínia N. Régis Machado', 'Jardim Novo Horizonte da Cachoeira', '83502-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35910, 'Londrina', 'Virginio Marchezini', 'Parigot de Souza 2', '86082-165', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35911, 'Curitiba', 'Viriato Corrêa', 'Fazendinha', '81330-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35912, 'Laranjeiras do Sul', 'Virmond', 'São Francisco', '85303-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35913, 'Curitiba', 'Virmond de Lima', 'Seminário', '80440-030', 'Largo', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35914, 'Curitiba', 'Visconde de Abaeté', 'Bairro Alto', '82820-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35915, 'Curitiba', 'Visconde de Abrantes', 'Jardim das Américas', '81540-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35916, 'Ponta Grossa', 'Visconde de Araguaia', 'Uvaranas', '84032-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35917, 'Ponta Grossa', 'Visconde de Baraúna', 'Jardim Carvalho', '84016-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35918, 'Piraquara', 'Visconde de Cairu', 'Jardim Bela Vista', '83301-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35919, 'Curitiba', 'Visconde de Cairu', 'Seminário', '80240-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35920, 'Curitiba', 'Visconde de Caravelas', 'Jardim das Américas', '81540-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35921, 'Londrina', 'Visconde de Guarapuava', 'Paulista', '86079-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35922, 'Guarapuava', 'Visconde de Guarapuava', 'Centro', '85010-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35923, 'Pato Branco', 'Visconde de Guarapuava', 'Pinheirinho', '85506-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35924, 'Paranavaí', 'Visconde de Guarapuava', 'Jardim Santos Dumont', '87706-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35925, 'Cascavel', 'Visconde de Guarapuava', 'Cancelli', '85811-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35926, 'Cascavel', 'Visconde de Guarapuava', 'Canadá', '85813-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35927, 'Cascavel', 'Visconde de Guarapuava', 'Centro', '85810-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35928, 'Cascavel', 'Visconde de Guarapuava', 'Centro', '85801-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35929, 'Cascavel', 'Visconde de Guarapuava', 'Vila Tolentino', '85802-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35930, 'Curitiba', 'Visconde de Guarapuava', 'Batel', '80240-010', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35931, 'Curitiba', 'Visconde de Guarapuava', 'Alto da Rua XV', '80050-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35932, 'Curitiba', 'Visconde de Guarapuava', 'Centro', '80060-060', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35933, 'Curitiba', 'Visconde de Guarapuava', 'Centro', '80010-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35934, 'Curitiba', 'Visconde de Guarapuava', 'Centro', '80250-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35935, 'Ponta Grossa', 'Visconde de Inhauma', 'Ronda', '84051-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35936, 'Ponta Grossa', 'Visconde de Inhomirim', 'Uvaranas', '84020-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35937, 'Ponta Grossa', 'Visconde de Irajá', 'Cará-cará', '84032-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35938, 'Ponta Grossa', 'Visconde de Itaboraí', 'Oficinas', '84036-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35939, 'Ponta Grossa', 'Visconde de Itaboraí', 'Nova Rússia', '84053-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35940, 'Ponta Grossa', 'Visconde de Jaguari', 'Boa Vista', '84073-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35941, 'Ponta Grossa', 'Visconde de Jaguary', 'Uvaranas', '84032-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35942, 'Ponta Grossa', 'Visconde de Jequetinhonha', 'Oficinas', '84036-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35943, 'Ponta Grossa', 'Visconde de Macaé', 'Nova Rússia', '84053-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35944, 'Curitiba', 'Visconde de Macaé', 'Uberaba', '81530-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35945, 'Londrina', 'Visconde de Mauá', 'Jardim Tatiani', '86070-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35946, 'Laranjeiras do Sul', 'Visconde de Mauá', 'Getúlio Vargas', '85304-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35947, 'Maringá', 'Visconde de Mauá', 'Jardim Alvorada', '87035-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35948, 'Ponta Grossa', 'Visconde de Mauá', 'Oficinas', '84040-290', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35949, 'Ponta Grossa', 'Visconde de Mauá', 'Oficinas', '84045-100', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35950, 'Ponta Grossa', 'Visconde de Mauá', 'Colônia Dona Luiza', '84043-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35951, 'Cambé', 'Visconde de Mauá', 'Parque Residencial Manela', '86185-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35952, 'Apucarana', 'Visconde de Mauá', 'Barra Funda', '86800-565', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35953, 'Almirante Tamandaré', 'Visconde de Mauá', 'Jardim São Carlos', '83507-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35954, 'Pato Branco', 'Visconde de Nacar', 'Jardim América', '85502-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35955, 'Maringá', 'Visconde de Nacar', 'Zona 04', '87014-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35956, 'Ponta Grossa', 'Visconde de Nacar', 'Centro', '84010-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35957, 'Paranaguá', 'Visconde de Nacar', 'Centro Histórico', '83203-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35958, 'Pato Branco', 'Visconde de Nacar', 'Anchieta', '85501-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35959, 'Campo Largo', 'Visconde de Nacar', 'Loteamento Ouro Verde II', '83606-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35960, 'Curitiba', 'Visconde de Nacar', 'Centro', '80410-201', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35961, 'Curitiba', 'Visconde de Nacar', 'Centro', '80410-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35962, 'Maringá', 'Visconde de Nassau', 'Zona 07', '87020-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35963, 'Apucarana', 'Visconde de Parnaíba', 'Vila Regina', '86801-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35964, 'Ponta Grossa', 'Visconde de Porto Alegre', 'Nova Rússia', '84070-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35965, 'Ponta Grossa', 'Visconde de Santo Thyrso', 'Oficinas', '84036-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35966, 'Ponta Grossa', 'Visconde de Sinimbú', 'Orfãs', '84070-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35967, 'Pato Branco', 'Visconde de Tamandaré', 'Centro', '85501-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35968, 'Pato Branco', 'Visconde de Tamandaré', 'Santa Terezinha', '85506-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35969, 'Guarapuava', 'Visconde de Taunay', 'Industrial', '85053-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35970, 'Ponta Grossa', 'Visconde de Taunay', 'Contorno', '84052-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35971, 'Ponta Grossa', 'Visconde de Taunay', 'Centro', '84010-760', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35972, 'Ponta Grossa', 'Visconde de Taunay', 'Centro', '84051-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35973, 'Paranavaí', 'Visconde de Taunay', 'Jardim São Jorge', '87711-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35974, 'Maringá', 'Visconde de Taunay', 'Zona 08', '87050-320', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35975, 'Campo Largo', 'Visconde de Taunay', 'Loteamento Ouro Verde I', '83606-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35976, 'Ponta Grossa', 'Visconde do Bom Retiro', 'Uvaranas', '84030-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35977, 'Curitiba', 'Visconde do Cerro Frio', 'Novo Mundo', '81050-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35978, 'Ponta Grossa', 'Visconde do Rio Branco', 'Oficinas', '84036-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35979, 'Ponta Grossa', 'Visconde do Rio Branco', 'Olarias', '84035-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35980, 'São José dos Pinhais', 'Visconde do Rio Branco', 'Centro', '83005-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35981, 'Cascavel', 'Visconde do Rio Branco', 'Claudete', '85811-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35982, 'Cascavel', 'Visconde do Rio Branco', 'Centro', '85810-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35983, 'Cascavel', 'Visconde do Rio Branco', 'Vila Tolentino', '85802-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35984, 'Campo Largo', 'Visconde do Rio Branco', 'Loteamento Ouro Verde I', '83606-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35985, 'Cascavel', 'Visconde do Rio Branco', 'Centro', '85801-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35986, 'Castro', 'Visconde do Rio Branco', 'Centro', '84165-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35987, 'Curitiba', 'Visconde do Rio Branco', 'Mercês', '80410-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35988, 'Curitiba', 'Visconde do Rio Branco', 'Mercês', '80410-001', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35989, 'Curitiba', 'Visconde do Rio Branco', 'Centro', '80420-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35990, 'Campo Mourão', 'Visconde Luiz Botelho Mourão', 'Jardim Flórida', '87300-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35991, 'Paranavaí', 'Vista Alegre', 'Jardim São Jorge', '87711-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35992, 'Cascavel', 'Vista Alegre', 'Santa Cruz', '85806-745', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35993, 'Curitiba', 'Vista Verde', 'Pilarzinho', '82100-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35994, 'Laranjeiras do Sul', 'Vital Brasil', 'Centro', '85301-095', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35995, 'Londrina', 'Vital Brasil', 'Kase', '86026-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35996, 'Maringá', 'Vital Brasil', 'Jardim Alvorada', '87035-220', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35997, 'Almirante Tamandaré', 'Vital Brasil', 'Planta Nossa Senhora do Pilar', '83508-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35998, 'Cambé', 'Vital Brasil', 'Jardim Montecatini', '86185-525', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (35999, 'Campo Largo', 'Vital Brasil', 'Vila David Antônio', '83609-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36000, 'Cascavel', 'Vital Brasil', 'Maria Luiza', '85819-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36001, 'Curitiba', 'Vital Brasil', 'Portão', '80320-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36002, 'Londrina', 'Vital Ferreira Chagas', 'Sabará III', '86066-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36003, 'Curitiba', 'Vital Gulisz', 'Pilarzinho', '82115-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36004, 'Londrina', 'Vital Muniz de Aquino', 'Tarobá', '86042-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36005, 'Curitiba', 'Vital Vernize', 'Cidade Industrial', '81460-377', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36006, 'Londrina', 'Vitalina Meleiro Lopes', 'Monte Belo', '86041-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36007, 'Curitiba', 'Vitalino Reck', 'Umbará', '81930-659', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36008, 'Curitiba', 'Vitélio Parzianello', 'Pinheirinho', '81825-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36009, 'Londrina', 'Vito Guglielmi', 'São Lourenço', '86043-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36010, 'Guarapuava', 'Vitoldo Kaminski', 'Cascavel', '85025-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36011, 'Foz do Iguaçu', 'Vítor Alves', 'Centro', '85851-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36012, 'Londrina', 'Vítor Assis Brasil', 'Conjunto Vivi Xavier', '86082-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36013, 'Ponta Grossa', 'Vítor Contin', 'Jardim Carvalho', '84015-840', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36014, 'Paranavaí', 'Vítor de Amaral', 'Jardim Santos Dumont', '87706-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36015, 'Maringá', 'Vítor do Amaral', 'Jardim Alvorada', '87035-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36016, 'São José dos Pinhais', 'Vítor Gomes de Lima', 'Afonso Pena', '83065-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36017, 'Colombo', 'Vítor Guebur', 'Jardim Cruzeiro', '83403-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36018, 'Apucarana', 'Vítor Hugo Pilizaro', 'Parque Bela Vista', '86803-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36019, 'Paranavaí', 'Vítor Lopes', 'Jardim Ipê', '87707-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36020, 'Paranavaí', 'Vítor Lopes', 'Jardim Ipê', '87706-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36021, 'Maringá', 'Vítor Meirelles', 'Zona 05', '87015-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36022, 'Maringá', 'Vítor Rodrigues Martins', 'Jardim Paris', '87083-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36023, 'Pato Branco', 'Vítor Sílvio Biazus', 'Trevo da Guarany', '85501-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36024, 'Curitiba', 'Vítor Stec', 'Xaxim', '81710-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36025, 'Londrina', 'Vitória', 'Vila Ernest', '86020-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36026, 'Guarapuava', 'Vitória', 'Bonsucesso', '85060-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36027, 'Maringá', 'Vitória', 'Vila Esperança', '87020-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36028, 'Piraquara', 'Vitória', 'Vila Vicente Macedo', '83303-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36029, 'São José dos Pinhais', 'Vitória', 'Ouro Fino', '83015-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36030, 'Toledo', 'Vitória', 'Vila Brasil', '85909-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36031, 'Umuarama', 'Vitória', 'Zona V', '87504-180', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36032, 'Campo Largo', 'Vitória', 'Loteamento Yara', '83605-330', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36033, 'Apucarana', 'Vitória', 'Barra Funda', '86800-530', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36034, 'Cascavel', 'Vitória', 'Ciro Nardi', '85802-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36035, 'Cambé', 'Vitória', 'Vila Guarani', '86182-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36036, 'Castro', 'Vitória', 'Água Suja', '84165-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36037, 'Campo Mourão', 'Vitória', 'Conjunto Habitacional Mendes', '87306-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36038, 'Campo Largo', 'Vitória', 'Jardim Rivabem', '83605-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36039, 'Curitiba', 'Vitória', 'Cabral', '80035-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36040, 'Curitiba', 'Vitória da Conquista', 'Santa Felicidade', '82410-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36041, 'Araucária', 'Vitória Durau', 'Vila Nova', '83703-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36042, 'Curitiba', 'Vitória Mansur Mattar', 'Cidade Industrial', '81460-167', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36043, 'Curitiba', 'Vitória Meira da Cruz', 'Cidade Industrial', '81170-708', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36044, 'Curitiba', 'Vitória Moreira Damaceno', 'Cidade Industrial', '81290-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36045, 'Sarandi', 'Vitória-regia', 'Jardim Verão', '87111-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36046, 'Guarapuava', 'Vitória-régia', 'Morro Alto', '85067-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36047, 'Foz do Iguaçu', 'Vitória-régia', 'Jardim Eliza I', '85853-580', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36048, 'Londrina', 'Vitória-régia', 'Ouro Branco', '86042-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36049, 'Maringá', 'Vitória-régia', 'Conjunto João de Barro Porto Seguro II', '87055-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36050, 'Paranaguá', 'Vitória-régia', 'Conjunto Nilson Neves', '83215-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36051, 'Pinhais', 'Vitória-régia', 'Planta Walde Rosi Galvão', '83328-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36052, 'Piraquara', 'Vitória-régia', 'Planta Guarituba Pequena', '83310-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36053, 'Ponta Grossa', 'Vitória-régia', 'Contorno', '84060-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36054, 'Telêmaco Borba', 'Vitória-régia', 'Área 03', '84271-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36055, 'Cambé', 'Vitória-régia', 'Jardim Ana Eliza', '86188-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36056, 'Cascavel', 'Vitória-régia', 'Guarujá', '85804-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36057, 'Campo Mourão', 'Vitória-Régia', 'Jardim Alvorada', '87308-380', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36058, 'Araucária', 'Vitória-régia', 'Campina da Barra', '83709-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36059, 'Foz do Iguaçu', 'Vitorino', 'Jardim Belvedere I', '85867-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36060, 'Francisco Beltrão', 'Vitorino', 'Marrecas', '85601-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36061, 'Curitiba', 'Vitorino', 'Xaxim', '81720-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36062, 'Cascavel', 'Vitorino Araújo', '14 de Novembro', '85804-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36063, 'Francisco Beltrão', 'Vitorino Bertaiolli', 'São Cristóvão', '85601-354', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36064, 'Curitiba', 'Vitorino Boscardim', 'Campo Comprido', '81270-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36065, 'Colombo', 'Vitorino Ceccon', 'Santa Gema', '83407-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36066, 'Paranavaí', 'Vitorino Faccin', 'Jardim Paranavaí', '87701-255', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36067, 'Colombo', 'Vitorino Fracaro', 'Vila Maria Ignácia', '83412-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36068, 'Curitiba', 'Vitorino Kaviski', 'Bigorrilho', '80710-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36069, 'Colombo', 'Vitorino Polli', 'Jardim Adriana', '83408-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36070, 'Toledo', 'Vitorino Sartori', 'Jardim Porto Alegre', '85906-708', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36071, 'Maringá', 'Vitório Balani', 'Zona 05', '87015-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36072, 'Colombo', 'Vitório Benjamin Mocelin', 'Jardim São Marcos', '83402-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36073, 'Campo Largo', 'Vitório Buch', 'Vila Vista Alegre', '83604-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36074, 'Colombo', 'Vitório Canestraro', 'Vila Maria do Rosário', '83413-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36075, 'Colombo', 'Vitório Colle', 'Jardim Rio Verde', '83405-360', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36076, 'Curitiba', 'Vitório Debiazio', 'Barreirinha', '82700-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36077, 'Maringá', 'Vitório Del Ângelo', 'Jardim Cidade Monções', '87060-355', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36078, 'Curitiba', 'Vitório do Amaral Cattani', 'Tarumã', '82530-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36079, 'Colombo', 'Vitório Domingos d''Agostin', 'Jardim Mediterrâneo', '83401-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36080, 'Londrina', 'Vitório Ferrari', 'Parque Residencial Alcântara', '86047-307', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36081, 'Curitiba', 'Vitório Foggiato', 'São Lourenço', '82200-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36082, 'Curitiba', 'Vitório João Brunor', 'Abranches', '82130-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36083, 'São José dos Pinhais', 'Vitório Juliatto', 'Afonso Pena', '83050-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36084, 'Toledo', 'Vitório Leduc', 'Independência', '85906-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36085, 'Curitiba', 'Vitório Macanhan', 'Tarumã', '82530-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36086, 'Colombo', 'Vitório Manoel Franceschi', 'Jardim Magnópolis', '83403-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36087, 'Londrina', 'Vitório Marandola', 'Operária', '86038-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36088, 'São José dos Pinhais', 'Vitório Marenda', 'Afonso Pena', '83045-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36089, 'Curitiba', 'Vitório Mocelin', 'Tatuquara', '81470-135', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36090, 'Araucária', 'Vitório Perreto', 'Porto das Laranjeiras', '83703-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36091, 'Cambé', 'Vitório Pomini', 'Novo Bandeirantes', '86188-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36092, 'Maringá', 'Vitório Sambatti', 'Conjunto Habitacional Karina', '87047-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36093, 'Curitiba', 'Vitório Sbalqueiro', 'Vista Alegre', '82100-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36094, 'Londrina', 'Vitório Sborgi', 'Colúmbia', '86057-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36095, 'Piraquara', 'Vitório Scarante', 'Vila Juliana', '83306-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36096, 'Piraquara', 'Vitório Scarante', 'Centro', '83301-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36097, 'Araucária', 'Vitório Sfendrych', 'Barigui', '83707-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36098, 'Londrina', 'Vitório Sisti', 'Jardim Tókio', '86063-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36099, 'Colombo', 'Vitório Strapasson', 'Sapopema', '83414-456', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36100, 'Londrina', 'Vitório Zendrini', 'Eucaliptos', '86031-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36101, 'Arapongas', 'Viuvinha', 'Conjunto Centauro', '86709-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36102, 'Foz do Iguaçu', 'Vivaldo', 'Parque Morumbi II', '85858-725', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36103, 'Foz do Iguaçu', 'Vivaldo de Lima', 'Parque Morumbi II', '85859-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36104, 'Apucarana', 'Vivaldo José Teixeira', 'Jardim Menegazzo', '86802-526', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36105, 'Ponta Grossa', 'Viveiros de Castro', 'Uvaranas', '84032-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36106, 'Curitiba', 'Vivian Calopreso Braga', 'Juvevê', '80030-350', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36107, 'Curitiba', 'Vivian Stec Toledo', 'São Braz', '82300-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36108, 'Curitiba', 'Viviane Guimarães Rezende', 'Cidade Industrial', '81230-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36109, 'Curitiba', 'Viviany Cristina Wanto', 'Portão', '81320-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36110, 'Pato Branco', 'Vividense', 'Bortot', '85501-375', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36111, 'Piraquara', 'Voadete Smaka Ivanoski', 'Vila São Cristóvão', '83305-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36112, 'Cascavel', 'Volochem', 'Universitário', '85819-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36113, 'Francisco Beltrão', 'Volta Redonda', 'Pinheirinho', '85603-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36114, 'Guarapuava', 'Volta Redonda', 'Boqueirão', '85020-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36115, 'Foz do Iguaçu', 'Volta Redonda', 'Jardim Vale do Sol', '85862-455', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36116, 'Curitiba', 'Volta Redonda', 'Campo Comprido', '81240-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36117, 'Londrina', 'Voltaire', 'Jardim Yoshikawa', '86025-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36118, 'Curitiba', 'Voltaire', 'Barreirinha', '82700-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36119, 'Guarapuava', 'Voluntários da Pátria', 'Alto da XV', '85065-155', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36120, 'Londrina', 'Voluntários da Pátria', 'Andrade', '86061-120', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36121, 'Paranavaí', 'Voluntários da Pátria', 'Jardim São Jorge', '87710-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36122, 'Umuarama', 'Voluntários da Pátria', 'Jardim Tamoio', '87505-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36123, 'São José dos Pinhais', 'Voluntários da Pátria', 'Centro', '83005-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36124, 'Cascavel', 'Voluntários da Pátria', 'Canadá', '85813-241', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36125, 'Cascavel', 'Voluntários da Pátria', 'Região do Lago 1', '85812-161', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36126, 'Cascavel', 'Voluntários da Pátria', 'Centro', '85812-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36127, 'Cascavel', 'Voluntários da Pátria', 'Country', '85813-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36128, 'Castro', 'Voluntários da Pátria', 'Núcleo Habitacional Padre Piva', '84178-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36129, 'Curitiba', 'Voluntários da Pátria', 'Centro', '80020-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36130, 'Curitiba', 'Von Ihering', 'Barreirinha', '82700-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36131, 'Cambé', 'Votorões', 'Jardim Tupi', '86183-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36132, 'Guarapuava', 'Votorós', 'Vila Bela', '85025-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36133, 'Arapongas', 'Vulturina', 'Vila Araponguinha', '86705-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36134, 'Ponta Grossa', 'W', 'Boa Vista', '84072-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36135, 'Umuarama', 'W', 'Parque das Jaboticabeiras', '87509-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36136, 'Curitiba', 'Wacco Cso', 'Bacacheri', '82515-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36137, 'Curitiba', 'Wacílio Zacachuka', 'Tatuquara', '81480-286', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36138, 'Campo Largo', 'Wadeco Krupa', 'Jardim Busmayer', '83606-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36139, 'Curitiba', 'Wadisnaw Mucharski', 'Abranches', '82220-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36140, 'Londrina', 'Wadya Calixto Dagher', 'Jardim Marumbi', '86035-135', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36141, 'Guarapuava', 'Wadyh C. Tahech', 'São Cristóvão', '85063-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36142, 'Curitiba', 'Wagia Kassab Khury', 'São Lourenço', '82210-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36143, 'Londrina', 'Wagner Bauer', 'Parque Residencial Michael Licha', '86078-675', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36144, 'Londrina', 'Wagner Cassemiro da Cunha', 'Conjunto Residencial Santa Rita V', '86072-506', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36145, 'Apucarana', 'Wagner Nora Ribeiro', 'Recanto Mundo Novo', '86805-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36146, 'Londrina', 'Wagner Olinto Magalhães', 'Jardim Neman Sahyun', '86041-285', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36147, 'Curitiba', 'Walace Landal', 'Santa Cândida', '82720-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36148, 'Pinhais', 'Waldemar Cador', 'Moradias Palmital', '83325-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36149, 'Curitiba', 'Waldemar Carta', 'Novo Mundo', '81050-635', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36150, 'Curitiba', 'Waldemar Cavanha', 'Campo Comprido', '81240-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36151, 'Curitiba', 'Waldemar Daros', 'Cidade Industrial', '81460-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36152, 'Foz do Iguaçu', 'Waldemar de Freitas', 'Jardim Iguaçu', '85853-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36153, 'Umuarama', 'Waldemar Evaristo da Silva', 'Jardim Alto da Boa Vista', '87506-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36154, 'Toledo', 'Waldemar Gnass', 'Jardim Porto Alegre', '85907-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36155, 'Toledo', 'Waldemar Grahl', 'Jardim Recanto', '85902-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36156, 'Curitiba', 'Waldemar Henrique Ehlke', 'Xaxim', '81710-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36157, 'Castro', 'Waldemar Hey', 'Jardim Colonial', '84178-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36158, 'Curitiba', 'Waldemar Kost', 'Hauer', '81630-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36159, 'Curitiba', 'Waldemar Kost', 'Hauer', '81610-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36160, 'Campo Largo', 'Waldemar Leo Braga', 'Jardim Social', '83606-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36161, 'Campo Largo', 'Waldemar Leon Borges', 'Conjunto Águas Claras', '83602-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36162, 'Curitiba', 'Waldemar Loureiro Campos', 'Boqueirão', '81650-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36163, 'Curitiba', 'Waldemar Loureiro Campos', 'Boqueirão', '81670-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36164, 'Curitiba', 'Waldemar Loureiro Campos', 'Xaxim', '81720-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36165, 'Curitiba', 'Waldemar Loureiro Campos', 'Xaxim', '81830-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36166, 'Guarapuava', 'Waldemar Moss', 'Industrial', '85053-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36167, 'Laranjeiras do Sul', 'Waldemar Moss', 'Vila Industrial', '85303-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36168, 'Londrina', 'Waldemar Pastore', 'Santa Rita 1', '86072-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36169, 'Curitiba', 'Waldemar Pereira da Silva', 'Uberaba', '81580-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36170, 'Curitiba', 'Waldemar Portugal Freixo', 'Boa Vista', '82650-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36171, 'Pinhais', 'Waldemar Robison', 'Planta Guilherme Weiss', '83324-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36172, 'Toledo', 'Waldemar Rossoni', 'Jardim Alta Floresta', '85905-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36173, 'Toledo', 'Waldemar Schorar', 'Conjunto Habitacional São Francisco', '85915-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36174, 'Londrina', 'Waldemar Spranger', 'São Jorge', '86047-300', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36175, 'Curitiba', 'Waldemar Trotta', 'Santa Felicidade', '82410-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36176, 'Toledo', 'Waldemar Turatti', 'Residencial Santa Clara', '85907-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36177, 'Pato Branco', 'Waldemar Vigano', 'São Vicente', '85506-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36178, 'São José dos Pinhais', 'Waldemar Zetola', 'Três Marias', '83030-710', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36179, 'Curitiba', 'Waldemar Zetola', 'Santa Cândida', '82640-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36180, 'Apucarana', 'Waldemir de Araújo Leite', 'Loteamento Belvedere', '86813-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36181, 'Curitiba', 'Waldemiro David Geronasso', 'Boa Vista', '82560-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36182, 'Curitiba', 'Waldemiro José Borges', 'Cajuru', '82950-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36183, 'Curitiba', 'Waldemiro Nardino', 'Xaxim', '81810-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36184, 'Curitiba', 'Waldemiro Ry', 'Novo Mundo', '81020-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36185, 'Londrina', 'Waldenir Costa', 'Conjunto Habitacional  Alexandre Urbanas', '86037-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36186, 'Cascavel', 'Waldir Azevedo', 'Floresta', '85815-176', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36187, 'Curitiba', 'Waldir Dacol', 'Pilarzinho', '82120-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36188, 'Londrina', 'Waldir de Azevedo', 'Parigot de Souza 2', '86082-160', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36189, 'Curitiba', 'Waldomiro Antônio Dalarmi', 'Cascatinha', '82015-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36190, 'Guarapuava', 'Waldomiro B. de Camargo', 'Bonsucesso', '85045-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36191, 'Londrina', 'Waldomiro Batista de Araújo', 'Franciscone', '86083-580', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36192, 'Laranjeiras do Sul', 'Waldomiro Bee', 'Centro', '85301-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36193, 'Curitiba', 'Waldomiro Bley', 'Capão Raso', '81020-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36194, 'Maringá', 'Waldomiro Cordeiro da Silva', 'Parque Residencial Quebec', '87023-485', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36195, 'Curitiba', 'Waldomiro Corrêa de Matos', 'Campo Comprido', '81220-445', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36196, 'Curitiba', 'Waldomiro Daldigan', 'Uberaba', '81590-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36197, 'Curitiba', 'Waldomiro de Mello Moraes', 'Sítio Cercado', '81925-569', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36198, 'Curitiba', 'Waldomiro Dombeck', 'Boa Vista', '82510-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36199, 'Londrina', 'Waldomiro Fernandes', 'Jamaica', '86063-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36200, 'Londrina', 'Waldomiro Ferreira da Silva', 'Sabará I', '86066-140', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36201, 'Araucária', 'Waldomiro Gayer', 'Costeira', '83709-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36202, 'Maringá', 'Waldomiro Martins', 'Parque Residencial Quebec', '87023-437', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36203, 'Londrina', 'Waldomiro Pistun', 'Conjunto Parigot de Souza 3', '86081-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36204, 'Curitiba', 'Waldomiro Rauth', 'Boqueirão', '81730-330', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36205, 'Curitiba', 'Walenty Golas', 'Campo Comprido', '81200-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36206, 'Castro', 'Walfrido Barreto Lopes', 'Loteamento Jardim Pandorf', '84182-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36207, 'Piraquara', 'Walfrido Belão', 'Capoeira dos Dinos', '83307-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36208, 'Colombo', 'Walfrido Ceccon', 'Centro', '83414-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36209, 'Piraquara', 'Walfrido Cordeiro da Silva', 'Jardim dos Estados 3', '83307-116', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36210, 'São José dos Pinhais', 'Walfrido Costa', 'Rio Pequeno', '83065-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36211, 'Curitiba', 'Walfrido de Britto', 'Cidade Industrial', '81315-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36212, 'Almirante Tamandaré', 'Walfrido de Paula Cavalheiro', 'Planta Mosacal', '83513-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36213, 'Curitiba', 'Walfrido Ferreira de Andrade', 'Cascatinha', '82020-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36214, 'Curitiba', 'Walfrido Leal', 'Cidade Industrial', '81460-266', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36215, 'Londrina', 'Walfrido Rincon Kemmer', 'Catuai', '86086-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36216, 'Colombo', 'Walfrido Strapasson', 'Vila Maria do Rosário', '83413-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36217, 'Londrina', 'Walkiria Val', 'Avelino A Vieira', '86056-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36218, 'Londrina', 'Wallace H. Morton', 'Cafezal 1', '86049-195', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36219, 'Pinhais', 'Walmor Alves Mota', 'Moradias Perdizes', '83326-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36220, 'Curitiba', 'Walt Disney', 'Cajuru', '82950-350', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36221, 'Londrina', 'Walter Bussadori', 'Parque Industrial Buena Vista', '86032-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36222, 'Londrina', 'Walter da Silva', 'Jardim Piza', '86073-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36223, 'Guarapuava', 'Walter Dallavechia', 'Jardim das Américas', '85030-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36224, 'Piraquara', 'Walter de Jesus dos Santos', 'Jardim Monte Líbano', '83311-235', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36225, 'Curitiba', 'Walter de Mari', 'Butiatuvinha', '82400-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36226, 'Ponta Grossa', 'Walter Eckert', 'Contorno', '84052-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36227, 'Ponta Grossa', 'Walter Fernandes', 'Contorno', '84052-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36228, 'Paranaguá', 'Walter Gomes Corrêa', 'Jardim Samambaia', '83212-275', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36229, 'Curitiba', 'Walter Guimarães da Costa', 'São Lourenço', '82210-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36230, 'Curitiba', 'Walter Jorge de Paiva', 'Uberaba', '81590-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36231, 'Apucarana', 'Walter José Rank', 'Jardim Pinheiros', '86803-387', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36232, 'Curitiba', 'Walter José Wunderlich Júnior', 'Cidade Industrial', '81460-357', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36233, 'Maringá', 'Walter Kraiser', 'Zona 08', '87050-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36234, 'Umuarama', 'Walter Kreiser', 'Zona VII', '87503-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36235, 'Umuarama', 'Walter Kreiser', 'Zona I', '87501-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36236, 'Umuarama', 'Walter Luiz da Cunha', 'Parque San Remo III', '87506-360', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36237, 'Curitiba', 'Walter Marquadt', 'Jardim Botânico', '80215-095', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36238, 'Cambé', 'Walter Mazzio', 'Vila Mesquita', '86182-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36239, 'Curitiba', 'Walter Moacir Ferri', 'São João', '82030-115', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36240, 'Londrina', 'Walter Motta Campos', 'Vale das Araucárias', '86047-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36241, 'Londrina', 'Walter Oldemburgo', 'Jardim São Rafael', '86035-295', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36242, 'Curitiba', 'Walter Otto Guaita', 'Cidade Industrial', '81460-197', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36243, 'Londrina', 'Walter Pereira', 'Cilo 3', '86072-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36244, 'Toledo', 'Walter Ponden', 'Jardim Santa Maria', '85903-145', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36245, 'Castro', 'Walter Poton Bouguignon', 'Jardim das Araucárias', '84174-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36246, 'Curitiba', 'Walter Rodolfo Behling', 'Guabirotuba', '81510-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36247, 'Curitiba', 'Walter S. de Castro Velloso', 'Cidade Industrial', '81280-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36248, 'Curitiba', 'Walter Soares Fernandes', 'Pilarzinho', '82115-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36249, 'Curitiba', 'Walter Sprengel', 'Tatuquara', '81470-317', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36250, 'Londrina', 'Walter Zamarian', 'Boa Vista', '86039-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36251, 'Cascavel', 'Waltrudes Klein', 'Cancelli', '85811-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36252, 'Londrina', 'Wanda Carnio', 'Jamile Dequech', '86048-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36253, 'Pinhais', 'Wanda dos Santos Mullmann', 'Vila Tarumã', '83323-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36254, 'Araucária', 'Wanda Fila', 'Boqueirão', '83704-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36255, 'Guarapuava', 'Wanda Kulka Moss', 'Cascavel', '85025-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36256, 'São José dos Pinhais', 'Wanda Kuss Salata', 'Colônia Rio Grande', '83020-645', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36257, 'Curitiba', 'Wanda Rocha de Souza', 'Pilarzinho', '82110-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36258, 'Araucária', 'Wanda Sekne', 'Costeira', '83708-726', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36259, 'Curitiba', 'Wanda Wolf', 'Santa Felicidade', '82410-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36260, 'Londrina', 'Wanderlei Barbosa de Castro', 'Jardim Alphaville', '86084-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36261, 'Campo Largo', 'Wanderley Caetano da Cruz', 'Núcleo Habitacional Doutor Abranches Guimarães', '83601-776', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36262, 'Pinhais', 'Wanderley do Amaral', 'Jardim Pedro Demeterco', '83324-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36263, 'Londrina', 'Wanderley Neves de Souza', 'Jardim São Jorge', '86082-817', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36264, 'Paranaguá', 'Washington', 'Parque Agari', '83215-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36265, 'Colombo', 'Washington', 'Jardim Bela Vista', '83404-560', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36266, 'Londrina', 'Washington de Souza Carvalho', 'Conjunto Habitacional José Belinati', '86084-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36267, 'Londrina', 'Washington Luís Maurutto', 'Parque Industrial Alicante', '86087-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36268, 'Foz do Iguaçu', 'Washington Luiz', 'Parque Presidente I', '85863-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36269, 'Guarapuava', 'Washington Luiz', 'Boqueirão', '85020-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36270, 'Ponta Grossa', 'Washington Luiz', 'Neves', '84021-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36271, 'Ponta Grossa', 'Washington Luiz', 'Neves', '84020-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36272, 'Pinhais', 'Washington Luiz', 'Vila Amélia', '83330-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36273, 'Telêmaco Borba', 'Washington Luiz', 'Alto das Oliveiras', '84266-450', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36274, 'Toledo', 'Washington Luiz', 'Jardim Filadélpia', '85902-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36275, 'Telêmaco Borba', 'Washington Luiz', 'Alto das Oliveiras', '84265-370', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36276, 'Cascavel', 'Washington Luiz', 'Parque São Paulo', '85803-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36277, 'Apucarana', 'Washington Luiz', 'Jardim Trabalhista', '86807-395', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36278, 'Londrina', 'Washington Luiz Siqueira', 'Conjunto Habitacional José Garcia Molina', '86080-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36279, 'Londrina', 'Washington Siqueira', 'Roseira', '86041-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36280, 'Curitiba', 'Waterloo Marchesini', 'Seminário', '80740-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36281, 'Cascavel', 'Watkins Glen', 'Interlagos', '85814-325', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36282, 'Foz do Iguaçu', 'Watslaf Boiarski', 'Jardim São Miguel', '85858-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36283, 'Foz do Iguaçu', 'Watslaf Nieradka', 'Vila Remígio', '85852-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36284, 'Londrina', 'Watson Macedo', 'Conjunto Vivi Xavier', '86082-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36285, 'Ponta Grossa', 'Watt', 'Colônia Dona Luiza', '84045-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36286, 'Curitiba', 'Weber', 'Vista Alegre', '80820-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36287, 'Curitiba', 'Wellington Borges Araújo', 'Sítio Cercado', '81925-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36288, 'Curitiba', 'Wellington de Oliveira Vianna', 'Ahú', '80530-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36289, 'Londrina', 'Wenceslau Braz', 'Hedy', '86062-660', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36290, 'Ponta Grossa', 'Wenceslau Braz', 'Uvaranas', '84026-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36291, 'Pinhais', 'Wenceslau Braz', 'Vila Amélia', '83330-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36292, 'Telêmaco Borba', 'Wenceslau Braz', 'Centro', '84261-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36293, 'Sarandi', 'Wenceslau Braz', 'Jardim Ana Eliza', '87112-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36294, 'Colombo', 'Wenceslau Braz', 'Jardim Cristina III', '83410-740', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36295, 'Apucarana', 'Wenceslau Braz', 'Jardim Trabalhista', '86807-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36296, 'Castro', 'Wenceslau Braz', 'Vila Rio Branco', '84172-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36297, 'Cascavel', 'Wenceslau Braz', 'Parque São Paulo', '85803-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36298, 'Curitiba', 'Wenceslau Carlos Glaser Neto', 'Atuba', '82600-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36299, 'Laranjeiras do Sul', 'Wenceslau Chrusciak', 'São Francisco', '85303-065', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36300, 'Curitiba', 'Wenceslau Cvintal', 'São Braz', '82300-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36301, 'Pinhais', 'Wenceslau Forlepa', 'Loteamento Pineville', '83325-597', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36302, 'Curitiba', 'Wenceslau Glaser', 'Vila Izabel', '80320-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36303, 'São José dos Pinhais', 'Wenceslau Marek', 'Águas Belas', '83010-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36304, 'Colombo', 'Wenceslau Prado', 'Jardim Santa Cândida', '83402-125', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36305, 'Curitiba', 'Wenceslau Sarnacki', 'Mossunguê', '81210-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36306, 'Curitiba', 'Wenceslau Teixeira Alves', 'Cajuru', '82920-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36307, 'Londrina', 'Wenceslau Zamuner', 'Esperança', '86046-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36308, 'Curitiba', 'Werner Gross', 'Bom Retiro', '80520-610', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36309, 'Curitiba', 'Werner Jehring', 'Cidade Industrial', '81305-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36310, 'Toledo', 'Werner Schiller', 'Jardim Europa', '85907-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36311, 'Castro', 'Werner Schittenhelm', 'Loteamento Jardim Pandorf', '84182-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36312, 'Londrina', 'Werner Sobral Arcoverde', 'Vale dos Tucanos', '86047-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36313, 'Londrina', 'Werner Von Braun', 'San Fernando', '86040-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36314, 'Guarapuava', 'Wesceslau Braz', 'Morro Alto', '85065-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36315, 'Londrina', 'Weslley César Vanzo', 'Parque Residencial do Lago', '86050-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36316, 'Londrina', 'Weyner Júnior Maciel Alves', 'Condomínio Royal Golf Residence', '86055-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36317, 'Curitiba', 'Wiegando Olsen', 'Cidade Industrial', '81460-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36318, 'Curitiba', 'Wilhem Ruscheweyh', 'Pinheirinho', '81870-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36319, 'Foz do Iguaçu', 'Wilibaldo Fritzen', 'Jardim Panorama II', '85856-567', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36320, 'Curitiba', 'Wilkys Amazonas Correia', 'Pilarzinho', '82115-050', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36321, 'Curitiba', 'Willi Lippel', 'São Braz', '82315-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36322, 'Toledo', 'Willi Tesch', 'Conjunto Habitacional São Francisco', '85912-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36323, 'Curitiba', 'William Booth', 'Boqueirão', '81650-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36324, 'Curitiba', 'William Booth', 'Boqueirão', '81730-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36325, 'Londrina', 'Willian Carlos Santos', 'Aníbal de Siqueira Cabral', '86089-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36326, 'Guarapuava', 'Willian Luís Milani', 'Morro Alto', '85070-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36327, 'Curitiba', 'Willian Walter Atkinson', 'Vista Alegre', '82100-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36328, 'Curitiba', 'Willibaldo Kayser', 'Cidade Industrial', '81170-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36329, 'Pato Branco', 'Willibat', 'Chaparral', '85507-270', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36330, 'Londrina', 'Willie Davids', 'Centro', '86010-400', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36331, 'Toledo', 'Willy Barth', 'Panorama', '85911-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36332, 'Paranaguá', 'Willy Hauer', 'Vila Garcia', '83218-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36333, 'Toledo', 'Willy Wey', 'Conjunto Habitacional Britânia', '85903-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36334, 'Londrina', 'Wilmar dos Santos', 'Conjunto Habitacional Bronzzetti', '86037-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36335, 'Toledo', 'Wilmar Ribeiro', 'Conjunto Habitacional São Francisco', '85915-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36336, 'Curitiba', 'Wilmar Sauner', 'Tatuquara', '81470-130', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36337, 'Londrina', 'Wilmar Sauner', 'Jardim Santa Cruz', '86084-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36338, 'Toledo', 'Wilson Albuquerque', 'Jardim La Salle', '85903-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36339, 'Curitiba', 'Wilson Dacheux Pereira', 'Alto Boqueirão', '81770-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36340, 'Londrina', 'Wilson de Oliveira', 'Residencial Moradias Tibagi', '86080-715', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36341, 'Curitiba', 'Wilson Feijó', 'Prado Velho', '80215-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36342, 'Apucarana', 'Wilson Franco Lucena', 'Vila Nova', '86812-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36343, 'Curitiba', 'Wilson Gomes Ramos', 'Abranches', '82220-510', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36344, 'Londrina', 'Wilson Gonçalves Brandão', 'Assis', '86085-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36345, 'Curitiba', 'Wilson Gurtensten', 'Butiatuvinha', '82315-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36346, 'Campo Largo', 'Wilson Leonildo de Pontes', 'Jardim Rondinha', '83607-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36347, 'Curitiba', 'Wilson Lois Koehler Júnior', 'Xaxim', '81630-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36348, 'São José dos Pinhais', 'Wilson Luciano Vion', 'Centro', '83005-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36349, 'Guarapuava', 'Wilson Luiz Silvério Martins', 'Santana', '85070-670', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36350, 'Apucarana', 'Wilson Manoel Cornelsen', 'Jardim Marissol', '86807-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36351, 'Apucarana', 'Wilson Moreno', 'Núcleo Habitacional Papa João Paulo I', '86801-026', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36352, 'Paranaguá', 'Wilson N. de Freitas', 'Ponta do Caju', '83206-447', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36353, 'Piraquara', 'Wilson Nóbrega de Franca', 'Vila Juliana', '83306-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36354, 'Curitiba', 'Wilson Portugal Lobato', 'Bairro Alto', '82840-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36355, 'Colombo', 'Wilson Ribeiro', 'Jardim Aurora', '83411-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36356, 'Curitiba', 'Wilson Stadler', 'Pinheirinho', '81820-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36357, 'Curitiba', 'Wilson Valdívia Domingues', 'Jardim das Américas', '81540-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36358, 'Curitiba', 'Wilson Walter Ruppel', 'Cidade Industrial', '81305-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36359, 'Londrina', 'Winston Churchill', 'Andes', '86076-000', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36360, 'Londrina', 'Winston Churchill', 'Coliseu', '86080-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36361, 'Ponta Grossa', 'Winston Churchill', 'Uvaranas', '84030-340', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36362, 'Curitiba', 'Winston Churchill', 'Capão Raso', '81130-000', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36363, 'Curitiba', 'Winston Churchill', 'Capão Raso', '81150-050', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36364, 'Foz do Iguaçu', 'Wisland Sanwais', 'Pilar Parque Campestre', '85862-280', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36365, 'Piraquara', 'Wismar da Costa Lima', 'Vila Fuck', '83305-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36366, 'Curitiba', 'Wladimir Kozak', 'Uberaba', '81570-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36367, 'Londrina', 'Wladimir Revenski', 'Monte Belo', '86041-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36368, 'Paranavaí', 'Wladislao Gaida', 'Jardim Panorama', '87707-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36369, 'Curitiba', 'Wolfgang Mozart', 'Vista Alegre', '80820-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36370, 'Maringá', 'X', 'Jardim São Domingos', '87070-806', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36371, 'Colombo', 'X', 'Vila Guaraci', '83404-420', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36372, 'Foz do Iguaçu', 'Xambrê', 'Jardim Nacional', '85862-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36373, 'Guarapuava', 'Xambrê', 'Boqueirão', '85020-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36374, 'Piraquara', 'Xambrê', 'Planta Araçatuba', '83301-495', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36375, 'São José dos Pinhais', 'Xambrê', 'Águas Belas', '83010-215', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36376, 'Umuarama', 'Xambrê', 'Zona IV', '87504-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36377, 'Araucária', 'Xambrê', 'Iguaçu', '83701-590', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36378, 'Colombo', 'Xambrê', 'Vila São José', '83410-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36379, 'Campo Mourão', 'Xambrê', 'Conjunto Habitacional Parigot de Souza', '87310-635', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36380, 'Curitiba', 'Xambrê', 'Cidade Industrial', '81250-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36381, 'Maringá', 'Xanadú', 'Jardim Imperial II', '87023-018', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36382, 'Piraquara', 'Xanxerê', 'Planta São Tiago', '83306-190', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36383, 'Cascavel', 'Xanxerê', 'Universitário', '85819-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36384, 'Curitiba', 'Xanxerê', 'Cidade Industrial', '81230-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36385, 'Londrina', 'Xapecó', 'Jardim Agari', '86025-540', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36386, 'Foz do Iguaçu', 'Xapurí', 'Jardim das Palmeiras II', '85869-707', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36387, 'Guarapuava', 'Xarquinho', 'Industrial', '85045-720', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36388, 'Maringá', 'Xavante', 'Parque das Grevíleas', '87025-060', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36389, 'Guarapuava', 'Xavantes', 'Vila Carli', '85040-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36390, 'Laranjeiras do Sul', 'Xavantes', 'São Francisco', '85303-215', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36391, 'Pato Branco', 'Xavantes', 'Amadori', '85502-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36392, 'Pato Branco', 'Xavantes', 'Centro', '85501-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36393, 'Telêmaco Borba', 'Xavantes', 'Nossa Senhora do Perpétuo Socorro', '84265-300', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36394, 'São José dos Pinhais', 'Xavantes', 'Colônia Rio Grande', '83025-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36395, 'Umuarama', 'Xavantes', 'Zona VI', '87503-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36396, 'Sarandi', 'Xavantes', 'Jardim Universal', '87114-285', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36397, 'Toledo', 'Xavantes', 'Jardim Paulista', '85909-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36398, 'Cascavel', 'Xavantes', 'Santa Cruz', '85806-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36399, 'Cambé', 'Xavantes', 'Jardim Tupi', '86183-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36400, 'Apucarana', 'Xavantes', 'Jardim Ponta Grossa', '86804-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36401, 'Sarandi', 'Xavantino', 'Jardim Esplanada', '87112-340', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36402, 'Guarapuava', 'Xavier da Silva', 'Trianon', '85012-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36403, 'Foz do Iguaçu', 'Xavier da Silva', 'Centro', '85852-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36404, 'Foz do Iguaçu', 'Xavier da Silva', 'Centro', '85851-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36405, 'Guarapuava', 'Xavier da Silva', 'Centro', '85010-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36406, 'Paranaguá', 'Xavier da Silva', 'Tuiuti', '83203-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36407, 'Ponta Grossa', 'Xavier da Silva', 'Centro', '84010-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36408, 'Paranaguá', 'Xavier da Silva', 'Industrial', '83221-680', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36409, 'Pato Branco', 'Xavier da Silva', 'Pinheirinho', '85506-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36410, 'Campo Largo', 'Xavier da Silva', 'Centro', '83601-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36411, 'Ponta Grossa', 'Xavier de Souza', 'Uvaranas', '84030-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36412, 'Ponta Grossa', 'Xavier Pinheiro', 'Uvaranas', '84030-150', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36413, 'Francisco Beltrão', 'Xaxim', 'Pinheirinho', '85603-475', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36414, 'Cascavel', 'Xaxim', 'Cancelli', '85811-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36415, 'Londrina', 'Xenofonte', 'Jardim Graziela', '86036-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36416, 'Laranjeiras do Sul', 'Xenofontes Freitas Lopes', 'São Francisco', '85303-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36417, 'Francisco Beltrão', 'Xerém', 'Presidente Kennedy', '85605-365', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36418, 'Cambé', 'Xetas', 'Jardim Tupi', '86183-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36419, 'Arapongas', 'Xexéu', 'Conjunto Tropical', '86702-320', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36420, 'Telêmaco Borba', 'Xibuí', 'Vila São Francisco de Assis', '84265-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36421, 'Foz do Iguaçu', 'Ximboré', 'Conjunto A', '85860-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36422, 'Foz do Iguaçu', 'Xingu', 'Loteamento Campos do Iguaçu', '85857-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36423, 'Guarapuava', 'Xingu', 'Boqueirão', '85022-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36424, 'Londrina', 'Xingu', 'Aparecida', '86025-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36425, 'Pato Branco', 'Xingu', 'Centro', '85501-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36426, 'Paranaguá', 'Xingu', 'Jardim Guaraituba', '83209-420', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36427, 'Maringá', 'Xingu', 'Parque das Grevíleas', '87025-090', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36428, 'Pato Branco', 'Xingu', 'Amadori', '85502-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36429, 'Umuarama', 'Xingu', 'Zona IV', '87504-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36430, 'Araucária', 'Xingu', 'Iguaçu', '83701-570', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36431, 'Cascavel', 'Xingu', 'Santa Cruz', '85806-230', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36432, 'Curitiba', 'Xingu', 'Bairro Alto', '82840-300', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36433, 'Foz do Iguaçu', 'Xique-xique', 'Jardim Lancaster', '85869-450', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36434, 'Curitiba', 'Xiquinho Zimermann', 'Cidade Industrial', '81350-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36435, 'Londrina', 'Xiriana', 'Oriente', '86027-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36436, 'Pato Branco', 'Xisto Ramirez Gutierrez', 'Aeroporto', '85503-040', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36437, 'Colombo', 'Y', 'Vila Guaraci', '83404-430', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36438, 'Apucarana', 'Yamato', 'Jardim Yamato', '86802-660', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36439, 'Cascavel', 'Yanomanis', 'Santo Onofre', '85806-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36440, 'Toledo', 'Yara', 'Jardim Recanto', '85902-070', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36441, 'Colombo', 'Yara', 'Jardim Curitiba', '83406-620', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36442, 'Curitiba', 'Yara Amaral', 'Tatuquara', '81470-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36443, 'Cascavel', 'Yara Amaral', 'Interlagos', '85814-288', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36444, 'Curitiba', 'Yassushi Mori', 'Boqueirão', '81650-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36445, 'Curitiba', 'Yedo de Faria Pinto', 'Cajuru', '82980-110', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36446, 'Londrina', 'Ylie Soloviev', 'Presidente Vargas', '86083-640', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36447, 'Colombo', 'Ylizerio de Lourdes', 'Vila Yara', '83408-370', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36448, 'Castro', 'Yoiti Iwashita', 'Vila do Rosário', '84168-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36449, 'Londrina', 'Yolanda Ceccarelli', 'Catuaí Parque Residence', '86047-800', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36450, 'Curitiba', 'Yolando João Toninelo', 'São Braz', '82310-170', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36451, 'Araucária', 'Yolando Zanardini Camargo', 'Tindiquera', '83708-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36452, 'Londrina', 'Yonessaki Ueda', 'San Fernando', '86040-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36453, 'Piraquara', 'York', 'Planta York', '83307-240', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36454, 'Araucária', 'Yoshiaki Nagano', 'Capela Velha', '83706-750', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36455, 'Londrina', 'Yoshikawa Koji', 'Jardim Tókio', '86063-010', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36456, 'Londrina', 'Yoshimasa Suzuki', 'Maria Lúcia', '86072-500', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36457, 'Cambé', 'Yoshimi Hamamoto', 'Parque Residencial Ana Rosa', '86183-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36458, 'Paranavaí', 'Yoshinobu Sunahara', 'Vila Operária', '87708-260', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36459, 'Apucarana', 'Yoshinori Fukushima', 'Recanto das Araras', '86812-650', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36460, 'Maringá', 'Yoshinori Kubota', 'Parque das Grevíleas', '87025-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36461, 'Curitiba', 'Yoshito Hanai', 'Novo Mundo', '81050-625', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36462, 'Londrina', 'Yosio Obuti', 'Parque Industrial Buena Vista', '86032-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36463, 'Apucarana', 'Yozo Kinoshita', 'Jardim Portal do Lago', '86802-076', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36464, 'Foz do Iguaçu', 'Ypacarai', 'Vila Paraguaia', '85864-080', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36465, 'Cascavel', 'Ypiranga', '14 de Novembro', '85804-117', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36466, 'Apucarana', 'Yuichi Takashina', 'Jardim Portal do Lago', '86802-077', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36467, 'Curitiba', 'Yukio Akashi', 'Pilarzinho', '82110-520', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36468, 'Londrina', 'Yuossif El Achi', 'Residencial Abussafe', '86037-787', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36469, 'São José dos Pinhais', 'Yuri Santos Machado', 'Guatupê', '83060-610', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36470, 'Campo Mourão', 'Yvan Bitencourt', 'Jardim Santa Cruz', '87309-700', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36471, 'Londrina', 'Yvan Bittencourt', 'Barbeta', '86078-550', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36472, 'Londrina', 'Yvette Dias da Silva', 'Jardim Nápoles', '86062-637', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36473, 'Colombo', 'Z', 'Vila Guaraci', '83404-440', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36474, 'Arapongas', 'Zabelê', 'Conjunto Del Condor', '86703-317', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36475, 'Foz do Iguaçu', 'Zacaria Vitalino da Silva', 'Jardim Irmã', '85867-475', 'Alameda', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36476, 'Curitiba', 'Zacarias', 'Centro', '80020-080', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36477, 'Curitiba', 'Zacarias Alves de Souza', 'Santa Felicidade', '82030-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36478, 'São José dos Pinhais', 'Zacarias Alves Pereira', 'Aristocrata', '83030-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36479, 'Almirante Tamandaré', 'Zacarias de Cristo', 'Loteamento Nova Morada', '83504-687', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36480, 'Londrina', 'Zacarias de Góes', 'Paulista', '86079-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36481, 'Pato Branco', 'Zacarias de Goes e Vasconcelos', 'Pinheirinho', '85506-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36482, 'Cambé', 'Zacarias de Goes e Vasconcelos', 'Jardim Silvino', '86188-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36483, 'Ponta Grossa', 'Zacarias de Góes e Vasconcelos', 'Uvaranas', '84020-220', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36484, 'Apucarana', 'Zacarias de Góes e Vasconcelos', 'Núcleo Habitacional Parigot de Souza', '86802-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36485, 'Curitiba', 'Zacarias de Paula Neves', 'Portão', '80320-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36486, 'Colombo', 'Zacarias de Paula Xavier', 'Centro', '83414-160', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36487, 'Curitiba', 'Zacarias Gomes de Souza', 'Uberaba', '81550-390', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36488, 'Pato Branco', 'Zacarias Koslinski', 'Trevo da Guarany', '85501-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36489, 'Colombo', 'Zacarias Machado de Meira', 'Jardim Osasco', '83403-100', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36490, 'Curitiba', 'Zacarias Mansur', 'São Braz', '82015-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36491, 'Curitiba', 'Zacarias Nassur', 'Santa Quitéria', '80310-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36492, 'Pinhais', 'Zacharias Abrahão', 'Chácara Esperança', '83328-450', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36493, 'Araucária', 'Zacharias Lemos', 'Boqueirão', '83704-410', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36494, 'Cascavel', 'Zaco Paraná', 'Independência', '85811-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36495, 'Umuarama', 'Zaeli', 'Parque San Remo I', '87506-230', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36496, 'Francisco Beltrão', 'Zaira Abdala', 'Água Branca', '85601-337', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36497, 'Colombo', 'Zaire', 'Vila Alto da Cruz II', '83405-140', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36498, 'Cambé', 'Zamberlan', 'Parque Residencial Ana Rosa', '86183-470', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36499, 'Pinhais', 'Zâmbia', 'Vila Progresso', '83320-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36500, 'Cambé', 'Zampar', 'Jardim Vila Rica', '86192-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36501, 'Francisco Beltrão', 'Zancanaro', 'São Cristóvão', '85601-055', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36502, 'Cascavel', 'Zandvoort', 'Interlagos', '85814-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36503, 'Ponta Grossa', 'Zanoni Rogoski', 'Colônia Dona Luiza', '84046-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36504, 'Araucária', 'Zdenco Gayer', 'Fazenda Velha', '83703-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36505, 'Almirante Tamandaré', 'Zeferina Cordeiro de Cristo', 'Vila Grécia', '83502-360', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36506, 'Curitiba', 'Zeferino da Costa', 'Xaxim', '81810-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36507, 'Campo Largo', 'Zeferino Marchiorato', 'Vila Elizabeth', '83607-210', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36508, 'Curitiba', 'Zeferino Pires Barbosa', 'Orleans', '82310-310', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36509, 'Curitiba', 'Zeila Moura dos Santos', 'Cristo Rei', '80050-600', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36510, 'Londrina', 'Zélia Cabral de Barros', 'Jardim Santa Fé', '86035-760', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36511, 'Curitiba', 'Zélia Maria Pimpão Ferraz', 'Barreirinha', '82710-120', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36512, 'Paranaguá', 'Zélia Simeão Poplade', 'Vila dos Comerciários', '83215-055', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36513, 'Curitiba', 'Zelinda Fanini Schier', 'Xaxim', '81710-580', 'Jardinete', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36514, 'Londrina', 'Zelindo Bonesi', 'Residencial José Lázaro Gouvea', '86050-756', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36515, 'Curitiba', 'Zem Bertapelle', 'Santa Felicidade', '82030-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36516, 'Curitiba', 'Zenaida Zukoski', 'Uberaba', '81590-430', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36517, 'Maringá', 'Zenioshi Isozaki', 'Parque Residencial Quebec', '87023-484', 'Viela', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36518, 'Curitiba', 'Zenita Ramos Gonçalves', 'Atuba', '82860-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36519, 'Curitiba', 'Zenite Pucci Simão', 'Alto Boqueirão', '81860-330', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36520, 'Paranaguá', 'Zenon P. da Costa', 'Bockmann', '83203-435', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36521, 'Paranaguá', 'Zenon Pereira Leite', 'Alto São Sebastião', '83203-730', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36522, 'Londrina', 'Zephiro Modenute', 'Jardim Primavera', '86086-490', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36523, 'Ponta Grossa', 'Zequinha de Abreu', 'Ronda', '84051-560', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36524, 'Curitiba', 'Zilah Walbach Prestes', 'Butiatuvinha', '82410-690', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36525, 'Curitiba', 'Zilda Maria Abbage', 'Sítio Cercado', '81925-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36526, 'Apucarana', 'Zilda Seixas Amaral', 'Parque Industrial Zona Norte', '86806-380', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36527, 'Curitiba', 'Zília Quadri Merhy', 'Cascatinha', '82020-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36528, 'Londrina', 'Zinco', 'Jardim São Francisco de Assis', '86067-130', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36529, 'Apucarana', 'Zinco', 'Parque Industrial Zona Norte', '86806-480', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36530, 'Londrina', 'Zinia', 'Ouro Branco', '86042-030', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36531, 'Londrina', 'Zirbo Quintino Pontes', 'Catuai', '86086-290', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36532, 'Ponta Grossa', 'Zircão', 'Neves', '84021-530', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36533, 'Cascavel', 'Zircão', 'Esmeralda', '85806-630', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36534, 'Maringá', 'Zircônia', 'Jardim Real', '87083-565', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36535, 'Londrina', 'Zircônio', 'Santa Inês', '86030-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36536, 'Curitiba', 'Zonardy Ribas', 'Boqueirão', '81750-380', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36537, 'São José dos Pinhais', 'Zoraide Buhrer Ravaglio', 'Rio Pequeno', '83070-090', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36538, 'Curitiba', 'Zozino Pinheiro', 'Cidade Industrial', '81260-250', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36539, 'Londrina', 'Zuleika de Abreu Ferraz Noronha', 'Indusville', '86031-350', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36540, 'Londrina', 'Zuleima Aparecida Lucas Camilo', 'Parque das Colinas', '86077-190', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36541, 'Toledo', 'Zulmir Longhi', 'Centro', '85903-180', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36542, 'Londrina', 'Zulmira Augusto Andrello', 'Cafezal 1', '86049-020', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36543, 'Curitiba', 'Zulmira Bacila', 'Uberaba', '81580-200', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36544, 'Londrina', 'Zulmira Cavazzani Thomazi', 'Jardim Primavera', '86086-400', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36545, 'Londrina', 'Zulmira Maria de Almeida', 'Jardim Nova Esperança', '86044-628', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36546, 'Colombo', 'Zulmiro Teodoro', 'Santa Gema', '83407-208', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36547, 'Colombo', 'Zumbi', 'Jardim das Perdizes', '83409-190', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36548, 'Curitiba', 'Zumbi', 'Santa Cândida', '82630-460', 'Rua', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36549, 'Maringá', 'Zumbi dos Palmares', 'Conjunto João de Barro I', '87053-125', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36550, 'Almirante Tamandaré', 'Zumbi dos Palmares', 'Jardim Apucarana', '83505-150', 'Avenida', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36551, 'Curitiba', 'Zumbi dos Palmares', 'Pinheirinho', '81110-435', 'Praça', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36552, 'Foz do Iguaçu', 'Zurique', 'Beverly Falls Park', '85858-220', 'Travessa', 'PR');
INSERT INTO staging.pr (id, city, street, district, zip, street_type, state) VALUES (36553, 'Maringá', 'Zygmunt Krosnowski', 'Parque Industrial Bandeirantes', '87045-370', 'Rua', 'PR');


--
-- PostgreSQL database dump complete
--

-- import from staging tables into schema 'dem'
-- first patch any known incorrect values

UPDATE dem.state SET code = 'AP' WHERE code = 'AM' AND name = 'Amapa' AND country = 'BR';
UPDATE dem.state SET code = 'AM' WHERE code = 'AZ' AND name = 'Amazonas'  AND country = 'BR';
UPDATE dem.state SET code = 'MT' WHERE code = 'MG' AND name = 'Mato Grosso'  AND country = 'BR';
UPDATE dem.state SET code = 'PB' WHERE code = 'PR' AND name = 'Paraiba'  AND country = 'BR';
UPDATE dem.state SET code = 'PR' WHERE code = 'PN' AND name = 'Parana'  AND country = 'BR';

-- provide accented portuguese brazilian states 
select i18n.upd_tx('generic', 'Ceara', 'Ceará');
select i18n.upd_tx('generic', 'Espirito Santo', 'Espírito Santo');
select i18n.upd_tx('generic', 'Goias', 'Goiás');
select i18n.upd_tx('generic', 'Maranhao', 'Maranhão');
select i18n.upd_tx('generic', 'Para', 'Pará');
select i18n.upd_tx('generic', 'Paraiba', 'Paraíba');
select i18n.upd_tx('generic', 'Parana', 'Paraná');
select i18n.upd_tx('generic', 'Piaui', 'Piauí');
select i18n.upd_tx('generic', 'Rondonia', 'Rondônia');
select i18n.upd_tx('generic', 'Sao Paulo', 'São Paulo');

-- not needed because the next function achieves it
-- insert unaccented brazilian urb strings into i18n.keys for later translation
-- SELECT i18n.i18n(s_i.unaccented)
-- FROM staging.i18n_generic_br s_i
-- ;

-- provide accented portugues brazilian urbs 
select i18n.upd_tx('generic', s_i.unaccented, s_i.accented)
from staging.i18n_generic_br s_i;


-- we would not be inserting states from this source, since these states are accented
-- INSERT INTO dem.state (
--   code,
--   name,
--   country
-- )
-- SELECT DISTINCT ON (UPPER(s_state.code)) UPPER(s_state.code), i18n.i18n(s_state.name), 'BR'
-- FROM staging.state s_state
-- -- INNER JOIN dem.state d_state
-- -- ON UPPER(d_state.code) = CASE WHEN s_state.code IS NULL THEN '??' ELSE UPPER(s_state.code) END
-- -- INNER JOIN dem.country d_c
-- -- ON UPPER(d_state.country)=UPPER(d_c.code)
-- WHERE s_state.code IS NOT NULL AND s_state.name IS NOT NULL
-- AND NOT EXISTS
--   (SELECT 1 FROM dem.state d_state WHERE UPPER(d_state.code) = CASE WHEN s_state.code IS NULL THEN '??' ELSE UPPER(s_state.code) END
--   AND d_state.country = (SELECT code FROM dem.country d_c WHERE UPPER('Brazil') =UPPER(d_c.name))
--   )
-- ORDER BY UPPER(s_state.code)
-- ;
-- 

-- try to fill in missing zips from the unaccented cities list
UPDATE staging.i18n_generic_br s_i
SET zip = s_s.zip
FROM staging.street s_s
WHERE s_i.accented = s_s.city AND s_i.state = s_s.state
AND (s_i.zip IS NULL OR s_i.zip = 'NULL')
;

-- insert distinct city - state combinations
INSERT INTO dem.urb (
  name,
  id_state,
  postcode
)
SELECT DISTINCT ON (UPPER(s_i.state), UPPER(s_i.unaccented), UPPER(s_i.zip))
  s_i.unaccented,
  (SELECT id FROM dem.state d_s WHERE d_s.code = UPPER(s_i.state) AND d_s.country = 'BR') as id_state,
  CASE WHEN s_i.zip IS NULL OR s_i.zip = 'NULL' THEN ''
       ELSE s_i.zip
       END
FROM staging.i18n_generic_br s_i
INNER JOIN dem.state d_s
ON UPPER(s_i.state) = UPPER(d_s.code) 
INNER JOIN dem.country d_c
ON d_s.country=d_c.code
WHERE s_i.unaccented IS NOT NULL AND s_i.state IS NOT NULL AND s_i.zip IS NOT NULL AND s_i.zip <> 'NULL'
AND NOT EXISTS
  (SELECT 1 FROM dem.urb d_u
   INNER JOIN dem.state d_s
   ON d_u.id_state = d_s.id
   INNER JOIN dem.country d_c
   ON d_s.country=d_c.code
   WHERE UPPER(s_i.unaccented) = UPPER(d_u.name)
   AND UPPER(s_i.state) = d_s.code
   AND d_s.country = 'BR'
  )
ORDER BY UPPER(s_i.state), UPPER(s_i.unaccented), UPPER(s_i.zip)
;


-- following is a conundrum…
-- Candidate urbs may warrant to be created when they did not yet exist,
-- but some may be accented while others are not. Where a match resides in a translation table,
-- the unaccented base value can be used, but this needs tracking in order that a second 'pass'
-- over the data set does not import the accented values among the non-accented (on account of
-- having avoided to employ the accented values the first time, these won't have been created
-- and so must be excluded in the second pass so as to not insert them.

ALTER TABLE staging.street
ADD COLUMN accented BOOLEAN
;

UPDATE staging.street
SET accented = CASE WHEN (SELECT UPPER(i_t.orig)
                          FROM i18n.translations i_t
                          INNER JOIN staging.street s_s
                          ON UPPER(i_t.trans) = UPPER(s_s.city)
                          WHERE i_t.lang = 'generic') IS NOT NULL THEN TRUE
                    ELSE FALSE
                    END;

-- where the city name is found among translations, import the streets if they don't exist
INSERT INTO dem.street (
  name,
  id_urb,
  postcode,
  suburb
)
SELECT DISTINCT ON (UPPER(s_s.street_type || ' ' || s_s.street), UPPER(s_s.city), UPPER(s_s.zip))
    s_s.street_type || ' ' || s_s.street,
    d_u.id,
    s_s.zip,
    s_s.district
FROM staging.street s_s
INNER JOIN dem.urb d_u
ON (SELECT UPPER(i_t.orig)
	FROM i18n.translations i_t
	INNER JOIN staging.street s_s
	ON UPPER(i_t.trans) = UPPER(s_s.city)
	WHERE i_t.lang = 'generic'
   ) = UPPER(d_u.name)
INNER JOIN dem.state d_s
ON d_u.id_state = d_s.id
WHERE accented IS TRUE AND UPPER(s_s.state) = UPPER(d_s.code) AND d_s.country = 'BR'
AND NOT EXISTS (
   SELECT 1 FROM dem.street
   WHERE dem.street.id_urb =
     (SELECT d_u.id FROM dem.urb d_u
      INNER JOIN dem.state d_s
      ON d_s.id = d_u.id_state
      WHERE UPPER(d_u.name) = (SELECT UPPER(i_t.orig)
                               FROM i18n.translations i_t
                               WHERE UPPER(i_t.trans) = UPPER(s_s.city)
                              )
            AND UPPER(d_s.code)=UPPER(s_s.state)
            AND d_s.country = 'BR'
     )
     AND UPPER(dem.street.name) = UPPER(s_s.street_type || ' ' || s_s.street)
     AND UPPER(dem.street.postcode) = UPPER(s_s.zip)
   )
AND s_s.street IS NOT NULL AND s_s.city IS NOT NULL AND s_s.zip IS NOT NULL AND s_s.zip <> 'NULL'
;

-- where the city name seems unaccented, import the streets if they don't exist
INSERT INTO dem.street (
  name,
  id_urb,
  postcode,
  suburb
)
SELECT DISTINCT ON (UPPER(s_s.street_type || ' ' || s_s.street), UPPER(s_s.city), UPPER(s_s.zip))
    s_s.street_type || ' ' || s_s.street,
    d_u.id,
    s_s.zip,
    s_s.district
FROM staging.street s_s
INNER JOIN dem.urb d_u
ON UPPER(s_s.city) = UPPER(d_u.name)
INNER JOIN dem.state d_s
ON d_u.id_state = d_s.id
WHERE accented IS FALSE AND UPPER(s_s.state) = UPPER(d_s.code) AND d_s.country = 'BR'
AND NOT EXISTS (
   SELECT 1 FROM dem.street
   WHERE dem.street.id_urb =
     (SELECT d_u.id FROM dem.urb d_u
      INNER JOIN dem.state d_s
      ON d_s.id = d_u.id_state
      WHERE UPPER(d_u.name) = UPPER(s_s.city)
            AND UPPER(d_s.code)=UPPER(s_s.state)
            AND d_s.country = 'BR'
     )
     AND UPPER(dem.street.name) = UPPER(s_s.street_type || ' ' || s_s.street)
     AND UPPER(dem.street.postcode) = UPPER(s_s.zip)
   )
AND s_s.street IS NOT NULL AND s_s.city IS NOT NULL AND s_s.zip IS NOT NULL AND s_s.zip <> 'NULL'
;
commit;

-- =================
-- cleanup and exit
-- =================

\unset ON_ERROR_STOP
-- optionally
-- DROP TABLE staging.foo CASCADE;
DROP TABLE staging.i18n_generic_br;

DROP TABLE staging.state;

DROP TABLE staging.street CASCADE;

DROP TABLE staging.ac;
DROP TABLE staging.al;
DROP TABLE staging.am;
DROP TABLE staging.ap;
DROP TABLE staging.ba;
DROP TABLE staging.ce;
DROP TABLE staging.df;
DROP TABLE staging.es;
DROP TABLE staging.go;
DROP TABLE staging.ma;
DROP TABLE staging.mg;
DROP TABLE staging.ms;
DROP TABLE staging.mt;
DROP TABLE staging.pa;
DROP TABLE staging.pb;
DROP TABLE staging.pe;
DROP TABLE staging.pi;
DROP TABLE staging.pr;
DROP TABLE staging.rj;
DROP TABLE staging.rn;
DROP TABLE staging.ro;
DROP TABLE staging.rr;
DROP TABLE staging.rs;
DROP TABLE staging.sc;
DROP TABLE staging.se;
DROP TABLE staging.sp;
DROP TABLE staging.to;

\set ON_ERROR_STOP 1

-- end